@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2011 EDF S.A.
+# Copyright (C) 1998-2012 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -135,8 +135,7 @@ class Parser(object):
         l = father.getElementsByTagName(childname)
 
         if len(l) == 0:
-            el = self.doc.createElement(childname)
-            return father.appendChild(el)
+            return None
         elif len(l) == 1:
             return l.item(0)
         else:
@@ -393,7 +392,7 @@ class Parser(object):
                 script.append(True)
             else:
                 script.append(False)
-                
+
             label.append(str(node.attributes["label"].value))
             nodes.append(node)
             try:
@@ -414,19 +413,20 @@ class Parser(object):
 
     def getResult(self, node):
         """
-        Read:
-            <data file='profil1.dat' dest="">
-                <plot fig='1' xcol='1' ycol='2' legend='U'/>
-                <plot fig='2' xcol='1' ycol='3' legend='V'/>
-            </data>
-
         @type node: C{DOM Element}
         @param node: node of the current case
         @rtype: C{List}, C{List}
-        @return: C{List} of nodes <plot>, and C{List} of file names
+        @return: C{List} of nodes <resu>, and C{List} of file names
         """
-        file  = str(node.attributes["file"].value)
-        plots = node.getElementsByTagName("plot")
+        f  = str(node.attributes["file"].value)
+
+        if node.tagName == "data":
+            plots = node.getElementsByTagName("plot")
+        elif node.tagName == "resu":
+            plots = node.getElementsByTagName("scalar")
+        else:
+            plots = []
+
         try:
             dest  = str(node.attributes["dest"].value)
         except:
@@ -436,7 +436,49 @@ class Parser(object):
         except:
             repo = None
 
-        return plots, file, dest, repo
+        return plots, f, dest, repo
+
+
+    def getInput(self, node):
+        """
+        @type node: C{DOM Element}
+        @param node: node of the current case
+        @rtype: C{List}, C{List}
+        @return: C{List} of nodes <input>, and C{List} of file names
+        """
+        f  = str(node.attributes["file"].value)
+
+        try:
+            dest  = str(node.attributes["dest"].value)
+        except:
+            dest = None
+        try:
+            repo = str(node.attributes["repo"].value)
+        except:
+            repo = None
+
+        return  f, dest, repo
+
+
+    def getProbes(self, node):
+        """
+        Read:
+            <probes file='monitoring_pressure.dat' dest="" fig="3"/>
+
+        @type node: C{DOM Element}
+        @param node: node of the current case
+        """
+        f  = str(node.attributes["file"].value)
+        try:
+            dest  = str(node.attributes["dest"].value)
+        except:
+            dest = None
+        try:
+            fig  = str(node.attributes["fig"].value)
+        except:
+            fig = None
+
+        return f, dest, fig
 
 
     def getMeasurement(self, l):
@@ -485,6 +527,17 @@ class Parser(object):
         return cmd
 
 
+    def getVTKCommands(self, node):
+        """
+        """
+        cmd = []
+        for n in node.getElementsByTagName("vtk_command"):
+            if n.nodeType == minidom.Node.ELEMENT_NODE and n.childNodes:
+                if n.tagName == "vtk_command":
+                    cmd.append(n.childNodes[0].data)
+        return cmd
+
+
     def getAttributes(self, node):
         """
         Return a dictionary with attributes and value of a node.
@@ -495,16 +548,31 @@ class Parser(object):
         return d
 
 
-    def getAttribute(self, node, k, bool=True):
+    def getAttribute(self, node, k, default = None):
         """
         Return a value of an attribute.
         """
         if k in node.attributes.keys():
             return node.attributes[k].value
         else:
-            if bool:
+            if default == None:
                 raise ValueError, "Error: attribute %s is mandatory!" % k
             else:
-                return None
+                return default
+
+
+    def getAttributeTuple(self, node, k, default = None):
+        """
+        Return a value of an attribute.
+        """
+        if k in node.attributes.keys():
+            n = node.attributes[k].value
+            return tuple(float(s) for s in n[1:-1].split(','))
+        else:
+            if default == None:
+                raise ValueError, "Error: attribute %s is mandatory!" % k
+            else:
+                return default
+
 
 #-------------------------------------------------------------------------------
