@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2011 EDF S.A.
+# Copyright (C) 1998-2012 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -42,6 +42,7 @@ import fnmatch
 from autovnv.Parser import Parser
 from autovnv.TexMaker import Report1, Report2
 from autovnv.Drawing import Plotter
+from autovnv.PlotVTK import PlotVTK
 from autovnv.Command import run_command
 
 #-------------------------------------------------------------------------------
@@ -89,13 +90,12 @@ class RunThread(threading.Thread):
 #-------------------------------------------------------------------------------
 
 class Case(object):
-    def __init__(self, rlog, exe, diff, study, data, repo, dest):
+    def __init__(self, pkg, rlog, diff, study, data, repo, dest):
         """
         @type data: C{Dictionary}
         @param data: contains all keyword and value read in the parameters file
         """
         self.__log      = rlog
-        self.__exe      = exe
         self.__diff     = diff
         self.__study    = study
         self.__data     = data
@@ -115,19 +115,139 @@ class Case(object):
         self.threshold  = "default"
         self.diff_value = []
 
-        self.figures    = []
-        self.verbatim   = []
+        self.exe, self.pkg = self.__get_exe()
 
 
-    def compile(self):
+    def __get_exe(self):
+        """
+        Return the name of the exe of the case, in order to mix
+        Code_Saturne and NEPTUNE_CFD test cases in the same study.
+        """
+        run_ref = os.path.join(self.__repo, self.label, "SCRIPTS", "runcase")
+
+        # Read the runcase script from the Repository
+
+        try:
+            f = file(run_ref, mode = 'r')
+        except IOError:
+            print "Error: can not opening %s\n" % run_ref
+            sys.exit(1)
+
+        lines = f.readlines()
+        f.close()
+
+        exe    = ""
+        for name in ('code_saturne', 'neptune_cfd'):
+            for line in lines:
+                if re.search(r'^\\' + name, line):
+                    exe = name
+
+        if not exe:
+            print "Error: name of the executable for the case %s not found. Stop." % self.label
+            sys.exit(1)
+
+        if exe == "code_saturne":
+            from Base.XMLinitialize import XMLinit
+            from cs_package import package
+            pkg = package()
+        elif exe == "neptune_cfd":
+            from core.XMLinitialize import XMLinit
+            from nc_package import package
+            pkg = package()
+
+        return exe, pkg
+
+
+    def update(self):
+        """
+        Update path for the script in the Repository.
+        """
+        # 1) Load the xml file of parameters in order to update it
+        #    with the __backwardCompatibility method.
+
+        from Base.XMLengine import Case
+
+        if self.exe == "code_saturne":
+            from Base.XMLinitialize import XMLinit
+        elif self.exe == "neptune_cfd":
+            from core.XMLinitialize import XMLinit
+
+        for fn in os.listdir(os.path.join(self.__repo, self.label, "DATA")):
+            fp = os.path.join(self.__repo, self.label, "DATA", fn)
+            if os.path.isfile(fp):
+                fd = os.open(fp , os.O_RDONLY)
+                f = os.fdopen(fd)
+                l = f.readline()
+                f.close()
+                if l.startswith('''<?xml version="1.0" encoding="utf-8"?><Code_Saturne_GUI''') or \
+                   l.startswith('''<?xml version="1.0" encoding="utf-8"?><NEPTUNE_CFD_GUI'''):
+                    try:
+                        case = Case(package = self.pkg, file_name = fp)
+                    except:
+                        print "File of parameters reading error.\n"
+                        print "This file is not in accordance with XML specifications."
+                        sys.exit(1)
+
+                    case['xmlfile'] = fp
+                    case.xmlCleanAllBlank(case.xmlRootNode())
+                    XMLinit(case).initialize()
+                    case.xmlSaveDocument()
+
+        # 2) Create RESU directory if needed
+        r = os.path.join(self.__repo, self.label, "RESU")
+        if not os.path.isdir(r):
+            os.makedirs(r)
+
+        # 3) Update the GUI script from the Repository
+        ref = os.path.join(self.__repo, self.label, "DATA", self.pkg.guiname)
+
+        try:
+            f = file(ref, mode = 'r')
+        except IOError:
+            print "Error: can not opening %s\n" % ref
+            sys.exit(1)
+
+        lines = f.readlines()
+        f.close()
+
+        for i in range(len(lines)):
+            if re.search(r'^prefix=', lines[i]):
+                 lines[i] = "prefix=" + self.pkg.prefix + "\n"
+
+        f = file(ref, mode = 'w')
+        f.writelines(lines)
+        f.close()
+
+        # 4) Update the runcase script from the Repository
+        ref = os.path.join(self.__repo, self.label, "SCRIPTS", "runcase")
+
+        try:
+            f = file(ref, mode = 'r')
+        except IOError:
+            print "Error: can not opening %s\n" % ref
+            sys.exit(1)
+
+        lines = f.readlines()
+        f.close()
+
+        for i in range(len(lines)):
+            if re.search(r'^export PATH=', lines[i]):
+                 lines[i] = 'export PATH="' + self.pkg.bindir +'":$PATH\n'
+
+        f = file(ref, mode = 'w')
+        f.writelines(lines)
+        f.close()
+
+
+    def compile(self, d):
         """
         Just compile user sources if exist.
         @rtype: C{String}
         @return: the status of the succes of the compilation.
         """
         home = os.getcwd()
-        os.chdir(os.path.join(self.__dest, self.label, 'SRC'))
-        cmd = self.__exe + " compile -t"
+        os.chdir(os.path.join(d, self.label, 'SRC'))
+        cmd = os.path.join(self.pkg.bindir, self.exe) + " compile -t"
 
         p = subprocess.Popen(cmd,
                              shell=True,
@@ -147,13 +267,14 @@ class Case(object):
 
     def __suggest_run_id(self):
 
-        cmd = self.__exe + " run --suggest-id"
+        cmd = os.path.join(self.pkg.bindir, self.exe) + " run --suggest-id"
         p = subprocess.Popen(cmd,
                              shell=True,
                              stdout=subprocess.PIPE,
                              stderr=subprocess.PIPE)
         i = p.communicate()[0]
         run_id = string.join(i.split())
+
         return run_id, os.path.join(self.__dest, self.label, "RESU", run_id)
 
 
@@ -167,38 +288,34 @@ class Case(object):
         # Read the runcase from the Repository
 
         try:
-            run_ref_f = file(run_ref, mode='r')
+            f = file(run_ref, mode = 'r')
         except IOError:
             print "Error: can not opening %s\n" % run_ref
             sys.exit(1)
 
-        patterns = r'^\\code_saturne', r'^\\neptune_cfd'
-
-        for line in run_ref_f.readlines():
-            for p in patterns:
-                if re.search(p, line):
-                    run_cmd = string.join(line.split())
-        run_ref_f.close()
+        for line in f.readlines():
+            if re.search(r'^\\' + self.exe, line):
+                run_cmd = string.join(line.split())
+        f.close()
 
         # Write the new runcase
 
         try:
-            run_new_f = file(run_new, mode='r')
+            f = file(run_new, mode = 'r')
         except IOError:
             print "Error: can not opening %s\n" % run_new
             sys.exit(1)
 
-        lines = run_new_f.readlines()
-        run_new_f.close()
+        lines = f.readlines()
+        f.close()
 
         for i in range(len(lines)):
-            for p in patterns:
-                if re.search(p, lines[i]):
-                    lines[i] = run_cmd + " --id=" + run_id
+            if re.search(r'^\\' + self.exe, lines[i]):
+                lines[i] = run_cmd + " --id=" + run_id
 
-        run_new_f = file(run_new, mode='w')
-        run_new_f.writelines(lines)
-        run_new_f.close()
+        f = file(run_new, mode = 'w')
+        f.writelines(lines)
+        f.close()
 
 
     def run(self):
@@ -271,7 +388,10 @@ class Case(object):
         for i in range(len(info)):
             if info[i][:4] == 'Diff':
                 if info[i-3] not in ['i4', 'u4']:
-                    tab.append([info[i-7].replace("_", "\_"), info[i+3], info[i+5], self.threshold])
+                    tab.append( [info[i-7].replace("_", "\_"),
+                                 info[i+3],
+                                 info[i+5],
+                                 self.threshold] )
 
         os.chdir(home)
 
@@ -283,7 +403,7 @@ class Study(object):
     """
     Create, run and compare all cases fir a given study.
     """
-    def __init__(self, parser, study, exe, dif, rlog):
+    def __init__(self, pkg, parser, study, exe, dif, rlog):
         """
         Constructor.
           1. initialize attributes,
@@ -299,11 +419,11 @@ class Study(object):
         @param dif: name of the diff executable: C{cs_io_dump -d}.
         """
         # Initialize attributes
-        self.__parser  = parser
-        self.__study   = study
-        self.__exe     = exe
-        self.__diff    = dif
-        self.__log     = rlog
+        self.__parser   = parser
+        self.__study    = study
+        self.__main_exe = exe
+        self.__diff     = dif
+        self.__log      = rlog
 
         self.__repo = os.path.join(self.__parser.getRepository(),  study)
         self.__dest = os.path.join(self.__parser.getDestination(), study)
@@ -312,24 +432,24 @@ class Study(object):
             print "Error: the directory %s does not exist" % self.__repo
             sys.exit(1)
 
+        self.Cases = []
+        self.matplotlib_figures = []
+        self.vtk_figures = []
+
         # build the list of the cases
         self.cases = parser.getCasesLabel(study)
         if not self.cases:
-            print "Error: no case defined in %s study" % study
-            sys.exit(1)
-
-        self.Cases = []
-        for data in self.__parser.getCasesKeywords(self.__study):
-            c = Case(self.__log,
-                     self.__exe,
-                     self.__diff,
-                     self.__study,
-                     data,
-                     self.__repo,
-                     self.__dest)
-            self.Cases.append(c)
-
-        self.matplotlib_figures = []
+            print "\n\n\nWarning: no case defined in %s study\n\n\n" % study
+        else:
+            for data in self.__parser.getCasesKeywords(self.__study):
+                c = Case(pkg,
+                         self.__log,
+                         self.__diff,
+                         self.__study,
+                         data,
+                         self.__repo,
+                         self.__dest)
+                self.Cases.append(c)
 
 
     def getCasesLabel(self):
@@ -349,7 +469,7 @@ class Study(object):
 
         # Create study if necessary
         if not os.path.isdir(self.__dest):
-            cmd = self.__exe + " create --quiet --study " + self.__dest
+            cmd = self.__main_exe + " create --quiet --study " + self.__dest
             retval, t = run_command(cmd, self.__log)
             shutil.rmtree(os.path.join(self.__dest, "CASE1"))
 
@@ -357,20 +477,22 @@ class Study(object):
             ref = os.path.join(self.__repo, "MESH")
             if os.path.isdir(ref):
                 l = os.listdir(ref)
-                meshes = fnmatch.filter(l, '*.unv')   \
-                       + fnmatch.filter(l, '*.med')   \
-                       + fnmatch.filter(l, '*.case')  \
-                       + fnmatch.filter(l, '*.ngeom') \
-                       + fnmatch.filter(l, '*.ccm')   \
-                       + fnmatch.filter(l, '*.cgns')  \
-                       + fnmatch.filter(l, '*.neu')   \
-                       + fnmatch.filter(l, '*.msh')   \
-                       + fnmatch.filter(l, '*.des')
+                meshes = []
+                for cpr in ["", ".gz"]:
+                    for fmt in ["unv",
+                                "med",
+                                "ngeom",
+                                "ccm",
+                                "cgns",
+                                "neu",
+                                "msh",
+                                "des"]:
+                        meshes += fnmatch.filter(l, "*." + fmt + cpr)
                 des = os.path.join(self.__dest, "MESH")
-                for m in os.listdir(ref):
+                for m in l:
                     if m in meshes:
                         os.symlink(os.path.join(ref, m), os.path.join(des, m))
-                    else:
+                    elif m != ".svn":
                         shutil.copy2(os.path.join(ref, m), des)
 
             # Copy external scripts for post-processing
@@ -383,14 +505,15 @@ class Study(object):
         # Create cases
         os.chdir(self.__dest)
 
-        for c in self.cases:
-            if not os.path.isdir(c):
-                cmd = self.__exe + " create --case " + c  \
-                      + " --quiet --noref --copy-from " \
-                      + os.path.join(self.__repo, c)
+        for c in self.Cases:
+            if not os.path.isdir(c.label):
+                e = os.path.join(c.pkg.bindir, c.exe)
+                cmd = e + " create --case " + c.label  \
+                      + " --quiet --noref --copy-from "    \
+                      + os.path.join(self.__repo, c.label)
                 retval, t = run_command(cmd, self.__log)
             else:
-                print "Warning: the case %s already exists in the destination." % c
+                print "Warning: the case %s already exists in the destination." % c.label
 
         os.chdir(repbase)
 
@@ -400,7 +523,7 @@ class Studies(object):
     """
     Manage all Studies and all Cases described in the files of parameters.
     """
-    def __init__(self, f, v, r, c, p, exe, dif):
+    def __init__(self, pkg, f, v, r, c, p, exe, dif):
         """
         Constructor.
           1. create if necessary the destination directory,
@@ -429,19 +552,17 @@ class Studies(object):
 
         # Test if the repository exists
 
-        self.getRepository()
+        self.repo = self.getRepository()
 
         # create if necessary the destination directory
 
-        try:
-            os.makedirs(self.getDestination())
-        except:
-            pass
+        self.dest = self.getDestination()
+        if not os.path.isdir(self.dest):
+            os.makedirs(self.dest)
 
         # copy the xml file of parameters for update and restart
 
-        file = os.path.join(self.getDestination(), \
-                            os.path.basename(f))
+        file = os.path.join(self.dest, os.path.basename(f))
         try:
             shutil.copyfile(f, file)
         except:
@@ -451,18 +572,20 @@ class Studies(object):
 
         self.__parser  = Parser(file)
         self.__plotter = Plotter(self.__parser)
+        self.__plotvtk = PlotVTK(self.__parser)
 
         # build the list of the studies
 
-        doc = os.path.join(self.getDestination(), "auto_vnv.log")
+        doc = os.path.join(self.dest, "auto_vnv.log")
         self.__log = open(doc, "w")
         self.labels  = self.__parser.getStudiesLabel()
         self.studies = []
         for l in self.labels:
-            self.studies.append( [l, Study(self.__parser, l, exe, dif, self.__log)] )
+            self.studies.append( [l, Study(pkg, self.__parser, l, \
+                                  exe, dif, self.__log)] )
 
         # start the report
-        self.report = os.path.join(self.getDestination(), "report.txt")
+        self.report = os.path.join(self.dest, "report.txt")
         self.reportFile = open(self.report, mode='w')
         self.reportFile.write('\n')
 
@@ -482,14 +605,6 @@ class Studies(object):
         if not iok:
             self.__running = False
 
-        iok = 0
-        for l, s in self.studies:
-            for case in s.Cases:
-                if case.plot == 'on':
-                   iok+=1
-        if not iok:
-            self.__postpro = False
-
 
     def reporting(self, msg, screen_only=False):
         """
@@ -537,6 +652,26 @@ class Studies(object):
         return self.__parser.getDestination()
 
 
+    def updateRepository(self):
+        """
+        Create all studies and all cases.
+        """
+        iok = 0
+        for l, s in self.studies:
+            self.reporting('  o Update repository: ' + l)
+            for case in s.Cases:
+                self.reporting('    - update  %s' % case.label)
+                case.update()
+                if case.compile(os.path.join(self.repo, l)) == "OK":
+                    self.reporting('    - compile %s --> OK' % case.label)
+                else:
+                    self.reporting('    - compile %s --> FAILED' % case.label)
+                    iok+=1
+        if iok:
+            self.reporting('Error: compilation failed. Number of failed cases: %s' % iok)
+            sys.exit(1)
+
+
     def createStudies(self):
         """
         Create all studies and all cases.
@@ -557,7 +692,7 @@ class Studies(object):
             self.reporting('  o Compile study: ' + l)
             for case in s.Cases:
                 if case.compute == 'on':
-                    if case.compile() == "OK":
+                    if case.compile(os.path.join(self.dest, l)) == "OK":
                         self.reporting('    - compile %s --> OK' % case.label)
                     else:
                         self.reporting('    - compile %s --> FAILED' % case.label)
@@ -577,11 +712,11 @@ class Studies(object):
                 pre, label, nodes, args = self.__parser.getPrepro(case.node)
                 for i in range(len(label)):
                     if pre[i]:
-                        cmd = os.path.join(self.getDestination(), l, "MESH", label[i])
+                        cmd = os.path.join(self.dest, l, "MESH", label[i])
                         if os.path.isfile(cmd):
                             cmd += " " + args[i]
                             repbase = os.getcwd()
-                            os.chdir(os.path.join(self.getDestination(), l, "MESH"))
+                            os.chdir(os.path.join(self.dest, l, "MESH"))
                             retcode, t = run_command(cmd, self.__log)
                             os.chdir(repbase)
                             self.reporting('    - script %s --> OK (%s s)' % (cmd, t))
@@ -613,8 +748,11 @@ class Studies(object):
                             n1 = self.__parser.getChilds(case.node, "compare")
                             n2 = self.__parser.getChilds(case.node, "script")
                             n3 = self.__parser.getChilds(case.node, "data")
-                            for n in n1 + n2 + n3:
-                                if self.__parser.getAttribute(n, "dest", False) == "":
+                            n4 = self.__parser.getChilds(case.node, "probe")
+                            n5 = self.__parser.getChilds(case.node, "resu")
+                            n6 = self.__parser.getChilds(case.node, "input")
+                            for n in n1 + n2 + n3 + n4 + n5 + n6:
+                                if self.__parser.getAttribute(n, "dest") == "":
                                     self.__parser.setAttribute(n, "dest", run_id)
                         else:
                             self.reporting('    - run %s --> FAILED' % case.label)
@@ -647,7 +785,7 @@ class Studies(object):
         # 3. Update the file of parameters with the name of the result directory
             self.__parser.setAttribute(node, attr, os.listdir(result)[0])
         else:
-            self.reporting('Error: check compare/script/plot failed.')
+            self.reporting('Error: check compare/script/plot/probe/resu/input failed.')
             sys.exit(1)
 
 
@@ -656,11 +794,11 @@ class Studies(object):
         Check coherency between xml file of parameters and repository and destination.
         """
         if repo != None:
-            result = os.path.join(self.getRepository(), study_label, case_label, 'RESU')
+            result = os.path.join(self.repo, study_label, case_label, 'RESU')
             self.__check_dir(study_label, case_label, node, result, repo, "repo")
 
         if dest != None:
-            result = os.path.join(self.getDestination(), study_label, case_label, 'RESU')
+            result = os.path.join(self.dest, study_label, case_label, 'RESU')
             self.__check_dir(study_label, case_label, node, result, dest, "dest")
 
 
@@ -720,14 +858,14 @@ class Studies(object):
                 script, label, nodes, args, repo, dest = self.__parser.getScript(case.node)
                 for i in range(len(label)):
                     if script[i] and case.is_run != "KO":
-                        cmd = os.path.join(self.getDestination(), l, "POST", label[i])
+                        cmd = os.path.join(self.dest, l, "POST", label[i])
                         if os.path.isfile(cmd):
                             cmd += " " + args[i]
                             if repo[i]:
-                                r = os.path.join(self.getRepository(),  l, case.label, "RESU", repo[i])
+                                r = os.path.join(self.repo,  l, case.label, "RESU", repo[i])
                                 cmd += " -r " + r
                             if dest[i]:
-                                d = os.path.join(self.getDestination(), l, case.label, "RESU", dest[i])
+                                d = os.path.join(self.dest, l, case.label, "RESU", dest[i])
                                 cmd += " -d " + d
                             retcode, t = run_command(cmd, self.__log)
                             self.reporting('    - script %s --> OK (%s s)' % (cmd, t))
@@ -749,15 +887,37 @@ class Studies(object):
                             dest = None
                         self.__check_dirs(l, case.label, node, repo, dest)
 
+                    for node in self.__parser.getChilds(case.node, "probes"):
+                        file, dest, fig = self.__parser.getProbes(node)
+                        if destination == False:
+                            dest = None
+                        repo = None
+                        self.__check_dirs(l, case.label, node, repo, dest)
+
+                    for node in self.__parser.getChilds(case.node, "resu"):
+                        plots, file, dest, repo = self.__parser.getResult(node)
+                        if destination == False:
+                            dest = None
+                        self.__check_dirs(l, case.label, node, repo, dest)
+
+                    for node in self.__parser.getChilds(case.node, "input"):
+                        file, dest, repo = self.__parser.getInput(node)
+                        if destination == False:
+                            dest = None
+                        self.__check_dirs(l, case.label, node, repo, dest)
+
 
     def plot(self):
         """
-        Draw plots.
+        Plot data.
         """
         for l, s in self.studies:
             self.reporting('  o Plot study: ' + l)
             self.__plotter.plot_study(l, s)
 
+        for l, s in self.studies:
+            self.__plotvtk.plot_study(l, s)
+
 
     def build_reports(self, report1, report2):
         """
@@ -769,10 +929,9 @@ class Studies(object):
         @return: list of file to be attached to the report.
         """
         attached_files = []
-        dest = self.getDestination()
 
         # Fisrt global report
-        doc1 = Report1(dest,
+        doc1 = Report1(self.dest,
                        report1,
                        self.__log,
                        self.report,
@@ -797,15 +956,17 @@ class Studies(object):
 
         # Second detailed report
         if self.__compare or self.__postpro:
-            doc2 = Report2(dest, report2, self.__log)
+            doc2 = Report2(self.dest, report2, self.__log)
 
             for l, s in self.studies:
                 doc2.appendLine("\\section{%s}" % l)
 
-                if s.matplotlib_figures:
-                    doc2.appendLine("\\subsection{Results for case %s}" % case.label)
-                    for png in s.matplotlib_figures:
-                        doc2.addFigure(png)
+                if s.matplotlib_figures or s.vtk_figures:
+                    doc2.appendLine("\\subsection{Graphical results}")
+                    for g in s.matplotlib_figures:
+                        doc2.addFigure(g)
+                    for g in s.vtk_figures:
+                        doc2.addFigure(g)
 
                 for case in s.Cases:
                     if case.is_compare == "done":
@@ -815,6 +976,27 @@ class Studies(object):
                         elif self.__compare:
                             doc2.appendLine("No difference between the repository and the destination.")
 
+                    nodes = self.__parser.getChilds(case.node, "input")
+                    if nodes:
+                        doc2.appendLine("\\subsection{Results for case %s}" % case.label)
+                        for node in nodes:
+                            f, dest, repo = self.__parser.getInput(node)
+                            doc2.appendLine("\\subsubsection{%s}" % f)
+
+                            if dest:
+                                d = dest
+                                dd = self.dest
+                            elif repo:
+                                d = repo
+                                dd = self.repo
+
+                            ff = os.path.join(dd, l, case.label, "RESU", d, f)
+
+                            if not os.path.isfile(ff):
+                                print "\n\nWarning: this file does not exist: %s\n\n" % ff
+                            else:
+                                doc2.addInput(ff)
+
             attached_files.append(doc2.close())
 
         return attached_files
