@@ -5,7 +5,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2011 EDF S.A.
+# Copyright (C) 1998-2012 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -351,7 +351,6 @@ class domain(base_domain):
                  n_procs_weight = None,       # recommended number of processes
                  n_procs_min = None,          # min. number of processes
                  n_procs_max = None,          # max. number of processes
-                 n_procs_partition = None,    # n. processes for partitioner
                  logging_args = None,         # command-line options for logging
                  param = None,                # XML parameters file
                  prefix = None,               # installation prefix
@@ -383,19 +382,9 @@ class domain(base_domain):
 
         # Preprocessor options
 
-        self.mesh_input = None
-
         self.mesh_dir = None
         self.meshes = None
 
-        # Partition options
-
-        self.exec_partition = True
-
-        self.partition_n_procs = n_procs_partition
-        self.partition_list = None
-        self.partition_args = None
-
         # Solver options
 
         self.exec_solver = True
@@ -409,6 +398,8 @@ class domain(base_domain):
         # Additional data
 
         self.thermochemistry_data = None
+        self.janaf_data = None
+        self.solidfuel_data = None
         self.meteo_data = None
 
         self.user_input_files = None
@@ -652,27 +643,6 @@ class domain(base_domain):
         if not self.exec_solver:
             return
 
-        if self.n_procs < 2:
-            self.exec_partition = False
-        elif self.exec_partition == False and self.partition_input != None:
-            partition_input = os.path.expanduser(self.partition_input)
-            if not os.path.isabs(partition_input):
-                partition_input = os.path.join(self.case_dir, partition_input)
-            part_name = 'domain_number_' + str(self.n_procs)
-            partition = os.path.join(partition_input, part_name)
-            if os.path.isfile(partition):
-                part_dir = os.path.join(self.exec_dir, 'partition')
-                if not os.path.isdir(part_dir):
-                    os.mkdir(part_dir)
-                self.symlink(partition, os.path.join(part_dir, part_name))
-            else:
-                w_str = \
-                    'Warning: no partitioning file is available\n' \
-                    '         (no ' + partition + ').\n' \
-                    '\n' \
-                    '         Geometry-based partitioning will be used.\n'
-                sys.stderr.write(w_str)
-
         # Parameters file
 
         if self.param != None:
@@ -697,12 +667,36 @@ class domain(base_domain):
                     self.symlink(restart_input,
                                  os.path.join(self.exec_dir, 'restart'))
 
+        # Partition input files
+
+        if self.partition_input != None:
+
+            partition_input = os.path.expanduser(self.partition_input)
+            if not os.path.isabs(partition_input):
+                partition_input = os.path.join(self.case_dir, partition_input)
+
+            if os.path.exists(partition_input):
+
+                if not os.path.isdir(partition_input):
+                    err_str = partition_input + ' is not a directory.'
+                    raise RunCaseError(err_str)
+                else:
+                    self.symlink(partition_input,
+                                 os.path.join(self.exec_dir, 'partition_input'))
+
         # Data for specific physics
 
+        if self.solidfuel_data != None:
+            self.copy_data_file(self.solidfuel_data,
+                                'dp_FCP.xml',
+                                'thermochemistry')
+
         if self.thermochemistry_data != None:
             self.copy_data_file(self.thermochemistry_data,
                                 'dp_thch',
                                 'thermochemistry')
+
+        if self.thermochemistry_data != None or self.solidfuel_data != None or self.janaf_data == 'on':
             if not os.path.isfile('JANAF'):
                 self.copy_data_file(os.path.join(self.package.pkgdatadir,
                                                  'data',
@@ -793,19 +787,21 @@ class domain(base_domain):
                 raise RunCaseError(err_str)
 
             if (type(m) == tuple):
-                m = m[0]
+                m0 = m[0]
+            else:
+                m0 = m
 
-            m = os.path.expanduser(m)
+            m0 = os.path.expanduser(m0)
 
-            mesh_path = m
-            if (not os.path.isabs(m)) and len(mesh_dirs) > 0:
+            mesh_path = m0
+            if (not os.path.isabs(m0)) and len(mesh_dirs) > 0:
                 for mesh_dir in mesh_dirs:
-                    mesh_path = os.path.join(mesh_dir, m)
+                    mesh_path = os.path.join(mesh_dir, m0)
                     if os.path.isfile(mesh_path):
                         break
 
             if not os.path.isfile(mesh_path):
-                err_str = 'Mesh file ' + m + ' not found'
+                err_str = 'Mesh file ' + m0 + ' not found'
                 if not (os.path.isabs(mesh_path) or mesh_dirs):
                     err_str += '(no mesh directory given)'
                 raise RunCaseError(err_str)
@@ -839,7 +835,6 @@ class domain(base_domain):
                     'Check the preprocessor.log file for details.\n\n'
                 sys.stderr.write(err_str)
 
-                self.exec_partition = False
                 self.exec_solver = False
 
                 self.error = 'preprocess'
@@ -855,146 +850,6 @@ class domain(base_domain):
 
     #---------------------------------------------------------------------------
 
-    def check_partitioner(self):
-        """
-        Tests if the partitioner is available and partitioning is defined.
-        """
-
-        if self.n_procs < 2 and self.partition_list == None:
-            self.exec_partition = False
-
-        if (self.exec_partition == False):
-            return
-
-        w_str = None
-
-        if self.partition_n_procs < 2:
-            partitioner = self.package.get_partitioner()
-        else:
-            partitioner = self.package_compute.get_partitioner()
-
-        if not os.path.isfile(partitioner):
-            if self.n_procs > 1:
-                w_str = \
-                    'Warning: ' + partitioner + ' not found.\n\n' \
-                    'The partitioner may not have been installed' \
-                    '  (this is the case if neither METIS nor SCOTCH ' \
-                    ' are available).\n\n'
-
-        if os.path.isdir(os.path.join(self.exec_dir, 'mesh_input')):
-            w_str = \
-                'Warning: mesh_input is a directory\n\n' \
-                'The Kernel must be run to concatenate its contents\n' \
-                ' before graph-based partitioning is available.\n\n'
-
-        if w_str:
-            w_str += 'Partitioning by a space-filling curve will be used.\n\n'
-            sys.stderr.write(w_str)
-            self.exec_partition = False
-            self.partition_n_procs = None
-
-    #---------------------------------------------------------------------------
-
-    def run_partitioner(self):
-        """
-        Runs the partitioner in the execution directory
-        """
-
-        self.check_partitioner()
-        if self.exec_partition == False:
-            return
-
-        # Build command
-
-        cmd = self.package.get_partitioner()
-
-        if self.logging_args != None:
-            cmd += ' ' + self.logging_args
-
-        if self.partition_args != None:
-            cmd += ' ' + self.partition_args
-
-        if self.partition_list != None:
-            cmd += ' ' + any_to_str(self.partition_list)
-
-        if self.exec_solver and self.n_procs != None:
-            np = self.n_procs
-            if self.partition_list == None:
-                cmd += ' ' + str(np)
-            elif np > 1 and not np in self.partition_list:
-                cmd += ' ' + str(np)
-
-        # Run command
-
-        cur_dir = os.path.realpath(os.getcwd())
-        if cur_dir != self.exec_dir:
-            os.chdir(self.exec_dir)
-
-        retcode = run_command(cmd)
-
-        if retcode != 0:
-            err_str = \
-                'Error running the partitioner.\n' \
-                'Check the partition.log file for details.\n\n'
-            sys.stderr.write(err_str)
-
-            self.exec_solver = False
-
-            self.error = 'partition'
-
-        if cur_dir != self.exec_dir:
-            os.chdir(cur_dir)
-
-        return retcode
-
-    #---------------------------------------------------------------------------
-
-    def partitioner_command(self):
-        """
-        Returns a tuple indicating the partitioner's working directory,
-        executable path, and associated command-line arguments.
-        """
-        # Working directory and executable path
-
-        wd = self.exec_dir
-        exec_path = self.package_compute.get_partitioner()
-
-        # Build kernel command-line arguments
-
-        args = ''
-
-        if self.logging_args != None:
-            args += ' ' + self.logging_args
-
-        if self.partition_n_procs > 1:
-            args += ' --mpi'
-
-        if self.mpi_io != None:
-            args += ' --mpi-io ' + self.mpi_io
-
-        if self.partition_args != None:
-            args += ' ' + self.partition_args
-
-        if self.partition_list != None:
-            args += ' ' + any_to_str(self.partition_list)
-
-        if self.exec_solver and self.n_procs != None:
-            np = self.n_procs
-            if self.partition_list == None:
-                args += ' ' + str(np)
-            elif np > 1 and not np in self.partition_list:
-                args += ' ' + str(np)
-
-        # Adjust for Valgrind if used
-
-        if self.valgrind != None:
-            args = self.solver_path + ' ' + args
-            exec_path = self.valgrind
-
-        return wd, exec_path, args
-
-    #---------------------------------------------------------------------------
-
     def solver_command(self, **kw):
         """
         Returns a tuple indicating the solver's working directory,
@@ -1084,53 +939,6 @@ class domain(base_domain):
 
     #---------------------------------------------------------------------------
 
-    def copy_partition_results(self):
-        """
-        Retrieve partition results from the execution directory
-        """
-
-        if not self.exec_partition:
-            return
-
-        # Determine if we should purge the execution directory
-
-        purge = True
-        if self.error == 'partition':
-            purge = False
-
-        # Copy log file first.
-
-        f = os.path.join(self.exec_dir, 'partition.log')
-        if os.path.isfile(f):
-            self.copy_result(f, purge)
-
-        # Copy output if required (only purge if we have no further
-        # errors, as it may be necessary for future debugging).
-
-        if self.error != '':
-            purge = False
-
-        if purge:
-            f = os.path.join(self.exec_dir, 'partition.sh')
-            if os.path.isfile(f):
-                self.purge_result(f)
-
-        d = os.path.join(self.exec_dir, 'partition')
-
-        if self.partition_list or not self.exec_solver:
-            if os.path.isdir(d):
-                self.copy_result(d, purge)
-        elif purge:
-            self.purge_result(d)
-
-        # Purge mesh_input if it was used solely by the partitioner
-
-        if self.mesh_input and self.exec_solver == False:
-            if self.error == '':
-                self.purge_result('mesh_input')
-
-    #---------------------------------------------------------------------------
-
     def copy_solver_results(self):
         """
         Retrieve solver results from the execution directory
@@ -1155,14 +963,10 @@ class domain(base_domain):
 
         purge_list = []
 
-        for f in ['mesh_input', 'restart']:
+        for f in ['mesh_input', 'restart', 'partition_input']:
             if f in dir_files:
                 purge_list.append(f)
 
-        f = 'partition'
-        if f in dir_files and (not self.partition_list):
-            purge_list.append(f)
-
         # Determine files from this stage to ignore or to possibly remove
 
         for f in [self.package.solver, 'run_solver.sh']:
@@ -1234,251 +1038,11 @@ class domain(base_domain):
             p = self.package.get_preprocessor()
             s.write('    preprocessor : ' + any_to_str(p) + '\n')
 
-        if self.exec_partition:
-            p = self.package.get_partitioner()
-            s.write('    partitioner  : ' + any_to_str(p) + '\n')
-
         if self.exec_solver:
             s.write('    solver       : ' + self.solver_path + '\n')
 
 #-------------------------------------------------------------------------------
 
-# SYRTHES 3 coupling
-
-class syrthes3_domain(base_domain):
-
-    def __init__(self,
-                 package,
-                 name = None,
-                 echo_comm = None,       # coupling verbosity
-                 coupling_mode = 'MPI',  # 'MPI' or 'sockets'
-                 coupled_apps = None,    # coupled domain names if n_domains > 1
-                 pset_size = 1):         # size of processor set (for IBM BG/P)
-
-
-        base_domain.__init__(self, package, name, 1, pset_size, pset_size)
-
-        self.log_file = 'syrthes.log'
-
-        # Directories, and files in case structure
-
-        self.data_dir = None
-        self.result_dir = None
-        self.src_dir = None
-        self.echo_comm = echo_comm
-
-        self.set_coupling_mode(coupling_mode)
-
-        self.coupled_apps = coupled_apps
-
-        self.exec_solver = True
-
-    #---------------------------------------------------------------------------
-
-    def set_case_dir(self, case_dir):
-
-        base_domain.set_case_dir(self, case_dir)
-
-        # Names, directories, and files in case structure
-
-        # No RESU dir for SYRTHES 3 case, as toplevel RESU_COUPLING
-        # is used in coupled case, and the script does not handle
-        # standalone SYRTHES 3 calculations (which require a different
-        # executable)
-
-        self.result_dir = None
-
-    #---------------------------------------------------------------------------
-
-    def set_coupling_mode(self, coupling_mode):
-
-        # Check that coupling mode is either 'MPI' or 'sockets'
-        coupling_modes = ('MPI', 'sockets')
-        if coupling_mode not in coupling_modes:
-            err_str = \
-                'SYRTHES3 coupling mode "' + str(coupling_mode) + '" unknown.\n' \
-                + 'Allowed modes: ' + str(coupling_modes) + '.\n'
-            raise RunCaseError(err_str)
-
-        # Coupling mode
-        self.coupling_mode = coupling_mode
-
-    #---------------------------------------------------------------------------
-
-    def compile_and_link(self):
-        """
-        Compile and link user subroutines if necessary
-        """
-
-        # Check if there are files to compile in source path
-
-        dir_files = os.listdir(self.src_dir)
-
-        src_files = (fnmatch.filter(dir_files, '*.c')
-                     + fnmatch.filter(dir_files, '*.[fF]'))
-
-        copy_dir = None
-        exec_src = None
-
-        if len(src_files) > 0:
-
-            # Add header files to list so as not to forget to copy them
-
-            src_files = src_files + fnmatch.filter(dir_files, '*.h')
-
-            # Copy source files to execution directory
-
-            exec_src = os.path.join(self.exec_dir, 'src')
-            os.mkdir(exec_src)
-
-            for f in src_files:
-                src_file = os.path.join(self.src_dir, f)
-                dest_file = os.path.join(exec_src, f)
-                shutil.copy2(src_file, dest_file)
-
-        log_name = os.path.join(self.exec_dir, 'compile.log')
-        log = open(log_name, 'w')
-
-        retval = cs_compile.compile_and_link_syrthes(self.package,
-                                                     exec_src,
-                                                     self.exec_dir,
-                                                     stdout=log,
-                                                     stderr=log)
-
-        log.close()
-
-        if retval != 0:
-            # In case of error, copy source to results directory now,
-            # as no calculation is possible, then raise exception.
-            for f in [self.package.srcdir, 'compile.log']:
-                self.copy_result(f)
-            raise RunCaseError('Compile or link error.')
-
-        self.solver_path = os.path.join(self.exec_dir, 'syrthes')
-
-    #---------------------------------------------------------------------------
-
-    def solver_command(self, **kw):
-        """
-        Returns a tuple indicating SYRTHES's working directory,
-        executable path, and associated command-line arguments.
-        """
-
-        wd = self.exec_dir              # Working directory
-        exec_path = self.solver_path    # Executable
-
-        # Build kernel command-line arguments
-
-        args = ' --log syrthes.log'
-        if self.echo_comm != None:
-            args += ' --echo-comm ' + str(self.echo_comm)
-
-        if self.coupling_mode == 'MPI':
-            args += ' --app-name ' + os.path.basename(self.case_dir)
-            if self.coupled_apps != None:
-                args += ' --comm-mpi ' + any_to_str(self.coupled_apps)
-            else:
-                args += ' --comm-mpi '
-
-        elif self.coupling_mode == 'sockets':
-            if 'host_port' in kw:
-                args += ' --comm-socket ' + any_to_str(kw['host_port'])
-
-        # handled directly
-
-        # Adjust for Valgrind if used
-
-        if self.valgrind != None:
-            args = self.solver_path + ' ' + args
-            exec_path = self.valgrind
-
-        return wd, exec_path, args
-
-    #---------------------------------------------------------------------------
-
-    def prepare_data(self):
-        """
-        Copy data to the execution directory
-        """
-
-        cwd = os.getcwd()
-        os.chdir(self.exec_dir)
-
-        syrthes_env = os.path.join(self.data_dir, 'syrthes.env')
-
-        cmd = self.package.get_runcase_script('runcase_syrthes')
-        cmd += ' -copy-data -syrthes-env=' + syrthes_env
-
-        if run_command(cmd) != 0:
-            raise RunCaseError
-
-        os.chdir(cwd)
-
-    #---------------------------------------------------------------------------
-
-    def preprocess(self):
-        """
-        Empty for SYRTHES 3
-        """
-        pass
-
-    #---------------------------------------------------------------------------
-
-    def preprocess(self):
-        """
-        Run preprocessing stages (empty for SYRTHES 3)
-        """
-
-        return
-
-    #---------------------------------------------------------------------------
-
-    def copy_results(self):
-        """
-        Retrieve results from the execution directory
-        """
-
-        dir_files = os.listdir(self.src_dir)
-
-        purge = True
-        if self.error != '':
-            purge = False
-
-        # Copy user sources, compile log, and execution log if present
-
-        for f in ['src', 'compile.log', 'syrthes.log']:
-            if f in dir_files:
-                self.copy_result(f, purge)
-                dir_files.remove(f)
-
-        if self.exec_dir == self.result_dir:
-            return
-
-        cwd = os.getcwd()
-        os.chdir(self.exec_dir)
-
-        cmd = self.package.get_runcase_script('runcase_syrthes') \
-            + ' -copy-results -result-dir=' + self.result_dir
-
-        if run_command(cmd) != 0:
-            raise RunCaseError
-
-        os.chdir(cwd)
-
-    #---------------------------------------------------------------------------
-
-    def summary_info(self, s):
-        """
-        Output summary data into file s
-        """
-
-        base_domain.summary_info(self, s)
-
-        if self.solver_path:
-            s.write('    SYRTHES      : ' + self.solver_path + '\n')
-
-#-------------------------------------------------------------------------------
-
 # SYRTHES 4 coupling
 
 class syrthes_domain(base_domain):
@@ -1520,8 +1084,6 @@ class syrthes_domain(base_domain):
         self.result_dir = None
         self.echo_comm = None
 
-        self.set_coupling_mode('MPI')
-
         self.exec_solver = True
 
         # Generation of SYRTHES case deferred until we know how
@@ -1542,21 +1104,6 @@ class syrthes_domain(base_domain):
 
     #---------------------------------------------------------------------------
 
-    def set_coupling_mode(self, coupling_mode):
-
-        # Check that coupling mode is either 'MPI' or 'sockets'
-        coupling_modes = ('MPI')
-        if coupling_mode not in coupling_modes:
-            err_str = \
-                'SYRTHES4 coupling mode "' + str(coupling_mode) + '" unknown.\n' \
-                + 'Allowed modes: ' + str(coupling_modes) + '.\n'
-            raise RunCaseError(err_str)
-
-        # Coupling mode
-        self.coupling_mode = coupling_mode
-
-    #---------------------------------------------------------------------------
-
     def set_exec_dir(self, exec_dir):
 
         if os.path.isabs(exec_dir):
@@ -1604,9 +1151,7 @@ class syrthes_domain(base_domain):
         if self.syrthes_case.n_procs_ray > 0:
             args += ' -r ' + str(self.n_procs_ray)
 
-        if self.coupling_mode == 'MPI':
-
-            args += ' --name ' + self.name
+        args += ' --name ' + self.name
 
         # Output to a logfile
         args += ' --log ' + self.logfile
@@ -1726,6 +1271,18 @@ class syrthes_domain(base_domain):
         Retrieve results from the execution directory
         """
 
+        # Post-processing
+        if self.syrthes_case.post_mode != None:
+          retval = self.syrthes_case.postprocessing(mode = \
+                   self.syrthes_case.post_mode)
+        else:
+          retval = 0
+
+        if retval != 0:
+            err_str = '\n   Error during SYRTHES postprocessing\n'
+            raise RunCaseError(err_str)
+
+
         if self.exec_dir == self.result_dir:
             return
 
