@@ -5,7 +5,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2011 EDF S.A.
+# Copyright (C) 1998-2012 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -30,8 +30,6 @@ import tempfile
 
 from optparse import OptionParser
 
-from cs_config import build_syrthes
-
 from cs_exec_environment import run_command, set_modules
 
 #-------------------------------------------------------------------------------
@@ -77,10 +75,6 @@ def process_cmd_line(argv, pkg):
                       metavar="<libs>",
                       help="optional libraries")
 
-    parser.add_option("--syrthes", dest="link_syrthes",
-                      action="store_true",
-                      help="SYRTHES link")
-
     parser.set_defaults(test_mode=False)
     parser.set_defaults(force_link=False)
     parser.set_defaults(keep_going=False)
@@ -89,7 +83,6 @@ def process_cmd_line(argv, pkg):
     parser.set_defaults(version="")
     parser.set_defaults(opt_libs="")
     parser.set_defaults(log_name=None)
-    parser.set_defaults(link_syrthes=False)
 
     (options, args) = parser.parse_args(argv)
 
@@ -112,27 +105,31 @@ def process_cmd_line(argv, pkg):
         sys.exit(1)
 
     return options.test_mode, options.force_link, options.keep_going, \
-           src_dir, dest_dir, options.version, options.opt_libs, \
-           options.link_syrthes
+           src_dir, dest_dir, options.version, options.opt_libs
 
 #-------------------------------------------------------------------------------
 
-def so_dirs_path(flags, rpath):
+def so_dirs_path(flags, pkg):
     """
     Assemble path for shared libraries in nonstandard directories.
     """
-    retval = ""
-    first = True
+    retval = " " + pkg.rpath
+    count = 0
+
+    pkg_lib = os.path.join(pkg.libdir, pkg.name)
+    if os.path.isdir(pkg_lib):
+        retval = retval + ":" + pkg_lib
+        count += 1
 
     args = flags.split(" ")
 
     for arg in args:
         if arg[0:2] == '-L' and arg[0:10] != '-L/usr/lib' and arg[0:6] != '-L/lib':
-            if first == True:
-                retval = " " + rpath + ":" + arg[2:]
-                first = False
-            else:
-                retval = retval + ":" + arg[2:]
+            retval = retval + ":" + arg[2:]
+            count += 1
+
+    if count == 0:
+        retval = ""
 
     return retval
 
@@ -168,6 +165,26 @@ def compile_and_link(pkg, srcdir, destdir, optlibs,
     hxx_files = fnmatch.filter(dir_files, '*.hxx') + fnmatch.filter(dir_files, '*.hpp')
     f_files = fnmatch.filter(dir_files, '*.[fF]90')
 
+    # Special handling for some linkers (such as Mac OS X), for which
+    # no multiple definitions are allowable in static mode;
+    # in this case, extract archive, then overwrite with user files.
+
+    p_libs = pkg.libs
+    if pkg.special_user_link == 'ar_x':
+        if force_link or (len(c_files) + len(cxx_files) + len(f_files)) > 0:
+            i = p_libs.find(' ')
+            if (i > 0):
+                lib0 = os.path.join(pkg.libdir, 'lib' + p_libs[2:i] + '.a')
+                p_libs = p_libs[i+1:]
+            else:
+                lib0 = os.path.join(pkg.libdir, 'lib' + p_libs[2:] + '.a')
+                p_libs = ''
+            cmd = 'ar x ' + lib0
+            if run_command(cmd, echo=True, stdout=stdout, stderr=stderr) != 0:
+                retval = 1
+
+    # Compile files
+
     for f in c_files:
         if (retval != 0 and not keep_going):
             break
@@ -194,7 +211,7 @@ def compile_and_link(pkg, srcdir, destdir, optlibs,
         if run_command(cmd, echo=True, stdout=stdout, stderr=stderr) != 0:
             retval = 1
 
-    user_mod_name = 'user_modules.f90'
+    user_mod_name = 'cs_user_modules.f90'
     if user_mod_name in f_files:
         f_files.remove(user_mod_name)
         f_files.insert(0, user_mod_name)
@@ -223,87 +240,10 @@ def compile_and_link(pkg, srcdir, destdir, optlibs,
         if optlibs != None:
             if len(optlibs) > 0:
                 cmd = cmd + " " + optlibs
-        cmd = cmd + " " + pkg.ldflags + " " + pkg.libs
+        cmd = cmd + " " + pkg.ldflags + " " + p_libs
         cmd = cmd + " " + pkg.deplibs
         if pkg.rpath != "":
-            cmd = cmd + " " + so_dirs_path(cmd, pkg.rpath)
-        if run_command(cmd, echo=True, stdout=stdout, stderr=stderr) != 0:
-            retval = 1
-
-    # Cleanup
-
-    for f in os.listdir(temp_dir):
-        os.remove(os.path.join(temp_dir, f))
-
-    # Return to original directory
-
-    os.chdir(call_dir)
-    os.rmdir(temp_dir)
-
-    return retval
-
-#-------------------------------------------------------------------------------
-
-def compile_and_link_syrthes(pkg, srcdir, destdir,
-                             stdout = sys.stdout, stderr = sys.stderr):
-    """
-    Compilation and link function.
-    """
-    retval = 0
-
-    exec_name = "syrthes"
-    if destdir != None:
-        exec_name = os.path.join(destdir, exec_name)
-
-    # Change to temporary directory
-
-    call_dir = os.getcwd()
-    temp_dir = tempfile.mkdtemp(suffix=".cs_compile_syrthes")
-    os.chdir(temp_dir)
-
-    # Find files to compile in source path
-
-    if srcdir != None:
-        dir_files = os.listdir(srcdir)
-    else:
-        dir_files = []
-
-    c_files = fnmatch.filter(dir_files, '*.c')
-    h_files = fnmatch.filter(dir_files, '*.h')
-    f_files = fnmatch.filter(dir_files, '*.[fF]')
-
-    for f in c_files:
-        cmd = build_syrthes.cc
-        if len(h_files) > 0:
-            cmd = cmd + " -I" + srcdir
-        cmd = cmd + " " + build_syrthes.cppflags
-        cmd = cmd + " " + build_syrthes.cflags
-        cmd = cmd + " " + pkg.ple_cppflags
-        cmd = cmd + " -c " + os.path.join(srcdir, f)
-        if run_command(cmd, echo=True, stdout=stdout, stderr=stderr) != 0:
-            retval = 1
-
-    for f in f_files:
-        cmd = build_syrthes.fc
-        if len(h_files) > 0:
-            cmd = cmd + " -I" + srcdir
-        cmd = cmd + " " + build_syrthes.cppflags
-        cmd = cmd + " " + build_syrthes.fcflags
-        cmd = cmd + " -c " + os.path.join(srcdir, f)
-        if run_command(cmd, echo=True, stdout=stdout, stderr=stderr) != 0:
-            retval = 1
-
-    if retval == 0:
-        # Link with Code_Saturne C compiler
-        cmd = pkg.cc
-        cmd = cmd + " -o " + exec_name
-        if (len(f_files)) > 0:
-          cmd = cmd + " *.o"
-        cmd = cmd + " -L" + pkg.libdir + " " + pkg.ldflags
-        cmd = cmd + " -lsyrcs"
-        cmd = cmd + " " + build_syrthes.ldflags + " " + build_syrthes.libs
-        if pkg.rpath != "":
-            cmd = cmd + " " + so_dirs_path(cmd, pkg.rpath)
+            cmd = cmd + " " + so_dirs_path(cmd, pkg)
         if run_command(cmd, echo=True, stdout=stdout, stderr=stderr) != 0:
             retval = 1
 
@@ -329,7 +269,7 @@ def main(argv, pkg):
     """
 
     test_mode, force_link, keep_going, src_dir, dest_dir, \
-        version, opt_libs, link_syrthes = process_cmd_line(argv, pkg)
+        version, opt_libs = process_cmd_line(argv, pkg)
 
     if (version):
         pkg = pkg.get_alternate_version(version)
@@ -339,11 +279,8 @@ def main(argv, pkg):
     if test_mode == True:
         dest_dir = None
 
-    if link_syrthes == True:
-        retcode = compile_and_link_syrthes(pkg, src_dir, dest_dir)
-    else:
-        retcode = compile_and_link(pkg, src_dir, dest_dir, opt_libs,
-                                   force_link, keep_going)
+    retcode = compile_and_link(pkg, src_dir, dest_dir, opt_libs,
+                               force_link, keep_going)
 
     sys.exit(retcode)
 
