@@ -5,7 +5,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2011 EDF S.A.
+# Copyright (C) 1998-2012 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -70,7 +70,7 @@ def get_shell_type():
     user_shell = os.getenv('SHELL')
     if not user_shell:
         user_shell = '/bin/sh'
-    elif user_shell[-3] == 'csh':
+    elif user_shell[-3:] == 'csh':
         user_shell = '/bin/sh'
 
     return user_shell
@@ -368,7 +368,7 @@ class resource_info(batch_info):
             if not os.path.isfile(os.getenv('TMPDIR') + '/machines'):
                 self.hosts_file = None
         elif self.hosts_file != None:
-            if self.host_file[0] == '$':
+            if self.hosts_file[0] == '$':
                 if not os.path.isfile(os.getenv(self.hosts_file[1:])):
                     self.hosts_file = None
             elif not os.path.isfile(self.hosts_file):
@@ -399,6 +399,20 @@ class resource_info(batch_info):
 
     #---------------------------------------------------------------------------
 
+    def n_procs_per_node(self):
+
+        """
+        Determine number of processors per node.
+        """
+
+        ppn = 1
+        if self.n_procs != None and  self.n_nodes != None:
+            ppn = self.n_procs / self.n_nodes
+
+        return ppn
+
+    #---------------------------------------------------------------------------
+
     def n_procs_from_hosts_file(self, hosts_file):
 
         """
@@ -599,7 +613,7 @@ class mpi_environment:
         Returns MPI environment info.
         """
 
-        # Note that self.mpiexec will usually be ' -n ' if present;
+        # Note that self.mpiexec_n will usually be ' -n ' if present;
         # blanks are used to separate from the surrounding arguments,
         # but in the case of srun, which uses a -n<n_procs> instead
         # of -n <n_procs> syntax, setting it to ' -n' will be enough.
@@ -614,6 +628,8 @@ class mpi_environment:
         self.mpiexec = None
         self.mpiexec_opts = None
         self.mpiexec_n = None
+        self.mpiexec_n_per_node = None
+        self.mpiexec_separator = None
         self.mpiexec_exe = None
         self.mpiexec_args = None
         self.mpmd = MPI_MPMD_none
@@ -631,6 +647,7 @@ class mpi_environment:
                                'LAM_MPI':self.__init_lam__,
                                'BGL_MPI':self.__init_bgl__,
                                'BGP_MPI':self.__init_bgp__,
+                               'BGQ_MPI':self.__init_bgq__,
                                'HP_MPI':self.__init_hp_mpi__,
                                'MPIBULL2':self.__init_mpibull2__}
             if self.type in mpi_env_by_type:
@@ -722,6 +739,10 @@ class mpi_environment:
             if self.mpiexec != None:
                 break
 
+        if (self.mpiexec == None):
+            basename = 'mpiexec'
+            self.mpiexec = 'mpiexec'
+
         # Determine if MPD should be handled
         # (if we are using a root MPD, no need for setup)
 
@@ -794,6 +815,11 @@ class mpi_environment:
                 if hostsfile != None:
                     self.mpiexec += ' -f ' + hostsfile
 
+            if (resource_info != None):
+                ppn = resource_info.n_procs_per_node()
+                if ppn != 1:
+                    self.mpiexec_n_per_node = ' -ppn ' + str(ppn)
+
         elif pm == 'gforker':
             hosts = False
             hostslist = resource_info.get_hosts_list()
@@ -907,6 +933,10 @@ class mpi_environment:
         launcher_base = os.path.basename(self.mpiexec)
 
         self.mpiexec_n = ' -n '
+        if (resource_info != None):
+            ppn = resource_info.n_procs_per_node()
+            if ppn != 1:
+                self.mpiexec_n_per_node = ' --npernode ' + str(ppn)
         if launcher_base[:7] == 'mpiexec':
             self.mpmd = MPI_MPMD_mpiexec | MPI_MPMD_script
         elif launcher_base[:7] == 'mpirun':
@@ -1041,8 +1071,6 @@ class mpi_environment:
 
         # Determine processor count and MPMD handling
 
-        launcher_base = os.path.basename(self.mpiexec)
-
         self.mpiexec_n = None
         self.mpmd = MPI_MPMD_configfile
 
@@ -1052,6 +1080,45 @@ class mpi_environment:
 
     #---------------------------------------------------------------------------
 
+    def __init_bgq__(self, p, resource_info=None, wdir = None):
+
+        """
+        Initialize for Blue Gene/Q environment.
+        """
+
+        # Set base executable path
+
+        self.mpiexec = 'runjob'
+
+        # Determine processor count and MPMD handling
+
+        self.mpiexec_n = ' --np '
+        rm = None
+        ppn = 1
+        if resource_info != None:
+            rm = resource_info.manager
+            ppn = resource_info.n_procs_per_node()
+        if rm == 'SLURM':
+            self.mpiexec = 'srun'
+            self.mpiexec_n = ' --ntasks='
+            if ppn != 1:
+                self.mpiexec_n_per_node = ' --ntasks-per-node=' + str(ppn)
+        else:
+            if ppn != 1:
+                self.mpiexec_n_per_node = ' --ranks-per-node ' + str(ppn)
+            self.mpiexec_separator = ':'
+        self.mpmd = None
+
+        # Other options to add
+
+        # self.mpiexec_exe = '--exe'
+        # self.mpiexec_args = '--args'
+        # self.mpiexec_envs = '--envs OMP_NUM_THREADS=' + str(omp_num_threads)
+
+        # Info commands
+
+    #---------------------------------------------------------------------------
+
     def __init_hp_mpi__(self, p, resource_info=None, wdir = None):
         """
         Initialize for HP MPI environment.
@@ -1213,23 +1280,11 @@ if __name__ == '__main__':
     pkg = cs_package.package()
     e = exec_environment(pkg)
 
-    mpi_env = mpi_environment(pkg)
-
-    print('mpi_env.bindir =        ', mpi_env.bindir)
-    print('mpi_env.mpiexec =       ', mpi_env.mpiexec)
-    print('mpi_env.mpiexec_args =  ', mpi_env.mpiexec_args)
-    print('mpi_env.mpiexec_exe =   ', mpi_env.mpiexec_exe)
-    print('mpi_env.mpiexec_opts =  ', mpi_env.mpiexec_opts)
-    print('mpi_env.mpiexec_n =     ', mpi_env.mpiexec_n)
-    print('mpi_env.gen_hostsfile = ', mpi_env.gen_hostsfile)
-    print('mpi_env.del_hostsfile = ', mpi_env.del_hostsfile)
-    print('mpi_env.mpiboot =       ', mpi_env.mpiboot)
-    print('mpi_env.mpihalt =       ', mpi_env.mpihalt)
-    print('mpi_env.info_cmds =     ', mpi_env.info_cmds)
-    print('mpi_env.mpmd =          ', mpi_env.mpmd)
-    print('mpi_env.type =          ', mpi_env.type)
-
-    print(mpi_env.info())
+    import pprint
+    pprint.pprint(e.__dict__)
+    pprint.pprint(e.resources__dict__)
+    pprint.pprint(e.mpi_env__dict__)
+    print(e.mpi_env.info())
 
 #-------------------------------------------------------------------------------
 # End
