@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2011 EDF S.A.
+# Copyright (C) 1998-2012 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -52,6 +52,8 @@ from PyQt4.QtGui  import *
 # Application modules
 #-------------------------------------------------------------------------------
 
+import cs_info
+
 from Base.MainForm import Ui_MainForm
 from Base.IdView import IdView
 from Base.BrowserView import BrowserView
@@ -69,6 +71,7 @@ except:
 from Pages.WelcomeView import WelcomeView
 from Pages.IdentityAndPathesModel import IdentityAndPathesModel
 
+
 #-------------------------------------------------------------------------------
 # log config
 #-------------------------------------------------------------------------------
@@ -78,45 +81,47 @@ log = logging.getLogger("MainView")
 log.setLevel(GuiParam.DEBUG)
 
 #-------------------------------------------------------------------------------
-# Main Window
+# Base Main Window
 #-------------------------------------------------------------------------------
 
-class MainView(QMainWindow, Ui_MainForm):
-
+class MainView(object):
+    """
+    Abstract class
+    """
     NextId = 1
     Instances = set()
 
-    def __init__(self,
-                 package          = None,
-                 cmd_case         = "",
-                 cmd_batch_window = False,
-                 cmd_batch_file   = 'runcase',
-                 cmd_tree_window  = True,
-                 cmd_read_only    = False,
-                 cmd_salome       = None):
+    def __new__(cls, cmd_package = None, cmd_case = "", cmd_salome = None):
         """
-        Initializes a Main Window for a new document:
-          1. finish the Main Window layout
-          2. connection betwenn signal and slot
-          3. Ctrl+C signal handler
-          4. create some instance variables
-          5. restore system settings
-
-        @type cmd_case:
-        @param cmd_case:
+        Factory
         """
-        QMainWindow.__init__(self)
-        Ui_MainForm.__init__(self)
+        if cmd_package.name == 'code_saturne':
+            return MainViewSaturne.__new__(MainViewSaturne, cmd_package, cmd_case, cmd_salome)
+        elif cmd_package.name == 'neptune_cfd':
+            from core.MainView import MainViewNeptune
+            return MainViewNeptune.__new__(MainViewNeptune, cmd_package, cmd_case, cmd_salome)
 
-        self.setupUi(self)
 
+    @staticmethod
+    def updateInstances(qobj):
+        """
+        Overwrites the Instances set with a set that contains only those
+        window instances that are still alive.
+        """
+        MainView.Instances = set([window for window \
+                in MainView.Instances if isAlive(window)])
+
+
+
+    def ui_initialize(self):
         self.setAttribute(Qt.WA_DeleteOnClose)
         MainView.Instances.add(self)
 
+        self.setWindowTitle(self.package.code_name + " GUI")
+
         self.Id = IdView()
         self.dockWidgetIdentity.setWidget(self.Id)
 
-        self.Browser = BrowserView()
         self.dockWidgetBrowser.setWidget(self.Browser)
 
         self.scrollArea = QScrollArea(self.frame)
@@ -132,32 +137,25 @@ class MainView(QMainWindow, Ui_MainForm):
 
         # connections
 
-        self.connect(self.fileOpenAction,   SIGNAL("activated()"),   self.fileOpen)
-        self.connect(self.fileNewAction,    SIGNAL("activated()"),   self.fileNew)
+        self.connect(self.fileOpenAction,   SIGNAL("triggered()"),   self.fileOpen)
+        self.connect(self.fileNewAction,    SIGNAL("triggered()"),   self.fileNew)
         self.connect(self.menuRecent,       SIGNAL("aboutToShow()"), self.updateRecentFileMenu)
-        self.connect(self.fileSaveAction,   SIGNAL("activated()"),   self.fileSave)
-        self.connect(self.fileSaveAsAction, SIGNAL("activated()"),   self.fileSaveAs)
-        self.connect(self.fileCloseAction,  SIGNAL("activated()"),   self.close)
-        self.connect(self.fileQuitAction,   SIGNAL("activated()"),   self.fileQuit)
+        self.connect(self.fileSaveAction,   SIGNAL("triggered()"),   self.fileSave)
+        self.connect(self.fileSaveAsAction, SIGNAL("triggered()"),   self.fileSaveAs)
+        self.connect(self.fileCloseAction,  SIGNAL("triggered()"),   self.close)
+        self.connect(self.fileQuitAction,   SIGNAL("triggered()"),   self.fileQuit)
 
-        self.connect(self.openXtermAction,      SIGNAL("activated()"), self.openXterm)
-        self.connect(self.displayCaseAction,    SIGNAL("activated()"), self.displayCase)
-        self.connect(self.reload_modulesAction, SIGNAL("activated()"), self.reload_modules)
-        self.connect(self.reload_pageAction,    SIGNAL("activated()"), self.reload_page)
+        self.connect(self.openXtermAction,      SIGNAL("triggered()"), self.openXterm)
+        self.connect(self.displayCaseAction,    SIGNAL("triggered()"), self.displayCase)
 
         self.connect(self.IdentityAction, SIGNAL("toggled(bool)"), self.dockWidgetIdentityDisplay)
         self.connect(self.BrowserAction,  SIGNAL("toggled(bool)"), self.dockWidgetBrowserDisplay)
 
-        self.connect(self.displayAboutAction,    SIGNAL("activated()"), self.displayAbout)
-        self.connect(self.backgroundColorAction, SIGNAL("activated()"), self.setColor)
-        self.connect(self.actionFont,            SIGNAL("activated()"), self.setFontSize)
+        self.connect(self.displayAboutAction,    SIGNAL("triggered()"), self.displayAbout)
+        self.connect(self.backgroundColorAction, SIGNAL("triggered()"), self.setColor)
+        self.connect(self.actionFont,            SIGNAL("triggered()"), self.setFontSize)
 
-        self.connect(self.displayLicenceAction,   SIGNAL("activated()"), self.displayLicence)
-        #self.connect(self.displayConfigAction,   SIGNAL("activated()"), self.displayConfig)
-        self.connect(self.displayCSManualAction,  SIGNAL("activated()"), self.displayCSManual)
-        self.connect(self.displayCSTutorialAction, SIGNAL("activated()"), self.displayCSTutorial)
-        self.connect(self.displayCSKernelAction,  SIGNAL("activated()"), self.displayCSKernel)
-        self.connect(self.displayCSRefcardAction,  SIGNAL("activated()"), self.displayCSRefcard)
+        self.connect(self.displayLicenceAction,   SIGNAL("triggered()"), self.displayLicence)
 
         # connection for page layout
 
@@ -168,19 +166,6 @@ class MainView(QMainWindow, Ui_MainForm):
 
         signal.signal(signal.SIGINT, signal.SIG_DFL)
 
-        # create some instance variables
-
-        self.cmd_case    = cmd_case
-        self.salome      = cmd_salome
-        self.batch_type  = cs_batch_type
-        self.batch       = cmd_batch_window
-        self.batch_file  = cmd_batch_file
-        self.batch_lines = []
-        self.tree_w      = cmd_tree_window
-        self.read_o      = cmd_read_only
-        self.notree      = 0
-        self.package     = package
-
         self.resize(800, 700)
         #self.setMaximumSize(QSize(2000, 900))
 
@@ -210,8 +195,6 @@ class MainView(QMainWindow, Ui_MainForm):
                 app = QCoreApplication.instance()
                 app.setFont(font)
 
-        title = self.tr("Code_Saturne GUI")
-        self.setWindowTitle(title)
         self.updateRecentFileMenu()
         QTimer.singleShot(0, self.loadInitialFile)
 
@@ -221,16 +204,6 @@ class MainView(QMainWindow, Ui_MainForm):
 #        self.setMinimumSize(QSize(700, 600))
 
 
-    @staticmethod
-    def updateInstances(qobj):
-        """
-        Overwrites the Instances set with a set that contains only those
-        window instances that are still alive.
-        """
-        MainView.Instances = set([window for window \
-                in MainView.Instances if isAlive(window)])
-
-
     def loadInitialFile(self):
         """
         Private method.
@@ -341,42 +314,6 @@ class MainView(QMainWindow, Ui_MainForm):
                 self.recentFiles.takeLast()
 
 
-    def initializeBatchRunningWindow(self):
-        """
-        initializes variables concerning the display of batchrunning
-        """
-        self.IdPthMdl = IdentityAndPathesModel(self.case)
-        fic = self.IdPthMdl.getXmlFileName()
-
-        if not fic:
-            file_name = os.getcwd()
-            if os.path.basename(f) == 'DATA': file_name = os.path.dirname(file_name)
-            self.IdPthMdl.setCasePath(file_name)
-        else:
-            file_dir = os.path.split(fic)[0]
-            if file_dir:
-                self.IdPthMdl.setCasePath(os.path.split(file_dir)[0])
-                if not os.path.basename(file_dir) == 'DATA':
-                    self.IdPthMdl.setCasePath(file_dir)
-            else:
-                file_dir = os.path.split(os.getcwd())[0]
-                self.IdPthMdl.setCasePath(file_dir)
-
-        for p, rep in [('data_path',     'DATA'),
-                       ('resu_path',     'RESU'),
-                       ('user_src_path', 'SRC'),
-                       ('scripts_path',  'SCRIPTS')]:
-            self.IdPthMdl.setPathI(p,file_dir + '/' + rep)
-        self.IdPthMdl.setRelevantSubdir("yes", "")
-
-        self.IdPthMdl.setPathI('mesh_path',
-                               os.path.abspath(os.path.split(file_dir)[0] + '/' + 'MESH'))
-        self.case['batch'] =  self.batch_file
-        del IdentityAndPathesModel
-
-        self.updateStudyId()
-
-
     def closeEvent(self, event):
         """
         public slot
@@ -393,13 +330,13 @@ class MainView(QMainWindow, Ui_MainForm):
             #        if self.recentFiles else QVariant()
             settings.setValue("RecentFiles", recentFiles)
             settings.setValue("MainWindow/Geometry",
-                    QVariant(self.saveGeometry()))
+                              QVariant(self.saveGeometry()))
             settings.setValue("MainWindow/State",
-                    QVariant(self.saveState()))
+                              QVariant(self.saveState()))
             settings.setValue("MainWindow/Color",
-                    QVariant(self.palette().color(QPalette.Window).name()))
+                              QVariant(self.palette().color(QPalette.Window).name()))
             settings.setValue("MainWindow/Font",
-                    QVariant(self.font().toString()))
+                              QVariant(self.font().toString()))
 
             event.accept()
             log.debug("closeEvent -> accept")
@@ -457,28 +394,21 @@ class MainView(QMainWindow, Ui_MainForm):
         """
         if not hasattr(self, 'case'):
             self.case = XMLengine.Case(package=self.package)
-            self.case.root()['version'] = XML_DOC_VERSION
-            XMLinit(self.case)
-            title = self.tr("New parameters set") + " - " + self.tr(self.package.code_name) + self.tr(" GUI")
+            self.case.root()['version'] = self.XML_DOC_VERSION
+            self.initCase()
+            title = self.tr("New parameters set") + \
+                     " - " + self.tr(self.package.code_name) + self.tr(" GUI")
             self.setWindowTitle(title)
 
             self.Browser.configureTree(self.case)
             self.dockWidgetBrowserDisplay(True)
 
             self.case['salome'] = self.salome
-
-            p = displaySelectedPage('Identity and paths',
-                                    self,
-                                    self.case,
-                                    stbar=self.statusbar,
-                                    study=self.Id,
-                                    tree=self.Browser)
-            self.scrollArea.setWidget(p)
-
+            self.scrollArea.setWidget(self.displayFisrtPage())
             self.case['saved'] = "yes"
 
         else:
-            MainView(package=self.package, cmd_case="new case").show()
+            MainView(cmd_package=self.package, cmd_case="new case").show()
 
 
     def fileAlreadyLoaded(self, f):
@@ -522,11 +452,27 @@ class MainView(QMainWindow, Ui_MainForm):
         # check if the file to load is not already loaded
         if hasattr(self, 'case'):
             if not self.fileAlreadyLoaded(file_name):
-                MainView(package=self.package, cmd_case = file_name).show()
+                MainView(cmd_package=self.package, cmd_case = file_name).show()
         else:
             self.loadFile(file_name)
 
 
+    def loadingAborted(self, msg, fn):
+        """Show a message window dialog.
+        Delete the case if it is already loaded, but non conformal.
+
+        @param msg text to display in the popup window
+        @param fn name of the file pf parameters
+        """
+        msg += self.tr("\n\nThe loading of %s is aborted." % fn)
+        title = self.tr("File of parameters reading error")
+
+        QMessageBox.critical(self, title, msg)
+
+        if hasattr(self, 'case'):
+            delattr(self, 'case')
+
+
     def loadFile(self, file_name=None):
         """
         Private method
@@ -541,37 +487,49 @@ class MainView(QMainWindow, Ui_MainForm):
         fn = os.path.basename(file_name)
         log.debug("loadFile -> %s" % file_name)
 
+        # XML syntax checker
+
+        msg =  XMLengine.xmlChecker(file_name)
+        if msg:
+            self.loadingAborted(msg, fn)
+            return
+
         # Instantiate a new case
 
         try:
             self.case = XMLengine.Case(package=self.package, file_name=file_name)
         except:
-            err = QErrorMessage(self)
-            msg = self.tr("XML file reading error. "\
-                          "This file is not in accordance with XML "\
-                          "specifications. Please correct it and verify "\
-                          "it with XMLcheck tool.")
-            err.showMessage(msg)
-            if hasattr(self, 'case'):
-                delattr(self, 'case')
+            msg = self.tr("This file is not in accordance with XML specifications.")
+            self.loadingAborted(msg, fn)
             return
 
-        self.addRecentFile(fn)
+        # Check if the root node is the good one
+
+        if self.case.xmlRootNode().tagName != self.package.code_name + "_GUI":
+            msg = self.tr("This file seems not to be a %s file of parameters.\n\n"  \
+                          "XML root node found: %s" % \
+                          (self.package.code_name, self.case.xmlRootNode().tagName))
+            self.loadingAborted(msg, fn)
+            return
+
+        if self.case.root()['version'] != self.XML_DOC_VERSION:
+            msg = self.tr("The syntax version %s of this file of parameters does\n" \
+                          "not match with the version required y the GUI: %s." %    \
+                          (self.case.root()['version'], self.XML_DOC_VERSION) )
+            self.loadingAborted(msg, fn)
+            return
 
         # Cleaning the '\n' and '\t' from file_name (except in formula)
         self.case.xmlCleanAllBlank(self.case.xmlRootNode())
 
-        try:
-            XMLinit(self.case)
-        except:
-            err = QErrorMessage(self)
-            msg = self.tr("XML file reading error. "\
-                          "Perhaps the version of the file is to old.")
-            err.showMessage(msg)
-            if hasattr(self, 'case'):
-                delattr(self, 'case')
+        msg = self.initCase()
+        if msg:
+            self.loadingAborted(msg, fn)
             return
 
+        # All checks are fine, wan can continue...
+
+        self.addRecentFile(fn)
         self.Browser.configureTree(self.case)
         self.dockWidgetBrowserDisplay(True)
 
@@ -585,13 +543,7 @@ class MainView(QMainWindow, Ui_MainForm):
         msg = self.tr("Loaded: %s" % fn)
         self.statusbar.showMessage(msg, 2000)
 
-        p = displaySelectedPage('Identity and paths',
-                                self,
-                                self.case,
-                                stbar=self.statusbar,
-                                study=self.Id,
-                                tree=self.Browser)
-        self.scrollArea.setWidget(p)
+        self.scrollArea.setWidget(self.displayFisrtPage())
 
         self.case['saved'] = "yes"
 
@@ -636,7 +588,7 @@ class MainView(QMainWindow, Ui_MainForm):
 
         if hasattr(self, 'case'):
             if not self.fileAlreadyLoaded(file_name):
-                MainView(package=self.package, cmd_case = file_name).show()
+                MainView(cmd_package=self.package, cmd_case = file_name).show()
         else:
             self.loadFile(file_name)
 
@@ -715,12 +667,6 @@ class MainView(QMainWindow, Ui_MainForm):
 
         log.debug("fileSave(): ok")
 
-        if self.case['batch'] and self.batch_lines:
-            batch = self.case['scripts_path'] + "/" + self.case['batch']
-            f = open(batch, 'w')
-            f.writelines(self.batch_lines)
-            f.close()
-
         msg = self.tr("%s saved" % file_name)
         self.statusbar.showMessage(msg, 2000)
 
@@ -757,6 +703,54 @@ class MainView(QMainWindow, Ui_MainForm):
                 self.statusbar.showMessage(msg, 2000)
 
 
+    def displayManual(self, manual, reader = None):
+        """
+        private method
+
+        open a manual
+        """
+        argv_info = ['--guide']
+        argv_info.append(manual)
+        cs_info.main(argv_info, self.package)
+
+
+    def initializeBatchRunningWindow(self):
+        """
+        initializes variables concerning the display of batchrunning
+        """
+        self.IdPthMdl = IdentityAndPathesModel(self.case)
+        fic = self.IdPthMdl.getXmlFileName()
+
+        if not fic:
+            file_name = os.getcwd()
+            if os.path.basename(f) == 'DATA': file_name = os.path.dirname(file_name)
+            self.IdPthMdl.setCasePath(file_name)
+        else:
+            file_dir = os.path.split(fic)[0]
+            if file_dir:
+                self.IdPthMdl.setCasePath(os.path.split(file_dir)[0])
+                if not os.path.basename(file_dir) == 'DATA':
+                    self.IdPthMdl.setCasePath(file_dir)
+            else:
+                file_dir = os.path.split(os.getcwd())[0]
+                self.IdPthMdl.setCasePath(file_dir)
+
+        for p, rep in [('data_path',     'DATA'),
+                       ('resu_path',     'RESU'),
+                       ('user_src_path', 'SRC'),
+                       ('scripts_path',  'SCRIPTS')]:
+            self.IdPthMdl.setPathI(p,file_dir + '/' + rep)
+        self.IdPthMdl.setRelevantSubdir("yes", "")
+
+        self.IdPthMdl.setPathI('mesh_path',
+                               os.path.abspath(os.path.split(file_dir)[0] + '/' + 'MESH'))
+        self.case['batch'] =  self.batch_file
+        del IdentityAndPathesModel
+
+        self.updateStudyId()
+
+
+
     def batchFileUpdate(self):
         """
         Update the run command
@@ -826,162 +820,19 @@ class MainView(QMainWindow, Ui_MainForm):
             f.writelines(self.batch_lines)
             f.close()
 
+        else:
 
-    @pyqtSignature("")
-    def reload_modules(self):
-        """
-        public slot
-
-        reload all the currently loaded modules, and then update the GUI
-        """
-        log.debug("reload_modules()")
-        title = self.tr("Warning")
-        msg = self.tr("This reloads all the currently loaded modules. "\
-                      "This is a feature useful only for developers.  You might "\
-                      "see funny behaviour for already instantiated objects.\n\n"\
-                      "Are you sure you want to do this?")
-
-        ans = QMessageBox.question(self, title, msg,
-                                   QMessageBox.Yes|
-                                   QMessageBox.No)
-
-        if ans == QMessageBox.Yes:
-            self.scrollArea.widget().close()
-            reload_all_modules()
-            p = displaySelectedPage(self.case['currentPage'],
-                                    self,
-                                    self.case,
-                                    stbar=self.statusbar,
-                                    study=self.Id,
-                                    tree=self.Browser)
-            self.scrollArea.setWidget(p)
-
-
-    @pyqtSignature("")
-    def reload_page(self):
-        """
-        public slot
-
-        reload the current loaded page
-        """
-        log.debug("reload_page()")
-        title = self.tr("Warning")
-        msg = self.tr("This reloads all the current loaded page. "\
-                      "This is a feature useful only for developers. You might "\
-                      "see funny behaviour for already instantiated objects.\n\n"\
-                      "Are you sure you want to do this?")
-
-        ans = QMessageBox.question(self, title, msg,
-                                   QMessageBox.Yes|
-                                   QMessageBox.No)
-
-        if ans == QMessageBox.Yes:
-            self.scrollArea.widget().close()
-            reload_current_page()
-            p = displaySelectedPage(self.case['currentPage'],
-                                    self,
-                                    self.case,
-                                    stbar=self.statusbar,
-                                    study=self.Id,
-                                    tree=self.Browser)
-            self.scrollArea.setWidget(p)
-
-
-    @pyqtSignature("")
-    def displayAbout(self):
-        """
-        public slot
-
-        the About dialog window shows:
-         - title
-         - version
-         - contact
-        """
-        msg = self.package.code_name + "\n"                      +\
-              "version " + self.package.version + "\n\n"    +\
-              "For information about this application "  +\
-              "please contact:\n\n"                      +\
-              self.package.bugreport + "\n\n"               +\
-              "Please visit our site:\n"                 +\
-              self.package.url
-        QMessageBox.about(self, self.package.name + ' Interface', msg)
-
-
-    @pyqtSignature("")
-    def displayLicence(self):
-        """
-        public slot
-
-        GNU GPL license dialog window
-        """
-        QMessageBox.about(self, self.package.code_name + ' Interface', "see COPYING file") # TODO
-
-
-    @pyqtSignature("")
-    def displayConfig(self):
-        """
-        public slot
-
-        configuration information window
-        """
-        QMessageBox.about(self, self.package.code_name + ' Interface', "see config.py") # TODO
-
-
-    def displayManual(self, manual, reader = None):
-        """
-        private method
-
-        open a manual
-        """
-        try:
-            import cs_info
-        except:
-            QMessageBox.warning(self, self.package.code_name + ' Interface',
-                                "The module 'cs_info' is not available.")
-            return
-        argv_info = ['--guide']
-        argv_info.append(manual)
-        cs_info.main(argv_info, self.package)
-
-
-    @pyqtSignature("")
-    def displayCSManual(self):
-        """
-        public slot
-
-        open the user manual
-        """
-        self.displayManual('user')
-
-
-    @pyqtSignature("")
-    def displayCSTutorial(self):
-        """
-        public slot
-
-        open the tutorial for Code_Saturne
-        """
-        self.displayManual('tutorial')
-
-
-    @pyqtSignature("")
-    def displayCSKernel(self):
-        """
-        public slot
-
-        open the theory and programmer's guide
-        """
-        self.displayManual('theory')
-
-
-    @pyqtSignature("")
-    def displayCSRefcard(self):
-        """
-        public slot
-
-        open the quick reference card for Code_Saturne
-        """
-        self.displayManual('refcard')
+            try:
+                node_models = self.case.xmlGetNode('thermophysical_models')
+                node_cht = node_models.xmlGetNode('conjugate_heat_transfer')
+                node_syr = node_cht.xmlGetNode('external_coupling')
+                if len(node_syr.xmlGetNodeList('syrthes')) > 0:
+                    msg = "The Calculation management/Prepare batch page should be " \
+                        + "visited before saving so that the script file is updated " \
+                        + "relative to the XML file."
+                    QMessageBox.warning(self, self.package.code_name + ' Interface', msg)
+            except Exception:
+                pass
 
 
     @pyqtSignature("const QModelIndex &")
@@ -1026,16 +877,45 @@ class MainView(QMainWindow, Ui_MainForm):
             raise
 
 
-    def displayWelcomePage(self):
+    @pyqtSignature("")
+    def displayAbout(self):
         """
-        private method
+        public slot
 
-        display the Welcome (and the default) page
+        the About dialog window shows:
+         - title
+         - version
+         - contact
         """
-        self.page = WelcomeView()
-        #self.page.resize(600,500)
-        self.scrollArea.setWidget(self.page)
-        #self.gridlayout2.addWidget(self.page, 0, 0)
+        msg = self.package.code_name + "\n"                 +\
+              "version " + self.package.version + "\n\n"    +\
+              "For information about this application "     +\
+              "please contact:\n\n"                         +\
+              self.package.bugreport + "\n\n"               +\
+              "Please visit our site:\n"                    +\
+              self.package.url
+        QMessageBox.about(self, self.package.name + ' Interface', msg)
+
+
+    @pyqtSignature("")
+    def displayLicence(self):
+        """
+        public slot
+
+        GNU GPL license dialog window
+        """
+        QMessageBox.about(self, self.package.code_name + ' Interface', "see COPYING file") # TODO
+
+
+    @pyqtSignature("")
+    def displayConfig(self):
+        """
+        public slot
+
+        configuration information window
+        """
+        QMessageBox.about(self, self.package.code_name + ' Interface', "see config.py") # TODO
+
 
 
     @pyqtSignature("")
@@ -1079,6 +959,125 @@ class MainView(QMainWindow, Ui_MainForm):
         """
         return text
 
+#-------------------------------------------------------------------------------
+# Main Window for Code_Saturne
+#-------------------------------------------------------------------------------
+
+class MainViewSaturne(QMainWindow, Ui_MainForm, MainView):
+
+    def __new__(cls, cmd_package = None, cmd_case = "", cmd_salome = None):
+        return super(MainViewSaturne, cls). __new__(cls, cmd_package, cmd_case, cmd_salome)
+
+
+    def __init__(self,
+                 cmd_package      = None,
+                 cmd_case         = "",
+                 cmd_salome       = None):
+        """
+        Initializes a Main Window for a new document:
+          1. finish the Main Window layout
+          2. connection betwenn signal and slot
+          3. Ctrl+C signal handler
+          4. create some instance variables
+          5. restore system settings
+
+        @type cmd_case:
+        @param cmd_case:
+        """
+        QMainWindow.__init__(self)
+        Ui_MainForm.__init__(self)
+
+        self.setupUi(self)
+
+        # create some instance variables
+
+        self.cmd_case    = cmd_case
+        self.salome      = cmd_salome
+        self.batch_type  = cs_batch_type
+        self.batch       = None
+        self.batch_file  = 'runcase'
+        self.batch_lines = []
+        self.package     = cmd_package
+
+        self.XML_DOC_VERSION = XML_DOC_VERSION
+
+        self.Browser = BrowserView()
+        self.ui_initialize()
+
+        self.connect(self.displayCSManualAction,   SIGNAL("triggered()"), self.displayCSManual)
+        self.connect(self.displayCSTutorialAction, SIGNAL("triggered()"), self.displayCSTutorial)
+        self.connect(self.displayCSKernelAction,   SIGNAL("triggered()"), self.displayCSKernel)
+        self.connect(self.displayCSRefcardAction,  SIGNAL("triggered()"), self.displayCSRefcard)
+
+
+    def initCase(self):
+        """
+        Initializes the new case with default xml nodes.
+        If previous case, just check if all mandatory nodes exist.
+        """
+        return XMLinit(self.case).initialize()
+
+
+    def displayWelcomePage(self):
+        """
+        Display the Welcome (and the default) page
+        """
+        self.page = WelcomeView()
+        self.scrollArea.setWidget(self.page)
+
+
+    def displayFisrtPage(self):
+        """
+        Display the first page if a file of parameters (new or previous) is loaded
+        """
+        return displaySelectedPage('Identity and paths',
+                                    self,
+                                    self.case,
+                                    stbar=self.statusbar,
+                                    study=self.Id,
+                                    tree=self.Browser)
+
+
+    @pyqtSignature("")
+    def displayCSManual(self):
+        """
+        public slot
+
+        open the user manual
+        """
+        self.displayManual('user')
+
+
+    @pyqtSignature("")
+    def displayCSTutorial(self):
+        """
+        public slot
+
+        open the tutorial for Code_Saturne
+        """
+        self.displayManual('tutorial')
+
+
+    @pyqtSignature("")
+    def displayCSKernel(self):
+        """
+        public slot
+
+        open the theory and programmer's guide
+        """
+        self.displayManual('theory')
+
+
+    @pyqtSignature("")
+    def displayCSRefcard(self):
+        """
+        public slot
+
+        open the quick reference card for Code_Saturne
+        """
+        self.displayManual('refcard')
+
+#-------------------------------------------------------------------------------
 
 def isAlive(qobj):
     """
@@ -1094,13 +1093,6 @@ def isAlive(qobj):
         return False
     return True
 
-
 #-------------------------------------------------------------------------------
-# Local main program
+# End
 #-------------------------------------------------------------------------------
-
-if __name__ == "__main__":
-    app = QApplication(sys.argv)
-    Main = MainView()
-    Main.show()
-    sys.exit(app.exec_())
