@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2011 EDF S.A.
+# Copyright (C) 1998-2012 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -645,7 +645,7 @@ class BatchRunningModelTestCase(unittest.TestCase):
         from Base.Toolbox import GuiParam
         GuiParam.lang = 'en'
         self.case = Case(None)
-        XMLinit(self.case)
+        XMLinit(self.case).initialize()
 
         self.case['batch_type'] = None
         self.case['scripts_path'] = os.getcwd()
