@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2011 EDF S.A.
+# Copyright (C) 1998-2012 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -26,6 +26,9 @@
 This module contains the following classes and function:
 - BatchRunningUserFilesDialogView
 - BatchRunningAdvancedOptionsDialogView
+- BatchRunningStopByIterationDialogView
+- BatchRunningListingLinesDisplayedDialogView
+- ListingDialogView
 - BatchRunningView
 """
 
@@ -35,6 +38,7 @@ This module contains the following classes and function:
 
 import os, sys
 import string, types
+import re
 import logging
 import subprocess
 
@@ -45,6 +49,9 @@ import subprocess
 from PyQt4.QtCore import *
 from PyQt4.QtGui  import *
 
+import cs_case
+import cs_exec_environment
+
 #-------------------------------------------------------------------------------
 # Application modules import
 #-------------------------------------------------------------------------------
@@ -52,10 +59,12 @@ from PyQt4.QtGui  import *
 from Pages.BatchRunningForm import Ui_BatchRunningForm
 from Pages.BatchRunningUserFilesDialogForm import Ui_BatchRunningUserFilesDialogForm
 from Pages.BatchRunningAdvancedOptionsDialogForm import Ui_BatchRunningAdvancedOptionsDialogForm
+from Pages.BatchRunningStopByIterationDialogForm import Ui_BatchRunningStopByIterationDialogForm
 
 from Base.Common import cs_batch_type
 from Base.Toolbox import GuiParam
 from Base.QtPage import ComboModel, IntValidator, RegExpValidator, setGreenColor
+from Base.CommandMgrDialogView import CommandMgrDialogView
 from Pages.BatchRunningModel import BatchRunningModel
 from Pages.ScriptRunningModel import ScriptRunningModel
 from Pages.LocalizationModel import LocalizationModel, Zone
@@ -193,6 +202,7 @@ class BatchRunningUserFilesDialogView(QDialog, Ui_BatchRunningUserFilesDialogFor
         """
         return text
 
+#-------------------------------------------------------------------------------
 
 class QListModel(QStandardItemModel):
     def __init__(self, row,  column,  parent=None):
@@ -209,6 +219,7 @@ class QListModel(QStandardItemModel):
 
         return result
 
+#-------------------------------------------------------------------------------
 
 class DataDelegate(QItemDelegate):
     def __init__(self, parent=None, path=None):
@@ -289,7 +300,6 @@ class BatchRunningAdvancedOptionsDialogView(QDialog, Ui_BatchRunningAdvancedOpti
 
         # Combo models
         self.modelSCRATCHDIR   = ComboModel(self.comboBoxSCRATCHDIR, 2, 1)
-        self.modelPartitType   = ComboModel(self.comboBox_2, 4, 1)
         self.modelCSOUT1       = ComboModel(self.comboBox_6, 2, 1)
         self.modelCSOUT2       = ComboModel(self.comboBox_7, 3, 1)
 
@@ -297,14 +307,6 @@ class BatchRunningAdvancedOptionsDialogView(QDialog, Ui_BatchRunningAdvancedOpti
         self.modelSCRATCHDIR.addItem(self.tr("automatic"), 'automatic')
         self.modelSCRATCHDIR.addItem(self.tr("prescribed"), 'prescribed')
 
-        self.modelPartitType.addItem(self.tr("Default"), 'default')
-        self.modelPartitType.addItem(self.tr("Scotch"), 'scotch')
-        self.modelPartitType.addItem(self.tr("Metis"), 'metis')
-        self.modelPartitType.addItem(self.tr("Morton curve (bounding box)"), 'morton sfc')
-        self.modelPartitType.addItem(self.tr("Morton curve (bounding cube)"), 'morton sfc cube')
-        self.modelPartitType.addItem(self.tr("Hilbert curve (bounding box)"), 'hilbert sfc')
-        self.modelPartitType.addItem(self.tr("Hilbert curve (bounding cube)"), 'hilbert sfc cube')
-
         self.modelCSOUT1.addItem(self.tr("to standard output"), 'stdout')
         self.modelCSOUT1.addItem(self.tr("to listing"), 'listing')
 
@@ -312,16 +314,10 @@ class BatchRunningAdvancedOptionsDialogView(QDialog, Ui_BatchRunningAdvancedOpti
         self.modelCSOUT2.addItem(self.tr("to standard output"), 'stdout')
         self.modelCSOUT2.addItem(self.tr("to listing_n<p>"), 'listing')
 
-        # Validators
-        partListVd = RegExpValidator(self.lineEdit_2, QRegExp("[0-9- ]*"))
-        self.lineEdit_2.setValidator(partListVd)
-
         # Connections
         self.connect(self.comboBoxSCRATCHDIR, SIGNAL("activated(const QString&)"), self.slotSCRATCHDIR)
         self.connect(self.toolButton, SIGNAL("clicked()"), self.slotSearchDirectory)
-        self.connect(self.comboBox_2, SIGNAL("activated(const QString&)"), self.slotExePartit)
         self.connect(self.toolButton_2, SIGNAL("clicked()"), self.slotSearchFile)
-        self.connect(self.lineEdit_2, SIGNAL("textChanged(const QString &)"), self.slotPartitionList)
         self.connect(self.lineEdit_3, SIGNAL("textChanged(const QString &)"), self.slotValgrind)
         self.connect(self.comboBox_6, SIGNAL("activated(const QString&)"), self.slotLogType)
         self.connect(self.comboBox_7, SIGNAL("activated(const QString&)"), self.slotLogType)
@@ -339,12 +335,6 @@ class BatchRunningAdvancedOptionsDialogView(QDialog, Ui_BatchRunningAdvancedOpti
             self.toolButton.setEnabled(True)
             self.modelSCRATCHDIR.setItem(str_model='prescribed')
 
-        self.partition_type = str(self.parent.mdl.getPartitionType())
-        self.modelPartitType.setItem(str_model=self.partition_type)
-
-        self.partition_list = self.parent.mdl.getString('partition_list')
-        self.lineEdit_2.setText(QString(self.partition_list))
-
         self.valgrind = self.parent.mdl.getString('valgrind')
         if self.valgrind != None:
             self.lineEdit_3.setText(QString(self.valgrind))
@@ -370,14 +360,6 @@ class BatchRunningAdvancedOptionsDialogView(QDialog, Ui_BatchRunningAdvancedOpti
         self.lineEdit.setText(QString(self.scratchdir))
 
 
-    @pyqtSignature("const QString &")
-    def slotPartitionList(self, text):
-        """
-        Input for Partitioner.
-        """
-        self.partition_list = str(text)
-
-
     @pyqtSignature("const QString &")
     def slotValgrind(self, text):
         """
@@ -386,14 +368,6 @@ class BatchRunningAdvancedOptionsDialogView(QDialog, Ui_BatchRunningAdvancedOpti
         self.valgrind = str(text)
 
 
-    @pyqtSignature("const QString &")
-    def slotExePartit(self, text):
-        """
-        Partitioner execution mode option.
-        """
-        self.partition_type = self.modelPartitType.dicoV2M[str(text)]
-
-
     def setLogType(self):
         """
         Set logging arguments.
@@ -471,9 +445,6 @@ class BatchRunningAdvancedOptionsDialogView(QDialog, Ui_BatchRunningAdvancedOpti
         Method called when user clicks 'OK'
         """
 
-        self.parent.mdl.setPartitionType(self.partition_type)
-        self.parent.mdl.setString('partition_list', self.partition_list.strip())
-
         self.parent.mdl.setString('valgrind', self.valgrind.strip())
         self.parent.mdl.setString('scratchdir', self.scratchdir)
 
@@ -495,12 +466,176 @@ class BatchRunningAdvancedOptionsDialogView(QDialog, Ui_BatchRunningAdvancedOpti
         """
         return text
 
+#-------------------------------------------------------------------------------
+# Popup window class: stop the computation at a iteration
+#-------------------------------------------------------------------------------
+
+class BatchRunningStopByIterationDialogView(QDialog, Ui_BatchRunningStopByIterationDialogForm):
+    """
+    Advanced dialog for stop the computation at a given iteration
+    """
+    def __init__(self, parent, default):
+        """
+        Constructor
+        """
+        QDialog.__init__(self, parent)
+
+        Ui_BatchRunningStopByIterationDialogForm.__init__(self)
+        self.setupUi(self)
+
+        self.setWindowTitle(self.tr("Stop"))
+
+        self.default = default
+        self.result  = self.default.copy()
+
+        v = IntValidator(self.lineEditStopIter, min=1)
+        self.lineEditStopIter.setValidator(v)
+
+        # Previous values
+        self.iter = self.default['iter']
+        self.lineEditStopIter.setText(QString(str(self.iter)))
+
+        self.connect(self.lineEditStopIter,
+                     SIGNAL("textChanged(const QString &)"),
+                     self.__slotStopIter)
+
+
+    @pyqtSignature("const QString &")
+    def __slotStopIter(self, text):
+        """
+        Private slot to set a iteration number to stop the code.
+        """
+        iter, ok = text.toInt()
+        if self.sender().validator().state == QValidator.Acceptable:
+            self.iter = iter
+
+
+    def get_result(self):
+        """
+        Method to get the result
+        """
+        return self.result
+
+
+    def accept(self):
+        """
+        Method called when user clicks 'OK'
+        """
+        self.result['iter'] = self.iter
+        QDialog.accept(self)
+
+
+    def reject(self):
+        """
+        Method called when user clicks 'Cancel'
+        """
+        QDialog.reject(self)
+
+#-------------------------------------------------------------------------------
+#
+#-------------------------------------------------------------------------------
+
+class ListingDialogView(CommandMgrDialogView):
+    def __init__(self, parent, case, title, cmd_list):
+        self.case = case
+
+        CommandMgrDialogView.__init__(self, parent, title, cmd_list, self.case['scripts_path'])
+
+        self.connect(self.pushButtonStop,   SIGNAL('clicked()'), self.__slotStop)
+        self.connect(self.pushButtonStopAt, SIGNAL('clicked()'), self.__slotStopAt)
+
+        self.exec_dir = ""
+        self.suffix   = ""
+        self.listing  = "listing"
+
+        self.slotProcess()
+
+
+    def slotReadFromStdout(self):
+        """
+        Public slot to handle the readyReadStandardOutput signal of the process.
+        """
+        if self.proc is None:
+            return
+        self.proc.setReadChannel(QProcess.StandardOutput)
+
+        while self.proc and self.proc.canReadLine():
+            ba = self.proc.readLine()
+            if ba.isNull(): return
+            str = QString()
+            s = QString(str.fromUtf8(ba.data()))[:-1]
+            self.logText.append(s)
+            self.__execDir(s)
+
+
+    def __execDir(self, s):
+        """
+        Private method. Find the directory of the code execution.
+        """
+        if self.suffix:
+            return
+
+        # Read directly the run directory from the sdtout of the code.
+        if not self.exec_dir:
+            if s.indexOf(QString("Result directory")) != -1:
+                self.exec_dir = "Result directory"
+        elif self.exec_dir == "Result directory":
+            self.exec_dir = string.join(string.split(str(s)), ' ')
+            title = os.path.basename(self.exec_dir)
+            self.setWindowTitle(title)
+            self.suffix = title
+
+
+    def __stopExec(self, iter, msg):
+        """
+        Private method. Stops the code.
+        """
+        line = "\n" + str(iter) + "\n\n"
+        ficstp = os.path.join(self.exec_dir, "ficstp")
+        f = open(ficstp, 'w')
+        f.write(line)
+        f.close()
+        QMessageBox.warning(self, self.tr("Warning"), msg)
+
+
+    @pyqtSignature("")
+    def __slotStop(self):
+        """
+        Private slot. Stops the code at the end of the current iteration.
+        """
+        iter = 1
+        msg = self.tr("Stop at the end of the current iteration.")
+        self.__stopExec(iter, msg)
+
+
+    @pyqtSignature("")
+    def __slotStopAt(self):
+        """
+        Private slot. Stops the code at the end of the given iteration.
+        """
+        default = {}
+        default['iter'] = 100
+        dlg = BatchRunningStopByIterationDialogView(self, default)
+        if dlg.exec_():
+            result = dlg.get_result()
+            msg = self.tr("Stop at iteration number: %i" % result['iter'])
+            self.__stopExec(result['iter'], msg)
+
+
+    @pyqtSignature("QProcess::ProcessState")
+    def slotStateChanged(self, state):
+        """
+        Public slot. Handle the current status of the process.
+        """
+        bool = not(state == QProcess.NotRunning)
+        self.pushButtonKill.setEnabled(bool)
+        self.pushButtonStop.setEnabled(bool)
+        self.pushButtonStopAt.setEnabled(bool)
 
 #-------------------------------------------------------------------------------
 # Main class
 #-------------------------------------------------------------------------------
 
-
 class BatchRunningView(QWidget, Ui_BatchRunningForm):
     """
     This class is devoted to the Computer selection.
@@ -519,6 +654,7 @@ class BatchRunningView(QWidget, Ui_BatchRunningForm):
         self.setupUi(self)
 
         self.case = case
+        self.parent = parent
 
         self.mdl = ScriptRunningModel(self.case)
 
@@ -601,13 +737,12 @@ class BatchRunningView(QWidget, Ui_BatchRunningForm):
 
         self.modelArg_cs_verif = ComboModel(self.comboBoxRunType, 2, 1)
 
-        self.modelArg_cs_verif.addItem(self.tr("Import mesh / partition only"), 'none')
+        self.modelArg_cs_verif.addItem(self.tr("Import mesh only"), 'none')
         self.modelArg_cs_verif.addItem(self.tr("Mesh preprocessing"), 'mesh preprocess')
         self.modelArg_cs_verif.addItem(self.tr("Mesh quality criteria"), 'mesh quality')
         self.modelArg_cs_verif.addItem(self.tr("Standard"), 'standard')
         self.modelArg_cs_verif.setItem(str_model=self.mdl.getRunType())
 
-
         # initialize Widgets
 
         # Check if the script file name is already defined
@@ -756,6 +891,11 @@ class BatchRunningView(QWidget, Ui_BatchRunningForm):
             QMessageBox.information(self, title, msg)
             return
 
+        # Ensure code is run from a case subdirectory
+
+        prv_dir = os.getcwd()
+        os.chdir(self.case['scripts_path'])
+
         # Do we have a mesh ?
 
         have_mesh = False
@@ -785,16 +925,19 @@ class BatchRunningView(QWidget, Ui_BatchRunningForm):
 
         key = self.case['batch_type']
 
-        batch = os.path.join(self.case['scripts_path'], self.case['batch'])
+        batch = os.path.join('.', self.case['batch'])
 
         if key == None:
-            cmd = 'nice nohup ' + batch + ' | tee ' + batch + '.log &'
+            run_id, run_title = self.__suggest_run_id()
+            self.__updateRuncase(run_id)
+            cmd = batch
+            key = 'localhost'
         elif key[0:3] == 'CCC':
-            cmd = 'qsub ' + batch
+            cmd = 'msub ' + batch
         elif key[0:5] == 'LOADL':
             cmd = 'llsubmit ' + batch
         elif key[0:3] == 'LSF':
-            cmd = 'bsub < ' + batch + ' ' + self.case['batch'] + ' &'
+            cmd = 'bsub < ' + batch
         elif key[0:3] == 'PBS' or key[0:3] == 'SGE':
             cmd = 'qsub ' + batch
         elif key[0:5] == 'SLURM':
@@ -805,8 +948,68 @@ class BatchRunningView(QWidget, Ui_BatchRunningForm):
         if self.case['salome']:
             from Pages import  SalomeHandler
             SalomeHandler.runSolver(self.case, batch)
+        elif key == 'localhost':
+            dlg = ListingDialogView(self.parent, self.case, run_title, [cmd])
+            dlg.show()
         else:
-            os.system(cmd)
+            cs_exec_environment.run_command(cmd)
+
+        os.chdir(prv_dir)
+
+
+    def __suggest_run_id(self):
+        """
+        Return an id.
+        """
+        cmd = os.path.join(self.case['package'].bindir,
+                           self.case['package'].name)
+        cmd += " run --suggest-id"
+        r_title = subprocess.Popen(cmd,
+                                   shell=True,
+                                   stdout=subprocess.PIPE).stdout.read()[:-1]
+        r_id = os.path.join(self.case['resu_path'], r_title)
+
+        run_id = r_id
+        run_title = r_title
+        j = 1
+        while os.path.isdir(run_id):
+            j += 1
+            run_id = r_id + "_" + str(j)
+            run_title = r_title + "(" + str(j) + ")"
+
+        return os.path.basename(run_id), run_title
+
+
+    def __updateRuncase(self, run_id):
+        """
+        Update the command line in the launcher C{runcase}.
+        """
+        runcase = os.path.join(self.case['scripts_path'], "runcase")
+
+        try:
+            run_ref_f = file(runcase, mode='r')
+        except IOError:
+            print "Error: can not opening %s\n" % runcase
+            sys.exit(1)
+        lines = run_ref_f.readlines()
+        run_ref_f.close()
+
+        pattern = r'^\\' + self.case['package'].name
+
+        for i in range(len(lines)):
+            if re.search(pattern, lines[i]):
+                l = lines[i].split()
+                if "--id" in l:
+                    l[l.index("--id") + 1] = run_id
+                else:
+                    l.append("--id")
+                    l.append(run_id)
+                lines[i] = string.join(l)
+
+        run_new_f = file(runcase, mode='w')
+        run_new_f.writelines(lines)
+        run_new_f.close()
+
 
 
     def getCommandOutput(self, cmd):
@@ -929,7 +1132,7 @@ class BatchRunningView(QWidget, Ui_BatchRunningForm):
         Layout of the second part of this page.
         """
 
-        self.job_name     = self.jmdl.dictValues['job_name']
+        self.job_name  = self.jmdl.dictValues['job_name']
         self.job_nodes = self.jmdl.dictValues['job_nodes']
         self.job_ppn  = self.jmdl.dictValues['job_ppn']
         self.job_procs = self.jmdl.dictValues['job_procs']
