@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2011 EDF S.A.
+# Copyright (C) 1998-2012 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -163,15 +163,13 @@ class StandardItemModelBoundaries(QStandardItemModel):
 
         # Corresponding dict for the nature of the boundary. used in combo delegate.
         self.dicoM2V = {
-            "wall" : { "inlet" : self.tr("Particles injection zone"),
-                       "bounce" : self.tr("Particles rebound zone"),
-                       "deposit1" : self.tr("Particles deposit"),
-                       "deposit2" : self.tr("Particles deposit + memory"),
-                       "deposit3" : self.tr("Particles deposit + suspension"),
-                       "depositfa" : self.tr("Particles deposit + attachment force") },
-            "inlet" : { "inlet" : self.tr("Particles injection zone") },
-            "outlet" : { "outlet" : self.tr("Particles outlet zone") },
-            "symmetry" : { "bounce" : self.tr("Particles rebound zone") }
+            "wall" : { "inlet" : self.tr("Particles inlet"),
+                       "bounce" : self.tr("Particles rebound"),
+                       "deposit1" : self.tr("Deposition and elimination"),
+                       "deposit2" : self.tr("Deposition") },
+            "inlet" : { "inlet" : self.tr("Particles inlet") },
+            "outlet" : { "outlet" : self.tr("Particles outlet") },
+            "symmetry" : { "bounce" : self.tr("Particles rebound") }
             }
 
         self.dicoV2M = {}
