@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2011 EDF S.A.
+# Copyright (C) 1998-2012 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -27,10 +27,8 @@ This module defines the 'Additional user's scalars' page.
 
 This module contains the following classes:
 - LabelDelegate
-- InitialValueDelegate
+- VarianceNameDelegate
 - VarianceDelegate
-- MinimumDelegate
-- MaximumDelegate
 - StandardItemModelScalars
 - DefineUserScalarsView
 """
@@ -126,38 +124,60 @@ class LabelDelegate(QItemDelegate):
             model.setData(index, QVariant(QString(new_plabel)), Qt.DisplayRole)
 
 #-------------------------------------------------------------------------------
-# Line edit delegate for the initial value
+# Line edit delegate for the variance name
 #-------------------------------------------------------------------------------
 
-class InitialValueDelegate(QItemDelegate):
+class VarianceNameDelegate(QItemDelegate):
+    """
+    Use of a QLineEdit in the table.
+    """
     def __init__(self, parent=None):
-        super(InitialValueDelegate, self).__init__(parent)
+        QItemDelegate.__init__(self, parent)
         self.parent = parent
+        self.old_plabel = ""
 
 
     def createEditor(self, parent, option, index):
         editor = QLineEdit(parent)
-        v = DoubleValidator(editor)
+        self.old_label = ""
+        rx = "[_a-zA-Z][_A-Za-z0-9]{1," + str(LABEL_LENGTH_MAX-1) + "}"
+        self.regExp = QRegExp(rx)
+        v = RegExpValidator(editor, self.regExp)
         editor.setValidator(v)
-        #editor.installEventFilter(self)
         return editor
 
 
     def setEditorData(self, editor, index):
         value = index.model().data(index, Qt.DisplayRole).toString()
+        self.old_plabel = str(value)
         editor.setText(value)
 
 
     def setModelData(self, editor, model, index):
         if not editor.isModified():
             return
+
         if editor.validator().state == QValidator.Acceptable:
-            value, ok = editor.text().toDouble()
-            for idx in self.parent.selectionModel().selectedIndexes():
-                if idx.column() == index.column():
-                    [label, old_init, vari, mini, maxi] = model.getData(idx)
-                    if model.checkInitMinMax(label, value, mini, maxi):
-                        model.setData(idx, QVariant(value), Qt.DisplayRole)
+            new_plabel = str(editor.text())
+
+            if new_plabel in model.mdl.getScalarLabelsList():
+                default = {}
+                default['label']  = self.old_plabel
+                default['list']   = model.mdl.getScalarLabelsList()
+                default['regexp'] = self.regExp
+                log.debug("setModelData -> default = %s" % default)
+
+                from Pages.VerifyExistenceLabelDialogView import VerifyExistenceLabelDialogView
+                dialog = VerifyExistenceLabelDialogView(self.parent, default)
+                if dialog.exec_():
+                    result = dialog.get_result()
+                    new_plabel = result['label']
+                    log.debug("setModelData -> result = %s" % result)
+                else:
+                    new_plabel = self.old_plabel
+
+            model.setData(index, QVariant(QString(new_plabel)), Qt.DisplayRole)
+
 
 #-------------------------------------------------------------------------------
 # Combo box delegate for the variance
@@ -175,22 +195,15 @@ class VarianceDelegate(QItemDelegate):
     def createEditor(self, parent, option, index):
         editor = QComboBox(parent)
         self.modelCombo = ComboModel(editor, 1, 1)
-        self.modelCombo.addItem(self.tr("No variance"), "no")
         editor.installEventFilter(self)
         return editor
 
 
     def setEditorData(self, editor, index):
-        sca = index.model().getData(index)[0]
-        if index.model().mdl.getVarianceLabelFromScalarLabel(sca):
-            return
-
         l1 = index.model().mdl.getScalarLabelsList()
         for s in index.model().mdl.getScalarsVarianceList():
             if s in l1: l1.remove(s)
 
-        if sca in l1: l1.remove(sca)
-
         for s in l1:
             self.modelCombo.addItem(s, s)
 
@@ -207,74 +220,6 @@ class VarianceDelegate(QItemDelegate):
         """
         return text
 
-#-------------------------------------------------------------------------------
-# Line edit delegate for minimum value
-#-------------------------------------------------------------------------------
-
-class MinimumDelegate(QItemDelegate):
-    def __init__(self, parent=None):
-        super(MinimumDelegate, self).__init__(parent)
-        self.parent = parent
-
-
-    def createEditor(self, parent, option, index):
-        editor = QLineEdit(parent)
-        v = DoubleValidator(editor)
-        editor.setValidator(v)
-        #editor.installEventFilter(self)
-        return editor
-
-
-    def setEditorData(self, editor, index):
-        value = index.model().data(index, Qt.DisplayRole).toString()
-        editor.setText(value)
-
-
-    def setModelData(self, editor, model, index):
-        if not editor.isModified():
-            return
-        if editor.validator().state == QValidator.Acceptable:
-            value, ok = editor.text().toDouble()
-            for idx in self.parent.selectionModel().selectedIndexes():
-                if idx.column() == index.column():
-                    [label, init, vari, old_mini, maxi] = model.getData(idx)
-                    if model.checkInitMinMax(label, init, value, maxi):
-                        model.setData(idx, QVariant(value), Qt.DisplayRole)
-
-#-------------------------------------------------------------------------------
-# Line edit delegate for maximum value
-#-------------------------------------------------------------------------------
-
-class MaximumDelegate(QItemDelegate):
-    def __init__(self, parent=None):
-        super(MaximumDelegate, self).__init__(parent)
-        self.parent = parent
-
-
-    def createEditor(self, parent, option, index):
-        editor = QLineEdit(parent)
-        v = DoubleValidator(editor)
-        editor.setValidator(v)
-        #editor.installEventFilter(self)
-        return editor
-
-
-    def setEditorData(self, editor, index):
-        value = index.model().data(index, Qt.DisplayRole).toString()
-        editor.setText(value)
-
-
-    def setModelData(self, editor, model, index):
-        if not editor.isModified():
-            return
-        if editor.validator().state == QValidator.Acceptable:
-            value, ok = editor.text().toDouble()
-            for idx in self.parent.selectionModel().selectedIndexes():
-                if idx.column() == index.column():
-                    [label, init, vari, mini, old_maxi] = model.getData(idx)
-                    if model.checkInitMinMax(label, init, mini, value):
-                        model.setData(idx, QVariant(value), Qt.DisplayRole)
-
 #-------------------------------------------------------------------------------
 # StandarItemModel class
 #-------------------------------------------------------------------------------
@@ -282,30 +227,20 @@ class MaximumDelegate(QItemDelegate):
 class StandardItemModelScalars(QStandardItemModel):
     """
     """
-    def __init__(self, parent, mdl, zone):
+    def __init__(self, parent, mdl):
         """
         """
         QStandardItemModel.__init__(self)
 
-        self.headers = [self.tr("Name"),
-                        self.tr("Initial\nvalue"),
-                        self.tr("Variance\nof scalar"),
-                        self.tr("Minimal\nvalue"),
-                        self.tr("Maximal\nvalue")]
+        self.headers = [self.tr("Name")]
 
         self.setColumnCount(len(self.headers))
 
-        self.toolTipRole = [self.tr("Code_Saturne keyword: NSCAUS"),
-                            self.tr("Code_Saturne user subroutine: usinv.F"),
-                            self.tr("Code_Saturne keyword: ISCAVR"),
-                            self.tr("Code_Saturne keyword: SCAMIN"),
-                            self.tr("Code_Saturne keyword: SCAMAX")]
+        self.toolTipRole = [self.tr("Code_Saturne keyword: NSCAUS")]
 
         self._data = []
-        self._disable = []
         self.parent = parent
         self.mdl  = mdl
-        self._zone = zone
 
 
     def data(self, index, role):
@@ -326,8 +261,6 @@ class StandardItemModelScalars(QStandardItemModel):
     def flags(self, index):
         if not index.isValid():
             return Qt.ItemIsEnabled
-        if (index.row(), index.column()) in self._disable:
-            return Qt.ItemIsSelectable
         return Qt.ItemIsEnabled | Qt.ItemIsSelectable | Qt.ItemIsEditable
 
 
@@ -352,39 +285,6 @@ class StandardItemModelScalars(QStandardItemModel):
             self._data[row][col] = new_plabel
             self.mdl.renameScalarLabel(old_plabel, new_plabel)
 
-        # Numerical values: init values, min and max
-        elif col == 1:
-            self._data[row][col], ok = value.toDouble()
-
-        elif col in [3, 4]:
-            if (row,3) not in self._disable:
-                self._data[row][col], ok = value.toDouble()
-
-        # Variance
-        elif col == 2:
-            variance = str(value.toString())
-            self._data[row][col] = variance
-
-            if (row,3) in self._disable: self._disable.remove((row,3))
-            if (row,4) in self._disable: self._disable.remove((row,4))
-            if variance != "no":
-                self._data[row][3] = 0.
-                self._data[row][4] = self.mdl.defaultScalarValues()['max_value']
-                # Disable values in columns 3 and 4
-                if (row,3) not in self._disable: self._disable.append((row,3))
-                if (row,4) not in self._disable: self._disable.append((row,4))
-            else:
-                label = self._data[row][0]
-                if self.mdl.getScalarType(label) == 'thermal':
-                    if (row,2) not in self._disable: self._disable.append((row,2))
-                else:
-                    if (row,2) in self._disable: self._disable.remove((row,2))
-
-        # Update the XML doc with the new data
-        if col != 0:
-            [label, init, vari, mini, maxi] = self._data[row]
-            self.mdl.setScalarValues(label, self._zone, init, mini, maxi, vari)
-
         self.emit(SIGNAL("dataChanged(const QModelIndex &, const QModelIndex &)"), index, index)
         return True
 
@@ -400,30 +300,19 @@ class StandardItemModelScalars(QStandardItemModel):
         """
         row = self.rowCount()
 
-        label = self.mdl.addUserScalar(self._zone, existing_label)
-        min = self.mdl.getScalarMinValue(label)
-        max = self.mdl.getScalarMaxValue(label)
-        ini = self.mdl.getScalarInitialValue(self._zone, label)
-        var = self.mdl.getScalarVariance(label)
-        if var in ("", "no variance", "no_variance"):
-            var = "no"
-        scalar = [label, ini, var, min, max]
+        label = self.mdl.addUserScalar(existing_label)
+        scalar = [label]
 
         self.setRowCount(row+1)
         self._data.append(scalar)
 
-        if self.mdl.getScalarType(label) == 'thermal':
-            if (row,2) not in self._disable: self._disable.append((row,2))
-        else:
-            if (row,2) in self._disable: self._disable.remove((row,2))
-
 
     def getItem(self, row):
         """
         Return the values for an item.
         """
-        [label, init, vari, mini, maxi] = self._data[row]
-        return label, init, vari, mini, maxi
+        [label] = self._data[row]
+        return label
 
 
     def deleteItem(self, row):
@@ -432,52 +321,137 @@ class StandardItemModelScalars(QStandardItemModel):
         """
         log.debug("deleteItem row = %i " % row)
 
-        for tuple in [(row,2), (row,3), (row,4)]:
-            if tuple in self._disable: self._disable.remove(tuple)
+        del self._data[row]
+        row = self.rowCount()
+        self.setRowCount(row-1)
+
+
+#-------------------------------------------------------------------------------
+# StandarItemModel class
+#-------------------------------------------------------------------------------
+
+class StandardItemModelVariance(QStandardItemModel):
+    """
+    """
+    def __init__(self, parent, mdl):
+        """
+        """
+        QStandardItemModel.__init__(self)
+
+        self.headers = [self.tr("Variance"),
+                        self.tr("Species_Name")]
+
+        self.setColumnCount(len(self.headers))
+
+        self.toolTipRole = [self.tr("Code_Saturne keyword: ???"),
+                            self.tr("Code_Saturne keyword: ???")]
+
+        self._data = []
+        self.parent = parent
+        self.mdl  = mdl
+
+
+    def data(self, index, role):
+        if not index.isValid():
+            return QVariant()
+
+        row = index.row()
+        col = index.column()
+
+        if role == Qt.ToolTipRole:
+            return QVariant(self.toolTipRole[col])
+        if role == Qt.DisplayRole:
+            return QVariant(self._data[row][col])
+
+        return QVariant()
+
+
+    def flags(self, index):
+        if not index.isValid():
+            return Qt.ItemIsEnabled
+        return Qt.ItemIsEnabled | Qt.ItemIsSelectable | Qt.ItemIsEditable
+
+
+    def headerData(self, section, orientation, role):
+        if orientation == Qt.Horizontal and role == Qt.DisplayRole:
+            return QVariant(self.headers[section])
+        return QVariant()
+
+
+    def setData(self, index, value, role):
+        if not index.isValid():
+            return Qt.ItemIsEnabled
+
+        # Update the row in the table
+        row = index.row()
+        col = index.column()
+
+        # Label
+        if col == 0:
+            old_plabel = self._data[row][col]
+            new_plabel = str(value.toString())
+            self._data[row][col] = new_plabel
+            self.mdl.renameScalarLabel(old_plabel, new_plabel)
+
+
+        # Variance
+        elif col == 1:
+            variance = str(value.toString())
+            self._data[row][col] = variance
+            [label, var] = self._data[row]
+            self.mdl.setScalarVariance(label,var)
+
+        self.emit(SIGNAL("dataChanged(const QModelIndex &, const QModelIndex &)"), index, index)
+        return True
+
+
+    def getData(self, index):
+        row = index.row()
+        return self._data[row]
+
+
+    def newItem(self, existing_label=None):
+        """
+        Add an item in the table view
+        """
+        if not self.mdl.getScalarLabelsList():
+            title = self.tr("Warning")
+            msg   = self.tr("There is no user scalar.\n"\
+                            "Please define a user scalar.")
+            QMessageBox.warning(self.parent, title, msg)
+            return
+        row = self.rowCount()
+        if existing_label == None:
+            label = self.mdl.addVariance()
+        else:
+            label = self.mdl.addVariance(existing_label)
+        var = self.mdl.getScalarVariance(label)
+        if var in ("", "no variance", "no_variance"):
+            var = "no"
+        scalar = [label, var]
+
+        self.setRowCount(row+1)
+        self._data.append(scalar)
+
+
+    def getItem(self, row):
+        """
+        Return the values for an item.
+        """
+        [label, var] = self._data[row]
+        return label, var
+
+
+    def deleteItem(self, row):
+        """
+        Delete the row in the model.
+        """
+        log.debug("deleteItem row = %i " % row)
 
         del self._data[row]
         row = self.rowCount()
         self.setRowCount(row-1)
 
-        for r in range(self.rowCount()):
-            if self.mdl.getScalarType(self._data[r][0]) == 'thermal':
-                if (r,2) not in self._disable: self._disable.append((r,2))
-            else:
-                if (r,2) in self._disable: self._disable.remove((r,2))
-
-
-    def checkInitMinMax(self, label, init, mini, maxi):
-        """
-        Verify the coherence between init, mini and maxi
-        """
-        log.debug("checkInitMinMax")
-        OK = 1
-
-        if mini > maxi:
-            title = self.tr("Information")
-            msg = self.tr("The minimal value is greater than the maximal "\
-                          "value. Therefore there will be no clipping for the "\
-                          "scalar named:\n\n%1").arg(label)
-            QMessageBox.information(self.parent, title, msg)
-            return OK
-
-        # if min or max is modified, initial value must be checked for all zones
-        for z in LocalizationModel('VolumicZone', self.mdl.case).getZones():
-            if z.getNature()['initialization'] == "on":
-                name = str(z.getCodeNumber())
-                ini = self.mdl.getScalarInitialValue(name, label)
-                if name == self._zone:
-                    ini = init
-
-                if ini < mini or ini > maxi:
-                    title = self.tr("Warning")
-                    msg = self.tr("The initial value must be set between the "\
-                                  "minimal and the maximal value of the scalar "\
-                                  "named: %1 for the volume region: %2").arg(label, z.getLabel())
-                    QMessageBox.warning(self.parent, title, msg)
-                    OK = 0
-
-        return OK
 
 #-------------------------------------------------------------------------------
 # Main class
@@ -498,67 +472,45 @@ class DefineUserScalarsView(QWidget, Ui_DefineUserScalarsForm):
         self.case = case
         self.mdl = DefineUserScalarsModel(self.case)
 
-        # widget layout
-
-        # 0/ Combo box model for zone
-        self.modelZone = ComboModel(self.comboBoxZone, 1, 1)
-
-        # Warning: the Volume region 'all_cells' is mandatory, it is exists always
-        zones = LocalizationModel('VolumicZone', self.case).getZones()
-        for z in zones:
-            if z.getNature()['initialization'] == "on":
-                label = z.getLabel()
-                name = str(z.getCodeNumber())
-                self.modelZone.addItem(self.tr(label), name)
-                if label == "all_cells":
-                    zone_label = label
-                    zone_name  = name
-
-        self.modelZone.setItem(str_model = zone_name)
-
-        # 2/ tableView
-        self.modelScalars = StandardItemModelScalars(self, self.mdl, zone_name)
-        self.table.horizontalHeader().setResizeMode(QHeaderView.Stretch)
-#        self.table.setEditTriggers(QAbstractItemView.DoubleClicked)
+        # tableView
+        self.modelScalars = StandardItemModelScalars(self, self.mdl)
+        self.modelVariance = StandardItemModelVariance(self, self.mdl)
+        self.tableScalars.horizontalHeader().setResizeMode(QHeaderView.Stretch)
+        self.tableVariance.horizontalHeader().setResizeMode(QHeaderView.Stretch)
 
         # Delegates
-        delegateLabel        = LabelDelegate(self.table)
-        delegateInitialValue = InitialValueDelegate(self.table)
-        delegateVariance     = VarianceDelegate(self.table)
-        delegateMinimum      = MinimumDelegate(self.table)
-        delegateMaximum      = MaximumDelegate(self.table)
+        delegateLabel        = LabelDelegate(self.tableScalars)
+        delegateVarianceName = VarianceNameDelegate(self.tableVariance)
+        delegateVariance     = VarianceDelegate(self.tableVariance)
 
-        self.table.setItemDelegateForColumn(0, delegateLabel)
-        self.table.setItemDelegateForColumn(1, delegateInitialValue)
-        self.table.setItemDelegateForColumn(2, delegateVariance)
-        self.table.setItemDelegateForColumn(3, delegateMinimum)
-        self.table.setItemDelegateForColumn(4, delegateMaximum)
+        self.tableScalars.setItemDelegateForColumn(0, delegateLabel)
+        self.tableVariance.setItemDelegateForColumn(0, delegateVarianceName)
+        self.tableVariance.setItemDelegateForColumn(1, delegateVariance)
 
         # Connections
-        self.connect(self.comboBoxZone,     SIGNAL("activated(const QString&)"), self.slotZone)
-        self.connect(self.pushButtonNew,    SIGNAL("clicked()"), self.slotAddScalar)
-        self.connect(self.pushButtonDelete, SIGNAL("clicked()"), self.slotDeleteScalar)
-        self.connect(self.modelScalars,     SIGNAL("dataChanged(const QModelIndex &, const QModelIndex &)"), self.dataChanged)
+        self.connect(self.pushButtonNew,       SIGNAL("clicked()"), self.slotAddScalar)
+        self.connect(self.pushButtonDelete,    SIGNAL("clicked()"), self.slotDeleteScalar)
+        self.connect(self.modelScalars,        SIGNAL("dataChanged(const QModelIndex &, const QModelIndex &)"), self.dataChanged)
+        self.connect(self.pushButtonVarNew,    SIGNAL("clicked()"), self.slotAddVariance)
+        self.connect(self.pushButtonVarDelete, SIGNAL("clicked()"), self.slotDeleteVariance)
+        self.connect(self.modelVariance,       SIGNAL("dataChanged(const QModelIndex &, const QModelIndex &)"), self.dataChanged)
 
         # widget initialization
-        self.slotZone(zone_label)
+        self.tableScalars.reset()
+        self.modelScalars = StandardItemModelScalars(self, self.mdl)
+        self.tableScalars.setModel(self.modelScalars)
 
+        self.tableVariance.reset()
+        self.modelVariance = StandardItemModelVariance(self, self.mdl)
+        self.tableVariance.setModel(self.modelVariance)
 
-    @pyqtSignature("const QString &")
-    def slotZone(self, text):
-        """
-        Get label of volume zone for initialization
-        """
-        log.debug("slotZone-> text = %s" % text)
-        zone_name = self.modelZone.dicoV2M[str(text)]
-        log.debug("slotZone-> name = %s" % zone_name)
-
-        self.table.reset()
-        self.modelScalars = StandardItemModelScalars(self, self.mdl, zone_name)
-        self.table.setModel(self.modelScalars)
-
-        for label in self.mdl.getScalarLabelsList():
+        l1 = self.mdl.getScalarLabelsList()
+        for s in self.mdl.getScalarsVarianceList():
+            if s in l1: l1.remove(s)
+        for label in l1:
             self.modelScalars.newItem(label)
+        for label in self.mdl.getScalarsVarianceList():
+            self.modelVariance.newItem(label)
 
 
     @pyqtSignature("")
@@ -566,7 +518,7 @@ class DefineUserScalarsView(QWidget, Ui_DefineUserScalarsForm):
         """
         Add a new item in the table when the 'Create' button is pushed.
         """
-        self.table.clearSelection()
+        self.tableScalars.clearSelection()
         self.modelScalars.newItem()
 
 
@@ -577,7 +529,7 @@ class DefineUserScalarsView(QWidget, Ui_DefineUserScalarsForm):
         of course from the XML file.
         """
         list = []
-        for index in self.table.selectionModel().selectedRows():
+        for index in self.tableScalars.selectionModel().selectedRows():
             row = index.row()
             list.append(row)
 
@@ -585,14 +537,56 @@ class DefineUserScalarsView(QWidget, Ui_DefineUserScalarsForm):
         list.reverse()
 
         for row in list:
-            label, init, vari, mini, maxi = self.modelScalars.getItem(row)
+            label = self.modelScalars.getItem(row)
             if self.mdl.getScalarType(label) == 'user':
                 self.mdl.deleteScalar(label)
-#                self.modelScalars.deleteItem(row)
+                self.modelScalars.deleteItem(row)
+            row_var = self.modelVariance.rowCount()
+            del_var = []
+            for r in range(row_var):
+                if label == self.modelVariance.getItem(r)[1]:
+                    del_var.append(self.modelVariance.getItem(r)[0])
+            for var in del_var:
+                tot_row = self.modelVariance.rowCount()
+                del_stat = 0
+                for rr in range(tot_row):
+                    if del_stat == 0:
+                        if var == self.modelVariance.getItem(rr)[0]:
+                            del_stat=1
+                            self.modelVariance.deleteItem(rr)
 
-        self.table.clearSelection()
-        txt = str(self.comboBoxZone.currentText())
-        self.slotZone(txt)
+        self.tableScalars.clearSelection()
+
+
+    @pyqtSignature("")
+    def slotAddVariance(self):
+        """
+        Add a new item in the table when the 'Create' button is pushed.
+        """
+        self.tableVariance.clearSelection()
+        self.modelVariance.newItem()
+
+
+    @pyqtSignature("")
+    def slotDeleteVariance(self):
+        """
+        Just delete the current selected entries from the table and
+        of course from the XML file.
+        """
+        list = []
+        for index in self.tableVariance.selectionModel().selectedRows():
+            row = index.row()
+            list.append(row)
+
+        list.sort()
+        list.reverse()
+
+        for row in list:
+            label = self.modelVariance.getItem(row)[0]
+            self.mdl.deleteScalar(label)
+            self.modelVariance.deleteItem(row)
+
+        self.tableVariance.clearSelection()
 
 
     @pyqtSignature("const QModelIndex &, const QModelIndex &")
