@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2011 EDF S.A.
+# Copyright (C) 1998-2012 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -53,7 +53,7 @@ from Pages.FluidCharacteristicsForm import Ui_FluidCharacteristicsForm
 from Pages.FluidCharacteristicsModel import FluidCharacteristicsModel
 from Pages.DefineUserScalarsModel import DefineUserScalarsModel
 from Pages.ReferenceValuesModel import ReferenceValuesModel
-
+from Pages.CompressibleModel import CompressibleModel
 from Pages.QMeiEditorView import QMeiEditorView
 
 #-------------------------------------------------------------------------------
@@ -118,6 +118,8 @@ mu = -999.0;
 Cp1 = 520.3;
 Cp2 = 1040.0;
 cp = Y1 * Cp1 + Y2 *Cp2;
+"""
+    volumic_viscosity="""# volumic_viscosity
 """
     thermal_conductivity="""# oxygen
 lambda = 6.2e-5 * Temp_K + 8.1e-3;
@@ -141,70 +143,154 @@ lambda = 4.431e-4 * Temp_K + 5.334e-2;
         self.case = case
         self.mdl = FluidCharacteristicsModel(self.case)
 
-        list = [('density', 'Rho'),
-                ('molecular_viscosity', 'Mu'),
-                ('specific_heat', 'Cp'),
-                ('thermal_conductivity', 'Al')]
+        if CompressibleModel(self.case).getCompressibleModel() != 'off':
+            list = [('density', 'Rho'),
+                    ('molecular_viscosity', 'Mu'),
+                    ('specific_heat', 'Cp'),
+                    ('volumic_viscosity', 'Viscv0'),
+                    ('thermal_conductivity', 'Al'),
+                    ('dynamic_diffusion', 'Diftl0')]
+        else:
+            list = [('density', 'Rho'),
+                    ('molecular_viscosity', 'Mu'),
+                    ('specific_heat', 'Cp'),
+                    ('thermal_conductivity', 'Al'),
+                    ('dynamic_diffusion', 'Diftl0')]
 
         self.list_scalars = []
-        m_sca = DefineUserScalarsModel(self.case)
-        s = m_sca.getThermalScalarLabel()
+        self.m_sca = DefineUserScalarsModel(self.case)
+        s = self.m_sca.getThermalScalarLabel()
         if s:
             self.list_scalars.append((s, self.tr("Thermal scalar")))
-        for s in m_sca.getUserScalarLabelsList():
+        for s in self.m_sca.getUserScalarLabelsList():
             self.list_scalars.append((s, self.tr("Additional scalar")))
 
+        # Particular Widget initialization taking into account of "Calculation Features"
+        mdl_atmo, mdl_joule, mdl_thermal, mdl_gas, mdl_coal = self.mdl.getThermoPhysicalModel()
+
         # Combo models
 
-        self.modelRho = ComboModel(self.comboBoxRho, 3, 1)
-        self.modelMu  = ComboModel(self.comboBoxMu, 3, 1)
-        self.modelCp  = ComboModel(self.comboBoxCp, 3, 1)
-        self.modelAl  = ComboModel(self.comboBoxAl, 3, 1)
+        self.modelRho      = ComboModel(self.comboBoxRho, 3, 1)
+        self.modelMu       = ComboModel(self.comboBoxMu, 3, 1)
+        self.modelCp       = ComboModel(self.comboBoxCp, 3, 1)
+        self.modelAl       = ComboModel(self.comboBoxAl, 3, 1)
+        self.modelDiff     = ComboModel(self.comboBoxDiff, 2, 1)
+        self.modelNameDiff = ComboModel(self.comboBoxNameDiff,1,1)
+        self.modelCv       = ComboModel(self.comboBoxCv, 3, 1)
+        self.modelViscv0   = ComboModel(self.comboBoxViscv0, 3, 1)
+        self.modelDiftl0   = ComboModel(self.comboBoxDiftl0, 3, 1)
 
         self.modelRho.addItem(self.tr('constant'), 'constant')
         self.modelRho.addItem(self.tr('user law'), 'user_law')
-        self.modelRho.addItem(self.tr('user subroutine (usphyv)'), 'variable')
+        if mdl_atmo != 'off':
+            self.modelRho.addItem(self.tr('defined in atphyv'), 'variable')
+        else:
+            self.modelRho.addItem(self.tr('user subroutine (cs_user_physical_properties)'), 'variable')
         self.modelMu.addItem(self.tr('constant'), 'constant')
         self.modelMu.addItem(self.tr('user law'), 'user_law')
-        self.modelMu.addItem(self.tr('user subroutine (usphyv)'), 'variable')
+        self.modelMu.addItem(self.tr('user subroutine (cs_user_physical_properties)'), 'variable')
         self.modelCp.addItem(self.tr('constant'), 'constant')
         self.modelCp.addItem(self.tr('user law'), 'user_law')
-        self.modelCp.addItem(self.tr('user subroutine (usphyv)'), 'variable')
+        self.modelCp.addItem(self.tr('user subroutine (cs_user_physical_properties)'), 'variable')
         self.modelAl.addItem(self.tr('constant'), 'constant')
         self.modelAl.addItem(self.tr('user law'), 'user_law')
-        self.modelAl.addItem(self.tr('user subroutine (usphyv)'), 'variable')
+        self.modelAl.addItem(self.tr('user subroutine (cs_user_physical_properties)'), 'variable')
+        self.modelDiff.addItem(self.tr('constant'), 'constant')
+        self.modelDiff.addItem(self.tr('user law'), 'user_law')
+        self.modelCv.addItem(self.tr('constant'), 'constant')
+        self.modelCv.addItem(self.tr('user law'), 'user_law')
+        self.modelCv.addItem(self.tr('user subroutine (cs_user_physical_properties)'), 'variable')
+        self.modelViscv0.addItem(self.tr('constant'), 'constant')
+        self.modelViscv0.addItem(self.tr('user law'), 'user_law')
+        self.modelViscv0.addItem(self.tr('user subroutine (cs_user_physical_properties)'), 'variable')
+        self.modelDiftl0.addItem(self.tr('constant'), 'constant')
+        self.modelDiftl0.addItem(self.tr('user law'), 'user_law')
+        self.modelDiftl0.addItem(self.tr('user subroutine (cs_user_physical_properties)'), 'variable')
+
+        self.scalar = ""
+        scalar_list = self.m_sca.getUserScalarLabelsList()
+        for s in self.m_sca.getScalarsVarianceList():
+            if s in scalar_list: scalar_list.remove(s)
+
+        if scalar_list != []:
+            self.scalar = scalar_list[0]
+            for scalar in scalar_list:
+                self.modelNameDiff.addItem(scalar)
 
         # Connections
 
-        self.connect(self.comboBoxRho, SIGNAL("activated(const QString&)"), self.slotStateRho)
-        self.connect(self.comboBoxMu, SIGNAL("activated(const QString&)"), self.slotStateMu)
-        self.connect(self.comboBoxCp, SIGNAL("activated(const QString&)"), self.slotStateCp)
-        self.connect(self.comboBoxAl, SIGNAL("activated(const QString&)"), self.slotStateAl)
-        self.connect(self.lineEditRho, SIGNAL("textChanged(const QString &)"), self.slotRho)
-        self.connect(self.lineEditMu, SIGNAL("textChanged(const QString &)"), self.slotMu)
-        self.connect(self.lineEditCp, SIGNAL("textChanged(const QString &)"), self.slotCp)
-        self.connect(self.lineEditAl, SIGNAL("textChanged(const QString &)"), self.slotAl)
-        self.connect(self.pushButtonRho, SIGNAL("clicked()"), self.slotFormulaRho)
-        self.connect(self.pushButtonMu, SIGNAL("clicked()"), self.slotFormulaMu)
-        self.connect(self.pushButtonCp, SIGNAL("clicked()"), self.slotFormulaCp)
-        self.connect(self.pushButtonAl, SIGNAL("clicked()"), self.slotFormulaAl)
+        self.connect(self.comboBoxRho,      SIGNAL("activated(const QString&)"), self.slotStateRho)
+        self.connect(self.comboBoxMu,       SIGNAL("activated(const QString&)"), self.slotStateMu)
+        self.connect(self.comboBoxCp,       SIGNAL("activated(const QString&)"), self.slotStateCp)
+        self.connect(self.comboBoxAl,       SIGNAL("activated(const QString&)"), self.slotStateAl)
+        self.connect(self.comboBoxDiff,     SIGNAL("activated(const QString&)"), self.slotStateDiff)
+        self.connect(self.comboBoxNameDiff, SIGNAL("activated(const QString&)"), self.slotNameDiff)
+        self.connect(self.comboBoxViscv0,   SIGNAL("activated(const QString&)"), self.slotStateViscv0)
+        self.connect(self.lineEditRho,      SIGNAL("textChanged(const QString &)"), self.slotRho)
+        self.connect(self.lineEditMu,       SIGNAL("textChanged(const QString &)"), self.slotMu)
+        self.connect(self.lineEditCp,       SIGNAL("textChanged(const QString &)"), self.slotCp)
+        self.connect(self.lineEditAl,       SIGNAL("textChanged(const QString &)"), self.slotAl)
+        self.connect(self.lineEditDiff,     SIGNAL("textChanged(const QString &)"), self.slotDiff)
+        self.connect(self.lineEditDiftl0,   SIGNAL("textChanged(const QString &)"), self.slotDiftl0)
+        self.connect(self.lineEditViscv0,   SIGNAL("textChanged(const QString &)"), self.slotViscv0)
+        self.connect(self.pushButtonRho,    SIGNAL("clicked()"), self.slotFormulaRho)
+        self.connect(self.pushButtonMu,     SIGNAL("clicked()"), self.slotFormulaMu)
+        self.connect(self.pushButtonCp,     SIGNAL("clicked()"), self.slotFormulaCp)
+        self.connect(self.pushButtonAl,     SIGNAL("clicked()"), self.slotFormulaAl)
+        self.connect(self.pushButtonDiff,   SIGNAL("clicked()"), self.slotFormulaDiff)
+        self.connect(self.pushButtonViscv0, SIGNAL("clicked()"), self.slotFormulaViscv0)
 
         # Validators
 
-        validatorRho = DoubleValidator(self.lineEditRho, min = 0.0)
-        validatorMu = DoubleValidator(self.lineEditMu, min = 0.0)
-        validatorCp = DoubleValidator(self.lineEditCp, min = 0.0)
-        validatorAl = DoubleValidator(self.lineEditAl, min = 0.0)
+        validatorRho    = DoubleValidator(self.lineEditRho, min = 0.0)
+        validatorMu     = DoubleValidator(self.lineEditMu, min = 0.0)
+        validatorCp     = DoubleValidator(self.lineEditCp, min = 0.0)
+        validatorAl     = DoubleValidator(self.lineEditAl, min = 0.0)
+        validatorDiff   = DoubleValidator(self.lineEditDiff, min = 0.0)
+        validatorCv     = DoubleValidator(self.lineEditCv, min = 0.0)
+        validatorViscv0 = DoubleValidator(self.lineEditViscv0, min = 0.0)
+        validatorDiftl0 = DoubleValidator(self.lineEditDiftl0, min = 0.0)
 
         validatorRho.setExclusiveMin(True)
         validatorMu.setExclusiveMin(True)
         validatorCp.setExclusiveMin(True)
         validatorAl.setExclusiveMin(True)
+        validatorDiff.setExclusiveMin(True)
+        validatorCv.setExclusiveMin(True)
+        validatorDiftl0.setExclusiveMin(True)
 
         self.lineEditRho.setValidator(validatorRho)
         self.lineEditMu.setValidator(validatorMu)
         self.lineEditCp.setValidator(validatorCp)
         self.lineEditAl.setValidator(validatorAl)
+        self.lineEditDiff.setValidator(validatorDiff)
+        self.lineEditCv.setValidator(validatorCv)
+        self.lineEditViscv0.setValidator(validatorViscv0)
+        self.lineEditDiftl0.setValidator(validatorDiftl0)
+
+        if scalar_list == []:
+            self.groupBoxDiff.hide()
+        else :
+            self.groupBoxDiff.show()
+            self.lineEditDiff.setText(QString(str(self.m_sca.getScalarDiffusivityInitialValue(self.scalar))))
+            diff_choice =  self.m_sca.getScalarDiffusivityChoice(self.scalar)
+            self.modelDiff.setItem(str_model=diff_choice)
+            self.modelNameDiff.setItem(str_model=str(self.scalar))
+            if diff_choice  != 'user_law':
+                self.pushButtonDiff.setEnabled(False)
+                setGreenColor(self.pushButtonDiff, False)
+            else:
+                self.pushButtonDiff.setEnabled(True)
+                setGreenColor(self.pushButtonDiff, True)
+
+        self.labelCv.setText(QString(self.tr("Deduce from the \nisobaric specific heat")))
+
+        #compressible
+        self.groupBoxCv.hide()
+        self.groupBoxViscv0.hide()
+
+        # combustion
+        self.groupBoxDiftl0.hide()
 
         # Standard Widget initialization
 
@@ -213,25 +299,28 @@ lambda = 4.431e-4 * Temp_K + 5.334e-2;
             __line   = getattr(self, "lineEdit" + symbol)
             __button = getattr(self, "pushButton" + symbol)
             __label  = getattr(self, "label" + symbol)
-            c = self.mdl.getPropertyMode(tag)
-            __model.setItem(str_model=c)
-            if c == 'user_law':
-                __button.setEnabled(True)
-                __label.setText(QString(self.tr("Reference value")))
+            if tag != 'dynamic_diffusion':
+                c = self.mdl.getPropertyMode(tag)
+                __model.setItem(str_model=c)
+                if c == 'user_law':
+                    __button.setEnabled(True)
+                    __label.setText(QString(self.tr("Reference value")))
+                else:
+                    __button.setEnabled(False)
+                    __label.setText(QString(self.tr("Reference value")))
             else:
-                __button.setEnabled(False)
+
                 __label.setText(QString(self.tr("Reference value")))
             self.mdl.getInitialValue(tag)
             __line.setText(QString(str(self.mdl.getInitialValue(tag))))
 
-        # Particular Widget initialization taking into account of "Calculation Features"
-
-        mdl_atmo, mdl_joule, mdl_thermal, mdl_gas, mdl_coal = self.mdl.getThermoPhysicalModel()
-
         # no 'thermal_conductivity' if not Joule and not Thermal scalar and not
         if mdl_joule == 'off' and mdl_thermal == 'off' and mdl_atmo == 'off':
             self.groupBoxAl.hide()
 
+        if mdl_gas != 'off' or mdl_coal != 'off':
+            self.groupBoxDiftl0.show()
+
         for tag, symbol in list:
             __model  = getattr(self, "model" + symbol)
             __line   = getattr(self, "lineEdit" + symbol)
@@ -249,6 +338,10 @@ lambda = 4.431e-4 * Temp_K + 5.334e-2;
                     __label.setText(QString(self.tr("Calculation by\n perfect gas law")))
                     __line.setText(QString(str("")))
                     __line.setEnabled(False)
+                elif tag == 'dynamic_diffusion':
+                    __model.setItem(str_model='user_law')
+                    __combo.setEnabled(False)
+                    __button.setEnabled(False)
                 else:
                     __model.setItem(str_model='constant')
                     self.mdl.setPropertyMode(tag, 'constant')
@@ -263,6 +356,39 @@ lambda = 4.431e-4 * Temp_K + 5.334e-2;
             if mdl_atmo != 'off':
                 if tag == 'density':
                     __model.disableItem(str_model='constant')
+                    __model.disableItem(str_model='user_law')
+                    __model.disableItem(str_model='variable')
+                    __model.setItem(str_model='variable')
+                    __combo.setEnabled(False)
+                    __button.setEnabled(False)
+
+            # Compressible Flows
+            if CompressibleModel(self.case).getCompressibleModel() != 'off':
+                if tag == 'density':
+                    __model.setItem(str_model='variable')
+                    __combo.setEnabled(False)
+                    __button.setEnabled(False)
+                    self.mdl.setPropertyMode(tag, 'variable')
+                    __line.setText(QString(str("")))
+                    __line.setEnabled(False)
+                self.groupBoxCv.hide()
+                self.groupBoxViscv0.hide()
+                if tag == 'specific_heat':
+                    __model.setItem(str_model='constant')
+                    __combo.setEnabled(False)
+                    __button.setEnabled(False)
+                    self.mdl.setPropertyMode(tag, 'constant')
+                    self.groupBoxCp.setTitle(QString('Isobaric specific heat'))
+                if tag == 'volumic_viscosity':
+                    __model.setItem(str_model='constant')
+                    __combo.setEnabled(False)
+                    __button.setEnabled(False)
+                    self.mdl.setPropertyMode(tag, 'constant')
+                self.groupBoxCv.show()
+                self.groupBoxViscv0.show()
+            else:
+                if tag == 'specific_heat':
+                    self.groupBoxCp.setTitle(QString('Specific heat'))
 
 
     @pyqtSignature("const QString &")
@@ -289,6 +415,14 @@ lambda = 4.431e-4 * Temp_K + 5.334e-2;
         self.__changeChoice(str(text), 'Cp', 'specific_heat')
 
 
+    @pyqtSignature("const QString &")
+    def slotStateViscv0(self, text):
+        """
+        Method to call 'getState' with correct arguements for 'Viscv0'
+        """
+        self.__changeChoice(str(text), 'Viscv0', 'volumic_viscosity')
+
+
     @pyqtSignature("const QString &")
     def slotStateAl(self, text):
         """
@@ -297,6 +431,36 @@ lambda = 4.431e-4 * Temp_K + 5.334e-2;
         self.__changeChoice(str(text), 'Al', 'thermal_conductivity')
 
 
+    @pyqtSignature("const QString &")
+    def slotStateDiff(self, text):
+        """
+        Method to set diffusion choice for the coefficient
+        """
+        choice = self.modelDiff.dicoV2M[str(text)]
+        log.debug("slotStateDiff -> %s" % (text))
+
+        if choice != 'user_law':
+            self.pushButtonDiff.setEnabled(False)
+            setGreenColor(self.pushButtonDiff, False)
+        else:
+            self.pushButtonDiff.setEnabled(True)
+            setGreenColor(self.pushButtonDiff, True)
+
+        self.m_sca.setScalarDiffusivityChoice(self.scalar, choice)
+
+
+    @pyqtSignature("const QString &")
+    def slotNameDiff(self, text):
+        """
+        Method to set the variance scalar choosed
+        """
+        choice = self.modelNameDiff.dicoV2M[str(text)]
+        log.debug("slotStateDiff -> %s" % (text))
+        self.scalar = str(text)
+        self.lineEditDiff.setText(QString(str(self.m_sca.getScalarDiffusivityInitialValue(self.scalar))))
+        self.modelDiff.setItem(str_model=self.m_sca.getScalarDiffusivityChoice(self.scalar))
+
+
     def __changeChoice(self, text, sym, tag):
         """
         Input variable state
@@ -350,6 +514,16 @@ lambda = 4.431e-4 * Temp_K + 5.334e-2;
             self.mdl.setInitialValueHeat(cp)
 
 
+    @pyqtSignature("const QString &")
+    def slotViscv0(self, text):
+        """
+        Update the volumic viscosity
+        """
+        viscv0, ok = self.lineEditViscv0.text().toDouble()
+        if self.sender().validator().state == QValidator.Acceptable:
+            self.mdl.setInitialValueVolumicViscosity(viscv0)
+
+
     @pyqtSignature("const QString &")
     def slotAl(self, text):
         """
@@ -360,14 +534,32 @@ lambda = 4.431e-4 * Temp_K + 5.334e-2;
             self.mdl.setInitialValueCond(al)
 
 
+    @pyqtSignature("const QString &")
+    def slotDiftl0(self, text):
+        """
+        Update the thermal conductivity
+        """
+        diftl0, ok = text.toDouble()
+        if self.sender().validator().state == QValidator.Acceptable:
+            self.mdl.setInitialValueDyn(diftl0)
+
+
+    @pyqtSignature("const QString &")
+    def slotDiff(self, text):
+        """
+        Update the thermal conductivity
+        """
+        diff, ok = text.toDouble()
+        if self.sender().validator().state == QValidator.Acceptable:
+            self.m_sca.setScalarDiffusivityInitialValue(self.scalar, diff)
+
+
     @pyqtSignature("")
     def slotFormulaRho(self):
         """
         User formula for density
         """
         exp = self.mdl.getFormula('density')
-        if not exp:
-            exp = "rho ="
         req = [('rho', 'Density')]
         exa = FluidCharacteristicsView.density
         setGreenColor(self.sender(), False)
@@ -397,8 +589,6 @@ lambda = 4.431e-4 * Temp_K + 5.334e-2;
         User formula for molecular viscosity
         """
         exp = self.mdl.getFormula('molecular_viscosity')
-        if not exp:
-            exp = "mu ="
         req = [('mu', 'Molecular Viscosity')]
         exa = FluidCharacteristicsView.molecular_viscosity
 
@@ -412,6 +602,10 @@ lambda = 4.431e-4 * Temp_K + 5.334e-2;
         symbols_mu.append(('rho0', 'Density (reference value) = ' + str(rho0_value)))
         symbols_mu.append(('p0', 'Reference pressure = ' + str(ref_pressure)))
         symbols_mu.append(('rho', 'Density'))
+        if CompressibleModel(self.case).getCompressibleModel() == 'on':
+            symbols_mu.append(('T', 'Temperature'))
+            ref_temperature = ReferenceValuesModel(self.case).getTemperature()
+            symbols_mu.append(('t0', 'Reference temperature = '+str(ref_temperature)+' K'))
 
         dialog = QMeiEditorView(self,expression = exp,
                                      required   = req,
@@ -430,8 +624,6 @@ lambda = 4.431e-4 * Temp_K + 5.334e-2;
         User formula for specific heat
         """
         exp = self.mdl.getFormula('specific_heat')
-        if not exp:
-            exp = "cp ="
         req = [('cp', 'Specific heat')]
         exa = FluidCharacteristicsView.specific_heat
 
@@ -454,14 +646,41 @@ lambda = 4.431e-4 * Temp_K + 5.334e-2;
             setGreenColor(self.sender(), False)
 
 
+    @pyqtSignature("")
+    def slotFormulaViscv0(self):
+        """
+        User formula for volumic viscosity
+        """
+        exp = self.mdl.getFormula('volumic_viscosity')
+        req = [('Viscv', 'Volumic viscosity')]
+        exa = FluidCharacteristicsView.volumic_viscosity
+        symbols_viscv0 = []
+        for s in self.list_scalars:
+           symbols_cp.append(s)
+        viscv0_value = self.mdl.getInitialValueVolumicViscosity()
+        ref_pressure = ReferenceValuesModel(self.case).getPressure()
+        ref_temperature = ReferenceValuesModel(self.case).getTemperature()
+        symbols_viscv0.append(('viscv0', 'Volumic viscosity (reference value) = '+str(viscv0_value)+' J/kg/K'))
+        symbols_viscv0.append(('p0', 'Reference pressure = '+str(ref_pressure)+' Pa'))
+        symbols_viscv0.append(('t0', 'Reference temperature = '+str(ref_temperature)+' K'))
+        symbols_viscv0.append(('T', 'Temperature'))
+        dialog = QMeiEditorView(self,expression = exp,
+                                     required   = req,
+                                     symbols    = symbols_viscv0,
+                                     examples   = exa)
+        if dialog.exec_():
+            result = dialog.get_result()
+            log.debug("slotFormulaViscv0 -> %s" % str(result))
+            self.mdl.setFormula('volumic_viscosity', result)
+            setGreenColor(self.sender(), False)
+
+
     @pyqtSignature("")
     def slotFormulaAl(self):
         """
         User formula for thermal conductivity
         """
         exp = self.mdl.getFormula('thermal_conductivity')
-        if not exp:
-            exp = "lambda ="
         req = [('lambda', 'Thermal conductivity')]
         exa = FluidCharacteristicsView.thermal_conductivity
 
@@ -479,11 +698,37 @@ lambda = 4.431e-4 * Temp_K + 5.334e-2;
                                      examples   = exa)
         if dialog.exec_():
             result = dialog.get_result()
-            log.debug("slotFormulaRho -> %s" % str(result))
+            log.debug("slotFormulaAl -> %s" % str(result))
             self.mdl.setFormula('thermal_conductivity', result)
             setGreenColor(self.sender(), False)
 
 
+    @pyqtSignature("")
+    def slotFormulaDiff(self):
+        """
+        User formula for the diffusion coefficient
+        """
+        name = self.m_sca.getScalarDiffusivityName(self.scalar)
+        exp = self.m_sca.getDiffFormula(self.scalar)
+        req = [(str(name), str(self.scalar)+'diffusion coefficient')]
+        exa = ''
+        sym = [('x','cell center coordinate'),
+               ('y','cell center coordinate'),
+               ('z','cell center coordinate'),]
+        sym.append((str(self.scalar),str(self.scalar)))
+        diff0_value = self.m_sca.getScalarDiffusivityInitialValue(self.scalar)
+        sym.append((str(name)+'_ref', str(self.scalar)+' diffusion coefficient (reference value) = '+str(diff0_value)+' m^2/s'))
+        dialog = QMeiEditorView(self,expression = exp,
+                                     required   = req,
+                                     symbols    = sym,
+                                     examples   = exa)
+        if dialog.exec_():
+            result = dialog.get_result()
+            log.debug("slotFormulaDiff -> %s" % str(result))
+            self.m_sca.setDiffFormula(self.scalar, result)
+            setGreenColor(self.pushButtonDiff, False)
+
+
     def tr(self, text):
         """
         Translation
