@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2011 EDF S.A.
+# Copyright (C) 1998-2012 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -121,7 +121,7 @@ class LagrangianBoundariesModel(Model):
         elif nature == "symmetry":
             self.isInList(value, ["bounce"])
         elif nature == "wall":
-            l = [ "inlet", "bounce", "deposit1", "deposit2", "deposit3", "depositfa"]
+            l = [ "inlet", "bounce", "deposit1", "deposit2"]
             #if iscoal: l.append("encra")
             self.isInList(value, l)
         self.node_boundary = self.node_boundaries.xmlInitChildNode(nature, label=labelbc)
@@ -686,7 +686,7 @@ class LagrangianBoundariesTestCase(unittest.TestCase):
         from Base.XMLengine import Case
         from Base.XMLinitialize import XMLinit
         self.case = Case()
-        XMLinit(self.case)
+        XMLinit(self.case).initialize()
 
 
     def tearDown(self):
