@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2011 EDF S.A.
+# Copyright (C) 1998-2012 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -44,7 +44,6 @@ from Base.Common import *
 import Base.Toolbox as Tool
 from Base.XMLvariables import Model
 from Base.XMLmodel import ModelTest
-import Pages.CoalThermoChemistry as CoalThermoChemistry
 
 #-------------------------------------------------------------------------------
 # log config
@@ -83,7 +82,7 @@ class LagrangianModel(Model):
         default['coupling_mode'] = "one_way"
         default['restart'] = "off"
         default['carrier_field_stationary'] = "off"
-        default['particles_max_number'] = 10000
+        default['particles_max_number'] = 1000000
         default['continuous_injection'] = "off"
         default['particles_models'] = "off"
         default['thermal'] = "off"
@@ -120,8 +119,10 @@ class LagrangianModel(Model):
                          'k-epsilon-PL',
                          'Rij-epsilon',
                          'Rij-SSG',
+                         'Rij-EBRSM',
                          'v2f-phi',
-                         'k-omega-SST'):
+                         'k-omega-SST',
+                         'Spalart-Allmaras'):
             return ('off',)
         else:
             return self.__lagrangianStatus
@@ -321,28 +322,6 @@ class LagrangianModel(Model):
         return self.__nodeParticlesModel()['model']
 
 
-    def setBreakUp(self, status):
-        """
-        Update the status for activation of evolution equation on the particle diameter.
-        """
-        self.isOnOff(status)
-        node_model = self.__nodeParticlesModel()
-        node_diameter = node_model.xmlInitChildNode('break_up', 'status')
-        node_diameter['status'] = status
-
-
-    def getBreakUp(self):
-        """
-        Return status for the activation of an evolution equation on the particle diameter.
-        """
-        node_model = self.__nodeParticlesModel()
-        node_diameter = node_model.xmlInitChildNode('break_up', 'status')
-        status = node_diameter['status']
-        if not status:
-            status = self.defaultParticlesValues()['break_up']
-            self.setBreakUp(status)
-        return status
-
 
     def setHeating(self, status):
         """
@@ -452,9 +431,8 @@ class LagrangianModel(Model):
         node_coal = node_model.xmlInitChildNode('coal_fouling', 'status')
         node_coal['status'] = status
         if status == "on":
-            self.coalThermoChModel = CoalThermoChemistry.CoalThermoChemistryModel("dp_FCP", self.case)
-            coals = self.coalThermoChModel.getCoals()
-            for icoal in range(coals.getNumber()):
+            self.coalCombustionModel = CoalCombustionModel(self.case)
+            for icoal in range(self.coalCombustionModel.getCoalNumber()):
                 self.getThresholdTemperatureOfFouling(icoal+1)
                 self.getCriticalViscosityOfFouling(icoal+1)
                 self.getCoef1OfFouling(icoal+1)
