@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2011 EDF S.A.
+# Copyright (C) 1998-2012 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -534,7 +534,7 @@ class LagrangianOutputTestCase(unittest.TestCase):
         from Base.XMLengine import Case
         from Base.XMLinitialize import XMLinit
         self.case = Case()
-        XMLinit(self.case)
+        XMLinit(self.case).initialize()
 
 
     def tearDown(self):
