@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2011 EDF S.A.
+# Copyright (C) 1998-2012 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -276,10 +276,9 @@ class StandardItemModelCoals(QStandardItemModel):
         self.case = case
         self.model = model
 
-        import Pages.CoalThermoChemistry as CoalThermoChemistry
-        self.coalThermoChModel = CoalThermoChemistry.CoalThermoChemistryModel("dp_FCP", self.case)
-        coals = self.coalThermoChModel.getCoals()
-        CoalsNumber = coals.getNumber()
+        import Pages.CoalCombustionModel as CoalCombustionModel
+        self.coalModel = CoalCombustionModel.CoalCombustionModel(self.case)
+        CoalsNumber = self.coalModel.getCoalNumber()
 
         for icoal in range(CoalsNumber):
             line = []
@@ -362,14 +361,14 @@ class LagrangianView(QWidget, Ui_LagrangianForm):
 
         # Combo model
         self.modelIILAGR = ComboModel(self.comboBoxIILAGR,3,1)
-        self.modelIILAGR.addItem(self.tr("One way coupling"), "one_way")
-        self.modelIILAGR.addItem(self.tr("Two way coupling"), "two_way")
+        self.modelIILAGR.addItem(self.tr("One-way coupling"), "one_way")
+        self.modelIILAGR.addItem(self.tr("Two-way coupling"), "two_way")
         self.modelIILAGR.addItem(self.tr("Frozen carrier flow"), "frozen")
 
-        self.modelIPHYLA = ComboModel(self.comboBoxIPHYLA,3,1)
+        self.modelIPHYLA = ComboModel(self.comboBoxIPHYLA,2,1)
         self.modelIPHYLA.addItem(self.tr("No model"), 'off')
-        self.modelIPHYLA.addItem(self.tr("Heating, break-up and evaporation"), 'thermal')
-        self.modelIPHYLA.addItem(self.tr("Pulverised coal model"), 'coal')
+        self.modelIPHYLA.addItem(self.tr("Heat transfer and evaporation"), 'thermal')
+        # self.modelIPHYLA.addItem(self.tr("Pulverised coal model"), 'coal')
 
         # Connections
         self.connect(self.comboBoxIILAGR, SIGNAL("activated(const QString&)"), self.slotIILAGR)
@@ -378,7 +377,6 @@ class LagrangianView(QWidget, Ui_LagrangianForm):
         self.connect(self.lineEditNBPMAX, SIGNAL("textChanged(const QString &)"), self.slotNBPMAX)
         self.connect(self.checkBoxINJCON, SIGNAL("clicked()"), self.slotINJCON)
         self.connect(self.comboBoxIPHYLA, SIGNAL("activated(const QString&)"), self.slotIPHYLA)
-        self.connect(self.checkBoxIDPVAR, SIGNAL("clicked()"), self.slotIDPVAR)
         self.connect(self.checkBoxITPVAR, SIGNAL("clicked()"), self.slotITPVAR)
         #self.connect(self.lineEditTPPART, SIGNAL("textChanged(const QString &)"), self.slotTPPART)
         #self.connect(self.lineEditCPPART, SIGNAL("textChanged(const QString &)"), self.slotCPPART)
@@ -459,6 +457,9 @@ class LagrangianView(QWidget, Ui_LagrangianForm):
         self.modelIPHYLA.setItem(str_model=part_model)
         self.slotIPHYLA(self.modelIPHYLA.dicoM2V[part_model])
 
+        # Disabling the coal model model waiting for validation
+        #self.modelIPHYLA.disableItem(str_model="coal")
+
 
     @pyqtSignature("const QString&")
     def slotIILAGR(self, text):
@@ -568,12 +569,6 @@ class LagrangianView(QWidget, Ui_LagrangianForm):
 
             self.frameModel1.show()
 
-            status = self.model.getBreakUp()
-            if status == "on":
-                self.checkBoxIDPVAR.setChecked(True)
-            else:
-                self.checkBoxIDPVAR.setChecked(False)
-
             status = self.model.getHeating()
             if status == "on":
                 self.checkBoxITPVAR.setChecked(True)
@@ -608,17 +603,6 @@ class LagrangianView(QWidget, Ui_LagrangianForm):
             self.slotIENCRA()
 
 
-    @pyqtSignature("")
-    def slotIDPVAR(self):
-        """
-        Input IDPVAR.
-        """
-        if self.checkBoxIDPVAR.isChecked():
-            self.model.setBreakUp("on")
-        else:
-            self.model.setBreakUp("off")
-
-
     @pyqtSignature("")
     def slotITPVAR(self):
         """
