@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2011 EDF S.A.
+# Copyright (C) 1998-2012 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -99,6 +99,48 @@ class SchemeOrderDelegate(QItemDelegate):
             if idx.column() == index.column():
                 model.setData(idx, QVariant(value))
 
+#-------------------------------------------------------------------------------
+# Combo box delegate for IRESOL
+#-------------------------------------------------------------------------------
+
+class SolverChoiceDelegate(QItemDelegate):
+    """
+    Use of a combo box in the table.
+    """
+    def __init__(self, parent=None, xml_model=None):
+        super(SolverChoiceDelegate, self).__init__(parent)
+        self.parent = parent
+        self.mdl = xml_model
+
+
+    def createEditor(self, parent, option, index):
+        editor = QComboBox(parent)
+        editor.addItem(QString("Conjugate gradient"))
+        editor.addItem(QString("Jacobi"))
+        editor.addItem(QString("BI-CGSTAB"))
+        editor.addItem(QString("GMRES"))
+        editor.addItem(QString("Multigrid"))
+        editor.installEventFilter(self)
+        if index.row() > 0:
+            editor.removeItem(4)
+        return editor
+
+
+    def setEditorData(self, comboBox, index):
+        dico = {"conjugate_gradient": 0, "jacobi": 1, "bi_cgstab": 2, "gmres": 3, "multigrid":4}
+        row = index.row()
+        string = index.model().dataSolver[row]['iresol']
+        idx = dico[string]
+        comboBox.setCurrentIndex(idx)
+
+
+    def setModelData(self, comboBox, model, index):
+        value = comboBox.currentText()
+        selectionModel = self.parent.selectionModel()
+        for idx in selectionModel.selectedIndexes():
+            if idx.column() == index.column():
+                model.setData(idx, QVariant(value))
+
 #-------------------------------------------------------------------------------
 # Line edit delegate for BLENCV
 #-------------------------------------------------------------------------------
@@ -135,22 +177,53 @@ class BlendingFactorDelegate(QItemDelegate):
                 if idx.column() == index.column():
                     model.setData(idx, QVariant(value))
 
+#-------------------------------------------------------------------------------
+# Line edit delegate for nswrsm
+#-------------------------------------------------------------------------------
+
+class RhsReconstructionDelegate(QItemDelegate):
+    def __init__(self, parent=None, xml_model=None):
+        super(RhsReconstructionDelegate, self).__init__(parent)
+        self.parent = parent
+        self.turb = xml_model
+
+
+    def createEditor(self, parent, option, index):
+        editor = QLineEdit(parent)
+        validator = QtPage.IntValidator(editor, min=1)
+        editor.setValidator(validator)
+        return editor
+
+
+    def setEditorData(self, editor, index):
+        value = index.model().data(index, Qt.DisplayRole).toString()
+        editor.setText(value)
+
+
+    def setModelData(self, editor, model, index):
+        value, ok = editor.text().toDouble()
+        if editor.validator().state == QValidator.Acceptable:
+            selectionModel = self.parent.selectionModel()
+            for idx in selectionModel.selectedIndexes():
+                if idx.column() == index.column():
+                    model.setData(idx, QVariant(value))
+
 #-------------------------------------------------------------------------------
 # Delegate for Solver QTableView
 #-------------------------------------------------------------------------------
 
-class SolveurDelegate(QItemDelegate):
+class SolverDelegate(QItemDelegate):
     def __init__(self, parent = None):
-        super(SolveurDelegate, self).__init__(parent)
+        super(SolverDelegate, self).__init__(parent)
         self.parent = parent
 
 
     def createEditor(self, parent, option, index):
         editor = QLineEdit(parent)
-        if index.column() == 2:
+        if index.column() == 3:
             validator = QtPage.DoubleValidator(editor, min=0., max=0.01)
             validator.setExclusiveMin(True)
-        else:
+        elif (index.column() == 2 or index.column() == 4):
             validator = QtPage.IntValidator(editor, min=1)
         editor.setValidator(validator)
         editor.installEventFilter(self)
@@ -163,9 +236,9 @@ class SolveurDelegate(QItemDelegate):
 
 
     def setModelData(self, editor, model, index):
-        if index.column() == 2:
+        if index.column() == 3:
             value, ok = editor.text().toDouble()
-        else:
+        elif (index.column() == 2 or index.column() == 4):
             value, ok = editor.text().toInt()
         if editor.validator().state == QValidator.Acceptable:
             selectionModel = self.parent.selectionModel()
@@ -192,13 +265,14 @@ class StandardItemModelScheme(QStandardItemModel):
                         self.tr("Scheme"),
                         self.tr("Blending\nFactor"),
                         self.tr("Slope\nTest"),
-                        self.tr("Flux\nReconstruction")]
+                        self.tr("Flux\nReconstruction"),
+                        self.tr("RHS Sweep\nReconstruction")]
         self.setColumnCount(len(self.headers))
 
         # Initialize the flags
         for row in range(self.rowCount()):
             for column in range(self.columnCount()):
-                if column < 3:
+                if column == 1 or column == 2 or column == 5:
                     role = Qt.DisplayRole
                 else:
                     role = Qt.CheckStateRole
@@ -221,6 +295,7 @@ class StandardItemModelScheme(QStandardItemModel):
             dico['ischcv'] = self.NPE.getScheme(label)
             dico['isstpc'] = self.NPE.getSlopeTest(label)
             dico['ircflu'] = self.NPE.getFluxReconstruction(label)
+            dico['nswrsm'] = self.NPE.getRhsReconstruction(label)
             self.dataScheme.append(dico)
             log.debug("populateModel-> dataScheme = %s" % dico)
             row = self.rowCount()
@@ -243,6 +318,8 @@ class StandardItemModelScheme(QStandardItemModel):
                 return QVariant(self.tr("Code_Saturne keyword: ISSTPC"))
             elif index.column() == 4:
                 return QVariant(self.tr("Code_Saturne keyword: IRCFLU"))
+            elif index.column() == 5:
+                return QVariant(self.tr("Code_Saturne keyword: NSWRSM"))
 
         elif role == Qt.DisplayRole:
             if index.column() == 0:
@@ -251,6 +328,8 @@ class StandardItemModelScheme(QStandardItemModel):
                 return QVariant(self.dicoM2V[dico['ischcv']])
             elif index.column() == 2:
                 return QVariant(dico['blencv'])
+            elif index.column() == 5:
+                return QVariant(dico['nswrsm'])
             else:
                 return QVariant()
 
@@ -282,7 +361,7 @@ class StandardItemModelScheme(QStandardItemModel):
 
         if index.column() == 0:
             return Qt.ItemIsEnabled | Qt.ItemIsSelectable
-        elif index.column() == 1 or index.column() == 2:
+        elif index.column() == 1 or index.column() == 2 or index.column() == 5:
             return Qt.ItemIsEnabled | Qt.ItemIsSelectable | Qt.ItemIsEditable
         elif index.column() == 3 or index.column() == 4:
             return Qt.ItemIsEnabled | Qt.ItemIsSelectable | Qt.ItemIsUserCheckable
@@ -347,6 +426,11 @@ class StandardItemModelScheme(QStandardItemModel):
                 self.dataScheme[row]['ircflu'] = "on"
             self.NPE.setFluxReconstruction(label, self.dataScheme[row]['ircflu'])
 
+        # set BLENCV
+        elif index.column() == 5:
+            self.dataScheme[row]['nswrsm'], ok = value.toInt()
+            self.NPE.setRhsReconstruction(label, self.dataScheme[row]['nswrsm'])
+
         self.emit(SIGNAL("dataChanged(const QModelIndex &, const QModelIndex &)"), index, index)
         return True
 
@@ -364,7 +448,7 @@ class StandardItemModelSolver(QStandardItemModel):
         QStandardItemModel.__init__(self)
         self.NPE = NPE
         self.SM = SM
-        self.setColumnCount(4)
+        self.setColumnCount(5)
         self.dataSolver = []
         # list of items to be disabled in the view
         self.disabledItem = []
@@ -372,19 +456,24 @@ class StandardItemModelSolver(QStandardItemModel):
 
 
     def populateModel(self):
-        for label in self.NPE.getSolveurList():
+        self.dicoV2M= {"Multigrid": 'multigrid',"Conjugate gradient" : 'conjugate_gradient',
+                       "Jacobi": 'jacobi', "BI-CGSTAB": 'bi_cgstab', "GMRES": 'gmres'}
+        self.dicoM2V= {"multigrid" : 'Multigrid',"conjugate_gradient" : 'Conjugate gradient',
+                       "jacobi": 'Jacobi', "bi_cgstab": 'BI-CGSTAB', 'gmres': "GMRES"}
+        for label in self.NPE.getSolverList():
             row = self.rowCount()
             self.setRowCount(row + 1)
 
             dico           = {}
             dico['label']  = label
+            dico['iresol'] = self.NPE.getSolverChoice(label)
             dico['nitmax'] = self.NPE.getMaxIterNumber(label)
-            dico['epsilo'] = self.NPE.getSolveurPrecision(label)
+            dico['epsilo'] = self.NPE.getSolverPrecision(label)
             if self.NPE.isScalar(label):
                 dico['cdtvar'] = self.NPE.getScalarTimeStepFactor(label)
             else:
                 dico['cdtvar'] = ""
-                self.disabledItem.append((row,3))
+                self.disabledItem.append((row,4))
 
             self.dataSolver.append(dico)
             log.debug("populateModel-> dataSolver = %s" % dico)
@@ -397,10 +486,12 @@ class StandardItemModelSolver(QStandardItemModel):
 
         if role == Qt.ToolTipRole:
             if index.column() == 1:
-                return QVariant(self.tr("Code_Saturne keyword: NITMAX"))
+                return QVariant(self.tr("Code_Saturne keyword: IRESOL"))
             elif index.column() == 2:
-                return QVariant(self.tr("Code_Saturne keyword: EPSILO"))
+                return QVariant(self.tr("Code_Saturne keyword: NITMAX"))
             elif index.column() == 3:
+                return QVariant(self.tr("Code_Saturne keyword: EPSILO"))
+            elif index.column() == 4:
                 return QVariant(self.tr("Code_Saturne keyword: CDTVAR"))
 
         elif role == Qt.DisplayRole:
@@ -410,10 +501,12 @@ class StandardItemModelSolver(QStandardItemModel):
             if index.column() == 0:
                 return QVariant(dico['label'])
             elif index.column() == 1:
-                return QVariant(dico['nitmax'])
+                return QVariant(self.dicoM2V[dico['iresol']])
             elif index.column() == 2:
-                return QVariant(dico['epsilo'])
+                return QVariant(dico['nitmax'])
             elif index.column() == 3:
+                return QVariant(dico['epsilo'])
+            elif index.column() == 4:
                 return QVariant(dico['cdtvar'])
             else:
                 return QVariant()
@@ -443,10 +536,12 @@ class StandardItemModelSolver(QStandardItemModel):
             if section == 0:
                 return QVariant(self.tr("Name"))
             elif section == 1:
-                return QVariant(self.tr("Maximum\nIteration Number"))
+                return QVariant(self.tr("Solver\nChoice"))
             elif section == 2:
-                return QVariant(self.tr("Solver\nPrecision"))
+                return QVariant(self.tr("Maximum\nIteration Number"))
             elif section == 3:
+                return QVariant(self.tr("Solver\nPrecision"))
+            elif section == 4:
                 return QVariant(self.tr("Time Step\nFactor"))
             else:
                 return QVariant()
@@ -458,20 +553,217 @@ class StandardItemModelSolver(QStandardItemModel):
         label = self.dataSolver[row]['label']
 
         if index.column() == 1:
+            self.dataSolver[row]['iresol'] = self.dicoV2M[str(value.toString())]
+            self.NPE.setSolverChoice(label, self.dataSolver[row]['iresol'])
+
+        elif index.column() == 2:
             self.dataSolver[row]['nitmax'], ok = value.toInt()
             self.NPE.setMaxIterNumber(label, self.dataSolver[row]['nitmax'])
 
-        elif index.column() == 2:
-            self.dataSolver[row]['epsilo'], ok = value.toDouble()
-            self.NPE.setSolveurPrecision(label, self.dataSolver[row]['epsilo'])
-
         elif index.column() == 3:
+            self.dataSolver[row]['epsilo'], ok = value.toDouble()
+            self.NPE.setSolverPrecision(label, self.dataSolver[row]['epsilo'])
+
+        elif index.column() == 4:
             self.dataSolver[row]['cdtvar'], ok = value.toDouble()
             self.NPE.setScalarTimeStepFactor(label, self.dataSolver[row]['cdtvar'])
 
         self.emit(SIGNAL("dataChanged(const QModelIndex &, const QModelIndex &)"), index, index)
         return True
 
+#-------------------------------------------------------------------------------
+# Line edit delegate for minimum value
+#-------------------------------------------------------------------------------
+
+class MinimumDelegate(QItemDelegate):
+    def __init__(self, parent=None):
+        super(MinimumDelegate, self).__init__(parent)
+        self.parent = parent
+
+
+    def createEditor(self, parent, option, index):
+        editor = QLineEdit(parent)
+        v = QtPage.DoubleValidator(editor)
+        editor.setValidator(v)
+        return editor
+
+
+    def setEditorData(self, editor, index):
+        value = index.model().data(index, Qt.DisplayRole).toString()
+        editor.setText(value)
+
+
+    def setModelData(self, editor, model, index):
+        if not editor.isModified():
+            return
+        if editor.validator().state == QValidator.Acceptable:
+            value, ok = editor.text().toDouble()
+            for idx in self.parent.selectionModel().selectedIndexes():
+                if idx.column() == index.column():
+                    maxi = model.getData(idx)['scamax']
+                    label = model.getData(idx)['label']
+                    if model.checkMinMax(label, value, maxi):
+                        model.setData(idx, QVariant(value), Qt.DisplayRole)
+
+
+#-------------------------------------------------------------------------------
+# Line edit delegate for maximum value
+#-------------------------------------------------------------------------------
+
+class MaximumDelegate(QItemDelegate):
+    def __init__(self, parent=None):
+        super(MaximumDelegate, self).__init__(parent)
+        self.parent = parent
+
+
+    def createEditor(self, parent, option, index):
+        editor = QLineEdit(parent)
+        v = QtPage.DoubleValidator(editor)
+        editor.setValidator(v)
+        return editor
+
+
+    def setEditorData(self, editor, index):
+        value = index.model().data(index, Qt.DisplayRole).toString()
+        editor.setText(value)
+
+
+    def setModelData(self, editor, model, index):
+        if not editor.isModified():
+            return
+        if editor.validator().state == QValidator.Acceptable:
+            value, ok = editor.text().toDouble()
+            for idx in self.parent.selectionModel().selectedIndexes():
+                if idx.column() == index.column():
+                    mini = model.getData(idx)['scamin']
+                    label = model.getData(idx)['label']
+                    if model.checkMinMax(label, mini, value):
+                        model.setData(idx, QVariant(value), Qt.DisplayRole)
+
+
+#-------------------------------------------------------------------------------
+# StandarItemModel class
+#-------------------------------------------------------------------------------
+
+class StandardItemModelClipping(QStandardItemModel):
+    """
+    """
+    def __init__(self, parent, NPE):
+        """
+        """
+        QStandardItemModel.__init__(self)
+
+        self.headers = [self.tr("Name"),
+                        self.tr("Minimal\nvalue"),
+                        self.tr("Maximal\nvalue")]
+
+        self.setColumnCount(len(self.headers))
+
+        self.toolTipRole = [self.tr("Code_Saturne keyword: NSCAUS"),
+                            self.tr("Code_Saturne keyword: SCAMIN"),
+                            self.tr("Code_Saturne keyword: SCAMAX")]
+
+        self._data = []
+        self._disable = []
+        self.parent = parent
+        self.NPE = NPE
+        self.populateModel()
+
+    def populateModel(self):
+        for label in self.NPE.getClippingList():
+            row = self.rowCount()
+            self.setRowCount(row + 1)
+            dico             = {}
+            dico['label']    = label
+            dico['scamin']   = self.NPE.getMinValue(label)
+            dico['scamax']   = self.NPE.getMaxValue(label)
+
+            self._data.append(dico)
+            log.debug("populateModel-> _data = %s" % dico)
+
+
+    def data(self, index, role):
+        if not index.isValid():
+            return QVariant()
+
+        row = index.row()
+        col = index.column()
+
+        if role == Qt.ToolTipRole:
+            return QVariant(self.toolTipRole[col])
+        if role == Qt.DisplayRole:
+            row = index.row()
+            dico = self._data[row]
+            if col == 0:
+                return QVariant(dico['label'])
+            elif col == 1:
+                return QVariant(dico['scamin'])
+            elif col == 2:
+                return QVariant(dico['scamax'])
+            else:
+                return QVariant()
+        elif role == Qt.TextAlignmentRole:
+            return QVariant(Qt.AlignCenter)
+
+        return QVariant()
+
+
+    def flags(self, index):
+        if not index.isValid():
+            return Qt.ItemIsEnabled
+
+        if index.column() == 0:
+            return Qt.ItemIsEnabled | Qt.ItemIsSelectable
+        else:
+            return Qt.ItemIsEnabled | Qt.ItemIsSelectable | Qt.ItemIsEditable
+
+
+    def headerData(self, section, orientation, role):
+        if orientation == Qt.Horizontal and role == Qt.DisplayRole:
+            return QVariant(self.headers[section])
+        return QVariant()
+
+
+    def setData(self, index, value, role=None):
+        if not index.isValid():
+            return Qt.ItemIsEnabled
+        row = index.row()
+        label = self._data[row]['label']
+
+        if index.column() == 1:
+            self._data[row]['scamin'] , ok = value.toDouble()
+            self.NPE.setMinValue(label, self._data[row]['scamin'])
+
+        elif index.column() == 2:
+            self._data[row]['scamax'], ok = value.toDouble()
+            self.NPE.setMaxValue(label, self._data[row]['scamax'])
+
+        self.emit(SIGNAL("dataChanged(const QModelIndex &, const QModelIndex &)"), index, index)
+        return True
+
+
+    def getData(self, index):
+        row = index.row()
+        return self._data[row]
+
+
+    def checkMinMax(self, label, mini, maxi):
+        """
+        Verify the coherence between mini and maxi
+        """
+        log.debug("checkMinMax")
+        OK = 1
+        if mini > maxi:
+            title = self.tr("Information")
+            msg = self.tr("The minimal value is greater than the maximal "\
+                          "value. Therefore there will be no clipping for the "\
+                          "scalar named:\n\n%1").arg(label)
+            QMessageBox.information(self.parent, title, msg)
+            return OK
+
+        return OK
+
+
 #-------------------------------------------------------------------------------
 # Main class
 #-------------------------------------------------------------------------------
@@ -509,7 +801,10 @@ class NumericalParamEquationView(QWidget, Ui_NumericalParamEquationForm):
         delegateBLENCV = BlendingFactorDelegate(self.tableViewScheme, self.turb)
         self.tableViewScheme.setItemDelegateForColumn(2, delegateBLENCV)
 
-        # Solveur
+        delegateNSWRSM = RhsReconstructionDelegate(self.tableViewScheme, self.turb)
+        self.tableViewScheme.setItemDelegateForColumn(5, delegateNSWRSM)
+
+        # Solver
         self.modelSolver = StandardItemModelSolver(self.NPE, self.SM)
         self.tableViewSolver.setModel(self.modelSolver)
         self.tableViewSolver.setAlternatingRowColors(True)
@@ -521,11 +816,34 @@ class NumericalParamEquationView(QWidget, Ui_NumericalParamEquationForm):
         self.tableViewSolver.horizontalHeader().setResizeMode(QHeaderView.Stretch)
 
         if self.SM.getSteadyFlowManagement() == 'on':
-            self.tableViewSolver.setColumnHidden(3, True)
+            self.tableViewSolver.setColumnHidden(4, True)
 
-        delegate = SolveurDelegate(self.tableViewSolver)
+        delegate = SolverDelegate(self.tableViewSolver)
         self.tableViewSolver.setItemDelegate(delegate)
 
+        delegateSolverChoice = SolverChoiceDelegate(self.tableViewSolver)
+        self.tableViewSolver.setItemDelegateForColumn(1, delegateSolverChoice)
+
+        # Clipping
+        self.modelClipping = StandardItemModelClipping(self, self.NPE)
+        self.tableViewClipping.setModel(self.modelClipping)
+        self.tableViewClipping.setAlternatingRowColors(True)
+        self.tableViewClipping.resizeColumnToContents(0)
+        self.tableViewClipping.resizeRowsToContents()
+        self.tableViewClipping.setSelectionBehavior(QAbstractItemView.SelectItems)
+        self.tableViewClipping.setSelectionMode(QAbstractItemView.ExtendedSelection)
+        self.tableViewClipping.setEditTriggers(QAbstractItemView.DoubleClicked)
+        self.tableViewClipping.horizontalHeader().setResizeMode(QHeaderView.Stretch)
+
+        delegateMin = MinimumDelegate(self.tableViewClipping)
+        self.tableViewClipping.setItemDelegateForColumn(1, delegateMin)
+
+        delegateMax = MaximumDelegate(self.tableViewClipping)
+        self.tableViewClipping.setItemDelegateForColumn(2, delegateMax)
+
+        if len(self.NPE.getClippingList()) == 0:
+            self.tab_clipping.setEnabled(False)
+
 
     def tr(self, text):
         """
