@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2011 EDF S.A.
+# Copyright (C) 1998-2012 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -309,7 +309,7 @@ class SolutionVerifView(QWidget, Ui_SolutionVerifForm):
         self.out = OutputControlModel(self.case)
 
         self.case2 = Case(package = self.case['package'], file_name = None)
-        XMLinit(self.case2)
+        XMLinit(self.case2).initialize()
         self.case2['xmlfile'] = 'cs_cmd'
         self.case2['salome'] = self.case['salome']
 
