@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2011 EDF S.A.
+# Copyright (C) 1998-2012 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -62,11 +62,14 @@ class TurbulenceModel(Variables, Model):
 
         self.node_models = self.case.xmlGetNode('thermophysical_models')
         self.node_lagr   = self.case.xmlGetNode('lagrangian')
-        self.node_coal   = self.node_models.xmlGetChildNode('pulverized_coal', 'model')
-        self.node_joule  = self.node_models.xmlGetChildNode('joule_effect',    'model')
-        self.node_gas    = self.node_models.xmlGetChildNode('gas_combustion',  'model')
-        self.node_turb   = self.node_models.xmlInitChildNode('turbulence', 'model')
+        self.node_coal   = self.node_models.xmlGetChildNode('solid_fuels',    'model')
+        self.node_joule  = self.node_models.xmlGetChildNode('joule_effect',   'model')
+        self.node_gas    = self.node_models.xmlGetChildNode('gas_combustion', 'model')
+        self.node_turb   = self.node_models.xmlInitChildNode('turbulence',    'model')
         self.node_bc     = self.case.xmlGetNode('boundary_conditions')
+        self.node_ana    = self.case.xmlInitNode('analysis_control')
+        self.node_prof   = self.node_ana.xmlInitNode('profiles')
+        self.node_ava    = self.node_ana.xmlInitNode('time_averages')
 
         self.__turbModel = ('off',
                             'mixing_length',
@@ -74,8 +77,10 @@ class TurbulenceModel(Variables, Model):
                             'k-epsilon-PL',
                             'Rij-epsilon',
                             'Rij-SSG',
+                            'Rij-EBRSM',
                             'v2f-phi',
                             'k-omega-SST',
+                            'Spalart-Allmaras',
                             'LES_Smagorinsky',
                             'LES_dynamique',
                             'LES_WALE')
@@ -94,7 +99,9 @@ class TurbulenceModel(Variables, Model):
                                'turb_eps',
                                'turb_phi',
                                'turb_fb',
-                               'turb_omega']
+                               'turb_omega',
+                               'turb_alpha',
+                               'turb_nusa']
 
 
     def turbulenceModels(self):
@@ -140,7 +147,7 @@ class TurbulenceModel(Variables, Model):
         @return: default values
         """
         default = {}
-        default['turbulence_model'] = "k-epsilon"
+        default['turbulence_model'] = "k-epsilon-PL"
         default['length_scale']     = 1.0
         default['scale_model']      = 1
         default['gravity_terms']    = "on"
@@ -162,10 +169,13 @@ class TurbulenceModel(Variables, Model):
             turbList = self.RANSmodels()
             turbList.insert(0, "off")
 
-        for node in (self.node_gas, self.node_coal, self.node_joule):
+        for node in (self.node_gas, self.node_joule):
             if node and node['model'] != 'off':
                 turbList = self.RANSmodels()
 
+        if self.node_coal and self.node_coal['model'] != 'off':
+            turbList = ('off', 'k-epsilon', 'k-epsilon-PL')
+
         return turbList
 
 
@@ -176,6 +186,10 @@ class TurbulenceModel(Variables, Model):
         for v in self.__allVariables:
             if v not in varList:
                 self.node_turb.xmlRemoveChild('variable', name=v)
+                for node in self.node_prof.xmlGetNodeList('profile'):
+                    node.xmlRemoveChild('var_prop', name=v)
+                for node in self.node_ava.xmlGetNodeList('time_average'):
+                    node.xmlRemoveChild('var_prop', name=v)
         self.node_turb.xmlRemoveChild('property', name=propName)
 
 
@@ -185,6 +199,8 @@ class TurbulenceModel(Variables, Model):
         """
         self.isInList(model_turb, self.turbulenceModelsList())
 
+        self.node_turb['model'] = model_turb
+
         NumericalParamGlobalModel(self.case).setTimeSchemeOrder(1)
 
         if model_turb == 'mixing_length':
@@ -209,6 +225,16 @@ class TurbulenceModel(Variables, Model):
             self.__updateInletsForTurbulence()
             self.__removeVariablesAndProperties(list, 'smagorinsky_constant')
 
+        elif model_turb == 'Rij-EBRSM':
+            list = ('component_R11', 'component_R22', 'component_R33',
+                    'component_R12', 'component_R13', 'component_R23',
+                    'turb_eps', 'turb_alpha')
+            for v in list:
+                self.setNewTurbulenceVariable(self.node_turb, v)
+            self.setNewProperty(self.node_turb, 'turb_viscosity')
+            self.__updateInletsForTurbulence()
+            self.__removeVariablesAndProperties(list, 'smagorinsky_constant')
+
         elif model_turb in self.LESmodels():
             self.setNewProperty(self.node_turb, 'smagorinsky_constant')
             self.__removeVariablesAndProperties([], 'turb_viscosity')
@@ -239,13 +265,18 @@ class TurbulenceModel(Variables, Model):
             self.__updateInletsForTurbulence()
             self.__removeVariablesAndProperties(list, 'smagorinsky_constant')
 
+        elif model_turb == 'Spalart-Allmaras':
+            list = ('turb_nusa')
+            self.setNewTurbulenceVariable(self.node_turb, 'turb_nusa')
+            self.setNewProperty(self.node_turb, 'turb_viscosity')
+            self.__updateInletsForTurbulence()
+            self.__removeVariablesAndProperties(list, 'smagorinsky_constant')
+
         else:
             model_turb = 'off'
             self.node_turb.xmlRemoveChild('variable')
             self.node_turb.xmlRemoveChild('property')
 
-        self.node_turb['model'] = model_turb
-
 
     def __updateInletsForTurbulence(self):
         """
@@ -317,6 +348,11 @@ class TurbulenceModel(Variables, Model):
             gravity = self.defaultTurbulenceValues()['gravity_terms']
             self.setGravity(gravity)
 
+        # force gravity force to off for Spalart-Allmaras model
+        if self.getTurbulenceModel() == 'Spalart-Allmaras':
+            gravity = 'off'
+            self.setGravity(gravity)
+
         return gravity
 
 
@@ -339,10 +375,12 @@ class TurbulenceModel(Variables, Model):
         if model in ('k-epsilon','k-epsilon-PL'):
             nodeList.append(self.node_turb.xmlGetNode('variable', name='turb_k'))
             nodeList.append(self.node_turb.xmlGetNode('variable', name='turb_eps'))
-        elif model in ('Rij-epsilon', 'Rij-SSG'):
+        elif model in ('Rij-epsilon', 'Rij-SSG', 'Rij-EBRSM'):
             for var in ('component_R11', 'component_R22', 'component_R33',
                         'component_R12', 'component_R13', 'component_R23', 'turb_eps'):
                 nodeList.append(self.node_turb.xmlGetNode('variable', name=var))
+            if model == 'Rij-EBRSM':
+                nodeList.append(self.node_turb.xmlGetNode('variable', name='turb_alpha'))
         elif model == 'v2f-phi':
             nodeList.append(self.node_turb.xmlGetNode('variable', name='turb_k'))
             nodeList.append(self.node_turb.xmlGetNode('variable', name='turb_eps'))
@@ -351,6 +389,8 @@ class TurbulenceModel(Variables, Model):
         elif model == 'k-omega-SST':
             nodeList.append(self.node_turb.xmlGetNode('variable', name='turb_k'))
             nodeList.append(self.node_turb.xmlGetNode('variable', name='turb_omega'))
+        elif model == 'Spalart-Allmaras':
+            nodeList.append(self.node_turb.xmlGetNode('variable', name='turb_nusa'))
         return nodeList
 
 #-------------------------------------------------------------------------------
@@ -473,6 +513,29 @@ class TurbulenceModelTestCase(ModelTest):
         assert mdl.node_turb == self.xmlNodeFromString(doc),\
            'Could not set the Rij-epsilon SSG turbulence model'
 
+    def checkSetRijepsilonEBRSM(self):
+        """Check whether the Rij-epsilon EBRSM turbulence model could be set"""
+        mdl = TurbulenceModel(self.case)
+        mdl.node_turb.xmlRemoveChild('variable')
+        mdl.setTurbulenceModel('Rij-EBRSM')
+        truc = mdl.node_turb
+        doc ='''<turbulence model="Rij-EBRSM">
+                <property label="TurbVisc" name="turb_viscosity"/>
+                <initialization choice="reference_velocity">
+                  <reference_velocity>1</reference_velocity>
+                </initialization>
+                <variable label="R11" name="component_R11"/>
+                <variable label="R22" name="component_R22"/>
+                <variable label="R33" name="component_R33"/>
+                <variable label="R12" name="component_R12"/>
+                <variable label="R13" name="component_R13"/>
+                <variable label="R23" name="component_R23"/>
+                <variable label="Dissip" name="turb_eps"/>
+                <variable label="alpha" name="turb_alpha"/>
+              </turbulence>'''
+        assert mdl.node_turb == self.xmlNodeFromString(doc),\
+           'Could not set the Rij-epsilon EBRSM turbulence model'
+
     def checkSetLESSmagorinsky(self):
         """Check whether the classical LES turbulence model could be set"""
         mdl = TurbulenceModel(self.case)
@@ -534,6 +597,20 @@ class TurbulenceModelTestCase(ModelTest):
         assert mdl.node_turb == self.xmlNodeFromString(doc),\
            'Could not set the k_Omega SST turbulence model'
 
+    def checkSpalartAllmaras(self):
+        """Check whether the Spalart-Allmaras turbulence model could be set"""
+        mdl = TurbulenceModel(self.case)
+        mdl.setTurbulenceModel('Spalart-Allmaras')
+        doc = '''<turbulence model="Spalart-Allmaras">
+                <variable label="NuTilda" name="turb_nusa"/>
+                <property label="TurbVisc" name="turb_viscosity"/>
+                <initialization choice="reference_velocity">
+                  <reference_velocity>1.0</reference_velocity>
+                </initialization>
+            </turbulence>'''
+        assert mdl.node_turb == self.xmlNodeFromString(doc),\
+           'Could not set the Spalart-Allmaras turbulence model'
+
     def checkGetTurbulenceModel(self):
         """Check whether the turbulence model could be get"""
         mdl = TurbulenceModel(self.case)
