@@ -5,7 +5,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2011 EDF S.A.
+  Copyright (C) 1998-2012 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -168,8 +168,6 @@ _lit_maillage(const ecs_cmd_t *cmd)
   ecs_maillage_t  *maillage = NULL;
   ecs_maillage_t  *maillage_lu = NULL;
 
-  const char titre[] = "Apres lecture du fichier de maillage ";
-
   /*xxxxxxxxxxxxxxxxxxxxxxxxxxx Instructions xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx*/
 
   for (ific = 0; ific < cmd->n_num_maillage; ific++) {
@@ -371,8 +369,6 @@ main(int    argc,
 
   bool               passe_verif;
 
-  ecs_file_t        *fic_imp;
-
   ecs_maillage_t    *maillage;
 
   ecs_post_t        *cas_post;
