@@ -6,7 +6,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2011 EDF S.A.
+  Copyright (C) 1998-2012 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -23,13 +23,12 @@
   Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
+/*----------------------------------------------------------------------------*/
 
-/*============================================================================
- *                                 Visibilité
- *============================================================================*/
+#include "ecs_def.h"
 
 /*----------------------------------------------------------------------------
- *  Fichiers `include' librairie standard C
+ * Standard C library headers
  *----------------------------------------------------------------------------*/
 
 #include <assert.h>
@@ -37,24 +36,24 @@
 #include <stdarg.h>
 #include <string.h>
 
-
 /*----------------------------------------------------------------------------
- *  Fichiers `include' visibles du  paquetage courant
+ *  Local headers
  *----------------------------------------------------------------------------*/
 
-#include "ecs_def.h"
 #include "ecs_mem.h"
 
-
 /*----------------------------------------------------------------------------
- *  Fichier  `include' du  paquetage courant associe au fichier courant
+ *  Headers for the current file
  *----------------------------------------------------------------------------*/
 
 #include "ecs_tab.h"
 
+/*----------------------------------------------------------------------------*/
+
+BEGIN_C_DECLS
 
 /*============================================================================
- *                              Fonctions privées
+ * Local function defintions
  *============================================================================*/
 
 /*----------------------------------------------------------------------------
@@ -144,7 +143,7 @@ ecs_loc_tab_char__desc_arbre(char              **val_tab,
 }
 
 /*============================================================================
- *                             Fonctions publiques
+ * Public function definitions
  *============================================================================*/
 
 /*----------------------------------------------------------------------------
@@ -555,3 +554,4 @@ ecs_tab_int__ref_en_indice(ecs_tab_int_t        tab_att_reference,
 
 /*----------------------------------------------------------------------------*/
 
+END_C_DECLS
