@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2011 EDF S.A.
+# Copyright (C) 1998-2012 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -52,9 +52,10 @@ from PyQt4.QtCore import Qt, QObject, QEvent, SIGNAL, SLOT
 # Application modules
 #-------------------------------------------------------------------------------
 
-from CFDSTUDYGUI_Commons import CFD_Code, Trace, CFD_Saturne, CFD_Neptune, sgPyQt
+from CFDSTUDYGUI_Commons import CFD_Code, CFD_Saturne, CFD_Neptune, sgPyQt
 from CFDSTUDYGUI_Commons import LogModeOn, LogModeOff, LoggingMgr, LoggingAgent
 import CFDSTUDYGUI_DataModel
+from CFDSTUDYGUI_Management import CFDGUI_Management, _d_DockWindowsRuncase
 
 #-------------------------------------------------------------------------------
 # log config
@@ -69,34 +70,26 @@ log.setLevel(logging.DEBUG)
 # Global definitions
 #-------------------------------------------------------------------------------
 
-_d_DockWindows = {}
-_d_DockWindowsBrowser = {}
-_d_DockWindowsRuncase = {}
-
-_selectedMainViewCase = []
 mw=None
 
-_LoggingMgr = LoggingMgr()
-
-
+def getObjectBrowserDock() :
+  dock = None
+  dsk = sgPyQt.getDesktop()
+  studyId = sgPyQt.getStudyId()
+  for dock in dsk.findChildren(QDockWidget):
+    dockTitle = str(dock.windowTitle())
+    if (dockTitle == 'Object Browser') :
+      return dock
 #-------------------------------------------------------------------------------
 # Function definitions
 #-------------------------------------------------------------------------------
-
-def getDockWindowsLists():
-    """
-    """
-    studyId = sgPyQt.getStudyId()
-    if studyId in _d_DockWindows.keys() and studyId in _d_DockWindowsBrowser.keys():
-        return True #_d_DockWindows[studyId],_d_DockWindowsBrowser[studyId]
-    else:
-        return False
+_c_CFDGUI = CFDGUI_Management()
 
 
 def tabObjectBrowser():
     """
-    Regroupe en onglets les DockWidgets contenant des QTreeView:
-    Object Browser et arbres CFDSTUDY
+    tabify DockWidgets which contains QTreeView :
+    Object Browser and CFDSTUDY tree
     """
     dsk = sgPyQt.getDesktop()
     ldock=dsk.findChildren(QDockWidget)
@@ -117,97 +110,17 @@ def updateObjectBrowser():
     sgPyQt.updateObjBrowser(studyId, 1)
     tabObjectBrowser()
 
-
-def updateDockWindows():
-    """
-    force le regroupement en onglets des fenetres d'etudes CFD
-    """
-    dsk = sgPyQt.getDesktop()
-    studyId = sgPyQt.getStudyId()
-
-    if not getDockWindowsLists():
-        return
-    if len(_d_DockWindows[studyId]) > 1:
-        for i in range(1,len(_d_DockWindows[studyId])):
-            dsk.tabifyDockWidget(_d_DockWindows[studyId][0], _d_DockWindows[studyId][i])
-
-
-def updateDockWindowsBrowser():
-    """
-    force le regroupement en onglets des fenetres Browser d'etudes CFD
-    """
-    dsk = sgPyQt.getDesktop()
-    studyId = sgPyQt.getStudyId()
-
-    if not getDockWindowsLists():
-        return
-    if len(_d_DockWindowsBrowser[studyId]) > 1:
-        for i in range(1,len(_d_DockWindowsBrowser[studyId])):
-            dsk.tabifyDockWidget(_d_DockWindowsBrowser[studyId][0], _d_DockWindowsBrowser[studyId][i])
-
-
-def findDockWindow(xmlName, caseName, studyCFDName):
+def findDockWindow( xmlName, caseName, studyCFDName):
     """
     Find if the dockwindow corresponding to this xmlcase is already opened
     """
     bool_findDockWindow = False
-    dsk = sgPyQt.getDesktop()
-    studyId = sgPyQt.getStudyId()
-    for dock in dsk.findChildren(QDockWidget):
-        dockTitle = str(dock.windowTitle())
-        if studyId not in _d_DockWindowsBrowser.keys():
-            _d_DockWindowsBrowser[studyId] = []
-        if (dockTitle == 'Object Browser') and (dock not in _d_DockWindowsBrowser[studyId]):
-            _d_DockWindowsBrowser[studyId].append(dock)
-        if studyId not in _d_DockWindows.keys():
-            _d_DockWindows[studyId] = []
 
-        if _d_DockWindows[studyId] != []:
-            for dock in _d_DockWindows[studyId]:
-                if string.rstrip(string.join([studyCFDName, caseName, xmlName], ".")) == string.rstrip(dockTitle) :
-                    bool_findDockWindow = True
-                    dock.show()
-                    dock.raise_()
+    if _c_CFDGUI != None :
+        bool_findDockWindow = _c_CFDGUI.findElem(xmlName, caseName, studyCFDName)
 
     return bool_findDockWindow
 
-def update_selectedMainViewCase_list(studyCFDName, caseName, xmlName) :
-    """
-    """
-    lind = []
-    ind = 0
-    for win in _selectedMainViewCase :
-        xmlfile = os.path.basename(win.case['xmlfile'])
-        boo = xmlfile.rstrip() == xmlName and win.salome.GetName()==caseName and win.salome.GetFather().GetName() == studyCFDName
-        if boo :
-            lind.append(ind)
-        ind = ind + 1
-    if len(lind) > 0 :
-        for i in lind :
-            del _selectedMainViewCase[i]
-
-def removeDockWindow(studyCFDName, caseName, xmlName=""):
-    """
-    Close the CFD_study_dock_windows from remove  popup menu in object browser
-    """
-    log.debug("removeDockWindow -> caseName = %s" % caseName)
-    dsk = sgPyQt.getDesktop()
-    studyId = sgPyQt.getStudyId()
-    for dock in dsk.findChildren(QDockWidget):
-        dockTitle = str(dock.windowTitle())
-        log.debug("removeDockWindow -> dockTitle = %s" % dockTitle)
-        stringName = string.rstrip(string.join([studyCFDName, caseName, xmlName], "."))
-        stringNameB = stringName + " Browser"
-        if stringName  == string.rstrip(dockTitle) or stringNameB == string.rstrip(dockTitle):
-            log.debug("removeDockWindow -> widget to close = %s" % dockTitle)
-            if "Browser" not in str(dockTitle):
-                _d_DockWindows[studyId].remove(dock)
-            else:
-                _d_DockWindowsBrowser[studyId].remove(dock)
-            dsk.removeDockWidget(dock)
-            dock.setParent(None)
-            dock.close()
-        updateObjectBrowser()
 
 #-------------------------------------------------------------------------------
 # Classes definition
@@ -218,34 +131,33 @@ class CFDSTUDYGUI_SolverGUI(QObject):
     Auxilliary class for interaction with solvers GUI
     """
     def __init__(self):
-        if Trace(): print "CFDSTUDY_SolverGUI.__init__: "
+        log.debug("CFDSTUDY_SolverGUI.__init__: ")
         QObject.__init__(self, None)
-        self._WindowsMap = {}
         self._CurrentWindow = None
-        _d_DockWindows = {}
-        _d_DockWindowsBrowser = {}
 
 
     def ExecGUI(self, WorkSpace, sobjXML, aCase, Args=''):
         """
         Executes GUI for solver relatively CFDCode
         """
-        if Trace(): print "CFDSTUDY_SolverGUI.ExecGUI: "
+        log.debug("CFDSTUDY_SolverGUI.ExecGUI: ")
         mw = None
         if sobjXML != None :
-            #searching in existing tabs
+            #searching
             aTitle = sobjXML.GetName()
-            win = self._findWindow(aTitle,aCase)
-            if win != None:
-                #need for activation
-                QApplication.postEvent(win, QEvent(QEvent.FocusIn))
-                return win
+            if aCase != None :
+                if findDockWindow(aTitle,aCase.GetName(),aCase.GetFather().GetName()):
+                    fileN = str(aCase.GetFather().GetName() + "." + aCase.GetName()) + '.' + str(aTitle)
+                    mess = "Case file " + fileN + " is already opened"
+                    QMessageBox.warning(None, "Warning: ",mess)
+                    return
         else:
             aTitle = "unnamed"
-            if findDockWindow(aTitle,aCase.GetName(),aCase.GetFather().GetName()):
-                mess = "A case is not finished to be set"
-                QMessageBox.warning(None, "Warning: ",mess)
-                return
+            if aCase != None :
+                if findDockWindow(aTitle,aCase.GetName(),aCase.GetFather().GetName()):
+                    mess = "A case not finished to be set is already opened"
+                    QMessageBox.warning(None, "Warning: ",mess)
+                    return
 
         if aCase != None:
             if CFD_Code() == CFD_Saturne:
@@ -253,7 +165,7 @@ class CFDSTUDYGUI_SolverGUI(QObject):
                 aChildList = CFDSTUDYGUI_DataModel.ScanChildren(aCase, "^DATA$")
                 if not len(aChildList)== 1:
                     # no DATA folder
-                    if Trace(): print "CFDSTUDYGUI_SolverGUI.ExecGUI:There are not data folder in selected by user case"
+                    log.debug("CFDSTUDYGUI_SolverGUI.ExecGUI:There are not data folder in selected by user case")
                     return None
                 aStartPath = CFDSTUDYGUI_DataModel._GetPath(aChildList[0])
             elif CFD_Code() == CFD_Neptune:
@@ -265,24 +177,11 @@ class CFDSTUDYGUI_SolverGUI(QObject):
         elif CFD_Code() == CFD_Neptune:
             mw = self._ExecIPB(WorkSpace, aTitle, Args)
         if mw != None:
-            self._WindowsMap[mw] = aCase
             self._CurrentWindow = mw
-            _selectedMainViewCase.append(mw)
+
         return mw
 
 
-    def eventFilter(self, anObject, anEvent):
-        log.debug("eventFilter")
-        if anEvent.type() == QEvent.Close:
-            del self._WindowsMap[anObject]
-        elif anEvent.type() == QEvent.Hide:
-            if self._CurrentWindow == anObject:
-                self._CurrentWindow = None
-        elif anEvent.type() == QEvent.Show:
-            self._CurrentWindow = anObject
-        return False
-
-
     def isActive(self):
         return self._CurrentWindow != None
 
@@ -291,7 +190,6 @@ class CFDSTUDYGUI_SolverGUI(QObject):
         log.debug("onSaveXmlFile")
         if self._CurrentWindow != None:
             if CFD_Code() == CFD_Saturne:
-                #print "self._CurrentWindow.case['xmlfile'] = ",self._CurrentWindow.case['xmlfile']
                 if self._CurrentWindow.case['xmlfile'] != "":
                     self._CurrentWindow.fileSave()
                 else:
@@ -305,9 +203,8 @@ class CFDSTUDYGUI_SolverGUI(QObject):
         """
         old_xml_file = None
         xml_file = None
-        NewSObj = None
-        OldSobj = None
-        if  len(_selectedMainViewCase) != 0:
+
+        if self._CurrentWindow != None :
             _sMainViewCase = self._CurrentWindow
             if CFD_Code() == CFD_Saturne:
                 old_xml_file = _sMainViewCase.case['xmlfile']
@@ -315,14 +212,12 @@ class CFDSTUDYGUI_SolverGUI(QObject):
                 xml_file = _sMainViewCase.case['xmlfile']
                 if old_xml_file == "" :
                     old_xml_file = None
-
-
         return old_xml_file,xml_file
 
 
     def getDockTitleName(self,xml_file):
         """
-        Build the Dock Title Name STUDY.CASE.file.xml with the entire file Name
+        Build the Dock Title Name STUDY.CASE.file.xml with the entire file Name path
         """
         lnames = string.split(xml_file,"/")
         if len(lnames) < 4: return None
@@ -334,40 +229,6 @@ class CFDSTUDYGUI_SolverGUI(QObject):
     def getDockTitleNameFromOB(self,studyname,casename,xmlname) :
         return string.join([studyname,casename,xmlname],".")
 
-    def replaceDockTitleName(self,new_xml_file,old_xml_file,case,study):
-        """
-        replace dock title name in the title of the dock widget and update
-        the _d_DockWindows and _d_DockWindowsBrowser dictionary
-        """
-        OldDockTitleName = self.getDockTitleName(old_xml_file)
-        NewDockTitleName = self.getDockTitleName(new_xml_file)
-
-        if NewDockTitleName == None:
-            mess = "File: "+xml_file+ \
-                   " is not stored into a CFDSTUDY directory structure like .../STUDY_CFD/CASE/DATA/filename.xml"
-            QMessageBox.warning(None, "File Error: ",mess)
-            return
-        if OldDockTitleName == None:
-            studyname = study.GetName()
-            casename  = case.GetName()
-            xmlname = "unnamed"
-            OldDockTitleName = string.join([studyname,casename,xmlname],".")
-        if NewDockTitleName != None:
-            studyId = sgPyQt.getStudyId()
-            if studyId in _d_DockWindows.keys():
-                for dock in _d_DockWindows[studyId]:
-                    if str(OldDockTitleName) in str(dock.windowTitle()):
-                        dock.setWindowTitle(str(NewDockTitleName))
-                        dock.show()
-                        dock.raise_()
-            if studyId in _d_DockWindowsBrowser.keys():
-                for dock in _d_DockWindowsBrowser[studyId]:
-                    if str(OldDockTitleName) in str(dock.windowTitle()):
-                        dock.setWindowTitle(string.join([str(NewDockTitleName),"Browser"]))
-                        dock.show()
-                        dock.raise_()
-        return
-
 
     def onOpenShell(self):
         """
@@ -495,6 +356,7 @@ class CFDSTUDYGUI_SolverGUI(QObject):
 
     def _ExecICS(self, WorkSpace, aCase, sobjXML, Args):
         """
+        mw.dockWidgetBrowser is the Browser of the CFD MainView
         """
         log.debug("_ExecICS")
         from cs_gui import process_cmd_line
@@ -506,8 +368,8 @@ class CFDSTUDYGUI_SolverGUI(QObject):
             Title = sobjXML.GetName()
         self.Workspace = WorkSpace
         pkg = package()
-        case, splash, batch_window, batch_file, tree_window, read_only = process_cmd_line(Args)
-        mw = MainView(pkg, case, batch_window, batch_file, tree_window, read_only, aCase)
+        case, splash = process_cmd_line(Args)
+        mw = MainView(pkg, case, aCase)
 
         aTitle = self.setWindowTitle_CFD(mw,aCase,Title)
         dsk = sgPyQt.getDesktop()
@@ -519,176 +381,189 @@ class CFDSTUDYGUI_SolverGUI(QObject):
 
         studyId = sgPyQt.getStudyId()
 
-        if studyId not in _d_DockWindows.keys():
-            _d_DockWindows[studyId] = []
-        _d_DockWindows[studyId].append(dock)
-
         dock.setVisible(True)
         dock.show()
-        ##dock.installEventFilter(self)
-        updateDockWindows()
 
         BrowserTitle = aTitle  + " Browser"
         mw.dockWidgetBrowser.setWindowTitle(BrowserTitle)
         dsk.addDockWidget(Qt.LeftDockWidgetArea,mw.dockWidgetBrowser)
 
-        if studyId not in _d_DockWindowsBrowser.keys():
-            _d_DockWindowsBrowser[studyId] = []
-        _d_DockWindowsBrowser[studyId].append(mw.dockWidgetBrowser)
         mw.dockWidgetBrowser.setVisible(True)
         mw.dockWidgetBrowser.show()
         mw.dockWidgetBrowser.raise_()
         dock.raise_()
 
+#MP Dock windows are managed by CFDGUI_Management class defined into CFDSTUDYGUI_Management.py
+
+        aStudyCFD = aCase.GetFather()
+        aCaseCFD  = aCase
+        xmlFileName = str(Title)
+        _c_CFDGUI.set_d_CfdCases(studyId,dock,mw.dockWidgetBrowser,mw,aStudyCFD,aCaseCFD,xmlFileName,sobjXML,None)
+
         self.connect(dock, SIGNAL("visibilityChanged(bool)"), self.setdockWindowBrowserActivated)
         self.connect(mw.dockWidgetBrowser, SIGNAL("visibilityChanged(bool)"),self.setdockWindowActivated)
 
-        updateDockWindowsBrowser()
+        self.connect(dock.toggleViewAction(), SIGNAL("toggled(bool)"), self.setdockWB)
+        self.connect(mw.dockWidgetBrowser.toggleViewAction(), SIGNAL("toggled(bool)"), self.setdock)
+
+        _c_CFDGUI.tabifyDockWindows(dsk,studyId)
+        self.showDockWindows( studyId,xmlFileName, aCaseCFD.GetName(), aStudyCFD.GetName())
         updateObjectBrowser()
 
         return mw
 
+    def setdockWB(self, istoggled) :
+        studyId = sgPyQt.getStudyId()
+        dock = self.sender().parent()
+        if _c_CFDGUI != None :
+          dockWB = _c_CFDGUI.getdockWB(studyId,dock)
+          if dockWB != None :
+            dockWB.setVisible(dock.isVisible())
+            if istoggled : dockWB.setVisible(True)
+            #
+            if istoggled :
+              dock.show()
+              dock.raise_()
+              dockWB.show()
+              dockWB.raise_()
+            mw = _c_CFDGUI.getMW(studyId,dock)
+            self._CurrentWindow = mw
+            mw.activateWindow()
 
-    def _findWindow(self, aTitle, aCase):
-        """
-        """
-        log.debug("_findWindow")
-        if aTitle == '' or aCase == None:
-            return None
-
-        for win in self._WindowsMap.keys():
-            if aTitle == str(win.windowTitle().toLatin1()) and \
-                       aCase.GetID() == self._WindowsMap[win].GetID():
-                return win
-
-        return None
-
+    def setdock(self, istoggled) :
+        studyId = sgPyQt.getStudyId()
+        dockWB = self.sender().parent()
+        if _c_CFDGUI != None :
+          dock = _c_CFDGUI.getdock(studyId,dockWB)
+          if dock != None :
+            dock.setVisible(dockWB.isVisible())
+            if istoggled : dock.setVisible(True)
+            if istoggled :
+              dock.show()
+              dock.raise_()
+              dockWB.show()
+              dockWB.raise_()
+            mw = _c_CFDGUI.getMW(studyId,dock)
+            self._CurrentWindow = mw
+            mw.activateWindow()
 
     def setdockWindowBrowserActivated(self,visible):
         """
+        mv is the Main CFD window allocated by MainView code
+        When we click on a cfd study window tab, the cfd study window appears and the associated CFD window browser raises too
         """
-        if not visible: return
-        dock = self.sender()
-        if dock.isActiveWindow() == False: return
-        titledock = str(dock.windowTitle())
         studyId = sgPyQt.getStudyId()
-        if studyId not in _d_DockWindowsBrowser.keys():
-            return
-        titledockBr = string.rstrip(titledock) + " Browser"
-        for i in range(len(_d_DockWindowsBrowser[studyId])):
-
-            if string.rstrip(titledockBr) == string.rstrip(str(_d_DockWindowsBrowser[studyId][i].windowTitle())):
-                _d_DockWindowsBrowser[studyId][i].activateWindow()
-                _d_DockWindowsBrowser[studyId][i].setVisible(True)
-                _d_DockWindowsBrowser[studyId][i].show()
-                _d_DockWindowsBrowser[studyId][i].raise_()
-                self.activateCurrentWindow(titledockBr)
-
+        dock = self.sender()
+        if not visible: return
+        if dock.isActiveWindow() == False: return
+        if _c_CFDGUI != None :
+          dockWB = _c_CFDGUI.getdockWB(studyId,dock)
+          if dockWB != None :
+            dockWB.activateWindow()
+            dockWB.setVisible(True)
+            dockWB.show()
+            dockWB.raise_()
+            mw = _c_CFDGUI.getMW(studyId,dock)
+            self._CurrentWindow = mw
+            mw.activateWindow()
+            ob = sgPyQt.getObjectBrowser()
+            # Clear the current selection in the SALOME object browser, which does not match with the shown dock window
+            ob.clearSelection()
 
     def setdockWindowActivated(self,visible):
         """
+        mv is the Main CFD window allocated by MainView code
+        When we click on a  CFD window browser tab, the CFD window browser appears and the associated cfd study window raises too
         """
-        if not visible: return
-        dock = self.sender()
-        if dock.isActiveWindow() == False: return
-        title = str(dock.windowTitle())
-        titledock,br = string.split(title," Browser")
+        dsk = sgPyQt.getDesktop()
         studyId = sgPyQt.getStudyId()
-        if studyId not in _d_DockWindowsBrowser.keys():
-            return
-        for i in range(len(_d_DockWindows[studyId])):
-            if string.rstrip(str(_d_DockWindows[studyId][i].windowTitle())) == string.rstrip(str(titledock)):
-                _d_DockWindows[studyId][i].activateWindow()
-                _d_DockWindows[studyId][i].setVisible(True)
-                _d_DockWindows[studyId][i].show()
-                _d_DockWindows[studyId][i].raise_()
-                self.activateCurrentWindow(titledock)
-
-
-    def activateCurrentWindow(self,title):
-        """
-        """
-        for mw in self._WindowsMap.keys():
-
-            casename = mw.salome.GetName()
-            xmlfile = os.path.basename(mw.case['xmlfile'])
-            xmlfile = xmlfile.rstrip()
-            if xmlfile == "" or xmlfile == None:
-                xmlfileName = "unnamed"
-            else:
-                xmlfileName = xmlfile
-            fatherCaseName = mw.salome.GetFather().GetName()
-            if string.rstrip(title) == string.join([fatherCaseName,casename,xmlfileName],"."):
-                self._CurrentWindow = mw
-                if mw not in _selectedMainViewCase:
-                    _selectedMainViewCase.append(mw)
-                mw.activateWindow()
+        dockWB = self.sender()
 
+        if not visible: return
+        if dockWB.isActiveWindow() == False: return
+        if _c_CFDGUI != None :
+          dock = _c_CFDGUI.getdock(studyId,dockWB)
+          if dock != None :
+            dock.activateWindow()
+            dock.setVisible(True)
+            dock.show()
+            dock.raise_()
+            mw = _c_CFDGUI.getMW(studyId,dock)
+            self._CurrentWindow = mw
+            mw.activateWindow()
+            ob = sgPyQt.getObjectBrowser()
+            # effacer la selection en cours
+            ob.clearSelection()
 
     def disconnectDockWindows(self):
         """
-        Hide the dock windows of CFDSTUDY GUI, when activating another Salome Component
+        Hide the dock windows of CFDSTUDY GUI, when activating another Salome module
         We can have one or several of them with the right click on the main menu bar of
         Salome
         """
         studyId = sgPyQt.getStudyId()
-        if studyId not in _d_DockWindowsBrowser.keys():
-            return
-        if studyId not in _d_DockWindows.keys():
-            return
-
-        if len(_d_DockWindows[studyId]) != 0:
-            for dock in _d_DockWindows[studyId]:
-                dock.hide()
-
-        if len(_d_DockWindowsBrowser[studyId]) != 0:
-            for dock in _d_DockWindowsBrowser[studyId]:
-                if dock.windowTitle() != 'Object Browser':
-                    dock.hide()
+        if _c_CFDGUI != None :
+          _c_CFDGUI.hideDocks(studyId)
+#MP runcase dock window is managed independently of the Management class CFDGUI_Management because it is not attached to an xml case in the CFD GUI
+#MP to analyze : impact : CFDSTUDYGUI_CommandMgr.py (runTextEdit) and CFDSTUDYGUI_Management.py
         if studyId not in _d_DockWindowsRuncase.keys():
-            return
+          return
         if len(_d_DockWindowsRuncase[studyId]) != 0:
-            for dock in _d_DockWindowsRuncase[studyId]:
-                dock.hide()
-
+            dock.hide()
+            dock.toggleViewAction().setVisible(False)
 
     def connectDockWindows(self):
         """
-        Show all the dock windows of CFDSTUDY GUI, when activating another Salome Component
-        visualise les dock windows  lors d'un changement de composant
+        Show all the dock windows of CFDSTUDY GUI, when activating Salome CFDSTUDY module
         """
         studyId = sgPyQt.getStudyId()
-        if studyId not in _d_DockWindowsBrowser.keys():
-            return
-        if studyId not in _d_DockWindows.keys():
-            return
-
-        if len(_d_DockWindows[studyId]) != 0:
-            for dock in _d_DockWindows[studyId]:
-                dock.show()
-                dock.setVisible(True)
-
-        if len(_d_DockWindowsBrowser[studyId]) != 0:
-            for dock in _d_DockWindowsBrowser[studyId]:
-                dock.show()
-                dock.setVisible(True)
-
+        if _c_CFDGUI != None :
+          _c_CFDGUI.showDocks(studyId)
+        updateObjectBrowser()
+#MP runcase dock window is managed independently of the Management class CFDGUI_Management because it is not attached to an xml case in the CFD GUI
+#MP to analyze : impact : CFDSTUDYGUI_CommandMgr.py (runTextEdit) and CFDSTUDYGUI_Management.py
         if studyId not in _d_DockWindowsRuncase.keys():
-            return
+          return
         if len(_d_DockWindowsRuncase[studyId]) != 0:
-            for dock in _d_DockWindowsRuncase[studyId]:
-                dock.show()
-                dock.setVisible(True)
+          for dock in _d_DockWindowsRuncase[studyId]:
+            dock.show()
+            dock.setVisible(True)
+            dock.toggleViewAction().setVisible(True)
+
+    def showDockWindows(self, studyId,xmlName, caseName, studyCFDName):
+        """
+        Find if the dockwindow corresponding to this xmlcase is already opened
+        """
+        if _c_CFDGUI != None :
+            _c_CFDGUI.showDockWindows(studyId,xmlName, caseName, studyCFDName)
+
+    def getStudyCaseXmlNames(self,mw) :
+
+        dsk = sgPyQt.getDesktop()
+        studyId = sgPyQt.getStudyId()
+        if _c_CFDGUI != None :
+            studyCFDName,caseName,xmlName  = _c_CFDGUI.getStudyCaseXmlNames(studyId,mw)
+        return studyCFDName,caseName,xmlName
+
+    def getCase(self,mw) :
+
+        dsk = sgPyQt.getDesktop()
+        studyId = sgPyQt.getStudyId()
+        if _c_CFDGUI != None :
+            case  = _c_CFDGUI.getCase(studyId,mw)
+        return case
+
+    def removeDockWindow(self,studyCFDName, caseName, xmlName=""):
+        """
+        Close the CFD_study_dock_windows from remove  popup menu in object browser
+        """
+        log.debug("removeDockWindow -> caseName = %s" % caseName)
+        dsk = sgPyQt.getDesktop()
+        studyId = sgPyQt.getStudyId()
+        if _c_CFDGUI != None :
+            _c_CFDGUI.delDock(dsk,studyId,studyCFDName, caseName, xmlName)
+            updateObjectBrowser()
+
 
 
-    def update_WindowsMap_dict(self,aCase,aXmlFileName) :
-        l_win = []
-        for win in self._WindowsMap.keys() :
-            xmlfile = os.path.basename(win.case['xmlfile'])
-            boo = self._WindowsMap[win].GetName() == aCase.GetName() and xmlfile.rstrip() == aXmlFileName and self._WindowsMap[win].GetFather().GetName() == aCase.GetFather().GetName()
-            if boo :
-                l_win.append(win)
-        if len(l_win) != 0 :
-            for w in l_win :
-                del self._WindowsMap[w]
 
