@@ -9,7 +9,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2011 EDF S.A.
+  Copyright (C) 1998-2012 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -79,8 +79,9 @@ void CS_PROCF(clmopt, CLMOPT)
                                *     merging should take place */
  const cs_int_t   *mltmmr,    /* <-- Number of active ranks under which no
                                *     merging takes place */
- const cs_int_t   *mltmst     /* <-- Number of ranks over which merging
+ const cs_int_t   *mltmst,    /* <-- Number of ranks over which merging
                                *     takes place */
+ const cs_int_t   *mlttyp     /* <-- Coarsening algorithm selection */
 );
 
 /*----------------------------------------------------------------------------
@@ -92,6 +93,17 @@ void CS_PROCF(clmimp, CLMIMP)
  void
 );
 
+/*----------------------------------------------------------------------------
+ * Order an array of real numbers by increasing value.
+ *----------------------------------------------------------------------------*/
+
+void CS_PROCF(clmlgo, CLMLGO)
+(
+ const cs_int_t   *nfac,      /* <-- Number of internal faces */
+ const cs_real_t   critr[],   /* <-- Array to order */
+ cs_int_t          iord[]     /* <-> ordering */
+);
+
 /*=============================================================================
  * Public function prototypes
  *============================================================================*/
@@ -104,30 +116,32 @@ void CS_PROCF(clmimp, CLMIMP)
  * destroyed before those arrays.
  *
  * parameters:
- *   n_cells     <-- Local number of cells
- *   n_cells_ext <-- Local number of cells + ghost cells
- *   n_faces     <-- Local number of faces
- *   symmetric   <-- True if xam is symmetric, false otherwise
- *   face_cell   <-- Face -> cells connectivity (1 to n)
- *   halo        <-- Halo structure associated with this level, or NULL.
- *   numbering   <-- vectorization or thread-related numbering info, or NULL
- *   cell_cen    <-- Cell center (size: 3.n_cells_ext)
- *   cell_vol    <-- Cell volume (size: n_cells_ext)
- *   face_normal <-- Internal face normals (size: 3.n_faces)
- *   da          <-- Matrix diagonal (size: n_cell_ext)
- *   xa          <-- Matrix extra-diagonal terms
- *                   (size: n_faces if symmetric, 2.n_faces otherwise)
+ *   n_cells         <-- Local number of cells
+ *   n_cells_ext     <-- Local number of cells + ghost cells
+ *   n_faces         <-- Local number of faces
+ *   symmetric       <-- True if xam is symmetric, false otherwise
+ *   diag_block_size <-- Block sizes for diagonal, or NULL
+ *   face_cell       <-- Face -> cells connectivity (1 to n)
+ *   halo            <-- Halo structure associated with this level, or NULL.
+ *   numbering       <-- vectorization or thread-related numbering info, or NULL
+ *   cell_cen        <-- Cell center (size: 3.n_cells_ext)
+ *   cell_vol        <-- Cell volume (size: n_cells_ext)
+ *   face_normal     <-- Internal face normals (size: 3.n_faces)
+ *   da              <-- Matrix diagonal (size: n_cell_ext)
+ *   xa              <-- Matrix extra-diagonal terms
+ *                       (size: n_faces if symmetric, 2.n_faces otherwise)
  *
  * returns:
  *   base grid structure
  *----------------------------------------------------------------------------*/
 
 cs_grid_t *
-cs_grid_create_from_shared(fvm_lnum_t             n_cells,
-                           fvm_lnum_t             n_cells_ext,
-                           fvm_lnum_t             n_faces,
-                           cs_bool_t              symmetric,
-                           const fvm_lnum_t      *face_cell,
+cs_grid_create_from_shared(cs_lnum_t              n_cells,
+                           cs_lnum_t              n_cells_ext,
+                           cs_lnum_t              n_faces,
+                           bool                   symmetric,
+                           const int             *diag_block_size,
+                           const cs_lnum_t       *face_cell,
                            const cs_halo_t       *halo,
                            const cs_numbering_t  *numbering,
                            const cs_real_t       *cell_cen,
@@ -153,6 +167,7 @@ cs_grid_destroy(cs_grid_t **grid);
  *   g           <-- Grid structure
  *   level       --> Level in multigrid hierarchy (or NULL)
  *   symmetric   --> Symmetric matrix coefficients indicator (or NULL)
+ *   db_size     --> Size of the diagonal block (or NULL)
  *   n_ranks     --> number of ranks with data (or NULL)
  *   n_cells     --> Number of local cells (or NULL)
  *   n_cells_ext --> Number of cells including ghosts (or NULL)
@@ -163,12 +178,13 @@ cs_grid_destroy(cs_grid_t **grid);
 void
 cs_grid_get_info(const cs_grid_t  *g,
                  int              *level,
-                 cs_bool_t        *symmetric,
+                 bool             *symmetric,
+                 int              *db_size,
                  int              *n_ranks,
-                 fvm_lnum_t       *n_cells,
-                 fvm_lnum_t       *n_cells_ext,
-                 fvm_lnum_t       *n_faces,
-                 fvm_gnum_t       *n_g_cells);
+                 cs_lnum_t        *n_cells,
+                 cs_lnum_t        *n_cells_ext,
+                 cs_lnum_t        *n_faces,
+                 cs_gnum_t        *n_g_cells);
 
 /*----------------------------------------------------------------------------
  * Get number of cells corresponding to a grid.
@@ -180,7 +196,7 @@ cs_grid_get_info(const cs_grid_t  *g,
  *   number of cells of grid structure
  *----------------------------------------------------------------------------*/
 
-fvm_lnum_t
+cs_lnum_t
 cs_grid_get_n_cells(const cs_grid_t  *g);
 
 /*----------------------------------------------------------------------------
@@ -193,7 +209,7 @@ cs_grid_get_n_cells(const cs_grid_t  *g);
  *   number of extended cells of grid structure
  *----------------------------------------------------------------------------*/
 
-fvm_lnum_t
+cs_lnum_t
 cs_grid_get_n_cells_ext(const cs_grid_t  *g);
 
 /*----------------------------------------------------------------------------
@@ -208,7 +224,7 @@ cs_grid_get_n_cells_ext(const cs_grid_t  *g);
  *   merging
  *----------------------------------------------------------------------------*/
 
-fvm_lnum_t
+cs_lnum_t
 cs_grid_get_n_cells_max(const cs_grid_t  *g);
 
 /*----------------------------------------------------------------------------
@@ -221,24 +237,21 @@ cs_grid_get_n_cells_max(const cs_grid_t  *g);
  *   global number of cells of grid structure
  *----------------------------------------------------------------------------*/
 
-fvm_gnum_t
+cs_gnum_t
 cs_grid_get_n_g_cells(const cs_grid_t  *g);
 
 /*----------------------------------------------------------------------------
  * Get grid's associated matrix information.
  *
  * parameters:
- *   g           <-- Grid structure
- *   da          --> Diagonal matrix coefficients
- *   xa          --> Non-diagonal matrix coefficients
- *   m           --> Associated matrix structure
+ *   g <-- Grid structure
+ *
+ * returns:
+ *   pointer to matrix structure
  *----------------------------------------------------------------------------*/
 
-void
-cs_grid_get_matrix(const cs_grid_t  *g,
-                   const cs_real_t  **da,
-                   const cs_real_t  **xa,
-                   cs_matrix_t      **m);
+const cs_matrix_t *
+cs_grid_get_matrix(const cs_grid_t  *g);
 
 #if defined(HAVE_MPI)
 
@@ -261,10 +274,10 @@ cs_grid_get_comm(const cs_grid_t  *g);
  * Create coarse grid from fine grid.
  *
  * parameters:
- *   f                   <-- Fine grid structure
- *   verbosity           <-- Verbosity level
- *   agglomeration_limit <-- Maximum allowed fine cells per coarse cell
- *   max_agglomeration   <-> Maximum fine cells per coarse cell
+ *   f                    <-- Fine grid structure
+ *   verbosity            <-- Verbosity level
+ *   aggregation_limit    <-- Maximum allowed fine cells per coarse cell
+ *   relaxation_parameter <-- P0/P1 relaxation factor
  *
  * returns:
  *   coarse grid structure
@@ -273,8 +286,7 @@ cs_grid_get_comm(const cs_grid_t  *g);
 cs_grid_t *
 cs_grid_coarsen(const cs_grid_t  *f,
                 int               verbosity,
-                int               agglomeration_limit,
-                int              *max_agglomeration,
+                int               aggregation_limit,
                 double            relaxation_parameter);
 
 /*----------------------------------------------------------------------------
@@ -343,7 +355,7 @@ cs_grid_prolong_cell_var(const cs_grid_t  *c,
 
 void
 cs_grid_project_cell_num(const cs_grid_t  *g,
-                         fvm_lnum_t        n_base_cells,
+                         cs_lnum_t         n_base_cells,
                          int               max_num,
                          int               c_cell_num[]);
 
@@ -358,7 +370,7 @@ cs_grid_project_cell_num(const cs_grid_t  *g,
 
 void
 cs_grid_project_cell_rank(const cs_grid_t  *g,
-                          fvm_lnum_t        n_base_cells,
+                          cs_lnum_t         n_base_cells,
                           int               f_cell_rank[]);
 
 /*----------------------------------------------------------------------------
@@ -373,7 +385,7 @@ cs_grid_project_cell_rank(const cs_grid_t  *g,
 
 void
 cs_grid_project_var(const cs_grid_t  *g,
-                    fvm_lnum_t        n_base_cells,
+                    cs_lnum_t         n_base_cells,
                     const cs_real_t   c_var[],
                     cs_real_t         f_var[]);
 
@@ -388,7 +400,7 @@ cs_grid_project_var(const cs_grid_t  *g,
 
 void
 cs_grid_project_diag_dom(const cs_grid_t  *g,
-                         fvm_lnum_t        n_base_cells,
+                         cs_lnum_t         n_base_cells,
                          cs_real_t         diag_dom[]);
 
 /*----------------------------------------------------------------------------
@@ -403,13 +415,18 @@ cs_grid_project_diag_dom(const cs_grid_t  *g,
  *                            takes place, or NULL
  *   merge_stride         --> number of ranks over which merging takes place,
  *                            or NULL
+ *   coarsening_type      --> coarsening type:
+ *                             0: algebraic with natural face traversal;
+ *                             1: algebraic with face traveral by criteria;
+ *                             2: algebraic with Hilbert face traversal;
  *----------------------------------------------------------------------------*/
 
 void
 cs_grid_get_defaults(int  *merge_mean_threshold,
                      int  *merge_glob_threshold,
                      int  *merge_min_ranks,
-                     int  *merge_stride);
+                     int  *merge_stride,
+                     int  *coarsening_type);
 
 /*----------------------------------------------------------------------------
  * Set the default parameters for multigrid coarsening.
@@ -422,13 +439,18 @@ cs_grid_get_defaults(int  *merge_mean_threshold,
  *   merge_min_ranks      <-- number of active ranks under which no merging
  *                            takes place
  *   merge_stride         <-- number of ranks over which merging takes place
+ *   coarsening_type      <-- coarsening type:
+ *                             0: algebraic with natural face traversal;
+ *                             1: algebraic with face traveral by criterai;
+ *                             2: algebraic with Hilbert face traversal;
  *----------------------------------------------------------------------------*/
 
 void
 cs_grid_set_defaults(int  merge_mean_threshold,
                      int  merge_glob_threshold,
                      int  merge_min_ranks,
-                     int  merge_stride);
+                     int  merge_stride,
+                     int  coarsening_type);
 
 /*----------------------------------------------------------------------------
  * Return the merge_stride if merging is active.
