@@ -5,7 +5,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2011 EDF S.A.
+  Copyright (C) 1998-2012 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -24,13 +24,9 @@
 
 /*----------------------------------------------------------------------------*/
 
-/* Detect version of C used (C89 or C99) */
+#define CS_IGNORE_MPI 1  /* No MPI for this application */
 
-#if !defined(__STDC_VERSION__)
-#  define __STDC_VERSION__ 1989
-#endif
-
-#include "cs_config.h"
+#include "cs_defs.h"
 
 /*
   Force LARGEFILE_SOURCE if large files enabled under 32-bit Linux or Blue Gene
@@ -40,7 +36,7 @@
 */
 
 #if (SIZEOF_LONG < 8) && (_FILE_OFFSET_BITS == 64)
-# if defined(__linux__) || defined(__blrts__) || defined(__bgp__)
+# if defined(__linux__) || defined(__blrts__) || defined(__bg__)
 #  if !defined(_POSIX_SOURCE)
 #    define _GNU_SOURCE 1
 #  endif
@@ -62,34 +58,6 @@
 #include <stdlib.h>
 #include <string.h>
 
-#if defined(HAVE_SYS_TYPES_H)
-#include <sys/types.h>
-#endif
-
-#if (__STDC_VERSION__ >= 199901L)
-#include <stdint.h>
-#endif
-
-/*----------------------------------------------------------------------------
- * Internationalization macros
- *----------------------------------------------------------------------------*/
-
-#if defined(ENABLE_NLS)
-
-#include <libintl.h>
-#define _(String) gettext(String)
-#define gettext_noop(String) String
-#define N_(String) gettext_noop(String)
-
-#else
-
-#define _(String) String
-#define N_(String) String
-#define textdomain(Domain)
-#define bindtextdomain(Package, Directory)
-
-#endif
-
 /*----------------------------------------------------------------------------
  *  Local headers
  *----------------------------------------------------------------------------*/
@@ -1901,7 +1869,6 @@ _find_and_extract_section(_cs_io_t    *inp,
 {
   size_t id;
   int extract_id = -1;
-  long long extract_offset = -1;
   _cs_io_sec_index_t *index = inp->index;
 
   /* Find matching sections */
@@ -1919,10 +1886,8 @@ _find_and_extract_section(_cs_io_t    *inp,
       match = 0;
 
     if (match == 1) {
-      if (extract_id < 0) {
+      if (extract_id < 0)
         extract_id = id;
-        extract_offset = index->offset[id];
-      }
       else
         _error(__FILE__, __LINE__, 0,
                _("File \"%s\" contains multiple sections\n"
