@@ -5,7 +5,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2011 EDF S.A.
+  Copyright (C) 1998-2012 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -24,24 +24,24 @@
 
 /*----------------------------------------------------------------------------*/
 
-#if defined(HAVE_CONFIG_H)
-#include "cs_config.h"
-#endif
-
 /* On glibc-based systems, define _GNU_SOURCE so as to enable floating-point
    error exceptions; on Itanium, optimized code may raise such exceptions
    due to speculative execution, so we only enable raising of such exceptions
    for code compiled in debug mode, where reduced optimization should not lead
    to such exceptions, and locating the "true" origin of floating-point
-   exceptions is helpful. */
+   exceptions is helpful.
+   _GNU_SOURCE must be defined before including any headers, to ensure
+   the correct feature macros are defined first. */
 
 #if defined(__linux__) || defined(__linux) || defined(linux)
-#if    (!defined(__ia64__) && !defined(__blrts__) && !defined(__bgp__)) \
+#if    (!defined(__ia64__) && !defined(__blrts__) && !defined(__bg__)) \
     || defined(DEBUG)
 #define _GNU_SOURCE
 #endif
 #endif
 
+#include "cs_defs.h"
+
 /*----------------------------------------------------------------------------
  * Standard C library headers
  *----------------------------------------------------------------------------*/
@@ -62,7 +62,6 @@
 
 #include <bft_mem.h>
 #include <bft_printf.h>
-#include <bft_timer.h>
 
 /*----------------------------------------------------------------------------
  * FVM library headers
@@ -80,6 +79,7 @@
 #include "cs_calcium.h"
 #include "cs_coupling.h"
 #include "cs_ctwr.h"
+#include "cs_field.h"
 #include "cs_gradient.h"
 #include "cs_gui.h"
 #include "cs_gui_mesh.h"
@@ -87,23 +87,32 @@
 #include "cs_gui_particles.h"
 #include "cs_io.h"
 #include "cs_join.h"
+#include "cs_log.h"
 #include "cs_mesh.h"
-#include "cs_mesh_quantities.h"
-#include "cs_mesh_save.h"
-#include "cs_mesh_quality.h"
-#include "cs_mesh_warping.h"
 #include "cs_mesh_coherency.h"
+#include "cs_mesh_from_builder.h"
+#include "cs_mesh_location.h"
+#include "cs_mesh_quality.h"
+#include "cs_mesh_quantities.h"
+#include "cs_mesh_bad_cells.h"
+#include "cs_mesh_save.h"
+#include "cs_mesh_smoother.h"
+#include "cs_mesh_to_builder.h"
+#include "cs_mesh_warping.h"
 #include "cs_multigrid.h"
 #include "cs_opts.h"
+#include "cs_partition.h"
 #include "cs_post.h"
 #include "cs_preprocessor_data.h"
 #include "cs_prototypes.h"
-#include "cs_proxy_comm.h"
 #include "cs_renumber.h"
 #include "cs_restart.h"
 #include "cs_sles.h"
 #include "cs_sat_coupling.h"
 #include "cs_syr_coupling.h"
+#include "cs_system_info.h"
+#include "cs_timer.h"
+#include "cs_les_inflow.h"
 
 /*----------------------------------------------------------------------------*/
 
@@ -172,6 +181,7 @@ cs_run(void)
 {
   double  t1, t2;
 
+  bool partition_preprocess = false;
   int  _verif = -1;
   int  check_mask = 0;
   int  cwf_post = 0;
@@ -179,12 +189,19 @@ cs_run(void)
 
   /* System information */
 
-  cs_base_system_info();
+#if defined(HAVE_MPI)
+  cs_system_info(cs_glob_mpi_comm);
+#else
+  cs_system_info();
+#endif
 
   cs_io_defaults_info();
 
+  cs_partition_external_library_info();
+
   /* Initialize global structures for main mesh */
 
+  cs_mesh_location_initialize();
   cs_glob_mesh = cs_mesh_create();
   cs_glob_mesh_builder = cs_mesh_builder_create();
   cs_glob_mesh_quantities = cs_mesh_quantities_create();
@@ -207,7 +224,13 @@ cs_run(void)
   _verif = (   (opts.preprocess | opts.verif) == true
             || opts.benchmark > 0) ? 1 : 0;
 
-  CS_PROCF(initi1, INITI1)(&_verif);
+  cs_field_define_keys_base();
+
+  cs_preprocessor_data_read_headers(cs_glob_mesh,
+                                    cs_glob_mesh_builder);
+
+  if (opts.preprocess == false)
+    CS_PROCF(initi1, INITI1)(&_verif);
 
   /* Discover applications visible through MPI (requires communication);
      this is done after main calculation initialization so that the user
@@ -222,15 +245,30 @@ cs_run(void)
 
   /* Initialize SYRTHES couplings and communication if necessary */
 
-  cs_syr_coupling_all_init(opts.syr_socket);
+  cs_syr_coupling_all_init();
 
   /* Initialize Code_Saturne couplings and communication if necessary */
 
   cs_sat_coupling_all_init();
 
-  /* Choose partitioning type */
+  /* Set partitioning options */
 
-  cs_preprocessor_data_part_choice(cs_gui_get_sfc_partition_type() + 2);
+  {
+    int j_id;
+    bool join = false;
+    bool join_periodic = false;
+
+    for (j_id = 0; j_id < cs_glob_n_joinings; j_id++) {
+      if ((cs_glob_join_array[j_id])->param.perio_type == FVM_PERIODICITY_NULL)
+        join = true;
+      else
+        join_periodic = true;
+    }
+
+    cs_partition_set_preprocess_hints(join, join_periodic);
+    cs_gui_partition();
+    cs_user_partition();
+  }
 
   /* Read Preprocessor output */
 
@@ -243,6 +281,13 @@ cs_run(void)
   cs_user_postprocess_writers();
   cs_post_init_writers();
 
+  /* Print info on fields and associated keys */
+
+  cs_field_log_defs();
+  cs_field_log_key_defs();
+  cs_field_log_all_key_vals(true);
+  cs_log_printf_flush(CS_LOG_SETUP);
+
   /* Join meshes / build periodicity links if necessary */
 
   cs_join_all();
@@ -251,7 +296,7 @@ cs_run(void)
 
   cs_user_mesh_thinwall(cs_glob_mesh);
 
-  /* Initialize extended connectivity, ghost cells and other
+  /* Initialize extended connectivity, ghost cells and other remaining
      parallelism-related structures */
 
   cs_mesh_init_halo(cs_glob_mesh, cs_glob_mesh_builder);
@@ -266,20 +311,50 @@ cs_run(void)
   cs_post_add_free_faces();
   cs_mesh_discard_free_faces(cs_glob_mesh);
 
+  /* Smoothe mesh if required */
+
+  cs_gui_mesh_smoothe(cs_glob_mesh);
+  cs_user_mesh_smoothe(cs_glob_mesh);
+
   /* Triangulate warped faces if necessary */
 
   cs_mesh_warping_get_defaults(&cwf_threshold, &cwf_post);
 
   if (cwf_threshold >= 0.0) {
 
-    t1 = bft_timer_wtime();
+    t1 = cs_timer_wtime();
     cs_mesh_warping_cut_faces(cs_glob_mesh, cwf_threshold, cwf_post);
-    t2 = bft_timer_wtime();
+    t2 = cs_timer_wtime();
 
     bft_printf(_("\n Cutting warped faces (%.3g s)\n"), t2-t1);
 
   }
 
+  /* Now that mesh modification is finished, save mesh if modified
+     (do this before building colors, which adds internal groups) */
+
+  cs_user_mesh_save(cs_glob_mesh); /* Disable or force */
+
+  partition_preprocess = cs_partition_get_preprocess();
+  if (cs_glob_mesh->modified > 0 || partition_preprocess) {
+    if (partition_preprocess) {
+      if (cs_glob_mesh->modified > 0)
+        cs_mesh_save(cs_glob_mesh, cs_glob_mesh_builder, "mesh_output");
+      else
+        cs_mesh_to_builder(cs_glob_mesh, cs_glob_mesh_builder, true, NULL);
+      cs_partition(cs_glob_mesh, cs_glob_mesh_builder, CS_PARTITION_MAIN);
+      cs_mesh_from_builder(cs_glob_mesh, cs_glob_mesh_builder);
+      cs_mesh_init_halo(cs_glob_mesh, cs_glob_mesh_builder);
+      cs_mesh_update_auxiliary(cs_glob_mesh);
+    }
+    else
+      cs_mesh_save(cs_glob_mesh, NULL, "mesh_output");
+  }
+
+  /* Destroy the temporary structure used to build the main mesh */
+
+  cs_mesh_builder_destroy(&cs_glob_mesh_builder);
+
   /* Renumber mesh based on code options */
 
   bft_printf(_("\n Renumbering mesh:\n"));
@@ -287,16 +362,6 @@ cs_run(void)
   cs_renumber_mesh(cs_glob_mesh,
                    cs_glob_mesh_quantities);
 
-  /* Destroy the temporary structure used to build the main mesh */
-
-  cs_mesh_builder_destroy(&cs_glob_mesh_builder);
-
-  /* Now that mesh modification is finished, save mesh if modified
-     (do this before building colors, which adds internal groups) */
-
-  if (cs_glob_mesh->modified == 1)
-    cs_mesh_save(cs_glob_mesh, "mesh_output");
-
   /* Initialize group classes and insert colors if possible */
 
   cs_mesh_build_colors(cs_glob_mesh);
@@ -310,14 +375,17 @@ cs_run(void)
 
   bft_printf_flush();
 
-  t1 = bft_timer_wtime();
+  t1 = cs_timer_wtime();
   cs_mesh_quantities_compute(cs_glob_mesh, cs_glob_mesh_quantities);
-  t2 = bft_timer_wtime();
+  cs_mesh_bad_cells_detect(cs_glob_mesh, cs_glob_mesh_quantities);
+  cs_user_mesh_bad_cells_tag(cs_glob_mesh, cs_glob_mesh_quantities);
+  t2 = cs_timer_wtime();
 
   bft_printf(_("\n Computing geometric quantities (%.3g s)\n"), t2-t1);
 
-  /* Initialize selectors for the mesh */
+  /* Initialize selectors and locations for the mesh */
   cs_mesh_init_selectors();
+  cs_mesh_location_build(cs_glob_mesh, -1);
 
   /* Initialize meshes for the main post-processing */
 
@@ -338,6 +406,7 @@ cs_run(void)
     bft_printf(_("\n Computing quality criteria\n"));
     cs_mesh_quality(cs_glob_mesh, cs_glob_mesh_quantities);
     cs_mesh_coherency_check();
+    cs_mesh_bad_cells_postprocess(cs_glob_mesh, cs_glob_mesh_quantities);
   }
   else if (opts.preprocess == true)
     cs_mesh_coherency_check();
@@ -437,6 +506,7 @@ cs_run(void)
 
     /* Initialize sparse linear systems resolution */
 
+    cs_matrix_initialize();
     cs_sles_initialize();
     cs_multigrid_initialize();
 
@@ -466,11 +536,16 @@ cs_run(void)
 
     cs_multigrid_finalize();
     cs_sles_finalize();
+    cs_matrix_finalize();
 
     /* Finalize gradient computation */
 
     cs_gradient_finalize();
 
+    /* Finalize synthetic inlet condition generation */
+
+    cs_inflow_finalize();
+
   }
 
   bft_printf(_("\n Destroying structures and ending computation\n"));
@@ -503,15 +578,17 @@ cs_run(void)
 
   cs_gui_particles_free();
 
+  /* Free field info */
+
+  cs_field_destroy_all();
+  cs_field_destroy_all_keys();
+
   /* Free main mesh after printing some statistics */
 
+  cs_mesh_location_finalize();
   cs_mesh_quantities_destroy(cs_glob_mesh_quantities);
   cs_mesh_destroy(cs_glob_mesh);
 
-  /* End of possible communication with a proxy */
-
-  cs_proxy_comm_finalize();
-
   /* CPU times and memory management finalization */
 
   cs_io_log_finalize();
@@ -538,10 +615,11 @@ main(int    argc,
 #if defined(HAVE_OPENMP) /* Determine default number of OpenMP threads */
   {
     int t_id;
+#pragma omp parallel private(t_id)
     {
       t_id = omp_get_thread_num();
       if (t_id == 0)
-        cs_glob_n_threads = omp_get_num_threads();
+        cs_glob_n_threads = omp_get_max_threads();
     }
   }
 #endif
@@ -563,7 +641,7 @@ main(int    argc,
   textdomain(PACKAGE);
 #endif
 
-  (void)bft_timer_wtime();
+  (void)cs_timer_wtime();
 
   /* Trap floating-point exceptions */
 
@@ -611,19 +689,6 @@ main(int    argc,
 
   cs_io_log_initialize();
 
-  /* In case of use with SALOME, optional connection with CFD_Proxy
-     launcher or load and start of YACS module */
-
-  /* Using CFD_Proxy, simply initialize connection before standard run */
-  if (opts.proxy_socket != NULL) {
-    cs_proxy_comm_initialize(opts.proxy_socket,
-                             opts.proxy_key,
-                             CS_PROXY_COMM_TYPE_SOCKET);
-    BFT_FREE(opts.proxy_socket);
-    opts.proxy_key = -1;
-    cs_calcium_set_comm_proxy();
-  }
-
   /* Running as a standalone SALOME component, load YACS component
      library and run yacsinit() component initialization and event loop,
      which should itself include the standard run routine */
@@ -635,7 +700,7 @@ main(int    argc,
     cs_calcium_unload_yacs();
   }
 
-  /* In standard case or with CFD_Proxy, simply call regular run() method */
+  /* In standard case, simply call regular run() method */
 
   else
     cs_run();
