@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2011 EDF S.A.
+! Copyright (C) 1998-2012 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -110,8 +110,8 @@ use period
 use ppppar
 use ppthch
 use ppincl
-use atincl
 use mesh
+use atincl
 
 !===============================================================================
 
@@ -166,13 +166,13 @@ actu = xkappa/log((distbf+rugd)/rugd)
 actt = xkappa/log((distbf+rugt)/rugt)
 
 ! prise en compte de l'humidite dans le rapport r/cp
-!if ( ippmod(iatmos).eq.2 ) then
-!   rscp1=(rair/cp0)*(1.+(rvsra-cpvcpa)*qvs(ifac))
-!   rscp2=(rair/cp0)*(1.+(rvsra-cpvcpa)*qv(iel))
-!else
-    rscp1 = rair/cp0
-    rscp2 = rair/cp0
-!endif
+if (ippmod(iatmos).eq.2) then
+   rscp1 = (rair/cp0)*(1.d0 + (rvsra-cpvcpa)*rcodcl(ifac, isca(itotwt),1))
+   rscp2 = (rair/cp0)*(1.d0 + (rvsra-cpvcpa)*rtp(iel,isca(itotwt)))
+else
+   rscp1 = rair/cp0
+   rscp2 = rair/cp0
+endif
 
   tpot1 = rcodcl(ifac,isca(iscalt),1)
   tpot2 = rtp(iel,isca(iscalt))
@@ -180,84 +180,89 @@ actt = xkappa/log((distbf+rugt)/rugt)
 !     .........    ............................................
 !     3.2 - compute virtual potential temperature at two levels
 !     .........    ............................................
-!if ( ippmod(iatmos).eq.2 ) then
-!    tpotv1=tpot1*(1.+(rvsra-1.)*qvs(ifac))
-!    tpotv2=tpot2*(1.+(rvsra-1.)*qv(iel))
-!else
+
+if (ippmod(iatmos).eq.2) then
+    tpotv1 = tpot1*(1.d0 + (rvsra - 1.d0)* rcodcl(ifac, isca(itotwt),1))
+    tpotv2 = tpot2*(1.d0 + (rvsra - 1.d0)* rtp(iel,isca(itotwt)))
+else
   tpotv1 = tpot1
   tpotv2 = tpot2
-!endif
+endif
+
+! Patch for the initial time step when thermal field is not initalized
+if (ntcabs.eq.1) tpotv2 = tpotv1
 
 !     .........    .....................................
 !     3.3 - compute layer average Richardson number
 !     .........    .....................................
 
-! NB: rib =0 if thermal flux conditions are imposed and tpot1 not defined
+! NB: rib = 0 if thermal flux conditions are imposed and tpot1 not defined
 if (abs(utau).le.epzero.or.icodcl(ifac,isca(iscalt)).eq.3) then
  rib = 0.d0
 else
- rib = 2.d0*gredu*distbf*(tpotv2-tpotv1)/(tpotv1+tpotv2)/utau/utau
+ rib = 2.d0*gredu*distbf*(tpotv2 - tpotv1)/(tpotv1 + tpotv2)/utau/utau
 endif
 
 !     .........    ..................................................
-!     3.4 - compute corrction factors based on ECMWF parametrisation
+!     3.4 - compute correction factors based on ECMWF parametrisation
 !         Louis (1982)
 !     ...............................................................
 
-  if (rib.ge.epzero) then
-     fm = 1./(1.+2.*b*rib/sqrt(1.+d*rib))
-     fh = 1/(1.+3.*b*rib*sqrt(1.+d*rib))
-  else
-     fmden1 = (distbf+rugt)*abs(rib)/rugt
-     fmden2 = 1.+3.d0*b*c*actu*actt*sqrt(fmden1)
-     fm = 1.d0-2.*b*rib/fmden2
-     fhden = 3.d0*b*c*actu*actt*sqrt((distbf+rugt)/rugt)
-     fh = 1.d0-(3.d0*b*rib)/(1.d0+fhden*sqrt(abs(rib)))
-  endif
+if (rib.ge.epzero) then
+  fm = 1.d0/(1.d0 + 2.d0*b*rib/sqrt(1.d0 + d*rib))
+  fh = 1.d0/(1.d0 + 3.d0*b*rib*sqrt(1.d0 + d*rib))
+else
+  fmden1 = (distbf + rugt)*abs(rib)/rugt
+  fmden2 = 1.d0 + 3.d0*b*c*actu*actt*sqrt(fmden1)
+  fm = 1.d0 - 2.d0*b*rib/fmden2
+  fhden = 3.d0*b*c*actu*actt*sqrt((distbf + rugt)/rugt)
+  fh = 1.d0 - (3.d0*b*rib)/(1.d0 + fhden*sqrt(abs(rib)))
+endif
 
-  if (fm.le.epzero) fm = epzero
-  if (abs(fh).le.epzero) fh = epzero
+if (fm.le.epzero) fm = epzero
+if (abs(fh).le.epzero) fh = epzero
 
-  cfnnu = 1.d0/sqrt(fm)
-  cfnns = fh/sqrt(fm)
-  if ((1.d0-rib).gt.epzero)then
-    cfnnk = sqrt(1.d0-rib)  ! +correction with turbulent Prandtl
-    cfnne = (1.d0-rib)/sqrt(fm)
-  else
-    cfnnk = 1.d0
-    cfnne = 1.d0
-  endif
+cfnnu = 1.d0/sqrt(fm)
+cfnns = fh/sqrt(fm)
+if ((1.d0-rib).gt.epzero)then
+  cfnnk = sqrt(1.d0 - rib)  ! +correction with turbulent Prandtl
+  cfnne = (1.d0-rib)/sqrt(fm)
+else
+  cfnnk = 1.d0
+  cfnne = 1.d0
+endif
 
 !     ------------------------------------
 !     4 - compute friction velocity  uet
 !     ------------------------------------
 
-  uet = actu * utau * sqrt(fm)
+uet = actu * utau * sqrt(fm)
 
 !     -----------------------------------------
 !     5 - compute surface sensible heat flux q0
 !     -----------------------------------------
 
-  q0 = (tpot1-tpot2) * uet * actt * fh / sqrt(fm)
+q0 = (tpot1-tpot2) * uet * actt * fh / sqrt(fm)
 
 !     -----------------------------------------------
-!     6 - compute Monin-Obukhov lenght (Garratt p 38)
+!     6 - compute Monin-Obukhov length (Garratt p 38)
 !     -----------------------------------------------
 
 if (abs(gredu*q0).le.epzero) then
   lmo = -99999.d0
 else
-  lmo = -uet**3*(t0+tkelvi)/(xkappa*abs(gredu)*q0)
+  lmo = -uet**3*(t0 + tkelvi)/(xkappa*abs(gredu)*q0)
 endif
 
 !     ---------------------------------------
 !     7 - compute surface latent heat flux e0
 !     ---------------------------------------
-
+!
 !  if ( ippmod(iatmos).eq.2 ) then
 !    e0 = (qvs(ifac)-qv(iel)) * uet * actt * fh / sqrt(fm)
 !  endif
 
+
 !----
 ! fin
 !----
