@@ -5,7 +5,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2011 EDF S.A.
+  Copyright (C) 1998-2012 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -24,9 +24,7 @@
 
 /*----------------------------------------------------------------------------*/
 
-#if defined(HAVE_CONFIG_H)
-#include "cs_config.h"
-#endif
+#include "cs_defs.h"
 
 /*----------------------------------------------------------------------------
  * Standard C library headers
@@ -43,30 +41,23 @@
 #include <mpi.h>
 #endif
 
-/*----------------------------------------------------------------------------
- * BFT library headers
- *----------------------------------------------------------------------------*/
-
-#include <bft_mem.h>
-#include <bft_error.h>
-#include <bft_printf.h>
-#include <bft_error.h>
-
-/*----------------------------------------------------------------------------
- * FVM library headers
- *----------------------------------------------------------------------------*/
-
-#include <fvm_nodal.h>
-#include <fvm_interface.h>
-#include <fvm_nodal_extract.h>
-#include <fvm_nodal_project.h>
-#include <fvm_nodal_triangulate.h>
-
 /*----------------------------------------------------------------------------
  * Local headers
  *----------------------------------------------------------------------------*/
 
+#include "bft_mem.h"
+#include "bft_error.h"
+#include "bft_printf.h"
+#include "bft_error.h"
+
+#include "fvm_nodal.h"
+
+#include "fvm_nodal_extract.h"
+#include "fvm_nodal_project.h"
+#include "fvm_nodal_triangulate.h"
+
 #include "cs_calcium.h"
+#include "cs_interface.h"
 #include "cs_mesh.h"
 #include "cs_mesh_quantities.h"
 #include "cs_mesh_connect.h"
@@ -89,8 +80,8 @@ BEGIN_C_DECLS
 
 struct _cs_ast_coupling_t {
 
-  fvm_gnum_t   n_g_faces;
-  fvm_gnum_t   n_g_nodes;
+  cs_gnum_t    n_g_faces;
+  cs_gnum_t    n_g_nodes;
 
   /* #if defined(HAVE_MPI) */
 
@@ -100,7 +91,7 @@ struct _cs_ast_coupling_t {
   cs_int_t    *face_index;
   cs_int_t    *node_index;
 
-  fvm_gnum_t  *NUM_GLOB_PTS;
+  cs_gnum_t   *NUM_GLOB_PTS;
 
   /* #endif */
 
@@ -140,34 +131,21 @@ void CS_PROCF(astgeo, ASTGEO)
   cs_real_t  *almax
 )
 {
-  int i,j, n_faces, nbpts;
+  int j, n_faces;
   int n_nodes;
-  int max = 0;
 
   fvm_nodal_t  *ifs_mesh;
 
-  fvm_gnum_t *num_glob_points = NULL;
-  fvm_gnum_t *num_glob_points_tot = NULL;
-
-  cs_int_t *index = NULL;
   cs_int_t *faces_color = NULL;
   cs_int_t *nodes_color = NULL;
-  cs_int_t *inter_nodes_color = NULL;
 
-  cs_real_t *coords = NULL;
-  cs_real_t *inter_coords = NULL;
   cs_real_t *faces_coords = NULL;
   cs_real_t *nodes_coords = NULL;
-  cs_real_t *coords_rang0 = NULL;
 
   cs_real_t *b_face_cog = cs_glob_mesh_quantities->b_face_cog;
 
   cs_ast_coupling_t  *ast_coupling = cs_glob_ast_coupling;
 
-#if defined(HAVE_MPI)
-  MPI_Status status;
-#endif
-
   n_faces = *(nbfast);
 
   ifs_mesh = cs_mesh_connect_faces_to_nodal(cs_glob_mesh,
@@ -203,10 +181,10 @@ void CS_PROCF(astgeo, ASTGEO)
   BFT_MALLOC(faces_coords, 3*n_faces, cs_real_t);
   BFT_MALLOC(nodes_coords, 3*n_nodes, cs_real_t);
 
-  assert(sizeof(fvm_coord_t)==sizeof(cs_real_t));
+  assert(sizeof(cs_coord_t)==sizeof(cs_real_t));
 
-  fvm_nodal_get_vertex_coords(ifs_mesh, FVM_INTERLACE,
-                              (fvm_coord_t *) nodes_coords);
+  fvm_nodal_get_vertex_coords(ifs_mesh, CS_INTERLACE,
+                              (cs_coord_t *) nodes_coords);
 
   for (j = 0; j < n_faces; j++) {
 
