@@ -5,7 +5,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2011 EDF S.A.
+  Copyright (C) 1998-2012 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -24,9 +24,7 @@
 
 /*----------------------------------------------------------------------------*/
 
-#if defined(HAVE_CONFIG_H)
-#include "cs_config.h"
-#endif
+#include "cs_defs.h"
 
 /*----------------------------------------------------------------------------
  * Standard C library headers
@@ -44,19 +42,15 @@
 #include <bft_error.h>
 #include <bft_printf.h>
 
-/*----------------------------------------------------------------------------
- * FVM library headers
- *----------------------------------------------------------------------------*/
-
-#include <fvm_interface.h>
-#include <fvm_periodicity.h>
-#include <fvm_order.h>
-
 /*----------------------------------------------------------------------------
  *  Local headers
  *----------------------------------------------------------------------------*/
 
 #include "cs_base.h"
+#include "cs_order.h"
+
+#include "cs_interface.h"
+#include "fvm_periodicity.h"
 
 /*----------------------------------------------------------------------------
  *  Header for the current file
@@ -110,6 +104,7 @@ static int _cs_glob_halo_use_barrier = 1;
  * parameters:
  *   halo      <-- pointer to halo structure
  *   sync_mode <-- kind of halo treatment (standard or extended)
+ *   stride    <-- number of (interlaced) values by entity
  *   var       <-- variable whose halo rotation terms are to be saved
  *                 (size: halo->n_local_elts + halo->n_elts[opt_type])
  *----------------------------------------------------------------------------*/
@@ -117,17 +112,18 @@ static int _cs_glob_halo_use_barrier = 1;
 static void
 _save_rotation_values(const cs_halo_t  *halo,
                       cs_halo_type_t    sync_mode,
+                      int               stride,
                       const cs_real_t   var[])
 {
-  cs_int_t  i, rank_id, shift, t_id;
-  cs_int_t  start_std, end_std, length, start_ext, end_ext;
+  cs_lnum_t  i, j, rank_id, shift, t_id;
+  cs_lnum_t  start_std, end_std, length, start_ext, end_ext;
 
   size_t  save_count = 0;
 
   cs_real_t  *save_buffer = _cs_glob_halo_rot_backup;
 
   const int  n_transforms = halo->n_transforms;
-  const cs_int_t  n_elts  = halo->n_local_elts;
+  const cs_lnum_t  n_elts  = halo->n_local_elts;
   const fvm_periodicity_t *periodicity = halo->periodicity;
 
   assert(halo != NULL);
@@ -150,8 +146,10 @@ _save_rotation_values(const cs_halo_t  *halo,
         length = halo->perio_lst[shift + 4*rank_id + 1];
         end_std = start_std + length;
 
-        for (i = start_std; i < end_std; i++)
-          save_buffer[save_count++] = var[i];
+        for (i = start_std; i < end_std; i++) {
+          for (j = 0; j < stride; j++)
+            save_buffer[save_count++] = var[i*stride + j];
+        }
 
         if (sync_mode == CS_HALO_EXTENDED) {
 
@@ -159,8 +157,10 @@ _save_rotation_values(const cs_halo_t  *halo,
           length = halo->perio_lst[shift + 4*rank_id + 3];
           end_ext = start_ext + length;
 
-          for (i = start_ext; i < end_ext; i++)
-            save_buffer[save_count++] = var[i];
+          for (i = start_ext; i < end_ext; i++) {
+            for (j = 0; j < stride; j++)
+              save_buffer[save_count++] = var[i*stride + j];
+          }
 
         }
 
@@ -177,22 +177,24 @@ _save_rotation_values(const cs_halo_t  *halo,
  * parameters:
  *   halo      <-- pointer to halo structure
  *   sync_mode <-- kind of halo treatment (standard or extended)
+ *   stride    <-- number of (interlaced) values by entity
  *   var       <-> variable whose halo rotation terms are to be restored
  *----------------------------------------------------------------------------*/
 
 static void
 _restore_rotation_values(const cs_halo_t  *halo,
                          cs_halo_type_t    sync_mode,
+                         int               stride,
                          cs_real_t         var[])
 {
-  cs_int_t  i, rank_id, shift, t_id;
-  cs_int_t  start_std, end_std, length, start_ext, end_ext;
+  cs_lnum_t  i, j, rank_id, shift, t_id;
+  cs_lnum_t  start_std, end_std, length, start_ext, end_ext;
 
   size_t restore_count = 0;
 
   const cs_real_t  *save_buffer = _cs_glob_halo_rot_backup;
   const int  n_transforms = halo->n_transforms;
-  const cs_int_t  n_elts  = halo->n_local_elts;
+  const cs_lnum_t  n_elts  = halo->n_local_elts;
   const fvm_periodicity_t *periodicity = halo->periodicity;
 
   if (sync_mode == CS_HALO_N_TYPES)
@@ -215,8 +217,10 @@ _restore_rotation_values(const cs_halo_t  *halo,
         length = halo->perio_lst[shift + 4*rank_id + 1];
         end_std = start_std + length;
 
-        for (i = start_std; i < end_std; i++)
-          var[i] = save_buffer[restore_count++];
+        for (i = start_std; i < end_std; i++) {
+          for (j = 0; j < stride; j++)
+            var[i*stride + j] = save_buffer[restore_count++];
+        }
 
         if (sync_mode == CS_HALO_EXTENDED) {
 
@@ -224,8 +228,10 @@ _restore_rotation_values(const cs_halo_t  *halo,
           length = halo->perio_lst[shift + 4*rank_id + 3];
           end_ext = start_ext + length;
 
-          for (i = start_ext; i < end_ext; i++)
-            var[i] = save_buffer[restore_count++];
+          for (i = start_ext; i < end_ext; i++) {
+            for (j = 0; j < stride; j++)
+              var[i*stride + j] = save_buffer[restore_count++];
+          }
 
         }
 
@@ -242,19 +248,21 @@ _restore_rotation_values(const cs_halo_t  *halo,
  * parameters:
  *   halo      <-- pointer to halo structure
  *   sync_mode <-- kind of halo treatment (standard or extended)
+ *   stride    <-- number of (interlaced) values by entity
  *   var       <-> variable whose halo rotation terms are to be zeroed
  *----------------------------------------------------------------------------*/
 
 static void
 _zero_rotation_values(const cs_halo_t  *halo,
                       cs_halo_type_t    sync_mode,
+                      int               stride,
                       cs_real_t         var[])
 {
-  cs_int_t  i, rank_id, shift, t_id;
-  cs_int_t  start_std, end_std, length, start_ext, end_ext;
+  cs_lnum_t  i, j, rank_id, shift, t_id;
+  cs_lnum_t  start_std, end_std, length, start_ext, end_ext;
 
   const int  n_transforms = halo->n_transforms;
-  const cs_int_t  n_elts  = halo->n_local_elts;
+  const cs_lnum_t  n_elts  = halo->n_local_elts;
   const fvm_periodicity_t *periodicity = halo->periodicity;
 
   if (sync_mode == CS_HALO_N_TYPES)
@@ -277,8 +285,10 @@ _zero_rotation_values(const cs_halo_t  *halo,
         length = halo->perio_lst[shift + 4*rank_id + 1];
         end_std = start_std + length;
 
-        for (i = start_std; i < end_std; i++)
-          var[i] = 0.0;
+        for (i = start_std; i < end_std; i++) {
+          for (j = 0; j < stride; j++)
+            var[i*stride + j] = 0.0;
+        }
 
         if (sync_mode == CS_HALO_EXTENDED) {
 
@@ -286,8 +296,10 @@ _zero_rotation_values(const cs_halo_t  *halo,
           length = halo->perio_lst[shift + 4*rank_id + 3];
           end_ext = start_ext + length;
 
-          for (i = start_ext; i < end_ext; i++)
-            var[i] = 0.0;
+          for (i = start_ext; i < end_ext; i++) {
+            for (j = 0; j < stride; j++)
+              var[i*stride + j] = 0.0;
+          }
 
         }
 
@@ -306,29 +318,29 @@ _zero_rotation_values(const cs_halo_t  *halo,
  * Create a halo structure.
  *
  * parameters:
- *   ifs  <--  pointer to a fvm_interface_set structure
+ *   ifs  <--  pointer to a cs_interface_set structure
  *
  * returns:
  *  pointer to created cs_halo_t structure
  *---------------------------------------------------------------------------*/
 
 cs_halo_t *
-cs_halo_create(fvm_interface_set_t  *ifs)
+cs_halo_create(cs_interface_set_t  *ifs)
 {
-  cs_int_t  i, tmp_id, perio_lst_size;
+  cs_lnum_t  i, tmp_id, perio_lst_size;
 
-  cs_int_t  loc_id = -1;
+  cs_lnum_t  loc_id = -1;
 
   cs_halo_t  *halo = NULL;
 
-  const fvm_interface_t  *interface = NULL;
+  const cs_interface_t  *interface = NULL;
 
   BFT_MALLOC(halo, 1, cs_halo_t);
 
-  halo->n_c_domains = fvm_interface_set_size(ifs);
+  halo->n_c_domains = cs_interface_set_size(ifs);
   halo->n_transforms = 0;
 
-  halo->periodicity = fvm_interface_set_periodicity(ifs);
+  halo->periodicity = cs_interface_set_periodicity(ifs);
   halo->n_rotations = 0;
 
   halo->n_local_elts = 0;
@@ -345,10 +357,10 @@ cs_halo_create(fvm_interface_set_t  *ifs)
 
   for (i = 0; i < halo->n_c_domains; i++) {
 
-    interface = fvm_interface_set_get(ifs, i);
-    halo->c_domain_rank[i] = fvm_interface_rank(interface);
+    interface = cs_interface_set_get(ifs, i);
+    halo->c_domain_rank[i] = cs_interface_rank(interface);
 
-    if (cs_glob_rank_id == fvm_interface_rank(interface))
+    if (cs_glob_rank_id == cs_interface_rank(interface))
       loc_id = i;
 
   } /* End of loop on ranks */
@@ -364,25 +376,25 @@ cs_halo_create(fvm_interface_set_t  *ifs)
   /* Order ranks */
 
   if (   halo->n_c_domains > 2
-      && fvm_order_local_test(&(halo->c_domain_rank[1]),
-                              NULL,
-                              halo->n_c_domains-1) == 0) {
+      && cs_order_gnum_test(&(halo->c_domain_rank[1]),
+                            NULL,
+                            halo->n_c_domains-1) == 0) {
 
-    fvm_lnum_t  *order = NULL;
-    fvm_gnum_t  *buffer = NULL;
+    cs_lnum_t  *order = NULL;
+    cs_gnum_t  *buffer = NULL;
 
-    assert(sizeof(fvm_lnum_t) == sizeof(cs_int_t));
+    assert(sizeof(cs_lnum_t) == sizeof(cs_int_t));
 
-    BFT_MALLOC(order, halo->n_c_domains - 1, fvm_lnum_t);
-    BFT_MALLOC(buffer, halo->n_c_domains - 1, fvm_gnum_t);
+    BFT_MALLOC(order, halo->n_c_domains - 1, cs_lnum_t);
+    BFT_MALLOC(buffer, halo->n_c_domains - 1, cs_gnum_t);
 
     for (i = 1; i < halo->n_c_domains; i++)
-      buffer[i-1] = (fvm_gnum_t)halo->c_domain_rank[i];
+      buffer[i-1] = (cs_gnum_t)halo->c_domain_rank[i];
 
-    fvm_order_local_allocated(NULL,
-                              buffer,
-                              order,
-                              halo->n_c_domains - 1);
+    cs_order_gnum_allocated(NULL,
+                            buffer,
+                            order,
+                            halo->n_c_domains - 1);
 
     for (i = 0; i < halo->n_c_domains - 1; i++)
       halo->c_domain_rank[i+1] = (cs_int_t)buffer[order[i]];
@@ -632,6 +644,8 @@ cs_halo_update_buffers(const cs_halo_t *halo)
 
     }
 
+    save_count *= 3;
+
     if (save_count > _cs_glob_halo_rot_backup_size) {
       _cs_glob_halo_rot_backup_size = save_count;
       BFT_REALLOC(_cs_glob_halo_rot_backup,
@@ -649,8 +663,10 @@ cs_halo_update_buffers(const cs_halo_t *halo)
 void
 cs_halo_free_buffer(void)
 {
-  if (_cs_glob_halo_rot_backup != NULL)
+  if (_cs_glob_halo_rot_backup != NULL) {
+    _cs_glob_halo_rot_backup_size = 0;
     BFT_FREE(_cs_glob_halo_rot_backup);
+  }
 }
 
 /*----------------------------------------------------------------------------
@@ -691,6 +707,7 @@ cs_halo_renumber_cells(cs_halo_t       *halo,
  * parameters:
  *   halo      <-- pointer to halo structure
  *   sync_mode <-- synchronization mode (standard or extended)
+ *   size      <-- datatype size
  *   num       <-> pointer to local number value array
  *----------------------------------------------------------------------------*/
 
@@ -700,13 +717,31 @@ cs_halo_sync_untyped(const cs_halo_t  *halo,
                      size_t            size,
                      void             *val)
 {
-  fvm_lnum_t i, start, length;
+  cs_lnum_t i, start, length;
   size_t j;
 
   cs_int_t end_shift = 0;
   int local_rank_id = (cs_glob_n_ranks == 1) ? 0 : -1;
+  unsigned char *src;
   unsigned char *restrict _val = val;
 
+#if defined(HAVE_MPI)
+
+  if (cs_glob_n_ranks > 1) {
+    const size_t send_buffer_size =   CS_MAX(halo->n_send_elts[CS_HALO_EXTENDED],
+                                             halo->n_elts[CS_HALO_EXTENDED])
+                                    * size;
+
+    if (send_buffer_size > _cs_glob_halo_send_buffer_size) {
+      _cs_glob_halo_send_buffer_size =  send_buffer_size;
+      BFT_REALLOC(_cs_glob_halo_send_buffer,
+                  _cs_glob_halo_send_buffer_size,
+                  char);
+    }
+  }
+
+#endif /* defined(HAVE_MPI) */
+
   if (sync_mode == CS_HALO_STANDARD)
     end_shift = 1;
 
@@ -748,6 +783,29 @@ cs_halo_sync_untyped(const cs_halo_t  *halo,
 
     }
 
+    /* Assemble buffers for halo exchange;
+       with threading, use dynamic scheduling ,as this is probably a small loop */
+
+    #pragma omp parallel for private(start, length, src, i, j) schedule(dynamic)
+    for (rank_id = 0; rank_id < halo->n_c_domains; rank_id++) {
+
+      if (halo->c_domain_rank[rank_id] != local_rank) {
+
+        start = halo->send_index[2*rank_id];
+        length = (  halo->send_index[2*rank_id + end_shift]
+                  - halo->send_index[2*rank_id]);
+
+        src = build_buffer + start*size;
+
+        for (i = 0; i < length; i++) {
+          for (j = 0; j < size; j++)
+            src[i*size + j] = _val[halo->send_list[start + i]*size + j];
+        }
+
+      }
+
+    }
+
     /* We wait for posting all receives (often recommended) */
 
     if (_cs_glob_halo_use_barrier)
@@ -761,20 +819,11 @@ cs_halo_sync_untyped(const cs_halo_t  *halo,
 
       if (halo->c_domain_rank[rank_id] != local_rank) {
 
-        unsigned char *src;
-
         start = halo->send_index[2*rank_id];
         length = (  halo->send_index[2*rank_id + end_shift]
                   - halo->send_index[2*rank_id]);
 
-        src = build_buffer + start*size;
-
-        for (i = 0; i < length; i++) {
-          for (j = 0; j < size; j++)
-            src[i*size + j] = _val[halo->send_list[start + i]*size + j];
-        }
-
-        MPI_Isend(src,
+        MPI_Isend(build_buffer + start*size,
                   length*size,
                   MPI_UNSIGNED_CHAR,
                   halo->c_domain_rank[rank_id],
@@ -833,7 +882,7 @@ cs_halo_sync_num(const cs_halo_t  *halo,
                  cs_halo_type_t    sync_mode,
                  cs_int_t          num[])
 {
-  fvm_lnum_t i, start, length;
+  cs_lnum_t i, start, length;
 
   cs_int_t end_shift = 0;
   int local_rank_id = (cs_glob_n_ranks == 1) ? 0 : -1;
@@ -851,7 +900,6 @@ cs_halo_sync_num(const cs_halo_t  *halo,
     int rank_id;
     int request_count = 0;
     cs_int_t *build_buffer = (cs_int_t *)_cs_glob_halo_send_buffer;
-    cs_int_t *buffer = NULL;
     const int local_rank = cs_glob_rank_id;
 
     /* Receive data from distant ranks */
@@ -863,9 +911,7 @@ cs_halo_sync_num(const cs_halo_t  *halo,
 
       if (halo->c_domain_rank[rank_id] != local_rank) {
 
-        buffer = num + halo->n_local_elts + start;
-
-        MPI_Irecv(buffer,
+        MPI_Irecv(num + halo->n_local_elts + start,
                   length,
                   CS_MPI_INT,
                   halo->c_domain_rank[rank_id],
@@ -879,17 +925,12 @@ cs_halo_sync_num(const cs_halo_t  *halo,
 
     }
 
-    /* We wait for posting all receives (often recommended) */
-
-    if (_cs_glob_halo_use_barrier)
-      MPI_Barrier(cs_glob_mpi_comm);
-
-    /* Send data to distant ranks */
+    /* Assemble buffers for halo exchange;
+       with threading, use dynamic scheduling ,as this is probably a small loop */
 
+    #pragma omp parallel for private(start, length, i) schedule(dynamic)
     for (rank_id = 0; rank_id < halo->n_c_domains; rank_id++) {
 
-      /* If this is not the local rank */
-
       if (halo->c_domain_rank[rank_id] != local_rank) {
 
         start = halo->send_index[2*rank_id];
@@ -899,9 +940,26 @@ cs_halo_sync_num(const cs_halo_t  *halo,
         for (i = 0; i < length; i++)
           build_buffer[start + i] = num[halo->send_list[start + i]];
 
-        buffer = build_buffer + start;
+      }
 
-        MPI_Isend(buffer,
+    }
+
+    /* We wait for posting all receives (often recommended) */
+
+    if (_cs_glob_halo_use_barrier)
+      MPI_Barrier(cs_glob_mpi_comm);
+
+    /* Send data to distant ranks */
+
+    for (rank_id = 0; rank_id < halo->n_c_domains; rank_id++) {
+
+      if (halo->c_domain_rank[rank_id] != local_rank) {
+
+        start = halo->send_index[2*rank_id];
+        length =   halo->send_index[2*rank_id + end_shift]
+                 - halo->send_index[2*rank_id];
+
+        MPI_Isend(build_buffer + start,
                   length,
                   CS_MPI_INT,
                   halo->c_domain_rank[rank_id],
@@ -960,16 +1018,10 @@ cs_halo_sync_var(const cs_halo_t  *halo,
                  cs_halo_type_t    sync_mode,
                  cs_real_t         var[])
 {
-  fvm_lnum_t i, start, length;
+  cs_lnum_t i, start, length;
 
-  cs_int_t end_shift = 0;
   int local_rank_id = (cs_glob_n_ranks == 1) ? 0 : -1;
-
-  if (sync_mode == CS_HALO_STANDARD)
-    end_shift = 1;
-
-  else if (sync_mode == CS_HALO_EXTENDED)
-    end_shift = 2;
+  const cs_lnum_t end_shift = (sync_mode == CS_HALO_STANDARD) ? 1 : 2;
 
 #if defined(HAVE_MPI)
 
@@ -978,7 +1030,6 @@ cs_halo_sync_var(const cs_halo_t  *halo,
     int rank_id;
     int request_count = 0;
     cs_real_t *build_buffer = (cs_real_t *)_cs_glob_halo_send_buffer;
-    cs_real_t *buffer = NULL;
     const int local_rank = cs_glob_rank_id;
 
     /* Receive data from distant ranks */
@@ -990,9 +1041,7 @@ cs_halo_sync_var(const cs_halo_t  *halo,
 
       if (halo->c_domain_rank[rank_id] != local_rank) {
 
-        buffer = var + halo->n_local_elts + start;
-
-        MPI_Irecv(buffer,
+        MPI_Irecv(var + halo->n_local_elts + start,
                   length,
                   CS_MPI_REAL,
                   halo->c_domain_rank[rank_id],
@@ -1006,17 +1055,12 @@ cs_halo_sync_var(const cs_halo_t  *halo,
 
     }
 
-    /* We wait for posting all receives (often recommended) */
-
-    if (_cs_glob_halo_use_barrier)
-      MPI_Barrier(cs_glob_mpi_comm);
-
-    /* Send data to distant ranks */
+    /* Assemble buffers for halo exchange;
+       with threading, use dynamic scheduling ,as this is probably a small loop */
 
+    #pragma omp parallel for private(start, length, i) schedule(dynamic)
     for (rank_id = 0; rank_id < halo->n_c_domains; rank_id++) {
 
-      /* If this is not the local rank */
-
       if (halo->c_domain_rank[rank_id] != local_rank) {
 
         start = halo->send_index[2*rank_id];
@@ -1026,9 +1070,26 @@ cs_halo_sync_var(const cs_halo_t  *halo,
         for (i = 0; i < length; i++)
           build_buffer[start + i] = var[halo->send_list[start + i]];
 
-        buffer = build_buffer + start;
+      }
 
-        MPI_Isend(buffer,
+    }
+
+    /* We wait for posting all receives (often recommended) */
+
+    if (_cs_glob_halo_use_barrier)
+      MPI_Barrier(cs_glob_mpi_comm);
+
+    /* Send data to distant ranks */
+
+    for (rank_id = 0; rank_id < halo->n_c_domains; rank_id++) {
+
+      if (halo->c_domain_rank[rank_id] != local_rank) {
+
+        start = halo->send_index[2*rank_id];
+        length =   halo->send_index[2*rank_id + end_shift]
+                 - halo->send_index[2*rank_id];
+
+        MPI_Isend(build_buffer + start,
                   length,
                   CS_MPI_REAL,
                   halo->c_domain_rank[rank_id],
@@ -1089,7 +1150,7 @@ cs_halo_sync_var_strided(const cs_halo_t  *halo,
                          cs_real_t         var[],
                          int               stride)
 {
-  fvm_lnum_t i, j, start, length;
+  cs_lnum_t i, j, start, length;
 
   cs_int_t end_shift = 0;
   int local_rank_id = (cs_glob_n_ranks == 1) ? 0 : -1;
@@ -1097,8 +1158,8 @@ cs_halo_sync_var_strided(const cs_halo_t  *halo,
 #if defined(HAVE_MPI)
 
   if (cs_glob_n_ranks > 1) {
-    const size_t send_buffer_size =   CS_MAX(halo->n_send_elts[sync_mode],
-                                             halo->n_elts[sync_mode])
+    const size_t send_buffer_size =   CS_MAX(halo->n_send_elts[CS_HALO_EXTENDED],
+                                             halo->n_elts[CS_HALO_EXTENDED])
                                     * sizeof(cs_real_t) * stride;
 
     if (send_buffer_size > _cs_glob_halo_send_buffer_size) {
@@ -1152,17 +1213,12 @@ cs_halo_sync_var_strided(const cs_halo_t  *halo,
 
     }
 
-    /* We wait for posting all receives (often recommended) */
-
-    if (_cs_glob_halo_use_barrier)
-      MPI_Barrier(cs_glob_mpi_comm);
-
-    /* Send data to distant ranks */
+    /* Assemble buffers for halo exchange;
+       with threading, use dynamic scheduling ,as this is probably a small loop */
 
+    #pragma omp parallel for private(start, length, i, j) schedule(dynamic)
     for (rank_id = 0; rank_id < halo->n_c_domains; rank_id++) {
 
-      /* If this is not the local rank */
-
       if (halo->c_domain_rank[rank_id] != local_rank) {
 
         start = halo->send_index[2*rank_id];
@@ -1187,9 +1243,28 @@ cs_halo_sync_var_strided(const cs_halo_t  *halo,
           }
         }
 
-        buffer = build_buffer + start*stride;
+      }
 
-        MPI_Isend(buffer,
+    }
+
+    /* We wait for posting all receives (often recommended) */
+
+    if (_cs_glob_halo_use_barrier)
+      MPI_Barrier(cs_glob_mpi_comm);
+
+    /* Send data to distant ranks */
+
+    for (rank_id = 0; rank_id < halo->n_c_domains; rank_id++) {
+
+      /* If this is not the local rank */
+
+      if (halo->c_domain_rank[rank_id] != local_rank) {
+
+        start = halo->send_index[2*rank_id];
+        length = (  halo->send_index[2*rank_id + end_shift]
+                  - halo->send_index[2*rank_id]);
+
+        MPI_Isend(build_buffer + start*stride,
                   length*stride,
                   CS_MPI_REAL,
                   halo->c_domain_rank[rank_id],
@@ -1261,9 +1336,10 @@ cs_halo_sync_var_strided(const cs_halo_t  *halo,
  * the behavior is the same as that of cs_halo_sync_var().
  *
  * parameters:
- *   halo      <-- pointer to halo structure
- *   sync_mode <-- synchronization mode (standard or extended)
- *   var       <-> pointer to variable value array
+ *   halo        <-- pointer to halo structure
+ *   sync_mode   <-- synchronization mode (standard or extended)
+ *   rotation_op <-- rotation operation
+ *   var         <-> pointer to variable value array
  *----------------------------------------------------------------------------*/
 
 void
@@ -1274,15 +1350,63 @@ cs_halo_sync_component(const cs_halo_t    *halo,
 {
   if (   halo->n_rotations > 0
       && rotation_op == CS_HALO_ROTATION_IGNORE)
-    _save_rotation_values(halo, sync_mode, var);
+    _save_rotation_values(halo, sync_mode, 1, var);
 
   cs_halo_sync_var(halo, sync_mode, var);
 
   if (halo->n_rotations > 0) {
     if (rotation_op == CS_HALO_ROTATION_IGNORE)
-      _restore_rotation_values(halo, sync_mode, var);
+      _restore_rotation_values(halo, sync_mode, 1, var);
     else if (rotation_op == CS_HALO_ROTATION_ZERO)
-      _zero_rotation_values(halo, sync_mode, var);
+      _zero_rotation_values(halo, sync_mode, 1, var);
+  }
+}
+
+/*----------------------------------------------------------------------------
+ * Update array of strided vector variable components (floating-point)
+ * halo values in case of parallelism or periodicity.
+ *
+ * This function aims at copying main values from local elements
+ * (id between 1 and n_local_elements) to ghost elements on distant ranks
+ * (id between n_local_elements + 1 to n_local_elements_with_halo).
+ *
+ * If rotation_op is equal to CS_HALO_ROTATION_IGNORE, halo values
+ * corresponding to periodicity with rotation are left unchanged from their
+ * previous values.
+ *
+ * If rotation_op is equal to CS_HALO_ROTATION_ZERO, halo values
+ * corresponding to periodicity with rotation are set to 0.
+ *
+ * If rotation_op is equal to CS_HALO_ROTATION_COPY, halo values
+ * corresponding to periodicity with rotation are exchanged normally, so
+ * the behavior is the same as that of cs_halo_sync_var_strided().
+ *
+ * parameters:
+ *   halo        <-- pointer to halo structure
+ *   sync_mode   <-- synchronization mode (standard or extended)
+ *   rotation_op <-- rotation operation
+ *   var         <-> pointer to variable value array
+ *   stride      <-- number of (interlaced) values by entity
+ *----------------------------------------------------------------------------*/
+
+void
+cs_halo_sync_components_strided(const cs_halo_t    *halo,
+                                cs_halo_type_t      sync_mode,
+                                cs_halo_rotation_t  rotation_op,
+                                cs_real_t           var[],
+                                int                 stride)
+{
+  if (   halo->n_rotations > 0
+      && rotation_op == CS_HALO_ROTATION_IGNORE)
+    _save_rotation_values(halo, sync_mode, stride, var);
+
+  cs_halo_sync_var_strided(halo, sync_mode, var, stride);
+
+  if (halo->n_rotations > 0) {
+    if (rotation_op == CS_HALO_ROTATION_IGNORE)
+      _restore_rotation_values(halo, sync_mode, stride, var);
+    else if (rotation_op == CS_HALO_ROTATION_ZERO)
+      _zero_rotation_values(halo, sync_mode, stride, var);
   }
 
 }
@@ -1327,8 +1451,10 @@ cs_halo_dump(const cs_halo_t  *halo,
              "  periodicity:    %p\n"
              "  n_rotations:    %d\n"
              "  n_local_elts:   %d\n",
-             halo, halo->n_transforms, halo->n_c_domains,
-             halo->periodicity, halo->n_rotations, halo->n_local_elts);
+             (const void *)halo,
+             halo->n_transforms, halo->n_c_domains,
+             (const void *)halo->periodicity,
+             halo->n_rotations, halo->n_local_elts);
 
   bft_printf("\nRanks on halo frontier:\n");
   for (i = 0; i < halo->n_c_domains; i++)
