@@ -5,7 +5,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2011 EDF S.A.
+  Copyright (C) 1998-2012 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -24,9 +24,7 @@
 
 /*----------------------------------------------------------------------------*/
 
-#if defined(HAVE_CONFIG_H)
-#include "cs_config.h"
-#endif
+#include "cs_defs.h"
 
 /*----------------------------------------------------------------------------
  * Standard C library headers
@@ -147,10 +145,6 @@ _arg_env_help(const char  *name)
   fprintf
     (e, _(" -q, --quality     mesh quality verification mode\n"));
 
-  fprintf
-    (e, _(" --syr-socket      enable sockets for SYRTHES 3 coupling\n"
-          "                   <port_num> port number on rank 0\n"));
-
   fprintf
     (e, _(" --version         print version number\n"));
 }
@@ -235,8 +229,6 @@ cs_opts_define(int         argc,
   int arg_id = 0, argerr = 0;
 
   const char moduleoptbase[] = "--yacs-module=";
-  const char socketoptbase[] = "--proxy-socket=";
-  const char keyoptbase[] = "--proxy-key=";
 
   /* Default initialization */
 
@@ -251,13 +243,8 @@ cs_opts_define(int         argc,
   opts->verif = false;
   opts->benchmark = 0;
 
-  opts->syr_socket = -1;
-
   opts->yacs_module = NULL;
 
-  opts->proxy_socket = NULL;
-  opts->proxy_key = -1;
-
   /* Parse command line arguments */
 
   while (++arg_id < argc && argerr == 0) {
@@ -363,46 +350,6 @@ cs_opts_define(int         argc,
     else if (strcmp(s, "-q") == 0 || strcmp(s, "--quality") == 0)
       opts->verif = true;
 
-#if defined(HAVE_SOCKET)
-
-    /* SYRTHES 3 coupling socket */
-
-    else if (strcmp(s, "--syr-socket") == 0) {
-      opts->syr_socket = _arg_to_int(arg_id + 1, argc, argv, &argerr);
-      if (argerr == 0)
-        arg_id++;
-    }
-
-    /* Proxy connection options (do not appear in help as they
-       are not destined to be used directly by a user) */
-
-    else if (strncmp(s, socketoptbase, strlen(socketoptbase)) == 0) {
-      const char *_s = s + strlen(socketoptbase);
-      BFT_MALLOC(opts->proxy_socket, strlen(_s) + 1, char);
-      strcpy(opts->proxy_socket, _s);
-    }
-
-    else if (strncmp(s, keyoptbase, strlen(keyoptbase)) == 0) {
-      const char *_start = s + strlen(keyoptbase);
-      char *_end = NULL;
-      opts->proxy_key = strtol(_start, &_end, 0);
-      if (_end != _start + strlen(_start))
-        argerr = 1;
-    }
-
-#else /* !defined(HAVE_SOCKET) */
-
-    else if (   strcmp(s, "--syr-socket") == 0
-             || (strncmp(s, socketoptbase, strlen(socketoptbase)) == 0)
-             || (strncmp(s, keyoptbase, strlen(keyoptbase)) == 0)) {
-      fprintf(stderr, _("%s was built without socket support,\n"
-                        "so option \"%s\" may not be used.\n"),
-              argv[0], s);
-      cs_exit(EXIT_FAILURE);
-    }
-
-#endif /* defined(HAVE_SOCKET) */
-
     /* Library loader options (do not appear in help as they
        are not destined to be used directly by a user) */
 
