@@ -5,7 +5,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2011 EDF S.A.
+  Copyright (C) 1998-2012 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -24,9 +24,7 @@
 
 /*----------------------------------------------------------------------------*/
 
-#if defined(HAVE_CONFIG_H)
-#include "cs_config.h"
-#endif
+#include "cs_defs.h"
 
 /*----------------------------------------------------------------------------
  * Standard C library headers
@@ -582,9 +580,9 @@ _sat_coupling_interpolate(cs_sat_coupling_t  *couplage)
   cs_real_t  *distant_surf   = NULL;
   cs_real_t  *distant_xyzcen = NULL;
 
-  const fvm_lnum_t   *lstfbr        = NULL;
-  const fvm_lnum_t   *element       = NULL;
-  const fvm_coord_t  *distant_coord = NULL;
+  const cs_lnum_t   *lstfbr        = NULL;
+  const cs_lnum_t   *element       = NULL;
+  const cs_coord_t  *distant_coord = NULL;
 
   cs_mesh_t  *mesh = cs_glob_mesh;
   cs_mesh_quantities_t  *mesh_quantities = cs_glob_mesh_quantities;
@@ -855,7 +853,7 @@ void CS_PROCF (ussatc, USSATC)
 
 void CS_PROCF (nbccpl, NBCCPL)
 (
- fvm_lnum_t  *n_couplings
+ cs_lnum_t   *n_couplings
 )
 {
   if (_cs_glob_n_sat_cp < 0) {
@@ -905,8 +903,8 @@ void CS_PROCF (defloc, DEFLOC)
   int  indic_loc[2] = {0, 0};
 
   char coupled_mesh_name[64];
-  fvm_lnum_t *c_elt_list = NULL;
-  fvm_lnum_t *f_elt_list = NULL;
+  cs_lnum_t *c_elt_list = NULL;
+  cs_lnum_t *f_elt_list = NULL;
   cs_sat_coupling_t  *coupl = NULL;
   fvm_nodal_t  *support_fbr = NULL;
   cs_mesh_quantities_t  *mesh_quantities = cs_glob_mesh_quantities;
@@ -932,7 +930,7 @@ void CS_PROCF (defloc, DEFLOC)
 
   if (coupl->cell_sup_sel != NULL) {
 
-    BFT_MALLOC(c_elt_list, cs_glob_mesh->n_cells, fvm_lnum_t);
+    BFT_MALLOC(c_elt_list, cs_glob_mesh->n_cells, cs_lnum_t);
 
     cs_selector_get_cell_list(coupl->cell_sup_sel,
                               &(coupl->nbr_cel_sup),
@@ -942,7 +940,7 @@ void CS_PROCF (defloc, DEFLOC)
 
   if (coupl->face_sup_sel != NULL) {
 
-    BFT_MALLOC(f_elt_list, cs_glob_mesh->n_b_faces, fvm_lnum_t);
+    BFT_MALLOC(f_elt_list, cs_glob_mesh->n_b_faces, cs_lnum_t);
 
     cs_selector_get_b_face_list(coupl->face_sup_sel,
                                 &(coupl->nbr_fbr_sup),
@@ -1016,7 +1014,7 @@ void CS_PROCF (defloc, DEFLOC)
 
   if (coupl->cell_cpl_sel != NULL) {
 
-    BFT_MALLOC(c_elt_list, cs_glob_mesh->n_cells, fvm_lnum_t);
+    BFT_MALLOC(c_elt_list, cs_glob_mesh->n_cells, cs_lnum_t);
 
     cs_selector_get_cell_list(coupl->cell_cpl_sel,
                               &nbr_cel_cpl,
@@ -1040,7 +1038,7 @@ void CS_PROCF (defloc, DEFLOC)
 
   if (coupl->face_cpl_sel != NULL) {
 
-    BFT_MALLOC(f_elt_list, cs_glob_mesh->n_b_faces, fvm_lnum_t);
+    BFT_MALLOC(f_elt_list, cs_glob_mesh->n_b_faces, cs_lnum_t);
 
     cs_selector_get_b_face_list(coupl->face_cpl_sel,
                                 &nbr_fbr_cpl,
@@ -1450,8 +1448,8 @@ void CS_PROCF (coocpl, COOCPL)
 
     if (n_pts_dist > 0) {
 
-      const fvm_lnum_t   *element;
-      const fvm_coord_t  *coord;
+      const cs_lnum_t   *element;
+      const cs_coord_t  *coord;
 
       element = ple_locator_get_dist_locations(localis);
       coord   = ple_locator_get_dist_coords(localis);
@@ -1669,7 +1667,7 @@ void CS_PROCF (tbicpl, TBICPL)
 {
   cs_int_t  ind;
   cs_int_t  nbr = 0;
-  cs_bool_t  distant = false;
+  bool  distant = false;
 
 #if defined(HAVE_MPI)
 
@@ -1745,7 +1743,7 @@ void CS_PROCF (tbrcpl, TBRCPL)
 {
   cs_int_t  ind;
   cs_int_t  nbr = 0;
-  cs_bool_t  distant = false;
+  bool  distant = false;
 
 #if defined(HAVE_MPI)
 
@@ -1815,7 +1813,7 @@ void CS_PROCF (mxicpl, MXICPL)
        cs_int_t  *varmax
 )
 {
-  cs_bool_t  distant = false;
+  bool  distant = false;
 
 #if defined(HAVE_MPI)
 
@@ -1925,7 +1923,7 @@ cs_sat_coupling_define(const char  *saturne_name,
  *   number of Code_Saturne couplings
  *----------------------------------------------------------------------------*/
 
-fvm_lnum_t
+int
 cs_sat_coupling_n_couplings(void)
 {
   return cs_glob_sat_n_couplings;
@@ -1942,7 +1940,7 @@ cs_sat_coupling_n_couplings(void)
  *----------------------------------------------------------------------------*/
 
 cs_sat_coupling_t *
-cs_sat_coupling_by_id(fvm_lnum_t coupling_id)
+cs_sat_coupling_by_id(int coupling_id)
 {
   cs_sat_coupling_t  *retval = NULL;
 
