@@ -5,7 +5,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2011 EDF S.A.
+  Copyright (C) 1998-2012 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -24,9 +24,9 @@
 
 /*----------------------------------------------------------------------------*/
 
-#if defined(HAVE_CONFIG_H)
-#include "cs_config.h"
-#endif
+#include "cs_defs.h"
+
+/*----------------------------------------------------------------------------*/
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -38,8 +38,6 @@
 #include <bft_mem.h>
 #include <bft_error.h>
 #include <bft_printf.h>
-#include <bft_sys_info.h>
-#include <bft_timer.h>
 
 #include "cs_halo.h"
 #include "cs_mesh.h"
@@ -338,8 +336,8 @@ void CS_PROCF(csgfam, CSGFAM)
 
 void
 cs_selector_get_b_face_list(const char  *criteria,
-                            fvm_lnum_t  *n_b_faces,
-                            fvm_lnum_t   b_face_list[])
+                            cs_lnum_t   *n_b_faces,
+                            cs_lnum_t    b_face_list[])
 {
   int c_id;
 
@@ -373,8 +371,8 @@ cs_selector_get_b_face_list(const char  *criteria,
 
 void
 cs_selector_get_i_face_list(const char  *criteria,
-                            fvm_lnum_t  *n_i_faces,
-                            fvm_lnum_t   i_face_list[])
+                            cs_lnum_t   *n_i_faces,
+                            cs_lnum_t    i_face_list[])
 {
   int c_id;
 
@@ -408,8 +406,8 @@ cs_selector_get_i_face_list(const char  *criteria,
 
 void
 cs_selector_get_cell_list(const char  *criteria,
-                          fvm_lnum_t  *n_cells,
-                          fvm_lnum_t   cell_list[])
+                          cs_lnum_t   *n_cells,
+                          cs_lnum_t    cell_list[])
 {
   int c_id;
 
@@ -447,20 +445,20 @@ cs_selector_get_cell_list(const char  *criteria,
 
 void
 cs_selector_get_cells_boundary(const char  *criteria,
-                               fvm_lnum_t  *n_i_faces,
-                               fvm_lnum_t  *n_b_faces,
-                               fvm_lnum_t   i_face_list[],
-                               fvm_lnum_t   b_face_list[])
+                               cs_lnum_t   *n_i_faces,
+                               cs_lnum_t   *n_b_faces,
+                               cs_lnum_t    i_face_list[],
+                               cs_lnum_t    b_face_list[])
 {
-  fvm_lnum_t ii, n_cells;
-  fvm_lnum_t *cell_list, *cell_flag;
+  cs_lnum_t ii, n_cells;
+  cs_lnum_t *cell_list, *cell_flag;
 
   const cs_mesh_t *mesh = cs_glob_mesh;
 
   /* Mark cells inside zone selection */
 
-  BFT_MALLOC(cell_list, mesh->n_cells, fvm_lnum_t);
-  BFT_MALLOC(cell_flag, mesh->n_cells, fvm_lnum_t);
+  BFT_MALLOC(cell_list, mesh->n_cells, cs_lnum_t);
+  BFT_MALLOC(cell_flag, mesh->n_cells, cs_lnum_t);
 
   for (ii = 0; ii < mesh->n_cells; ii++)
     cell_flag[ii] = 0;
@@ -480,8 +478,8 @@ cs_selector_get_cells_boundary(const char  *criteria,
   /* Now build lists of faces on cell boundaries */
 
   for (ii = 0; ii < mesh->n_i_faces; ii++) {
-    fvm_lnum_t c_id_0 = mesh->i_face_cells[ii*2] - 1;
-    fvm_lnum_t c_id_1 = mesh->i_face_cells[ii*2 + 1] - 1;
+    cs_lnum_t c_id_0 = mesh->i_face_cells[ii*2] - 1;
+    cs_lnum_t c_id_1 = mesh->i_face_cells[ii*2 + 1] - 1;
     if (cell_flag[c_id_0] != cell_flag[c_id_1]) {
       i_face_list[*n_i_faces] = ii + 1;
       *n_i_faces += 1;
@@ -489,7 +487,7 @@ cs_selector_get_cells_boundary(const char  *criteria,
   }
 
   for (ii = 0; ii < mesh->n_b_faces; ii++) {
-    fvm_lnum_t c_id = mesh->b_face_cells[ii] - 1;
+    cs_lnum_t c_id = mesh->b_face_cells[ii] - 1;
     if (cell_flag[c_id] == 1) {
       b_face_list[*n_b_faces] = ii + 1;
       *n_b_faces += 1;
@@ -510,9 +508,9 @@ cs_selector_get_cells_boundary(const char  *criteria,
  *----------------------------------------------------------------------------*/
 
 void
-cs_selector_get_perio_face_list(int          perio_num,
-                                fvm_lnum_t  *n_i_faces,
-                                fvm_lnum_t   i_face_list[])
+cs_selector_get_perio_face_list(int         perio_num,
+                                cs_lnum_t  *n_i_faces,
+                                cs_lnum_t   i_face_list[])
 {
   int ii;
   int *face_perio_num = NULL;
@@ -544,7 +542,7 @@ cs_selector_get_perio_face_list(int          perio_num,
 
 void
 cs_selector_get_family_list(const char  *criteria,
-                            fvm_lnum_t  *n_families,
+                            cs_lnum_t   *n_families,
                             cs_int_t     family_list[])
 {
   int c_id;
