@@ -8,7 +8,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2011 EDF S.A.
+  Copyright (C) 1998-2012 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -132,8 +132,8 @@ void CS_PROCF(csgfam, CSGFAM)
 
 void
 cs_selector_get_b_face_list(const char  *criteria,
-                            fvm_lnum_t  *n_b_faces,
-                            fvm_lnum_t   b_face_list[]);
+                            cs_lnum_t   *n_b_faces,
+                            cs_lnum_t    b_face_list[]);
 
 /*----------------------------------------------------------------------------
  * Fill a list of interior faces verifying a given selection criteria.
@@ -147,8 +147,8 @@ cs_selector_get_b_face_list(const char  *criteria,
 
 void
 cs_selector_get_i_face_list(const char  *criteria,
-                            fvm_lnum_t  *n_i_faces,
-                            fvm_lnum_t   i_face_list[]);
+                            cs_lnum_t   *n_i_faces,
+                            cs_lnum_t    i_face_list[]);
 
 /*----------------------------------------------------------------------------
  * Fill a list of cells verifying a given selection criteria.
@@ -162,8 +162,8 @@ cs_selector_get_i_face_list(const char  *criteria,
 
 void
 cs_selector_get_cell_list(const char  *criteria,
-                          fvm_lnum_t  *n_cells,
-                          fvm_lnum_t   cell_list[]);
+                          cs_lnum_t   *n_cells,
+                          cs_lnum_t    cell_list[]);
 
 /*----------------------------------------------------------------------------
  * Fill lists of faces at the boundary of a set of cells verifying a given
@@ -181,10 +181,10 @@ cs_selector_get_cell_list(const char  *criteria,
 
 void
 cs_selector_get_cells_boundary(const char  *criteria,
-                               fvm_lnum_t  *n_i_faces,
-                               fvm_lnum_t  *n_b_faces,
-                               fvm_lnum_t   i_face_list[],
-                               fvm_lnum_t   b_face_list[]);
+                               cs_lnum_t   *n_i_faces,
+                               cs_lnum_t   *n_b_faces,
+                               cs_lnum_t    i_face_list[],
+                               cs_lnum_t    b_face_list[]);
 
 /*----------------------------------------------------------------------------
  * Fill a list of interior faces belonging to a given periodicity.
@@ -198,8 +198,8 @@ cs_selector_get_cells_boundary(const char  *criteria,
 
 void
 cs_selector_get_perio_face_list(int          perio_num,
-                                fvm_lnum_t  *n_i_faces,
-                                fvm_lnum_t   i_face_list[]);
+                                cs_lnum_t   *n_i_faces,
+                                cs_lnum_t    i_face_list[]);
 
 /*----------------------------------------------------------------------------
  * Fill a list of families verifying a given selection criteria.
@@ -213,7 +213,7 @@ cs_selector_get_perio_face_list(int          perio_num,
 
 void
 cs_selector_get_family_list(const char  *criteria,
-                            fvm_lnum_t  *n_families,
+                            cs_lnum_t   *n_families,
                             cs_int_t     family_list[]);
 
 /*----------------------------------------------------------------------------*/
