@@ -5,7 +5,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2011 EDF S.A.
+  Copyright (C) 1998-2012 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -24,9 +24,7 @@
 
 /*----------------------------------------------------------------------------*/
 
-#if defined(HAVE_CONFIG_H)
-#include "cs_config.h"
-#endif
+#include "cs_defs.h"
 
 /*----------------------------------------------------------------------------
  * Standard C library headers
@@ -43,25 +41,6 @@
 #include <mpi.h>
 #endif
 
-/*----------------------------------------------------------------------------
- * BFT library headers
- *----------------------------------------------------------------------------*/
-
-#include <bft_mem.h>
-#include <bft_error.h>
-#include <bft_printf.h>
-
-/*----------------------------------------------------------------------------
- * FVM library headers
- *----------------------------------------------------------------------------*/
-
-#include <fvm_nodal.h>
-#include <fvm_interface.h>
-#include <fvm_nodal_extract.h>
-#include <fvm_nodal_project.h>
-#include <fvm_parall.h>
-#include <fvm_selector.h>
-
 /*----------------------------------------------------------------------------
  * PLE library headers
  *----------------------------------------------------------------------------*/
@@ -73,12 +52,23 @@
  * Local headers
  *----------------------------------------------------------------------------*/
 
+#include "bft_mem.h"
+#include "bft_error.h"
+#include "bft_printf.h"
+
+#include "fvm_nodal.h"
+#include "fvm_nodal_extract.h"
+#include "fvm_nodal_project.h"
+#include "fvm_selector.h"
+
 #include "cs_coupling.h"
+#include "cs_log.h"
 #include "cs_mesh.h"
+#include "cs_mesh_quantities.h"
 #include "cs_mesh_connect.h"
-#include "cs_selector.h"
 #include "cs_parall.h"
 #include "cs_post.h"
+#include "cs_selector.h"
 
 /*----------------------------------------------------------------------------
  *  Header for the current file
@@ -109,7 +99,7 @@ typedef struct _cs_syr4_coupling_ent_t {
   ple_locator_t     *locator;        /* Associated locator */
 
   int                elt_dim;        /* Element dimension */
-  fvm_lnum_t         n_elts;         /* Number of coupled elements */
+  cs_lnum_t          n_elts;         /* Number of coupled elements */
 
   fvm_nodal_t       *elts;           /* Coupled elements */
 
@@ -117,12 +107,18 @@ typedef struct _cs_syr4_coupling_ent_t {
 
   int                post_mesh_id;   /* 0 if post-processing is not active,
                                         or post-processing mesh_id (< 0) */
-  float             *wall_temp;      /* Wall temperature (received) */
+  float             *solid_temp;     /* Wall temperature (received) */
   float             *flux;           /* Flux (calculated) */
   float             *tfluid_tmp;     /* Fluid temperature (points to flux in
-                                        transient stage where wall_temp and
+                                        transient stage where solid_temp and
                                         fluid_temp are known, NULL once
                                         flux is calculated) */
+
+  /* Saved array for volume coupling. Will be used to build source term. */
+
+  double           *hvol;            /* Volumetric exchange coefficient. */
+  double           *sol_temp;        /* Solid temperature sent by SYRTHES */
+
 } cs_syr4_coupling_ent_t;
 
 /* Structure associated with Syrthes coupling */
@@ -170,6 +166,9 @@ static cs_syr4_coupling_t  **cs_glob_syr4_couplings = NULL;
 
 static int  cs_glob_syr4_post_mesh_ext[2] = {0, 1};
 
+static int  cs_syr4_coupling_conservativity = 0; /* No forcing by default */
+static int  cs_syr4_coupling_implicit = 1;
+
 /*============================================================================
  * Private function definitions
  *============================================================================*/
@@ -240,6 +239,7 @@ _finalize_comm(cs_syr4_coupling_t *syr_coupling)
     MPI_Comm_free(&(syr_coupling->comm));
     syr_coupling->comm = MPI_COMM_NULL;
   }
+
 #endif
 }
 
@@ -305,19 +305,19 @@ _exchange_sync(cs_syr4_coupling_t  *syr_coupling,
  * Post process variables associated with Syrthes couplings
  *
  * parameters:
- *   coupling_id         <--  Id of Syrthes coupling
- *   nt_cur_abs          <--  Current time step
- *   t_cur_abs           <--  Current time value
+ *   coupling        <--  Void pointer to SYRTHES coupling structure
+ *   nt_cur_abs      <--  Current time step
+ *   t_cur_abs       <--  Current time value
  *----------------------------------------------------------------------------*/
 
 static void
-_cs_syr4_coupling_post_function(int        coupling_id,
-                                int        nt_cur_abs,
-                                cs_real_t  t_cur_abs)
+_cs_syr4_coupling_post_function(void       *coupling,
+                                cs_int_t    nt_cur_abs,
+                                cs_real_t   t_cur_abs)
 {
   int type_id, var_id;
 
-  cs_syr4_coupling_t *syr_coupling = cs_syr4_coupling_by_id(coupling_id);
+  const cs_syr4_coupling_t  *syr_coupling = coupling;
   cs_syr4_coupling_ent_t *coupling_ent = NULL;
   const char *var_name[2] = {N_("Wall T"), N_("Flux")};
 
@@ -336,11 +336,11 @@ _cs_syr4_coupling_post_function(int        coupling_id,
         const float *face_var[2] = {NULL, NULL};
 
         if (type_id == 0) {
-          face_var[0] = coupling_ent->wall_temp;
+          face_var[0] = coupling_ent->solid_temp;
           face_var[1] = coupling_ent->flux;
         }
         else {
-          cell_var[0] = coupling_ent->wall_temp;
+          cell_var[0] = coupling_ent->solid_temp;
           cell_var[1] = coupling_ent->flux;
         }
 
@@ -397,15 +397,15 @@ _post_init(cs_syr4_coupling_t      *syr_coupling,
 
   coupling_ent->post_mesh_id = cs_post_get_free_mesh_id();
 
-  if (coupling_ent->wall_temp != NULL)
-    BFT_FREE(coupling_ent->wall_temp);
+  if (coupling_ent->solid_temp != NULL)
+    BFT_FREE(coupling_ent->solid_temp);
   if (coupling_ent->flux != NULL)
     BFT_FREE(coupling_ent->flux);
 
   /* Allocate arrays */
 
   if (coupling_ent->n_elts > 0) {
-    BFT_MALLOC(coupling_ent->wall_temp, coupling_ent->n_elts, float);
+    BFT_MALLOC(coupling_ent->solid_temp, coupling_ent->n_elts, float);
     BFT_MALLOC(coupling_ent->flux, coupling_ent->n_elts, float);
   }
   coupling_ent->tfluid_tmp = NULL;
@@ -425,8 +425,8 @@ _post_init(cs_syr4_coupling_t      *syr_coupling,
 
   /* Register post processing function */
 
-  cs_post_add_time_dep_var(_cs_syr4_coupling_post_function,
-                           coupling_id);
+  cs_post_add_time_dep_output(_cs_syr4_coupling_post_function,
+                              (void *)syr_coupling);
 
   /* Update start and end (negative) numbers associated with
      dedicated post processing meshes */
@@ -455,9 +455,10 @@ _create_coupled_ent(cs_syr4_coupling_t  *syr_coupling,
                     int                  elt_dim)
 {
   char *coupled_mesh_name = NULL;
-  fvm_gnum_t n_exterior = 0, n_dist_elts = 0;
-  fvm_lnum_t *elt_list = NULL;
-  fvm_coord_t *elt_centers = NULL;
+  cs_gnum_t n_exterior = 0, n_dist_elts = 0;
+  cs_gnum_t n_ext = 0;
+  cs_lnum_t *elt_list = NULL;
+  cs_coord_t *elt_centers = NULL;
   const double tolerance = 0.1;
   fvm_nodal_t *location_elts = NULL;
   ple_mesh_elements_closest_t *locate_on_closest = NULL;
@@ -479,10 +480,13 @@ _create_coupled_ent(cs_syr4_coupling_t  *syr_coupling,
   coupling_ent->elts = NULL;
 
   coupling_ent->post_mesh_id = 0;
-  coupling_ent->wall_temp = NULL;
+  coupling_ent->solid_temp = NULL;
   coupling_ent->flux = NULL;
   coupling_ent->tfluid_tmp = NULL;
 
+  coupling_ent->hvol = NULL;
+  coupling_ent->sol_temp = NULL;
+
   if (syr_coupling->verbosity > 0) {
     bft_printf(_("\nExtracting coupled mesh             ..."));
     bft_printf_flush();
@@ -493,11 +497,11 @@ _create_coupled_ent(cs_syr4_coupling_t  *syr_coupling,
   if (elt_dim == syr_coupling->dim) {
 
     BFT_MALLOC(coupled_mesh_name,
-               strlen("SYRTHES  cells") + strlen(syr_coupling->syr_name) + 1,
-               char);
+                 strlen(_("SYRTHES %s cells"))
+               + strlen(syr_coupling->syr_name) + 1, char);
     sprintf(coupled_mesh_name, _("SYRTHES %s cells"), syr_coupling->syr_name);
 
-    BFT_MALLOC(elt_list, cs_glob_mesh->n_cells, fvm_lnum_t);
+    BFT_MALLOC(elt_list, cs_glob_mesh->n_cells, cs_lnum_t);
 
     cs_selector_get_cell_list(select_criteria,
                               &(coupling_ent->n_elts),
@@ -511,7 +515,11 @@ _create_coupled_ent(cs_syr4_coupling_t  *syr_coupling,
                                        elt_list);
 
     BFT_FREE(elt_list);
-    BFT_FREE(coupled_mesh_name);
+
+    /* Allocate additional buffers */
+
+    BFT_MALLOC(coupling_ent->hvol, coupling_ent->n_elts, double);
+    BFT_MALLOC(coupling_ent->sol_temp, coupling_ent->n_elts, double);
 
   }
 
@@ -526,7 +534,7 @@ _create_coupled_ent(cs_syr4_coupling_t  *syr_coupling,
                char);
     sprintf(coupled_mesh_name, _("SYRTHES %s faces"), syr_coupling->syr_name);
 
-    BFT_MALLOC(elt_list, cs_glob_mesh->n_b_faces, fvm_lnum_t);
+    BFT_MALLOC(elt_list, cs_glob_mesh->n_b_faces, cs_lnum_t);
 
     cs_selector_get_b_face_list(select_criteria,
                                 &(coupling_ent->n_elts),
@@ -542,7 +550,6 @@ _create_coupled_ent(cs_syr4_coupling_t  *syr_coupling,
                                        elt_list);
 
     BFT_FREE(elt_list);
-    BFT_FREE(coupled_mesh_name);
 
   }
 
@@ -564,8 +571,8 @@ _create_coupled_ent(cs_syr4_coupling_t  *syr_coupling,
 
   if (syr_coupling->dim == 2) {
 
-    double      a[6];
-    fvm_lnum_t  n_errors = 0;
+    double  a[6];
+    cs_lnum_t  n_errors = 0;
 
     if (syr_coupling->verbosity > 0) {
       bft_printf(_("Projecting the extracted mesh to 2D ..."));
@@ -601,8 +608,8 @@ _create_coupled_ent(cs_syr4_coupling_t  *syr_coupling,
   /* Element information */
 
   if (syr_coupling->verbosity > 0) {
-    fvm_gnum_t n_g_elts = coupling_ent->n_elts;
-    fvm_parall_counter(&n_g_elts, 1);
+    cs_gnum_t n_g_elts = coupling_ent->n_elts;
+    cs_parall_counter(&n_g_elts, 1);
     bft_printf(_("\nExtracted mesh built of %llu elements.\n"),
                (unsigned long long)n_g_elts);
     bft_printf_flush();
@@ -641,9 +648,9 @@ _create_coupled_ent(cs_syr4_coupling_t  *syr_coupling,
 
     BFT_MALLOC(elt_centers,
                coupling_ent->n_elts*syr_coupling->dim,
-               fvm_coord_t);
+               cs_coord_t);
     fvm_nodal_get_element_centers(location_elts,
-                                  FVM_INTERLACE,
+                                  CS_INTERLACE,
                                   coupling_ent->elt_dim,
                                   elt_centers);
   }
@@ -706,17 +713,17 @@ _create_coupled_ent(cs_syr4_coupling_t  *syr_coupling,
 
     if (syr_coupling->visualization != 0) {
 
-      fvm_lnum_t i;
+      cs_lnum_t i;
       int writer_ids[] = {-1};
       int mesh_id = coupling_ent->post_mesh_id - 1;
-      fvm_lnum_t *p_vtx_num = NULL;
+      cs_lnum_t *p_vtx_num = NULL;
       fvm_io_num_t *vtx_io_num = NULL;
       fvm_nodal_t *syr_points = fvm_nodal_create("SYRTHES face centers",
                                                  syr_coupling->dim);
 
-      BFT_MALLOC(p_vtx_num, n_dist_elts, fvm_lnum_t);
+      BFT_MALLOC(p_vtx_num, n_dist_elts, cs_lnum_t);
 
-      for (i = 0; i < (fvm_lnum_t)n_dist_elts; i++)
+      for (i = 0; i < (cs_lnum_t)n_dist_elts; i++)
         p_vtx_num[i] = i+1;
 
       fvm_nodal_define_vertex_list(syr_points, n_dist_elts, p_vtx_num);
@@ -769,22 +776,163 @@ _create_coupled_ent(cs_syr4_coupling_t  *syr_coupling,
   /* Check that all points are effectively located */
 
   n_exterior = ple_locator_get_n_exterior(coupling_ent->locator);
+  n_ext = n_exterior;
 
-  fvm_parall_counter(&n_exterior, 1);
+  cs_parall_counter(&n_ext, 1);
+
+  if (n_ext) {
+
+    int i;
+    int writer_ids[] = {-1};
+    int mesh_id = cs_post_get_free_mesh_id();
+    cs_lnum_t *post_vtx_num = NULL;
+    cs_coord_t *exterior_coords = NULL;
+    cs_coord_t *el_list = NULL;
+    fvm_io_num_t *vtx_io_num = NULL;
+    fvm_nodal_t *ulck_points = fvm_nodal_create("unlocated elements (centers)",
+                                                syr_coupling->dim);
+    const ple_lnum_t *exterior_list
+      = ple_locator_get_exterior_list(coupling_ent->locator);
+
+    BFT_MALLOC(post_vtx_num, n_exterior, cs_lnum_t);
+    BFT_MALLOC(exterior_coords, 3*n_exterior, cs_coord_t);
+    BFT_MALLOC(el_list,
+               coupling_ent->n_elts*3,
+               cs_coord_t);
+
+    fvm_nodal_get_element_centers(coupling_ent->elts,
+                                  CS_INTERLACE,
+                                  coupling_ent->elt_dim,
+                                  el_list);
+
+    for (i = 0; i < (cs_lnum_t)n_exterior; i++) {
+      post_vtx_num[i] = i+1;
+      if (exterior_list[i] > coupling_ent->n_elts)
+        bft_error(__FILE__, __LINE__, 0,
+                  _("Error: invalid exterior elements selection."));
+      exterior_coords[3*i   ] = el_list[3*(exterior_list[i]-1)   ];
+      exterior_coords[3*i +1] = el_list[3*(exterior_list[i]-1) +1];
+      exterior_coords[3*i +2] = el_list[3*(exterior_list[i]-1) +2];
+    }
+
+    fvm_nodal_define_vertex_list(ulck_points,
+                                 (cs_lnum_t)n_exterior,
+                                 post_vtx_num);
+    fvm_nodal_set_shared_vertices
+      (ulck_points,
+       exterior_coords);
+
+    if (cs_glob_n_ranks > 1) {
+      vtx_io_num = fvm_io_num_create_from_scan(n_exterior);
+      fvm_nodal_init_io_num(ulck_points,
+                            fvm_io_num_get_global_num(vtx_io_num),
+                            0);
+    }
+
+    cs_post_define_existing_mesh(mesh_id,
+                                 ulck_points,
+                                 0,
+                                 true,
+                                 false,
+                                 1,
+                                 writer_ids);
+
+    cs_post_activate_writer(0, 1);
+    cs_post_write_meshes(-1, 0.0);
+    cs_post_free_mesh(mesh_id);
+
+    if (cs_glob_n_ranks > 1)
+      fvm_io_num_destroy(vtx_io_num);
+
+    BFT_FREE(el_list);
+    BFT_FREE(exterior_coords);
 
-  if (n_exterior)
     bft_error(__FILE__, __LINE__, 0,
               _("Coupling with SYRTHES impossible:\n"
                 "%llu element centers from mesh \"%s\"\n"
                 "not located on SYRTHES mesh."),
-              (unsigned long long)n_exterior, coupled_mesh_name);
+              (unsigned long long)n_ext, coupled_mesh_name);
+
+  }
 
   if (location_elts != coupling_ent->elts)
     fvm_nodal_destroy(location_elts);
 
+  BFT_FREE(coupled_mesh_name);
+
   return coupling_ent;
 }
 
+/*----------------------------------------------------------------------------
+ * Log timing info
+ *----------------------------------------------------------------------------*/
+
+static void
+_all_comm_times(void)
+{
+  int coupl_id, ent_id;
+  cs_syr4_coupling_t *syr_coupling = NULL;
+
+  if (cs_glob_syr4_n_couplings == 0)
+    return;
+
+  cs_log_printf(CS_LOG_PERFORMANCE, "\n");
+  cs_log_separator(CS_LOG_PERFORMANCE);
+
+  cs_log_printf(CS_LOG_PERFORMANCE,
+                _("\nSYRTHES 4 coupling overheads\n"));
+
+  for (coupl_id = 0; coupl_id < cs_glob_syr4_n_couplings; coupl_id++) {
+
+    syr_coupling = cs_glob_syr4_couplings[coupl_id];
+
+    for (ent_id = 0; ent_id < 2; ent_id++) {
+
+      cs_syr4_coupling_ent_t
+        *ce = (ent_id == 0) ? syr_coupling->faces : syr_coupling->cells;
+      const char *ent_type[] = {N_("surface"), N_("volume")};
+
+      if (ce != NULL) {
+
+        double location_wtime, exchange_wtime;
+        double location_comm_wtime, exchange_comm_wtime;
+
+        if (syr_coupling->syr_name != NULL)
+          cs_log_printf(CS_LOG_PERFORMANCE,
+                        _("\n  %s (%s):\n\n"),
+                        syr_coupling->syr_name, _(ent_type[ent_id]));
+        else
+          cs_log_printf(CS_LOG_PERFORMANCE,
+                        _("\n  coupling %d (%s):\n\n"),
+                        coupl_id + 1, _(ent_type[ent_id]));
+
+        ple_locator_get_times(ce->locator,
+                              &location_wtime,
+                              NULL,
+                              &exchange_wtime,
+                              NULL);
+
+        ple_locator_get_comm_times(ce->locator,
+                                   &location_comm_wtime,
+                                   NULL,
+                                   &exchange_comm_wtime,
+                                   NULL);
+
+        cs_log_printf(CS_LOG_PERFORMANCE,
+                      _("    location time:                 %12.3f\n"
+                        "      communication and wait:      %12.3f\n"
+                        "    variable exchange time:        %12.3f\n"
+                        "      communication and wait:      %12.3f\n"),
+                      location_wtime, location_comm_wtime,
+                      exchange_wtime, exchange_comm_wtime);
+
+      }
+
+    }
+
+  }
+}
+
 /*----------------------------------------------------------------------------
  * Destroy coupled entity helper structure.
  *
@@ -803,11 +951,17 @@ _destroy_coupled_ent(cs_syr4_coupling_ent_t **coupling_ent)
   if (ce->locator != NULL)
     ce->locator = ple_locator_destroy(ce->locator);
 
-  if (ce->wall_temp != NULL)
-    BFT_FREE(ce->wall_temp);
+  if (ce->solid_temp != NULL)
+    BFT_FREE(ce->solid_temp);
   if (ce->flux != NULL)
     BFT_FREE(ce->flux);
 
+  if (ce->hvol != NULL)
+    BFT_FREE(ce->hvol);
+
+  if (ce->sol_temp != NULL)
+    BFT_FREE(ce->sol_temp);
+
   if (ce->elts != NULL)
     ce->elts = fvm_nodal_destroy(ce->elts);
 
@@ -830,14 +984,14 @@ _post_var_update(cs_syr4_coupling_ent_t  *coupling_ent,
                  int                      step,
                  const cs_real_t         *var)
 {
-  fvm_lnum_t  n_elts, ii;
+  cs_lnum_t  n_elts, ii;
 
   assert(coupling_ent != NULL);
 
   if (coupling_ent->post_mesh_id == 0)
     return;
 
-  assert(coupling_ent->wall_temp != NULL);
+  assert(coupling_ent->solid_temp != NULL);
   assert(coupling_ent->flux != NULL);
 
   n_elts = coupling_ent->n_elts;
@@ -848,7 +1002,7 @@ _post_var_update(cs_syr4_coupling_ent_t  *coupling_ent,
 
   case 0:
     for (ii = 0; ii < n_elts; ii++)
-      coupling_ent->wall_temp[ii] = var[ii];
+      coupling_ent->solid_temp[ii] = var[ii];
     break;
 
   case 1:
@@ -860,7 +1014,7 @@ _post_var_update(cs_syr4_coupling_ent_t  *coupling_ent,
   case 2:
     assert(coupling_ent->tfluid_tmp == coupling_ent->flux);
     for (ii = 0; ii < n_elts; ii++)
-      coupling_ent->flux[ii] = var[ii] * (  coupling_ent->wall_temp[ii]
+      coupling_ent->flux[ii] = var[ii] * (  coupling_ent->solid_temp[ii]
                                           - coupling_ent->flux[ii]);
     coupling_ent->tfluid_tmp = NULL;
     break;
@@ -871,6 +1025,88 @@ _post_var_update(cs_syr4_coupling_ent_t  *coupling_ent,
 
 }
 
+/*----------------------------------------------------------------------------
+ * Ensure conservativity thanks to a corrector coefficient computed by SYRTHES
+ * SYRTHES computes a global flux for a given tfluid and hfluid field.
+ * Code_Saturne sent before its computed global flux for this time step.
+ *
+ * parameters:
+ *   syr_coupling    <-- SYRTHES coupling structure
+ *   coupl_face_list <-- list of coupled boundary faces
+ *----------------------------------------------------------------------------*/
+
+static void
+_ensure_conservativity(cs_syr4_coupling_t   *syr_coupling,
+                       const cs_lnum_t       coupl_face_list[])
+{
+  cs_lnum_t ii, face_id;
+
+  double g_flux = 0.0, _flux = 0.0, coef = 0.0;
+
+  double  *surf = cs_glob_mesh_quantities->b_face_surf;
+  cs_syr4_coupling_ent_t  *coupling_ent = NULL;
+
+  /* Sanity checks */
+
+  assert(surf != NULL);
+  assert(coupl_face_list != NULL);
+  assert(syr_coupling != NULL);
+  coupling_ent = syr_coupling->faces;
+  assert(coupling_ent != NULL);
+
+  /* Compute Code_Saturne's global flux */
+
+  for (ii = 0; ii < coupling_ent->n_elts; ii++) {
+    face_id = coupl_face_list[ii] - 1;
+    _flux += coupling_ent->flux[ii] * surf[face_id];
+  }
+
+#if defined(HAVE_MPI)
+  if (cs_glob_n_ranks > 1)
+    MPI_Reduce(&_flux, &g_flux, 1, MPI_DOUBLE, MPI_SUM, 0, cs_glob_mpi_comm);
+#endif
+
+  if (cs_glob_n_ranks == 1)
+    g_flux = _flux;
+
+  /* Send the computed global flux to SYRTHES and receive the corrector
+     coefficient */
+
+#if defined(HAVE_MPI)
+  if (cs_glob_rank_id < 1) {
+
+    MPI_Status  status;
+
+    /* Send global flux */
+
+    MPI_Send(&g_flux, 1, MPI_DOUBLE,
+             syr_coupling->syr_root_rank,
+             cs_syr4_coupling_tag,
+             syr_coupling->comm);
+
+    if (syr_coupling->verbosity > 0)
+      bft_printf(" Global heat flux exchanged with SYRTHES in W: %5.3e\n",
+                 g_flux);
+
+    /* Receive corrector coefficient */
+
+    MPI_Recv(&coef, 1, MPI_DOUBLE,
+             syr_coupling->syr_root_rank,
+             cs_syr4_coupling_tag,
+             syr_coupling->comm,
+             &status);
+
+  }
+#endif
+
+  /* Print message */
+
+  if (syr_coupling->verbosity > 0)
+    bft_printf(" Correction coefficient used to force conservativity during"
+               " coupling with SYRTHES: %5.3e\n", coef);
+
+}
+
 /*============================================================================
  * Public function definitions
  *============================================================================*/
@@ -882,7 +1118,7 @@ _post_var_update(cs_syr4_coupling_ent_t  *coupling_ent,
  *   number of SYRTHES couplings
  *----------------------------------------------------------------------------*/
 
-fvm_lnum_t
+cs_lnum_t
 cs_syr4_coupling_n_couplings(void)
 {
   return cs_glob_syr4_n_couplings;
@@ -899,7 +1135,7 @@ cs_syr4_coupling_n_couplings(void)
  *----------------------------------------------------------------------------*/
 
 cs_syr4_coupling_t *
-cs_syr4_coupling_by_id(fvm_lnum_t coupling_id)
+cs_syr4_coupling_by_id(cs_lnum_t coupling_id)
 {
   cs_syr4_coupling_t  *retval = NULL;
 
@@ -924,8 +1160,8 @@ cs_syr4_coupling_by_id(fvm_lnum_t coupling_id)
  *----------------------------------------------------------------------------*/
 
 void
-cs_syr4_coupling_add(fvm_lnum_t   dim,
-                     fvm_lnum_t   ref_axis,
+cs_syr4_coupling_add(cs_lnum_t    dim,
+                     cs_lnum_t    ref_axis,
                      const char  *face_sel_criterion,
                      const char  *cell_sel_criterion,
                      const char  *syr_name,
@@ -937,7 +1173,7 @@ cs_syr4_coupling_add(fvm_lnum_t   dim,
   /* Allocate _cs_syr4_coupling_t structure */
 
   BFT_REALLOC(cs_glob_syr4_couplings,
-              cs_glob_syr4_n_couplings + 1, cs_syr4_coupling_t*);
+              cs_glob_syr4_n_couplings + 1, cs_syr4_coupling_t *);
   BFT_MALLOC(syr_coupling, 1, cs_syr4_coupling_t);
 
   syr_coupling->dim = dim;
@@ -1003,12 +1239,14 @@ cs_syr4_coupling_add(fvm_lnum_t   dim,
 void
 cs_syr4_coupling_all_destroy(void)
 {
-  fvm_lnum_t i_coupl;
+  cs_lnum_t i_coupl;
   cs_syr4_coupling_t *syr_coupling = NULL;
 
   if (cs_glob_syr4_n_couplings == 0)
     return;
 
+  _all_comm_times();
+
   for (i_coupl = 0; i_coupl < cs_glob_syr4_n_couplings; i_coupl++) {
 
     syr_coupling = cs_glob_syr4_couplings[i_coupl];
@@ -1043,6 +1281,30 @@ cs_syr4_coupling_all_destroy(void)
   bft_printf_flush();
 }
 
+/*----------------------------------------------------------------------------
+ * Set conservativity forcing flag to True (1) or False (0) for all defined
+ * SYRTHES couplings
+ *
+ * parameter:
+ *   flag     <--  Conservativity forcing flag to set
+ *----------------------------------------------------------------------------*/
+
+void
+cs_syr4_coupling_set_conservativity(int  flag)
+{
+  cs_syr4_coupling_conservativity = flag;
+}
+
+/*----------------------------------------------------------------------------
+ * Set explicit treatment for the source terms in SYRTHES volume couplings
+ *----------------------------------------------------------------------------*/
+
+void
+cs_syr4_coupling_set_explicit_treatment(void)
+{
+  cs_syr4_coupling_implicit = 0;
+}
+
 /*----------------------------------------------------------------------------
  * Initialize communicator for SYRTHES coupling
  *
@@ -1063,6 +1325,7 @@ cs_syr4_coupling_init_comm(cs_syr4_coupling_t *syr_coupling,
 
   char  volume_flag = ' ';
   char  boundary_flag = ' ';
+  char  conservativity_flag = '1';
   char  op_name_send[32 + 1];
   char  op_name_recv[32 + 1];
 
@@ -1077,12 +1340,18 @@ cs_syr4_coupling_init_comm(cs_syr4_coupling_t *syr_coupling,
     boundary_flag = 'b';
   if (syr_coupling->cell_sel != NULL)
     volume_flag = 'v';
+  if (cs_syr4_coupling_conservativity == 0)
+    conservativity_flag = '0';
 
-  sprintf(op_name_send, "coupling:type:%c%c",
-          boundary_flag, volume_flag);
+  sprintf(op_name_send, "coupling:type:%c%c%c",
+          boundary_flag, volume_flag, conservativity_flag);
 
   _exchange_sync(syr_coupling, op_name_send, op_name_recv);
 
+  /* Only Code_Saturne set its conservativity flag.
+     To avoid an error, set the conservativity flag in op_name_recv */
+  op_name_recv[16] = op_name_send[16];
+
   if (strcmp(op_name_recv, op_name_send))
     bft_error
       (__FILE__, __LINE__, 0,
@@ -1112,7 +1381,7 @@ cs_syr4_coupling_init_mesh(cs_syr4_coupling_t  *syr_coupling)
   char op_name_send[32 + 1];
   char op_name_recv[32 + 1];
 
-  const fvm_lnum_t verbosity = syr_coupling->verbosity;
+  const cs_lnum_t verbosity = syr_coupling->verbosity;
 
   if (verbosity > 0)
     bft_printf(_("\n ** Processing the mesh for SYRTHES coupling "
@@ -1128,10 +1397,11 @@ cs_syr4_coupling_init_mesh(cs_syr4_coupling_t  *syr_coupling)
                                               syr_coupling->face_sel,
                                               syr_coupling->dim - 1);
 
-  if (syr_coupling->cell_sel != NULL)
+  if (syr_coupling->cell_sel != NULL) {
     syr_coupling->cells = _create_coupled_ent(syr_coupling,
                                               syr_coupling->cell_sel,
                                               syr_coupling->dim);
+  }
 
   /* Communication with SYRTHES */
   /*----------------------------*/
@@ -1157,23 +1427,78 @@ cs_syr4_coupling_init_mesh(cs_syr4_coupling_t  *syr_coupling)
 }
 
 /*----------------------------------------------------------------------------
- * Get number of associated coupled faces in main mesh
+ * Return 1 if this coupling is a surface coupling else 0
  *
  * parameters:
  *   syr_coupling <-- SYRTHES coupling structure
  *
  * returns:
+ *   1 or 0
+ *----------------------------------------------------------------------------*/
+
+int
+cs_syr4_coupling_is_surf(const cs_syr4_coupling_t  *syr_coupling)
+{
+  int retval = 0;
+
+  assert(syr_coupling != NULL);
+
+  if (syr_coupling->faces != NULL)
+    retval = 1;
+
+  return retval;
+}
+
+/*----------------------------------------------------------------------------
+ * Return 1 if this coupling is a volume coupling else 0
+ *
+ * parameters:
+ *   syr_coupling <-- SYRTHES coupling structure
+ *
+ * returns:
+ *   1 or 0
+ *----------------------------------------------------------------------------*/
+
+int
+cs_syr4_coupling_is_vol(const cs_syr4_coupling_t  *syr_coupling)
+{
+  int retval = 0;
+
+  assert(syr_coupling != NULL);
+
+  if (syr_coupling->cells != NULL)
+    retval = 1;
+
+  return retval;
+}
+
+/*----------------------------------------------------------------------------
+ * Get number of associated coupled elements in main mesh
+ *
+ * parameters:
+ *   syr_coupling <-- SYRTHES coupling structure
+ *   mode          <-- 0 (surface); 1 (volume)
+ *
+ * returns:
  *   number of vertices in coupled mesh
  *----------------------------------------------------------------------------*/
 
-fvm_lnum_t
-cs_syr4_coupling_get_n_faces(const cs_syr4_coupling_t *syr_coupling)
+cs_lnum_t
+cs_syr4_coupling_get_n_elts(const cs_syr4_coupling_t *syr_coupling,
+                            int                       mode)
 {
   cs_syr4_coupling_ent_t  *coupling_ent = NULL;
-  fvm_lnum_t retval = 0;
+  cs_lnum_t retval = 0;
+
+  /* Sanity checks */
 
   assert(syr_coupling != NULL);
-  coupling_ent = syr_coupling->faces;
+  assert(mode == 0 || mode == 1);
+
+  if (mode == 0)
+    coupling_ent = syr_coupling->faces;
+  else
+    coupling_ent = syr_coupling->cells;
 
   if (coupling_ent != NULL)
     retval = coupling_ent->n_elts;
@@ -1182,28 +1507,36 @@ cs_syr4_coupling_get_n_faces(const cs_syr4_coupling_t *syr_coupling)
 }
 
 /*----------------------------------------------------------------------------
- * Get local numbering of coupled faces
+ * Get local numbering of coupled elements
  *
  * parameters:
- *   syr_coupling    <-- SYRTHES coupling structure
- *   coupl_face_list --> List of coupled faces (1 to n)
+ *   syr_coupling  <-- SYRTHES coupling structure
+ *   cpl_elt_lst   --> List of coupled elements (1 to n)
+ *   mode          <-- 0 (surface); 1 (volume)
  *----------------------------------------------------------------------------*/
 
 void
-cs_syr4_coupling_get_face_list(const cs_syr4_coupling_t  *syr_coupling,
-                               cs_int_t                   coupl_face_list[])
+cs_syr4_coupling_get_elt_list(const cs_syr4_coupling_t  *syr_coupling,
+                              cs_int_t                   cpl_elt_lst[],
+                              int                        mode)
 {
   cs_syr4_coupling_ent_t  *coupling_ent = NULL;
 
-  assert(sizeof(fvm_lnum_t) == sizeof(cs_int_t));
-  assert(syr_coupling != NULL);
+  /* Sanity checks */
 
-  coupling_ent = syr_coupling->faces;
+  assert(sizeof(cs_lnum_t) == sizeof(cs_int_t));
+  assert(syr_coupling != NULL);
+  assert(mode == 0 || mode == 1);
+
+  if (mode == 0)
+    coupling_ent = syr_coupling->faces;
+  else
+    coupling_ent = syr_coupling->cells;
 
   if (coupling_ent != NULL)
     fvm_nodal_get_parent_num(coupling_ent->elts,
                              coupling_ent->elt_dim,
-                             coupl_face_list);
+                             cpl_elt_lst);
 }
 
 /*----------------------------------------------------------------------------
@@ -1211,16 +1544,25 @@ cs_syr4_coupling_get_face_list(const cs_syr4_coupling_t  *syr_coupling,
  *
  * parameters:
  *   syr_coupling <-- SYRTHES coupling structure
- *   twall        --> wall temperature
+ *   tsolid       --> solid temperature
+ *   mode         <-- 0: surface coupling; 1: volume coupling
  *----------------------------------------------------------------------------*/
 
 void
-cs_syr4_coupling_recv_twall(cs_syr4_coupling_t  *syr_coupling,
-                            cs_real_t            twall[])
+cs_syr4_coupling_recv_tsolid(cs_syr4_coupling_t  *syr_coupling,
+                             cs_real_t            tsolid[],
+                             int                  mode)
 {
+  int  i;
+
   cs_syr4_coupling_ent_t  *coupling_ent = NULL;
 
-  coupling_ent = syr_coupling->faces;
+  assert(mode == 0 || mode == 1);
+
+  if (mode == 0)
+    coupling_ent = syr_coupling->faces;
+  else
+    coupling_ent = syr_coupling->cells;
 
   if (coupling_ent == NULL)
     return;
@@ -1229,39 +1571,59 @@ cs_syr4_coupling_recv_twall(cs_syr4_coupling_t  *syr_coupling,
 
   ple_locator_exchange_point_var(coupling_ent->locator,
                                  NULL,
-                                 twall,
+                                 tsolid,
                                  NULL,
                                  sizeof(cs_real_t),
                                  1,
                                  0);
 
-  if (coupling_ent->n_elts > 0)
-    _post_var_update(coupling_ent, 0, twall);
+  if (coupling_ent->n_elts > 0) {
+    _post_var_update(coupling_ent, 0, tsolid);
+
+    if (mode == 1) { /* Saved tsolid for a future used
+                        in source term definition */
+      assert(coupling_ent->sol_temp != NULL);
+      for (i = 0; i < coupling_ent->n_elts; i++)
+        coupling_ent->sol_temp[i] = tsolid[i];
+    }
+
+  }
+
 }
 
 /*----------------------------------------------------------------------------
  * Send coupling variables to SYRTHES
  *
  * parameters:
- *   syr_coupling <-- SYRTHES coupling structure
- *   tf           <-- fluid temperature
- *   hwall        <-- wall heat exchange coefficient (numerical, not physical)
+ *   syr_coupling    <-- SYRTHES coupling structure
+ *   coupl_face_list <-- list of coupled boundary faces
+ *   tf              <-- fluid temperature
+ *   hf              <-- fluid heat exchange coef. (numerical or user-defined)
+ *   mode            <-- 0: surface coupling; 1: volume coupling
  *----------------------------------------------------------------------------*/
 
 void
-cs_syr4_coupling_send_tf_hwall(cs_syr4_coupling_t  *syr_coupling,
-                               cs_real_t            tf[],
-                               cs_real_t            hwall[])
+cs_syr4_coupling_send_tf_hf(cs_syr4_coupling_t  *syr_coupling,
+                            const cs_lnum_t      cpl_elt_lst[],
+                            cs_real_t            tf[],
+                            cs_real_t            hf[],
+                            cs_int_t             mode)
 {
-  fvm_lnum_t ii;
-  fvm_lnum_t n_dist = 0;
-  const fvm_lnum_t *dist_loc = NULL;
+  cs_lnum_t ii;
 
-  cs_syr4_coupling_ent_t  *coupling_ent = NULL;
+  cs_lnum_t n_dist = 0;
 
   double *send_var = NULL;
+  cs_syr4_coupling_ent_t  *coupling_ent = NULL;
 
-  coupling_ent = syr_coupling->faces;
+  const cs_lnum_t *dist_loc = NULL;
+
+  assert(mode == 0 || mode == 1);
+
+  if (mode == 0)
+    coupling_ent = syr_coupling->faces;
+  else
+    coupling_ent = syr_coupling->cells;
 
   if (coupling_ent == NULL)
     return;
@@ -1275,7 +1637,7 @@ cs_syr4_coupling_send_tf_hwall(cs_syr4_coupling_t  *syr_coupling,
 
   for (ii = 0; ii < n_dist; ii++) {
     send_var[ii*2]     = tf[dist_loc[ii] - 1];
-    send_var[ii*2 + 1] = hwall[dist_loc[ii] - 1];
+    send_var[ii*2 + 1] = hf[dist_loc[ii] - 1];
   }
 
   ple_locator_exchange_point_var(coupling_ent->locator,
@@ -1290,8 +1652,76 @@ cs_syr4_coupling_send_tf_hwall(cs_syr4_coupling_t  *syr_coupling,
 
   if (coupling_ent->n_elts > 0) {
     _post_var_update(coupling_ent, 1, tf);
-    _post_var_update(coupling_ent, 2, hwall);
+    _post_var_update(coupling_ent, 2, hf);
+
+    if (mode == 1) { /* Saved hf for a future used in source term definition */
+      assert(coupling_ent->hvol != NULL);
+      for (ii = 0; ii < coupling_ent->n_elts; ii++)
+        coupling_ent->hvol[ii] = hf[ii];
+    }
+
   }
+
+  /* Exchange flux and corrector coefficient to ensure conservativity */
+
+  if (cs_syr4_coupling_conservativity > 0 && mode == 0)
+    _ensure_conservativity(syr_coupling, cpl_elt_lst);
+
+}
+
+/*----------------------------------------------------------------------------
+ * Compute the explicit/implicit contribution to source terms in case of
+ * volume coupling with SYRTHES4
+ *
+ * parameters:
+ *   syr_coupling  <-- SYRTHES coupling structure
+ *   tf            <-- fluid temperature
+ *   ctbimp        <-> implicit contribution
+ *   ctbexp        <-> explicit contribution
+ *----------------------------------------------------------------------------*/
+
+void
+cs_syr4_coupling_ts_contrib(cs_syr4_coupling_t  *syr_coupling,
+                            const cs_real_t      tf[],
+                            cs_real_t            ctbimp[],
+                            cs_real_t            ctbexp[])
+{
+  int  i;
+
+  double  *hvol = NULL, *solid_temp = NULL;
+  cs_syr4_coupling_ent_t  *ent = NULL;
+
+  /* sanity checks */
+
+  assert(syr_coupling != NULL);
+  assert(syr_coupling->cells != NULL);
+
+  ent = syr_coupling->cells;
+  hvol = ent->hvol;
+  solid_temp = ent->sol_temp;
+
+  assert(hvol != NULL);
+  assert(solid_temp != NULL);
+
+  /* Compute contribution */
+
+  if (cs_syr4_coupling_implicit == 0) { /* Explicit treatment */
+
+    for (i = 0; i < ent->n_elts; i++) {
+      ctbexp[i] = -hvol[i] * (tf[i] - solid_temp[i]);
+      ctbimp[i] = 0.0;
+    }
+
+  }
+  else { /* Implicit treatment */
+
+    for (i = 0; i < ent->n_elts; i++) {
+      ctbexp[i] = hvol[i] * solid_temp[i];
+      ctbimp[i] = hvol[i];
+    }
+
+  } /* Test if implicit */
+
 }
 
 /*----------------------------------------------------------------------------*/
