@@ -5,7 +5,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2011 EDF S.A.
+  Copyright (C) 1998-2012 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -24,9 +24,7 @@
 
 /*----------------------------------------------------------------------------*/
 
-#if defined(HAVE_CONFIG_H)
-#include "cs_config.h"
-#endif
+#include "cs_defs.h"
 
 /*----------------------------------------------------------------------------
  * Standard C library headers
@@ -45,7 +43,6 @@
 
 #include <bft_mem.h>
 #include <bft_error.h>
-#include <bft_timer.h>
 
 /*----------------------------------------------------------------------------
  * FVM library headers
@@ -56,6 +53,7 @@
  *----------------------------------------------------------------------------*/
 
 #include "cs_base.h"
+#include "cs_timer.h"
 
 /*----------------------------------------------------------------------------
  *  Header for the current file
@@ -90,9 +88,9 @@ struct _cs_time_plot_t {
 
   cs_time_plot_format_t   format;  /* Associated format */
 
-  cs_bool_t   use_iteration;    /* Use iteration number instead of
+  bool        use_iteration;    /* Use iteration number instead of
                                  * physical time ? */
-  cs_bool_t   write_time_value; /* Output time value ? */
+  bool        write_time_value; /* Output time value ? */
 
   double      flush_times[2];   /* 0: File flush time interval
                                  *    (if < 0, no forced flush)
@@ -490,7 +488,7 @@ static cs_time_plot_t *
 _plot_file_create(const char             *plot_name,
                   const char             *file_prefix,
                   cs_time_plot_format_t   format,
-                  cs_bool_t               use_iteration,
+                  bool                    use_iteration,
                   double                  flush_wtime,
                   int                     n_buffer_steps)
 {
@@ -594,7 +592,7 @@ _plot_file_check_or_write(cs_time_plot_t  *p)
 
   }
   else {
-    double cur_time = bft_timer_wtime();
+    double cur_time = cs_timer_wtime();
     if (   p->flush_times[0] > 0
         && (cur_time - p->flush_times[1]) > p->flush_times[0]) {
       p->flush_times[1] = cur_time;
@@ -696,7 +694,7 @@ void CS_PROCF (tppini, TPPINI)
   cs_time_plot_format_t fmt;
   char *plot_name   = cs_base_string_f_to_c_create(tplnam, *lnam);
   char *file_prefix = cs_base_string_f_to_c_create(tplpre, *lpre);
-  cs_bool_t use_iteration = false;
+  bool use_iteration = false;
 
   if (*idtvar < 0 || *idtvar == 2)
     use_iteration = true;
@@ -783,7 +781,7 @@ void CS_PROCF (tpsini, TPSINI)
   cs_time_plot_format_t fmt;
   char *plot_name   = cs_base_string_f_to_c_create(tplnam, *lnam);
   char *file_prefix = cs_base_string_f_to_c_create(tplpre, *lpre);
-  cs_bool_t use_iteration = false;
+  bool use_iteration = false;
 
   if (*idtvar < 0 || *idtvar == 2)
     use_iteration = true;
@@ -849,7 +847,7 @@ void CS_PROCF (tplend, TPLEND)
       if (*tplnum <= 0 || *tplnum > (int)_n_files_max[fmt])
         bft_error(__FILE__, __LINE__, errno,
                   _("Plot number must be in the interval [1, %d] and not %d."),
-                  _n_files_max[fmt], *tplnum);
+                  (int)(_n_files_max[fmt]), *tplnum);
 
       p = _plot_files[fmt][*tplnum - 1];
 
@@ -978,7 +976,7 @@ cs_time_plot_t *
 cs_time_plot_init_probe(const char             *plot_name,
                         const char             *file_prefix,
                         cs_time_plot_format_t   format,
-                        cs_bool_t               use_iteration,
+                        bool                    use_iteration,
                         double                  flush_wtime,
                         int                     n_buffer_steps,
                         int                     n_probes,
@@ -1034,7 +1032,7 @@ cs_time_plot_t *
 cs_time_plot_init_struct(const char             *plot_name,
                          const char             *file_prefix,
                          cs_time_plot_format_t   format,
-                         cs_bool_t               use_iteration,
+                         bool                    use_iteration,
                          double                  flush_wtime,
                          int                     n_buffer_steps,
                          int                     n_structures,
