@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2011 EDF S.A.
+! Copyright (C) 1998-2012 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -30,16 +30,14 @@ subroutine dvvpst &
    lstcel , lstfac , lstfbr ,                                     &
    dt     , rtpa   , rtp    , propce , propfa , propfb ,          &
    coefa  , coefb  , statce , stativ , statfb ,                   &
-   tracel , trafac , trafbr ,                                     &
-   ra     )
+   tracel , trafac , trafbr )
 
 !===============================================================================
-! FONCTION :
+! Purpose:
 ! --------
 
-! ROUTINE DEVELOPPEUR POUR LA SORTIE STANDARD
-! DES VALEURS SUR LES MAILLAGES DE POST TRAITEMENT
-!   (appelee apres usproj)
+! Standard output of variables on post-processing meshes
+!   (called after cs_user_extra_operations)
 !-------------------------------------------------------------------------------
 ! Arguments
 !__________________.____._____.________________________________________________.
@@ -70,21 +68,19 @@ subroutine dvvpst &
 ! coefa, coefb     ! ra ! <-- ! boundary conditions                            !
 !  (nfabor, *)     !    !     !                                                !
 ! statce           ! tr ! <-- ! statistiques cellules (lagrangien)             !
-!(ncelet,nvlsta    !    !     !                                                !
-! stativ           ! tr ! <-- ! statistiques variance cellules                 !
-!(ncelet,nvlsta    !    !     !                          (lagrangien)          !
+!  (ncelet,nvlsta) !    !     !                                                !
+! stativ           ! tr ! <-- ! statistiques variance cellules (lagrangien)    !
+!  (ncelet,nvlsta) !    !     !                                                !
 ! statfb           ! tr ! <-- ! statistiques faces bord (lagrangien)           !
-!(nfabor,nvisbr    !    !     !                                                !
+!  (nfabor,nvisbr) !    !     !                                                !
 ! tracel(*)        ! tr ! <-- ! tab reel valeurs cellules post                 !
 ! trafac(*)        ! tr ! <-- ! tab reel valeurs faces int. post               !
 ! trafbr(*)        ! tr ! <-- ! tab reel valeurs faces bord post               !
-! ra(*)            ! ra ! --- ! main real work array                           !
 !__________________!____!_____!________________________________________________!
 
-!     TYPE : E (ENTIER), R (REEL), A (ALPHANUMERIQUE), T (TABLEAU)
-!            L (LOGIQUE)   .. ET TYPES COMPOSES (EX : TR TABLEAU REEL)
-!     MODE : <-- donnee, --> resultat, <-> Donnee modifiee
-!            --- tableau de travail
+!     Type: i (integer), r (real), s (string), a (array), l (logical),
+!           and composite types (ex: ra real array)
+!     mode: <-- input, --> output, <-> modifies data, --- work array
 !===============================================================================
 
 !===============================================================================
@@ -92,6 +88,7 @@ subroutine dvvpst &
 !===============================================================================
 
 use paramx
+use dimens, only: ndimfb
 use pointe
 use entsor
 use cstnum
@@ -124,13 +121,12 @@ integer          lstcel(ncelps), lstfac(nfacps), lstfbr(nfbrps)
 
 double precision dt(ncelet), rtpa(ncelet,*), rtp(ncelet,*)
 double precision propce(ncelet,*)
-double precision propfa(nfac,*), propfb(nfabor,*)
-double precision coefa(nfabor,*), coefb(nfabor,*)
+double precision propfa(nfac,*), propfb(ndimfb,*)
+double precision coefa(ndimfb,*), coefb(ndimfb,*)
 double precision statce(ncelet,nvlsta), statfb(nfabor,nvisbr)
 double precision stativ(ncelet,nvlsta)
 double precision tracel(ncelps*3)
 double precision trafac(nfacps*3), trafbr(nfbrps*3)
-double precision ra(*)
 
 ! Local variables
 
@@ -139,7 +135,7 @@ character*80     name80
 
 integer          inc   , iccocg, nswrgp, imligp, iwarnp
 integer          isorva, isaut
-integer          ifac  , iloc  , ivar , iclvar
+integer          ifac  , iloc  , ivar , iclvar, iclvaf
 integer          ira   , idivdt, ineeyp
 integer          ipp   , idimt , ii    , kk   , iel
 integer          ivarl , iip
@@ -148,10 +144,10 @@ integer          iscal , ipcvsl, ipcvst, iflmab
 integer          ientla, ivarpr
 integer          ipccp , ipcrom
 
-double precision xcp   , xvsl  , srfbn, distbr
+double precision xcp   , xvsl  , srfbn
 double precision visct , flumab, diipbx, diipby, diipbz
 double precision epsrgp, climgp, extrap
-double precision omgnrm, daxis2
+double precision pcentr
 
 double precision rbid(1)
 
@@ -164,126 +160,42 @@ double precision, allocatable, dimension(:) :: treco
 
 ipp = 0
 
-! Memoire
-
-
 !===============================================================================
-!     1.1. TRAITEMENT POUR LE MAILLAGE FLUIDE
+! 1.1. Fluid domain
 !===============================================================================
 
 if (numtyp .eq. -1) then
 
+  !  1.1.2 Variables supplementaires automatiques
+  !  --------------------------------------------
 
-!       1.1.1 TRAITEMENT DES VARIABLES POST TRAITABLES
-!       ----------------------------------------------
-
-  do ipp = 2, nvppmx
-
-!         -> si chrono demande sur la variable
-    if(ichrvr(ipp).eq.1) then
-
-!           -> pointeur de la variable dans RA (en absolu)
-!              (si negatif, c'est un vecteur)
-      ira = ipp2ra(ipp)
-!           -> si c'est un moment cumule, il faut diviser par le temps
-!             (si   0 ce n'est pas un moment,
-!              si > 0 c'est le pointeur dans RA,
-!              si < 0 c'est le rang dans DTCMOM)
-      idivdt = ippmom(ipp)
-!           -> dimension de la variable a ecrire
-      idimt = 1
-      if(ira.lt.0) then
-        idimt = 3
-        ira = -ira
-      endif
-
-!           -> nom de la variable
-      name80 = nomvar(ipp)
-      namevr = name80(1:32)
-
-!           -> si l'on a une variable vectorielle, on supprime
-!              la partie X, Y, ou Z en derniere ou avant-derniere
-!              position dans le nom
-
-      if (idimt.eq.3) then
-        name80 = nomvar(ipp+1)
-        namev1 = name80(1:32)
-        name80 = nomvar(ipp+2)
-        namev2 = name80(1:32)
-        call pstsnv ( namevr , namev1 , namev2 )
-        !==========
-      endif
-
-!           -> si c'est un moment cumule, il faut diviser par le temps
-      if(idivdt.gt.0) then
-        do iloc = 1, ncelps
-          iel = lstcel(iloc)
-          tracel(iloc) = ra(ira+iel-1)/                           &
-               max(ra(idivdt+iel-1),epzero)
-        enddo
-      elseif(idivdt.lt.0) then
-        do iloc = 1, ncelps
-          iel = lstcel(iloc)
-          tracel(iloc) = ra(ira+iel-1)/                           &
-               max(dtcmom(-idivdt),epzero)
-        enddo
-      endif
-
-!           Ecriture effective des valeurs calculees
-
-!           Valeurs non entrelaces
-      ientla = 0
-
-      if(idivdt.eq.0) then
-        ivarpr = 1
-        call psteva(nummai, namevr, idimt, ientla, ivarpr,        &
-        !==========
-                    ntcabs, ttcabs, ra(ira), rbid, rbid)
-
-      else
-        ivarpr = 0
-        call psteva(nummai, namevr, idimt, ientla, ivarpr,        &
-        !==========
-                    ntcabs, ttcabs, tracel, rbid, rbid)
-
-      endif
-
-    endif
-!         Fin du traitement en cas de sortie de la variable
-
-  enddo
-!       Fin de la boucle sur les variables
-
-!       1.1.2 VARIABLES SUPPLEMENTAIRES AUTOMATIQUES
-!       --------------------------------------------
-
-!       Distance a la paroi (si LES+VanDriest ou Rij+Echo ou K-w SST)
+  ! Distance a la paroi (si LES+VanDriest ou Rij+Echo ou K-w SST)
 
   if (ineedy.eq.1 .and. abs(icdpar).eq.1) then
 
-    NAMEVR = 'DistParoi'
+    namevr = 'DistWall'
     idimt = 1
     ientla = 0
     ivarpr = 1
 
-    call psteva(nummai, namevr, idimt, ientla, ivarpr,            &
+    call psteva(nummai, namevr, idimt, ientla, ivarpr,  &
     !==========
                 ntcabs, ttcabs, dispar, rbid, rbid)
 
   endif
 
-!       Yplus (si LES+VanDriest)
+  ! Yplus (si LES+VanDriest)
 
   if (ineedy.eq.1 .and. abs(icdpar).eq.1) then
 
     ineeyp = 0
-    if(itytur.eq.4.and.idries.eq.1) then
+    if (itytur.eq.4.and.idries.eq.1) then
       ineeyp = 1
     endif
 
     if (ineeyp.eq.1) then
 
-      NAMEVR = 'Yplus'
+      namevr = 'Yplus'
       idimt = 1
       ientla = 0
       ivarpr = 1
@@ -301,9 +213,8 @@ if (numtyp .eq. -1) then
   if (icorio.eq.1) then
 
     ipcrom = ipproc(irom)
-    omgnrm = sqrt(omegax**2 + omegay**2 + omegaz**2)
 
-    NAMEVR = 'Pressure'
+    namevr = 'Pressure'
     idimt = 1
     ientla = 0
     ivarpr = 0
@@ -312,14 +223,11 @@ if (numtyp .eq. -1) then
 
       iel = lstcel(iloc)
 
-      daxis2 =   (omegay*xyzcen(3,iel) - omegaz*xyzcen(2,iel))**2 &
-               + (omegaz*xyzcen(1,iel) - omegax*xyzcen(3,iel))**2 &
-               + (omegax*xyzcen(2,iel) - omegay*xyzcen(1,iel))**2
+      pcentr =   0.5d0*((omegay*xyzcen(3,iel) - omegaz*xyzcen(2,iel))**2 &
+                      + (omegaz*xyzcen(1,iel) - omegax*xyzcen(3,iel))**2 &
+                      + (omegax*xyzcen(2,iel) - omegay*xyzcen(1,iel))**2)
 
-      daxis2 = daxis2 / omgnrm**2
-
-      tracel(iloc) = rtp(iel,ipr)                          &
-          + 0.5d0*propce(iel,ipcrom)*omgnrm**2*daxis2
+      tracel(iloc) = rtp(iel,ipr) + propce(iel,ipcrom)*pcentr
 
     enddo
 
@@ -328,7 +236,7 @@ if (numtyp .eq. -1) then
                 ntcabs, ttcabs, tracel, rbid, rbid)
 
 
-    NAMEVR = 'Velocity'
+    namevr = 'Velocity'
     idimt = 3
     ientla = 1
     ivarpr = 0
@@ -353,14 +261,13 @@ if (numtyp .eq. -1) then
                 ntcabs, ttcabs, tracel, rbid, rbid)
   endif
 
-  ! Vitesse et pression relatives en cas de calcul en repre mobile
+  ! Vitesse et pression relatives en cas de calcul en repre fixe
 
   if (imobil.eq.1) then
 
     ipcrom = ipproc(irom)
-    omgnrm = sqrt(omegax**2 + omegay**2 + omegaz**2)
 
-    NAMEVR = 'Rel Pressure'
+    namevr = 'Rel Pressure'
     idimt = 1
     ientla = 0
     ivarpr = 0
@@ -369,14 +276,11 @@ if (numtyp .eq. -1) then
 
       iel = lstcel(iloc)
 
-      daxis2 =   (omegay*xyzcen(3,iel) - omegaz*xyzcen(2,iel))**2 &
-               + (omegaz*xyzcen(1,iel) - omegax*xyzcen(3,iel))**2 &
-               + (omegax*xyzcen(2,iel) - omegay*xyzcen(1,iel))**2
+      pcentr =   0.5d0*((omegay*xyzcen(3,iel) - omegaz*xyzcen(2,iel))**2 &
+                      + (omegaz*xyzcen(1,iel) - omegax*xyzcen(3,iel))**2 &
+                      + (omegax*xyzcen(2,iel) - omegay*xyzcen(1,iel))**2)
 
-      daxis2 = daxis2 / omgnrm**2
-
-      tracel(iloc) = rtp(iel,ipr)                          &
-          - 0.5d0*propce(iel,ipcrom)*omgnrm**2*daxis2
+      tracel(iloc) = rtp(iel,ipr) - propce(iel,ipcrom)*pcentr
 
     enddo
 
@@ -385,7 +289,7 @@ if (numtyp .eq. -1) then
                 ntcabs, ttcabs, tracel, rbid, rbid)
 
 
-    NAMEVR = 'Rel Velocity'
+    namevr = 'Rel Velocity'
     idimt = 3
     ientla = 1
     ivarpr = 0
@@ -413,70 +317,58 @@ if (numtyp .eq. -1) then
 
 
 !===============================================================================
-!     1.2. TRAITEMENT POUR LE MAILLAGE DE BORD
+! 1.2. Boundary
 !===============================================================================
 
-else if  (numtyp .eq. -2) then
+else if (numtyp .eq. -2) then
 
 
-! --    1.2.1 TRAITEMENT DE YPLUS AU BORD
-!       ----------------------------------
+  ! 1.2.1 output y+ at the boundary
+  ! -------------------------------
 
-  if(mod(ipstdv,ipstyp).eq.0) then
+  if (mod(ipstdv,ipstyp).eq.0) then
+
+    ! Variable name
 
-    !       Initialisation
     do ii = 1, 32
-      NAMEVR (II:II) = ' '
+      namevr (ii:ii) = ' '
     enddo
 
-    !       Nom de la variable
-    NAMEVR = 'Yplus'
+    namevr = 'Yplus'
 
-    !       Dimension de la variable (3 = vecteur, 1=scalaire)
-    idimt = 1
+    idimt = 1  ! variable dimension (3: vector, 1: scalar)
 
-    !       Calcul des valeurs de la variable sur les faces de bord
+    ! Compute variable on boundary faces
 
     do iloc = 1, nfbrps
       ifac = lstfbr(iloc)
       trafbr(1 + (iloc-1)*idimt) = yplbr(ifac)
     enddo
 
-    !           Valeurs non entrelaces, dfinies sur tableau de travail
+    ! Non interleaved values, defined in work array
+
     ientla = 0
     ivarpr = 0
 
     call psteva(nummai, namevr, idimt, ientla, ivarpr,          &
-                                !==========
-         ntcabs, ttcabs, rbid, rbid, trafbr)
+    !==========
+                ntcabs, ttcabs, rbid, rbid, trafbr)
 
-  endif
-! fin du test sur sortie de yplus
+  endif ! end of test on output of y+
 
+  !  1.2.2 Projection of variables at boundary with no reconstruction
+  !  ----------------------------------------------------------------
 
-! --    1.2.2 TRAITEMENT DES VARIABLES AU BORD SANS RECONSTRUCTION
-!       -----------------------------------------------------------
+  if (mod(ipstdv, ipstcl).eq.0) then
 
-  if(mod(ipstdv,ipstcl).eq.0) then
-
-!       Le codage ci-dessous est relativement avance :
-!         il accede aux variables directement au travers du macro tableau RA
-!         il comprend un artifice "ISAUT" permettant de reperer les vecteurs
-!           a posttraiter
-
-
-!       Boucle sur les variables usuelles
-!       ---------------------------------
+    ! Loop on main cell-based variables
+    !----------------------------------
 
     isaut = 0
 
     do ivar = 1, nvar
 
-
-!         Variables post-traitables
-!         (ISAUT est utilise pour ne pas postraiter plusieurs fois les
-!          composantes 2 et 3 d'un vecteur, initialise a 0 avant la boucle
-!          sur IVAR)
+      ! isaut used here to avoid multiple output for vector components 2 and 3
 
       ipp = ipprtp(ivar)
 
@@ -490,36 +382,28 @@ else if  (numtyp .eq. -2) then
         namevr = name80(1:32)
       endif
 
-!         Traitement des variables definies aux centres cellules  sortir
-!         ---------------------------------------------------------------
       if (isorva .eq. 1) then
 
+        ! if the sign of the index in ra is negative, we have a vector
 
-!         -> on verifie le signe du pointeur de la variable dans RA
-!         (si negatif, c'est un vecteur)
-
-!         -> dimension de la variable a ecrire
         idimt = 1
-        if(ipp2ra(ipp).lt.0) then
+        if (ipp2ra(ipp).lt.0) then
           idimt = 3
           isaut = 2
         endif
 
-!           -> si l'on a une variable vectorielle, on supprime
-!              la partie X, Y, ou Z en derniere ou avant-derniere
-!              position dans le nom
+        ! For vectors, remove X, Y, or Z at the end of the name
 
-      if (idimt.eq.3) then
-        name80 = nomvar(ipp+1)
-        namev1 = name80(1:32)
-        name80 = nomvar(ipp+2)
-        namev2 = name80(1:32)
-        call pstsnv ( namevr , namev1 , namev2 )
-        !==========
-      endif
+        if (idimt.eq.3) then
+          name80 = nomvar(ipp+1)
+          namev1 = name80(1:32)
+          name80 = nomvar(ipp+2)
+          namev2 = name80(1:32)
+          call pstsnv ( namevr , namev1 , namev2 )
+          !==========
+        endif
 
-!         Calcul des valeurs (non-reconstruites) de la variable
-!         sur les faces de bord
+        !  Compute non-reconstructed values at boundary faces
 
         do kk = 0, idimt-1
 
@@ -537,7 +421,7 @@ else if  (numtyp .eq. -2) then
 
         enddo
 
-!             Valeurs entrelaces, dfinies sur tableau de travail
+        ! Interleaved values, defined on work array
         ientla = 1
         ivarpr = 0
 
@@ -545,33 +429,27 @@ else if  (numtyp .eq. -2) then
         !==========
                     ntcabs, ttcabs, rbid, rbid, trafbr)
 
-      endif
-!         Fin du traitement en cas de sortie de la variable
+      endif ! End of variable output
 
-    enddo
-!       Fin de la boucle sur les variables
+    enddo ! End of loop on variables
 
-  endif
-!     Fin du test sur sortie des variables
+  endif ! End of test on variable boundary values output
 
+  ! Output thermal flux at boundary
+  ! -------------------------------
+  !  If working with enthalpy, compute an enthalpy flux
 
+  if (mod(ipstdv,ipstft).eq.0) then
 
-!       1.2.3 TRAITEMENT FLUX THERMIQUE AU BORD
-!       ----------------------------------------
-!           Si on travaille en enthalpie, on calcule un flux d'enthalpie
-
-  if(mod(ipstdv,ipstft).eq.0) then
-
-    if(iscalt.gt.0 .and. nscal.gt.0 .and.                &
-         iscalt.le.nscal) then
+    if (iscalt.gt.0 .and. nscal.gt.0 .and. iscalt.le.nscal) then
 
       !       Initialisation
       do ii = 1, 32
-        NAMEVR (II:II) = ' '
+        namevr (ii:ii) = ' '
       enddo
 
       !       Nom de la variable
-      NAMEVR = 'Flux thermique entrant W.m-2'
+      namevr = 'Input thermal flux W.m-2'
 
       !       Dimension de la variable (3 = vecteur, 1=scalaire)
       idimt = 1
@@ -581,6 +459,7 @@ else if  (numtyp .eq. -2) then
       iscal  = iscalt
       ivar   = isca(iscal)
       iclvar = iclrtp(ivar,icoef)
+      iclvaf = iclrtp(ivar,icoeff)
 
       !       Calcul des valeurs de la variable sur les faces de bord
 
@@ -660,9 +539,9 @@ else if  (numtyp .eq. -2) then
       deallocate(treco)
 
 
-      !          Calcul du flux (ouf          !) convectif et diffusif
+      ! Calcul du flux convectif et diffusif
 
-      if(ivisls(iscal).gt.0) then
+      if (ivisls(iscal).gt.0) then
         ipcvsl = ipproc(ivisls(iscal))
       else
         ipcvsl = 0
@@ -674,46 +553,22 @@ else if  (numtyp .eq. -2) then
         ifac = lstfbr(iloc)
         iel = ifabor(ifac)
 
-        if(ipcvsl.gt.0) then
+        if (ipcvsl.gt.0) then
           xvsl = propce(iel,ipcvsl)
         else
           xvsl = visls0(iscal)
         endif
-        srfbn = surfbn(ifac)
-        distbr = distb(ifac)
+        srfbn = max(surfbn(ifac), epzero**2)
         visct  = propce(iel,ipcvst)
         flumab = propfb(ifac,iflmab)
 
-        trafbr(1 + (iloc-1)*idimt) =                            &
-             (xvsl+visct/sigmas(iscal))/max(distbr,epzero)*     &
-             (coefa(ifac,iclvar)+(coefb(ifac,iclvar)-1.d0)*     &
-             rtp(iel,ivar))                                     &
-             - flumab/max(srfbn,epzero**2)*                    &
-             (coefa(ifac,iclvar)+ coefb(ifac,iclvar)*           &
-             rtp(iel,ivar))
+        trafbr(1 + (iloc-1)*idimt) =                                   &
+             (coefa(ifac,iclvaf) + coefb(ifac,iclvaf)*rtp(iel,ivar))   &
+             - flumab/srfbn*                                           &
+             (coefa(ifac,iclvar) + coefb(ifac,iclvar)*rtp(iel,ivar))
 
       enddo
 
-      !          Pour la temperature, on multiplie par CP
-      if(abs(iscsth(iscal)).eq.1) then
-        if(icp.gt.0) then
-          ipccp  = ipproc(icp   )
-        else
-          ipccp  = 0
-        endif
-        do iloc = 1, nfbrps
-          ifac = lstfbr(iloc)
-          iel = ifabor(ifac)
-          if(ipccp.gt.0) then
-            xcp = propce(iel,ipccp)
-          else
-            xcp    = cp0
-          endif
-          trafbr(1 + (iloc-1)*idimt)                            &
-               = xcp*trafbr(1 + (iloc-1)*idimt)
-        enddo
-      endif
-
       !             Valeurs entrelaces, dfinies sur tableau de travail
       ientla = 1
       ivarpr = 0
@@ -731,7 +586,7 @@ else if  (numtyp .eq. -2) then
 ! --    1.2.4 TRAITEMENT DES EFFORTS AUX BORDS
 !       --------------------------------------
 
-  if(mod(ipstdv,ipstfo).eq.0) then
+  if (mod(ipstdv,ipstfo).eq.0) then
 
 !       Initialisation
     do ii = 1, 32
@@ -788,8 +643,8 @@ if (nummai .eq. -1) then
 
     do icla  = 0, nbclst
 
-!     -> si IPAS = 0 : statistiques globales
-!        si 0 < IPAS =< NBCLST : statistiques par groupe
+!     -> si ICLA = 0 : statistiques globales
+!        si 0 < ICLA =< NBCLST : statistiques par groupe
 
       do ivarl = 1, nvlsta
 
@@ -802,14 +657,14 @@ if (nummai .eq. -1) then
           if (ivarl.eq.ivarl1) then
             name80 = nomlag(ivarl)
           else
-            WRITE(NAME80,'(A8,A4,I3)') NOMLAG(IVARL),'_grp',ICLA
+            write(name80,'(a8,a4,i3)') nomlag(ivarl),'_grp',icla
           endif
         else if (nvlsts.gt.0) then
           if (ivarl.eq.ivarl1) then
             name80 = nomlag(ilvu(ivarl-iii))
           else
-            WRITE(NAME80,'(A8,A4,I3)')                            &
-                 NOMLAG(ILVU(IVARL-III)),'_grp',ICLA
+            write(name80,'(a8,a4,i3)')                            &
+                 nomlag(ilvu(ivarl-iii)),'_grp',icla
           endif
         endif
 
@@ -841,14 +696,14 @@ if (nummai .eq. -1) then
           if (ivarl.eq.ivarl1) then
             name80 = nomlav(ivarl)
           else
-            WRITE(NAME80,'(A8,A4,I3)') NOMLAV(IVARL),'_grp',ICLA
+            write(name80,'(a8,a4,i3)') nomlav(ivarl),'_grp',icla
           endif
         else if (nvlsts.gt.0) then
           if (ivarl.eq.ivarl1) then
             name80 = nomlav(ilvu(ivarl-iii))
           else
-            WRITE(NAME80,'(A8,A4,I3)')                            &
-                 NOMLAV(ILVU(IVARL-III)),'_grp',ICLA
+            write(name80,'(a8,a4,i3)')                            &
+                 nomlav(ilvu(ivarl-iii)),'_grp',icla
           endif
         endif
 
@@ -1041,11 +896,11 @@ if (     ippmod(ieljou).ge.1                                      &
 endif
 
 !--------
-! FORMATS
+! Formats
 !--------
 
 !----
-! FIN
+! End
 !----
 
 return
