@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2011 EDF S.A.
+! Copyright (C) 1998-2012 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -157,7 +157,7 @@ iiromb = ipprob(irom  )
 do iel = 1, ncel
   propce(iel,iirom)  = ro0
 enddo
-if(iroext.gt.0.or.icalhy.eq.1) then
+if (iroext.gt.0.or.icalhy.eq.1.or.idilat.gt.1) then
   iiroma = ipproc(iroma )
   do iel = 1, ncel
     propce(iel,iiroma) = propce(iel,iirom)
@@ -240,6 +240,18 @@ do iscal = 1, nscal
   endif
 enddo
 
+! Initialisation of source terms for weakly compressible algorithm
+if (idilat.eq.4) then
+  do iel = 1, ncel
+    propce(iel,ipproc(iustdy(itsrho))) = 0.d0
+  enddo
+  do iscal = 1, nscal
+    do iel = 1, ncel
+      propce(iel,ipproc(iustdy(iscal))) = 0.d0
+    enddo
+  enddo
+endif
+
 
 !     Viscosite de maillage en ALE
 if (iale.eq.1) then
@@ -359,7 +371,13 @@ elseif(itytur.eq.3) then
       rtp(iel,iep)  = -grand
     enddo
 
-  endif
+    if(iturb.eq.32)then
+      do iel = 1, ncel
+        rtp(iel,ial) = 1.d0
+      enddo
+    endif
+
+ endif
 
 elseif(iturb.eq.60) then
 
@@ -469,7 +487,7 @@ if (ivelco.eq.1) then
       do jsou = 1, 3
         if (jsou.eq.isou) then
           coefbu(isou,jsou,ifac) = 1.d0
-          cofbfu(isou,jsou,ifac) = 1.d0
+          cofbfu(isou,jsou,ifac) = 0.d0
         else
           coefbu(isou,jsou,ifac) = 0.d0
           cofbfu(isou,jsou,ifac) = 0.d0
@@ -486,11 +504,11 @@ do ifac = 1, nfabor
   itrifb(ifac) = 0
 enddo
 
-! Type symtrie : on en a besoin dans le cas du calcul des gradients
-!     par moindres carrs tendu avec extrapolation du gradient au bord
+! Type symetrie : on en a besoin dans le cas du calcul des gradients
+!     par moindres carres etendu avec extrapolation du gradient au bord
 !     La valeur 0 permet de ne pas extrapoler le gradient sur les faces.
-!     Habituellement, on vite l'extrapolation sur les faces de symtries
-!     pour ne pas tomber sur une indtermination et une matrice 3*3 non
+!     Habituellement, on evite l'extrapolation sur les faces de symetries
+!     pour ne pas tomber sur une indetermination et une matrice 3*3 non
 !     inversible dans les configurations 2D).
 do ifac = 1, nfabor
   isympa(ifac) = 0
@@ -547,6 +565,8 @@ endif
 if(isto2t.gt.0) then
   if(itytur.eq.2) jj = 2
   if(itytur.eq.3) jj = 7
+  if(iturb.eq.30.or.iturb.eq.31) jj = 7
+  if(iturb.eq.32) jj = 8
   if(iturb.eq.50) jj = 4
   if(iturb.eq.60) jj = 2
   if(iturb.eq.70) jj = 1
