@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2011 EDF S.A.
+! Copyright (C) 1998-2012 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -116,7 +116,7 @@ double precision uvwk(ncelet,ndim)
 
 ! Local variables
 
-integer          iccocg, inc, iel, iel1, iel2, ifac, imax
+integer          iccocg, inc, iel, iel1, iel2, ifac, imax, imaxt
 integer          ii    , inod
 integer          isou, ivar, iitsm
 integer          iclipr, iclipf
@@ -124,11 +124,11 @@ integer          icliup, iclivp, icliwp, init
 integer          icluma, iclvma, iclwma
 integer          iflmas, iflmab, ipcrom, ipbrom
 integer          iflms1, iflmb1, iflmb0
-integer          nswrgp, imligp, iwarnp, imaspe
+integer          nswrgp, imligp, iwarnp, imaspe , itypfl
 integer          nbrval, iappel, iescop, idtsca
 integer          ndircp, icpt  , iecrw
 integer          numcpl
-double precision rnorm , rnorma, rnormi, vitnor
+double precision rnorm , rnormt, rnorma, rnormi, vitnor
 double precision dtsrom, unsrom, surf  , rhom
 double precision epsrgp, climgp, extrap, xyzmax(3)
 double precision thetap, xdu, xdv, xdw
@@ -151,13 +151,15 @@ double precision, allocatable, dimension(:,:) :: dfrcxt
 double precision, allocatable, dimension(:,:) :: frchy, dfrchy
 double precision, allocatable, dimension(:) :: esflum, esflub
 double precision, allocatable, dimension(:) :: flint, flbrd
+double precision, allocatable, dimension(:) :: coefap
+
 
 double precision, pointer, dimension(:) :: viscfi => null(), viscbi => null()
 
 !===============================================================================
 
 !===============================================================================
-! 1.  INITIALISATION
+! 0. Initialization
 !===============================================================================
 
 ! Allocate temporary arrays for the velocity-pressure resolution
@@ -165,6 +167,9 @@ allocate(viscf(nfac), viscb(nfabor))
 allocate(drtp(ncelet), smbr(ncelet), rovsdt(ncelet))
 allocate(trav(ncelet,3))
 
+! Array for delta p gradient boundary conditions
+allocate(coefap(nfabor))
+
 ! Allocate other arrays, depending on user options
 !if (iphydr.eq.1) allocate(dfrcxt(ncelet,3))
 allocate(dfrcxt(ncelet,3))
@@ -185,7 +190,7 @@ allocate(w4(ncelet), w5(ncelet), w6(ncelet))
 allocate(w7(ncelet), w8(ncelet), w9(ncelet))
 if (irnpnw.eq.1) allocate(w10(ncelet))
 
-if(iwarni(iu).ge.1) then
+if (iwarni(iu).ge.1) then
   write(nfecra,1000)
 endif
 
@@ -199,29 +204,29 @@ imax = 0
 ! Memoire
 
 
-if(nterup.gt.1) then
+if (nterup.gt.1) then
 
   do isou = 1, 3
-    if(isou.eq.1) ivar = iu
-    if(isou.eq.2) ivar = iv
-    if(isou.eq.3) ivar = iw
+    if (isou.eq.1) ivar = iu
+    if (isou.eq.2) ivar = iv
+    if (isou.eq.3) ivar = iw
     !     La boucle sur NCELET est une securite au cas
     !       ou on utiliserait UVWK par erreur a ITERNS = 1
+    !$omp parallel do
     do iel = 1,ncelet
       uvwk(iel,isou) = rtp(iel,ivar)
     enddo
   enddo
 
   ! Calcul de la norme L2 de la vitesse
-  if(iterns.eq.1) then
+  if (iterns.eq.1) then
     xnrmu0 = 0.d0
+    !$omp parallel do reduction(+:xnrmu0)
     do iel = 1, ncel
-      xnrmu0 = xnrmu0 +(rtpa(iel,iu)**2        &
-           + rtpa(iel,iv)**2        &
-           + rtpa(iel,iw)**2)       &
-           * volume(iel)
+      xnrmu0 =   xnrmu0 +(rtpa(iel,iu)**2 + rtpa(iel,iv)**2 + rtpa(iel,iw)**2) &
+               * volume(iel)
     enddo
-    if(irangp.ge.0) then
+    if (irangp.ge.0) then
       call parsom (xnrmu0)
       !==========
     endif
@@ -239,7 +244,7 @@ if(nterup.gt.1) then
 
   ! On assure la periodicite ou le parallelisme de UVWK et la pression
   ! (cette derniere vaut la pression a l'iteration precedente)
-  if(iterns.gt.1) then
+  if (iterns.gt.1) then
     if (irangp.ge.0.or.iperio.eq.1) then
       call synvec(uvwk(1,1), uvwk(1,2), uvwk(1,3))
       !==========
@@ -250,6 +255,21 @@ if(nterup.gt.1) then
 
 endif
 
+!===============================================================================
+! 1. Prediction of the mass flux in case of Low Mach compressible algorithm
+!===============================================================================
+
+if (idilat.eq.2.or.idilat.eq.3) then
+
+  call predfl &
+  !==========
+  ( nvar   , nscal  , ncetsm ,                            &
+    icetsm ,                                              &
+    dt     , rtp    , rtpa   ,                            &
+    propce , propfa , propfb ,                            &
+    smacel )
+
+endif
 
 !===============================================================================
 ! 2.  ETAPE DE PREDICTION DES VITESSES
@@ -277,7 +297,7 @@ call preduv &
 ! --- Sortie si pas de pression continuite
 !       on met a jour les flux de masse, et on sort
 
-if( iprco.le.0 ) then
+if ( iprco.le.0 ) then
 
   icliup = iclrtp(iu ,icoef)
   iclivp = iclrtp(iv ,icoef)
@@ -301,11 +321,12 @@ if( iprco.le.0 ) then
   extrap = extrag(iu)
 
   imaspe = 1
+  itypfl = 1
 
   call inimas &
   !==========
 ( nvar   , nscal  ,                                              &
-  iu  , iv  , iw  , imaspe ,                                     &
+  iu  , iv  , iw  , imaspe , itypfl ,                            &
   iflmb0 , init   , inc    , imrgra , iccocg , nswrgp , imligp , &
   iwarnp , nfecra ,                                              &
   epsrgp , climgp , extrap ,                                     &
@@ -315,6 +336,7 @@ if( iprco.le.0 ) then
   coefb(1,icliup), coefb(1,iclivp), coefb(1,icliwp),             &
   propfa(1,iflmas), propfb(1,iflmab) )
 
+
 !     En ALE on doit rajouter la composante en vitesse de maillage
   if (iale.eq.1) then
 
@@ -324,11 +346,13 @@ if( iprco.le.0 ) then
 
 !     On change de signe car on veut l'oppose de la vitesse de maillage
 !       aux faces
+    !$omp parallel do
     do iel = 1, ncelet
       rtp(iel,iuma) = -rtp(iel,iuma)
       rtp(iel,ivma) = -rtp(iel,ivma)
       rtp(iel,iwma) = -rtp(iel,iwma)
     enddo
+    !$omp parallel do if(nfabor > thr_n_min)
     do ifac = 1, nfabor
       coefa(ifac,icluma) = -coefa(ifac,icluma)
       coefa(ifac,iclvma) = -coefa(ifac,iclvma)
@@ -356,7 +380,9 @@ if( iprco.le.0 ) then
     extrap = extrag(iuma )
 
     imaspe = 1
+    itypfl = 1
 
+    !$omp parallel do
     do ifac = 1, nfac
       flint(ifac) = 0.d0
     enddo
@@ -364,7 +390,7 @@ if( iprco.le.0 ) then
     call inimas &
     !==========
  ( nvar   , nscal  ,                                              &
-   iu  , iv  , iw  , imaspe ,                                     &
+   iuma   , ivma   , iwma   , imaspe , itypfl ,                   &
    iflmb0 , init   , inc    , imrgra , iccocg , nswrgp , imligp , &
    iwarnp , nfecra ,                                              &
    epsrgp , climgp , extrap ,                                     &
@@ -374,17 +400,21 @@ if( iprco.le.0 ) then
    coefb(1,icluma), coefb(1,iclvma), coefb(1,iclwma),             &
    flint  , propfb(1,iflmab) )
 
+    !$omp parallel do
     do iel = 1, ncelet
       rtp(iel,iuma) = -rtp(iel,iuma)
       rtp(iel,ivma) = -rtp(iel,ivma)
       rtp(iel,iwma) = -rtp(iel,iwma)
     enddo
+    !$omp parallel do if(nfabor > thr_n_min)
     do ifac = 1, nfabor
       coefa(ifac,icluma) = -coefa(ifac,icluma)
       coefa(ifac,iclvma) = -coefa(ifac,iclvma)
       coefa(ifac,iclwma) = -coefa(ifac,iclwma)
     enddo
 
+    !$omp parallel do private(ii, inod, iel1, iel2, dtfac, rhofac, iecrw,  &
+    !$omp                     icpt, ddepx, ddepy, ddepz)
     do ifac = 1, nfac
       iecrw = 0
       ddepx = 0.d0
@@ -399,17 +429,16 @@ if( iprco.le.0 ) then
         ddepy = ddepy + depale(inod,2) + xyzno0(2,inod)-xyznod(2,inod)
         ddepz = ddepz + depale(inod,3) + xyzno0(3,inod)-xyznod(3,inod)
       enddo
-      !     If all the face vertices have imposed displacement, w is evaluated from
-      !       this displacement
+      ! If all the face vertices have prescribed displacement, w is evaluated
+      ! from this displacement
       if (iecrw.eq.0) then
         iel1 = ifacel(1,ifac)
         iel2 = ifacel(2,ifac)
         dtfac = 0.5d0*(dt(iel1) + dt(iel2))
         rhofac = 0.5d0*(propce(iel1,ipcrom) + propce(iel2,ipcrom))
-        propfa(ifac,iflmas) = propfa(ifac,iflmas) - rhofac*(      &
-             ddepx*surfac(1,ifac)                                 &
-             +ddepy*surfac(2,ifac)                                &
-             +ddepz*surfac(3,ifac) )/dtfac/icpt
+        propfa(ifac,iflmas) = propfa(ifac,iflmas) - rhofac*(                   &
+             ddepx*surfac(1,ifac) +ddepy*surfac(2,ifac) +ddepz*surfac(3,ifac)) &
+             /dtfac/icpt
         !     Else w is calculated from the cell-centre mesh velocity
       else
         propfa(ifac,iflmas) = propfa(ifac,iflmas) + flint(ifac)
@@ -431,6 +460,8 @@ if( iprco.le.0 ) then
     ipcrom = ipproc(irom  )
     ipbrom = ipprob(irom  )
 
+    !$omp parallel do private(iel1, iel2, dtfac, rhofac, &
+    !$omp                     vitbox, vitboy, vitboz)
     do ifac = 1, nfac
       iel1 = ifacel(1,ifac)
       iel2 = ifacel(2,ifac)
@@ -442,6 +473,8 @@ if( iprco.le.0 ) then
       propfa(ifac,iflmas) = propfa(ifac,iflmas) - rhofac*(        &
            vitbox*surfac(1,ifac) + vitboy*surfac(2,ifac) + vitboz*surfac(3,ifac) )
     enddo
+    !$omp parallel do private(iel, dtfac, rhofac, &
+    !$omp                     vitbox, vitboy, vitboz) if(nfabor > thr_n_min)
     do ifac = 1, nfabor
       iel = ifabor(ifac)
       dtfac  = dt(iel)
@@ -463,7 +496,7 @@ endif
 ! 3.  ETAPE DE PRESSION/CONTINUITE ( VITESSE/PRESSION )
 !===============================================================================
 
-if(iwarni(iu).ge.1) then
+if (iwarni(iu).ge.1) then
   write(nfecra,1200)
 endif
 
@@ -478,7 +511,7 @@ call resolp &
    icepdc , icetsm , itypsm ,                                     &
    isostd , idtsca ,                                              &
    dt     , rtp    , rtpa   , propce , propfa , propfb ,          &
-   coefa  , coefb  ,                                              &
+   coefa  , coefb  , coefap ,                                     &
    ckupdc , smacel ,                                              &
    frcxt  , dfrcxt , tpucou , trav   ,                            &
    viscf  , viscb  , viscfi , viscbi ,                            &
@@ -528,7 +561,7 @@ ipbrom = ipprob(irom  )
 !         se rapproche beaucoup de IREVMC=0.
 
 
-if( irevmc.eq.1 ) then
+if (irevmc.eq.1) then
 
   ! Allocate temporary arrays
   allocate(flint(nfac), flbrd(nfabor))
@@ -540,19 +573,20 @@ if( irevmc.eq.1 ) then
   iccocg = 1
   iflmb0 = 1
   if (iale.eq.1) iflmb0 = 0
-  nswrgp = nswrgr(iu )
-  imligp = imligr(iu )
-  iwarnp = iwarni(iu )
-  epsrgp = epsrgr(iu )
-  climgp = climgr(iu )
-  extrap = extrag(iu )
+  nswrgp = nswrgr(iu)
+  imligp = imligr(iu)
+  iwarnp = iwarni(iu)
+  epsrgp = epsrgr(iu)
+  climgp = climgr(iu)
+  extrap = extrag(iu)
 
   imaspe = 1
+  itypfl = 1
 
   call inimas &
   !==========
  ( nvar   , nscal  ,                                              &
-   iu  , iv  , iw  , imaspe ,                                     &
+   iu  , iv  , iw  , imaspe , itypfl ,                            &
    iflmb0 , init   , inc    , imrgra , iccocg , nswrgp , imligp , &
    iwarnp , nfecra ,                                              &
    epsrgp , climgp , extrap ,                                     &
@@ -562,20 +596,22 @@ if( irevmc.eq.1 ) then
    coefb(1,icliup), coefb(1,iclivp), coefb(1,icliwp),             &
    flint  , flbrd  )
 
+  !$omp parallel do
   do ifac = 1, nfac
     flint(ifac) = propfa(ifac,iflmas) - flint(ifac)
   enddo
+  !$omp parallel do if(nfabor > thr_n_min)
   do ifac = 1, nfabor
     flbrd(ifac) = propfb(ifac,iflmab) - flbrd(ifac)
   enddo
 
   call recvmc                                                     &
   !==========
- ( nvar   , nscal  ,                                              &
-   propce(1,ipcrom), flint  , flbrd  ,                            &
+ ( propce(1,ipcrom), flint  , flbrd  ,                            &
    w1     , w2     , w3     ,                                     &
    w4     , w5     , w6     )
 
+  !$omp parallel do
   do iel = 1, ncel
     rtp(iel,iu) = rtp(iel,iu) + w1(iel)
     rtp(iel,iv) = rtp(iel,iv) + w2(iel)
@@ -585,12 +621,11 @@ if( irevmc.eq.1 ) then
   ! Free memory
   deallocate(flint, flbrd)
 
-elseif( irevmc.eq.2 ) then
+else if (irevmc.eq.2) then
 
   call recvmc &
   !==========
-( nvar   , nscal  ,                                              &
-  propce(1,ipcrom), propfa(1,iflmas), propfb(1,iflmab),          &
+( propce(1,ipcrom), propfa(1,iflmas), propfb(1,iflmab),          &
   rtp(1,iu), rtp(1,iv), rtp(1,iw),                               &
   w4     , w5     , w6     )
 
@@ -606,10 +641,12 @@ else
   !     GRADIENT DE L'INCREMENT TOTAL DE PRESSION
 
   if (idtvar.lt.0) then
+    !$omp parallel do
     do iel = 1, ncel
       drtp(iel) = (rtp(iel,ipr) -rtpa(iel,ipr)) / relaxv(ipr)
     enddo
   else
+    !$omp parallel do
     do iel = 1, ncel
       drtp(iel) = rtp(iel,ipr) -rtpa(iel,ipr)
     enddo
@@ -639,7 +676,7 @@ else
    iwarnp , nfecra , epsrgp , climgp , extrap ,                   &
    rvoid  ,                                                       &
    dfrcxt(1,1),dfrcxt(1,2),dfrcxt(1,3),                           &
-   drtp   , coefa(1,iclipf) , coefb(1,iclipr)  ,                  &
+   drtp   , coefap        , coefb(1,iclipr)  ,                    &
    grad   )
 
   !     REACTUALISATION DU CHAMP DE VITESSES
@@ -647,6 +684,7 @@ else
   thetap = thetav(ipr)
   if (iphydr.eq.0) then
     if (idtsca.eq.0) then
+      !$omp parallel do private(dtsrom)
       do iel = 1, ncel
         dtsrom = -thetap*dt(iel)/propce(iel,ipcrom)
         rtp(iel,iu) = rtp(iel,iu)+dtsrom*grad(iel,1)
@@ -654,6 +692,7 @@ else
         rtp(iel,iw) = rtp(iel,iw)+dtsrom*grad(iel,3)
       enddo
     else
+      !$omp parallel do private(unsrom)
       do iel = 1, ncel
         unsrom = -thetap/propce(iel,ipcrom)
         rtp(iel,iu) = rtp(iel,iu) + unsrom*tpucou(iel,1)*grad(iel,1)
@@ -663,6 +702,7 @@ else
     endif
   else
     if (idtsca.eq.0) then
+      !$omp parallel do private(dtsrom)
       do iel = 1, ncel
         dtsrom = thetap*dt(iel)/propce(iel,ipcrom)
         rtp(iel,iu) = rtp(iel,iu) + dtsrom*(dfrcxt(iel,1)-grad(iel,1) )
@@ -670,6 +710,7 @@ else
         rtp(iel,iw) = rtp(iel,iw) + dtsrom*(dfrcxt(iel,3)-grad(iel,3) )
       enddo
     else
+      !$omp parallel do private(unsrom)
       do iel = 1, ncel
         unsrom = thetap/propce(iel,ipcrom)
         rtp(iel,iu) = rtp(iel,iu) &
@@ -681,6 +722,7 @@ else
       enddo
     endif
     !     mise a jour des forces exterieures pour le calcul des gradients
+    !$omp parallel do
     do iel=1,ncel
       frcxt(iel,1) = frcxt(iel,1) + dfrcxt(iel,1)
       frcxt(iel,2) = frcxt(iel,2) + dfrcxt(iel,2)
@@ -694,9 +736,9 @@ else
     iclipr = iclrtp(ipr,icoef)
     iclipf = iclrtp(ipr,icoeff)
     do ifac = 1,nfabor
-      if (isostd(ifac).eq.1)                              &
-           coefa(ifac,iclipr) = coefa(ifac,iclipr)              &
-           + coefa(ifac,iclipf)
+      if (isostd(ifac).eq.1) then
+        coefa(ifac,iclipr) = coefa(ifac,iclipr) + coefap(ifac)
+      endif
     enddo
   endif
 
@@ -705,7 +747,7 @@ else
 
 endif
 
-!     Ajout de la vitesse de maillage dans le flux convectif en ALE
+! In the ALE framework, we add the mesh velocity
 if (iale.eq.1) then
 
   icluma = iclrtp(iuma ,icoef)
@@ -714,11 +756,13 @@ if (iale.eq.1) then
 
 !     On change de signe car on veut l'oppose de la vitesse de maillage
 !       aux faces
+  !$omp parallel do
   do iel = 1, ncelet
     rtp(iel,iuma) = -rtp(iel,iuma)
     rtp(iel,ivma) = -rtp(iel,ivma)
     rtp(iel,iwma) = -rtp(iel,iwma)
   enddo
+  !$omp parallel do if(nfabor > thr_n_min)
   do ifac = 1, nfabor
     coefa(ifac,icluma) = -coefa(ifac,icluma)
     coefa(ifac,iclvma) = -coefa(ifac,iclvma)
@@ -746,7 +790,9 @@ if (iale.eq.1) then
   extrap = extrag(iuma )
 
   imaspe = 1
+  itypfl = 1
 
+  !$omp parallel do
   do ifac = 1, nfac
     flint(ifac) = 0.d0
   enddo
@@ -754,7 +800,7 @@ if (iale.eq.1) then
   call inimas &
   !==========
  ( nvar   , nscal  ,                                              &
-   iu  , iv  , iw  , imaspe ,                                     &
+   iu  , iv  , iw  , imaspe , itypfl ,                            &
    iflmb0 , init   , inc    , imrgra , iccocg , nswrgp , imligp , &
    iwarnp , nfecra ,                                              &
    epsrgp , climgp , extrap ,                                     &
@@ -764,17 +810,21 @@ if (iale.eq.1) then
    coefb(1,icluma), coefb(1,iclvma), coefb(1,iclwma),             &
    flint  , propfb(1,iflmab) )
 
+  !$omp parallel do
   do iel = 1, ncelet
     rtp(iel,iuma) = -rtp(iel,iuma)
     rtp(iel,ivma) = -rtp(iel,ivma)
     rtp(iel,iwma) = -rtp(iel,iwma)
   enddo
+  !$omp parallel do if(nfabor > thr_n_min)
   do ifac = 1, nfabor
     coefa(ifac,icluma) = -coefa(ifac,icluma)
     coefa(ifac,iclvma) = -coefa(ifac,iclvma)
     coefa(ifac,iclwma) = -coefa(ifac,iclwma)
   enddo
 
+  !$omp parallel do private(iecrw, ddepx, ddepy, ddepz, icpt, ii, inod, &
+  !$omp                     iel1, iel2, dtfac, rhofac)
   do ifac = 1, nfac
     iecrw = 0
     ddepx = 0.d0
@@ -821,10 +871,10 @@ if (imobil.eq.1) then
   ipcrom = ipproc(irom  )
   ipbrom = ipprob(irom  )
 
+  !$omp parallel do private(iel1, iel2, rhofac, vitbox, vitboy, vitboz)
   do ifac = 1, nfac
     iel1 = ifacel(1,ifac)
     iel2 = ifacel(2,ifac)
-    dtfac  = 0.5d0*(dt(iel1) + dt(iel2))
     rhofac = 0.5d0*(propce(iel1,ipcrom) + propce(iel2,ipcrom))
     vitbox = omegay*cdgfac(3,ifac) - omegaz*cdgfac(2,ifac)
     vitboy = omegaz*cdgfac(1,ifac) - omegax*cdgfac(3,ifac)
@@ -832,9 +882,10 @@ if (imobil.eq.1) then
     propfa(ifac,iflmas) = propfa(ifac,iflmas) - rhofac*(        &
          vitbox*surfac(1,ifac) + vitboy*surfac(2,ifac) + vitboz*surfac(3,ifac) )
   enddo
+  !$omp parallel do private(iel, rhofac, vitbox, vitboy, vitboz) &
+  !$omp          if(nfabor > thr_n_min)
   do ifac = 1, nfabor
     iel = ifabor(ifac)
-    dtfac  = dt(iel)
     rhofac = propfb(ifac,ipbrom)
     vitbox = omegay*cdgfbo(3,ifac) - omegaz*cdgfbo(2,ifac)
     vitboy = omegaz*cdgfbo(1,ifac) - omegax*cdgfbo(3,ifac)
@@ -851,7 +902,7 @@ endif
 !===============================================================================
 
 
-if(iescal(iescor).gt.0.or.iescal(iestot).gt.0) then
+if (iescal(iescor).gt.0.or.iescal(iestot).gt.0) then
 
   ! ---> REPERAGE DES VARIABLES
 
@@ -870,7 +921,7 @@ if(iescal(iescor).gt.0.or.iescal(iestot).gt.0) then
   !    Pour l'estimateur IESTOT, la pression doit etre echangee aussi.
 
   !    Cela ne remplace pas l'echange du debut de pas de temps
-  !     a cause de usproj qui vient plus tard et des calculs suite)
+  !     a cause de cs_user_extra_operations qui vient plus tard et des calculs suite)
 
 
   ! --- Vitesse
@@ -883,7 +934,7 @@ if(iescal(iescor).gt.0.or.iescal(iestot).gt.0) then
 
   !  -- Pression
 
-  if(iescal(iestot).gt.0) then
+  if (iescal(iestot).gt.0) then
 
     if (irangp.ge.0.or.iperio.eq.1) then
       call synsca(rtp(1,ipr))
@@ -908,11 +959,12 @@ if(iescal(iescor).gt.0.or.iescal(iestot).gt.0) then
   extrap = extrag(iu )
 
   imaspe = 1
+  itypfl = 1
 
   call inimas &
   !==========
  ( nvar   , nscal  ,                                              &
-   iu  , iv  , iw  , imaspe ,                                     &
+   iu  , iv  , iw  , imaspe , itypfl ,                            &
    iflmb0 , init   , inc    , imrgra , iccocg , nswrgp , imligp , &
    iwarnp , nfecra ,                                              &
    epsrgp , climgp , extrap ,                                     &
@@ -926,27 +978,30 @@ if(iescal(iescor).gt.0.or.iescal(iestot).gt.0) then
   ! ---> CALCUL DE L'ESTIMATEUR CORRECTION : DIVERGENCE DE ROM * U (N + 1)
   !                                          - GAMMA
 
-  if(iescal(iescor).gt.0) then
+  if (iescal(iescor).gt.0) then
     init = 1
     call divmas(ncelet,ncel,nfac,nfabor,init,nfecra,            &
-         ifacel,ifabor,esflum,esflub,w1)
+                ifacel,ifabor,esflum,esflub,w1)
 
     if (ncetsm.gt.0) then
+      !$omp parallel do private(iel) if(ncetsm > thr_n_min)
       do iitsm = 1, ncetsm
         iel = icetsm(iitsm)
         w1(iel) = w1(iel)-volume(iel)*smacel(iitsm,ipr)
       enddo
     endif
 
-    if(iescal(iescor).eq.2) then
+    if (iescal(iescor).eq.2) then
       iescop = ipproc(iestim(iescor))
+      !$omp parallel do
       do iel = 1, ncel
-        propce(iel,iescop) =  abs(w1(iel))
+        propce(iel,iescop) = abs(w1(iel))
       enddo
-    elseif(iescal(iescor).eq.1) then
+    elseif (iescal(iescor).eq.1) then
       iescop = ipproc(iestim(iescor))
+      !$omp parallel do
       do iel = 1, ncel
-        propce(iel,iescop) =  abs(w1(iel)) / volume(iel)
+        propce(iel,iescop) = abs(w1(iel)) / volume(iel)
       enddo
     endif
   endif
@@ -954,17 +1009,18 @@ if(iescal(iescor).gt.0.or.iescal(iestot).gt.0) then
 
   ! ---> CALCUL DE L'ESTIMATEUR TOTAL
 
-  if(iescal(iestot).gt.0) then
+  if (iescal(iestot).gt.0) then
 
     !   INITIALISATION DE TRAV AVEC LE TERME INSTATIONNAIRE
 
+    !$omp parallel do
     do iel = 1, ncel
       trav(iel,1) = propce(iel,ipcrom) * volume(iel) *          &
-           ( rtpa(iel,iu)- rtp(iel,iu) )/dt(iel)
+           (rtpa(iel,iu)- rtp(iel,iu))/dt(iel)
       trav(iel,2) = propce(iel,ipcrom) * volume(iel) *          &
-           ( rtpa(iel,iv)- rtp(iel,iv) )/dt(iel)
+           (rtpa(iel,iv)- rtp(iel,iv))/dt(iel)
       trav(iel,3) = propce(iel,ipcrom) * volume(iel) *          &
-           ( rtpa(iel,iw)- rtp(iel,iw) )/dt(iel)
+           (rtpa(iel,iw)- rtp(iel,iw))/dt(iel)
     enddo
 
     !   APPEL A PREDUV AVEC RTP ET RTP AU LIEU DE RTP ET RTPA
@@ -993,7 +1049,7 @@ endif
 ! 6.  TRAITEMENT DU POINT FIXE SUR LE SYSTEME VITESSE/PRESSION
 !===============================================================================
 
-if(nterup.gt.1) then
+if (nterup.gt.1) then
 ! TEST DE CONVERGENCE DE L'ALGORITHME ITERATIF
 ! On initialise ICVRGE a 1 et on le met a 0 si une des phases n'est
 ! pas convergee
@@ -1001,16 +1057,16 @@ if(nterup.gt.1) then
   icvrge = 1
 
   xnrmu = 0.d0
-  do iel = 1,ncel
+  !$omp parallel do private(xdu, xdv, xdw) reduction(+:xnrmu)
+  do iel = 1, ncel
     xdu = rtp(iel,iu) - uvwk(iel,1)
     xdv = rtp(iel,iv) - uvwk(iel,2)
     xdw = rtp(iel,iw) - uvwk(iel,3)
-    xnrmu = xnrmu +(xdu**2 + xdv**2 + xdw**2)     &
-         * volume(iel)
+    xnrmu = xnrmu +(xdu**2 + xdv**2 + xdw**2) * volume(iel)
   enddo
   ! --->    TRAITEMENT DU PARALLELISME
 
-  if(irangp.ge.0) call parsom (xnrmu)
+  if (irangp.ge.0) call parsom (xnrmu)
   !==========
   ! -- >    TRAITEMENT DU COUPLAGE ENTRE DEUX INSTANCES DE CODE_SATURNE
   do numcpl = 1, nbrcpl
@@ -1021,7 +1077,7 @@ if(nterup.gt.1) then
   xnrmu = sqrt(xnrmu)
 
   ! Indicateur de convergence du point fixe
-  if(xnrmu.ge.epsup*xnrmu0) icvrge = 0
+  if (xnrmu.ge.epsup*xnrmu0) icvrge = 0
 
 endif
 
@@ -1035,7 +1091,7 @@ if (idircl(ipr).eq.1) then
 else
   ndircp = ndircl(ipr)-1
 endif
-if(ndircp.le.0) then
+if (ndircp.le.0) then
   call prmoy0 &
   !==========
 ( ncelet , ncel   , nfac   , nfabor ,                         &
@@ -1049,8 +1105,9 @@ if (ippmod(icompf).lt.0) then
   xxp0   = xyzp0(1)
   xyp0   = xyzp0(2)
   xzp0   = xyzp0(3)
-  do iel=1,ncel
-    propce(iel,ipproc(iprtot))= rtp(iel,ipr)           &
+  !$omp parallel do
+  do iel = 1, ncel
+    propce(iel,ipproc(iprtot)) = rtp(iel,ipr)           &
          + ro0*( gx*(xyzcen(1,iel)-xxp0)               &
          + gy*(xyzcen(2,iel)-xyp0)                     &
          + gz*(xyzcen(3,iel)-xzp0) )                   &
@@ -1072,6 +1129,7 @@ if (iwarni(iu).ge.1) then
   write(nfecra,2000)
 
   rnorm = -1.d0
+  !$omp parallel do reduction(max:rnorm)
   do iel = 1, ncel
     rnorm  = max(rnorm,abs(rtp(iel,ipr)))
   enddo
@@ -1080,13 +1138,25 @@ if (iwarni(iu).ge.1) then
   write(nfecra,2100)rnorm
 
   rnorm = -1.d0
+  imax = 1
+  !$omp parallel private(imaxt, rnormt, vitnor)
+  rnormt = -1.d0
+  imaxt = 1
+  !$omp do
   do iel = 1, ncel
     vitnor = sqrt(rtp(iel,iu)**2+rtp(iel,iv)**2+rtp(iel,iw)**2)
-    if(vitnor.ge.rnorm) then
-      rnorm = vitnor
-      imax  = iel
+    if (vitnor.ge.rnormt) then
+      rnormt = vitnor
+      imaxt  = iel
     endif
   enddo
+  !$omp critical
+  if (rnormt.ge.rnorm) then
+    rnorm = rnormt
+    imax  = imaxt
+  endif
+  !$omp end critical
+  !$omp end parallel
 
   xyzmax(1) = xyzcen(1,imax)
   xyzmax(2) = xyzcen(2,imax)
@@ -1103,9 +1173,10 @@ if (iwarni(iu).ge.1) then
 
   ! Pour la periodicite et le parallelisme, rom est echange dans phyvar
 
-
   rnorma = -grand
   rnormi =  grand
+  !$omp parallel do reduction(max:rnorma) reduction(min:rnormi) &
+  !$omp          private(iel1, iel2, surf, rhom, rnorm)
   do ifac = 1, nfac
     iel1 = ifacel(1,ifac)
     iel2 = ifacel(2,ifac)
@@ -1125,6 +1196,8 @@ if (iwarni(iu).ge.1) then
 
   rnorma = -grand
   rnormi =  grand
+  !$omp parallel do reduction(max:rnorma) reduction(min:rnormi) &
+  !$omp          private(rnorm) if(nfabor > thr_n_min)
   do ifac = 1, nfabor
     rnorm = propfb(ifac,iflmab)/(surfbn(ifac)*propfb(ifac,ipbrom))
     rnorma = max(rnorma,rnorm)
@@ -1139,6 +1212,7 @@ if (iwarni(iu).ge.1) then
   write(nfecra,2400)rnorma, rnormi
 
   rnorm = 0.d0
+  !$omp parallel do reduction(+:rnorm) if(nfabor > thr_n_min)
   do ifac = 1, nfabor
     rnorm = rnorm + propfb(ifac,iflmab)
   enddo
@@ -1150,12 +1224,12 @@ if (iwarni(iu).ge.1) then
 
   write(nfecra,2001)
 
-  if(nterup.gt.1) then
-    if(icvrge.eq.0) then
+  if (nterup.gt.1) then
+    if (icvrge.eq.0) then
       write(nfecra,2600) iterns
       write(nfecra,2601) xnrmu, xnrmu0, epsup
       write(nfecra,2001)
-      if(iterns.eq.nterup) then
+      if (iterns.eq.nterup) then
         write(nfecra,2603)
         write(nfecra,2001)
       endif
@@ -1180,6 +1254,7 @@ deallocate(w1, w2, w3)
 deallocate(w4, w5, w6)
 deallocate(w7, w8, w9)
 if (allocated(w10)) deallocate(w10)
+deallocate(coefap)
 
 !--------
 ! FORMATS
@@ -1247,7 +1322,7 @@ if (allocated(w10)) deallocate(w10)
 #endif
 
 !----
-! FIN
+! End
 !----
 
 return
