@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2011 EDF S.A.
+! Copyright (C) 1998-2012 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -126,7 +126,7 @@ subroutine preduv &
 use paramx
 use dimens, only: ndimfb
 use numvar
-use pointe, only: forbr
+use pointe, only: forbr, porosi
 use entsor
 use cstphy
 use cstnum
@@ -178,16 +178,17 @@ double precision xnormp(ncelet)
 integer          iel   , ielpdc, ifac  , ivar  , isou
 integer          iccocg, inc   , init  , ii    , isqrt
 integer          ireslp, nswrgp, imligp, iwarnp, ippt  , ipp
-integer                  iclipr, icliup, iclivp, icliwp
-integer                          iclik , iclvar, iclvaf
-integer          ipcrom, ipcroa, ipcroo , ipcvis, ipcvst
+integer          iclipr, iclu  , iclv  , iclw
+integer          iclik , iclvar, iclvaf
+integer          ipcrom, ipcroa, ipcroo, ipcrho, ipcvis, ipcvst
 integer          iconvp, idiffp, ndircp, nitmap, nswrsp
 integer          ircflp, ischcp, isstpp, iescap
 integer          imgrp , ncymxp, nitmfp
 integer          iesprp, iestop
 integer          iptsna
-integer          iflmb0, nswrp , imaspe, ipbrom
+integer          iflmb0, nswrp , imaspe, ipbrom, itypfl
 integer          idiaex, idtva0
+integer          imucpp
 
 double precision rnorm , vitnor
 double precision romvom, drom
@@ -203,6 +204,7 @@ double precision rvoid(1)
 
 double precision, allocatable, dimension(:) :: eswork
 double precision, allocatable, dimension(:,:) :: grad
+double precision, allocatable, dimension(:) :: dpvar
 
 !===============================================================================
 
@@ -214,12 +216,13 @@ double precision, allocatable, dimension(:,:) :: grad
 if (iescal(iespre).gt.0) then
   allocate(eswork(ncelet))
 endif
+allocate(dpvar(ncelet))
 
 
 iclipr = iclrtp(ipr,icoef)
-icliup = iclrtp(iu ,icoef)
-iclivp = iclrtp(iv ,icoef)
-icliwp = iclrtp(iw ,icoef)
+iclu = iclrtp(iu ,icoef)
+iclv = iclrtp(iv ,icoef)
+iclw = iclrtp(iw ,icoef)
 
 if(itytur.eq.2 .or. itytur.eq.5 .or. iturb.eq.60) then
   iclik  = iclrtp(ik ,icoef)
@@ -232,7 +235,7 @@ ipbrom = ipprob(irom  )
 !     Reperage de rho courant (ie en cas d'extrapolation rho^n+1/2)
 ipcrom = ipproc(irom  )
 !     Reperage de rho^n en cas d'extrapolation
-if(iroext.gt.0) then
+if(iroext.gt.0.or.idilat.gt.1) then
   ipcroa = ipproc(iroma)
 else
   ipcroa = 0
@@ -248,6 +251,10 @@ else
   iptsna = 0
 endif
 
+! Compute the porosity if needed
+if (iterns.eq.1.and.iporos.eq.1) then
+  call usporo
+endif
 
 !===============================================================================
 ! 2.  GRADIENT DE PRESSION ET GRAVITE
@@ -341,6 +348,14 @@ call grdpot &
    rtpa(1,ipr)  , coefa(1,iclipr) , coefb(1,iclipr) ,             &
    grad   )
 
+! With porosity
+if (iporos.eq.1) then
+  do iel = 1, ncel
+    grad(iel,1) = grad(iel,1)*porosi(iel)
+    grad(iel,2) = grad(iel,2)*porosi(iel)
+    grad(iel,3) = grad(iel,3)*porosi(iel)
+  enddo
+endif
 
 !    Calcul des efforts aux parois (partie 2/5), si demande
 !    La pression a la face est calculee comme dans gradrc/gradmc
@@ -418,18 +433,19 @@ if(iappel.eq.1.and.irnpnw.eq.1) then
   extrap = extrag(iu )
 
   imaspe = 1
+  itypfl = 1
 
   call inimas &
   !==========
  ( nvar   , nscal  ,                                              &
-   iu  , iv  , iw  , imaspe ,                                     &
+   iu  , iv  , iw  , imaspe , itypfl ,                            &
    iflmb0 , init   , inc    , imrgra , iccocg , nswrp  , imligp , &
    iwarnp , nfecra ,                                              &
    epsrgp , climgp , extrap ,                                     &
    propce(1,ipcrom), propfb(1,ipbrom),                            &
    trav(1,1) , trav(1,2) , trav(1,3) ,                            &
-   coefa(1,icliup), coefa(1,iclivp), coefa(1,icliwp),             &
-   coefb(1,icliup), coefb(1,iclivp), coefb(1,icliwp),             &
+   coefa(1,iclu), coefa(1,iclv), coefa(1,iclw),                   &
+   coefb(1,iclu), coefb(1,iclv), coefb(1,iclw),                   &
    viscf  , viscb  )
 
 !     Calcul de div(rho dt/rho*grad P)
@@ -444,6 +460,12 @@ if(iappel.eq.1.and.irnpnw.eq.1) then
       xnormp(iel) = xnormp(iel)-volume(iel)*smacel(ii,ipr)
     enddo
   endif
+  ! Semi-analytic weakly compressible algorithm add + 1/rho Drho/Dt
+  if (idilat.eq.4)then
+    do iel = 1, ncel
+      xnormp(iel) = xnormp(iel) + propce(iel,ipproc(iustdy(itsrho)))
+    enddo
+  endif
 
 !     On conserve XNORMP, on complete avec u* a la fin et
 !       on le transfere a resolp
@@ -600,6 +622,15 @@ if(     (itytur.eq.2 .or. itytur.eq.5 .or. iturb.eq.60) &
    rtpa(1,ik)   , coefa(1,iclik)  , coefb(1,iclik)  ,             &
    grad   )
 
+  ! With porosity
+  if (iporos.eq.1) then
+    do iel = 1, ncel
+      grad(iel,1) = grad(iel,1)*porosi(iel)
+      grad(iel,2) = grad(iel,2)*porosi(iel)
+      grad(iel,3) = grad(iel,3)*porosi(iel)
+    enddo
+  endif
+
   d2s3 = 2.d0/3.d0
 
 !     Si on extrapole les termes source en temps : PROPCE
@@ -683,7 +714,7 @@ if (ivisse.eq.1.and.iterns.eq.1) then
    rtpa   , propce , propfa , propfb ,                            &
    coefa  , coefb  , ckupdc , smacel ,                            &
    trav   ,                                                       &
-!        ------
+!  ------
    viscf  , viscb  )
 
 !     Si on extrapole les termes source en temps :
@@ -758,6 +789,15 @@ if((ncepdp.gt.0).and.(iphydr.eq.0)) then
    rtpa   , propce , propfa , propfb ,                            &
    coefa  , coefb  , ckupdc , trav   )
 
+  ! With porosity
+  if (iporos.eq.1) then
+    do iel = 1, ncel
+      trav(iel,1) = trav(iel,1)*porosi(iel)
+      trav(iel,2) = trav(iel,2)*porosi(iel)
+      trav(iel,3) = trav(iel,3)*porosi(iel)
+    enddo
+  endif
+
 !     Si on itere sur navsto, on utilise TRAVA ; sinon TRAV
     if(nterup.gt.1) then
       do iel = 1, ncel
@@ -805,6 +845,14 @@ if((ncepdp.gt.0).and.(iphydr.eq.0)) then
    rtpa   , propce , propfa , propfb ,                            &
    coefa  , coefb  , ckupdc , trav   )
 
+  ! With porosity
+  if (iporos.eq.1) then
+    do iel = 1, ncel
+      trav(iel,1) = trav(iel,1)*porosi(iel)
+      trav(iel,2) = trav(iel,2)*porosi(iel)
+      trav(iel,3) = trav(iel,3)*porosi(iel)
+    enddo
+  endif
 
 !     Si on extrapole les termes source en temps :
 !       PROPCE recoit les termes extradiagonaux et
@@ -849,7 +897,7 @@ if((ncepdp.gt.0).and.(iphydr.eq.0)) then
 endif
 
 
-! ---> TERMES DE CORIOLIS
+! ---> TERMES DE CORIOLIS ! FIXME with porosity
 !     SI IPHYDR=1 LE TERME A DEJA ETE PRIS EN COMPTE AVANT
 
 if (icorio.eq.1.and.iphydr.eq.0) then
@@ -1088,6 +1136,7 @@ do isou = 1, 3
 
 !     Le calcul des parties implicite et explicite des termes sources
 !       utilisateurs est faite uniquement a la premiere iter sur navsto.
+! FIXME with porosity
   if(iterns.eq.1) then
 
     call ustsns                                                 &
@@ -1166,30 +1215,19 @@ do isou = 1, 3
 
 ! ---> TERME D'ACCUMULATION DE MASSE -(dRO/dt)*Volume
 
-  init = 1
-  call divmas(ncelet,ncel,nfac,nfabor,init,nfecra,                &
-                           ifacel,ifabor,flumas,flumab,w1)
-
-
-!     On ajoute a TRAV ou TRAVA la partie issue des termes implicites
-  if(iterns.eq.1) then
-    if(nterup.gt.1) then
-      do iel = 1, ncel
-        trava(iel,isou) = trava(iel,isou) + iconv(ivar)*w1(iel)*rtpa(iel,ivar)
-      enddo
-    else
-      do iel = 1, ncel
-        trav(iel,isou) = trav(iel,isou) + iconv(ivar)*w1(iel)*rtpa(iel,ivar)
-      enddo
-    endif
-  endif
-
   if(iappel.eq.1) then
-!     Extrapolation ou non, meme forme par coherence avec bilsc2
+
+    ! Low Mach compressible Algos
+    if (idilat.gt.1) then
+      ipcrho = ipcroa
+
+    ! Standard algo
+    else
+      ipcrho = ipcrom
+    endif
+
     do iel = 1, ncel
-      rovsdt(iel) =                                               &
-         istat(ivar)*(propce(iel,ipcrom)/dt(iel))*volume(iel)     &
-         -iconv(ivar)*w1(iel)*thetav(ivar)
+      rovsdt(iel) = istat(ivar)*propce(iel,ipcrho)/dt(iel)*volume(iel)
     enddo
 
 !     Le remplissage de ROVSDT est toujours indispensable,
@@ -1241,7 +1279,7 @@ do isou = 1, 3
       do ielpdc = 1, ncepdp
         iel = icepdc(ielpdc)
         rovsdt(iel) = rovsdt(iel) +                               &
-        propce(iel,ipcrom)*volume(iel)*ckupdc(ielpdc,isou)*thetap
+          propce(iel,ipcrom)*volume(iel)*ckupdc(ielpdc,isou)*thetap
       enddo
     endif
   endif
@@ -1363,6 +1401,12 @@ do isou = 1, 3
     enddo
   endif
 
+  ! With porosity
+  if (iporos.eq.1) then
+    do iel = 1, ncel
+      rovsdt(iel) = rovsdt(iel)*porosi(iel)
+    enddo
+  endif
 
 ! ---> PARAMETRES POUR LA RESOLUTION DU SYSTEME OU LE CALCUL DE l'ESTIMATEUR
 
@@ -1371,17 +1415,16 @@ do isou = 1, 3
   ireslp = iresol(ivar)
   ndircp = ndircl(ivar)
   nitmap = nitmax(ivar)
-!MO        IMRGRA
   nswrsp = nswrsm(ivar)
   nswrgp = nswrgr(ivar)
   imligp = imligr(ivar)
   ircflp = ircflu(ivar)
   ischcp = ischcv(ivar)
   isstpp = isstpc(ivar)
+  imucpp = 0
   imgrp  = imgr  (ivar)
   ncymxp = ncymax(ivar)
   nitmfp = nitmgf(ivar)
-!MO        IPP
   iwarnp = iwarni(ivar)
   blencp = blencv(ivar)
   epsilp = epsilo(ivar)
@@ -1402,12 +1445,12 @@ do isou = 1, 3
 
 !  Attention, dans le cas des estimateurs, eswork fournit l'estimateur
 !     des vitesses predites
-      call codits                                                 &
+      call codits &
       !==========
  ( nvar   , nscal  ,                                              &
    idtvar , ivar   , iconvp , idiffp , ireslp , ndircp , nitmap , &
    imrgra , nswrsp , nswrgp , imligp , ircflp ,                   &
-   ischcp , isstpp , iescap ,                                     &
+   ischcp , isstpp , iescap , imucpp ,                            &
    imgrp  , ncymxp , nitmfp , ipp    , iwarnp ,                   &
    blencp , epsilp , epsrsp , epsrgp , climgp , extrap ,          &
    relaxp , thetap ,                                              &
@@ -1416,27 +1459,27 @@ do isou = 1, 3
                      coefa(1,iclvaf) , coefb(1,iclvaf) ,          &
                      flumas , flumab ,                            &
    viscfi , viscbi , viscf  , viscb  ,                            &
-   rovsdt , smbr   , rtp(1,ivar)     ,                            &
-   eswork )
+   rovsdt , smbr   , rtp(1,ivar)     , dpvar  ,                   &
+   rvoid  , eswork )
 
     elseif(iterns.gt.1) then
 
-      call codits                                                 &
+      call codits &
       !==========
  ( nvar   , nscal  ,                                              &
    idtvar , ivar   , iconvp , idiffp , ireslp , ndircp , nitmap , &
    imrgra , nswrsp , nswrgp , imligp , ircflp ,                   &
-   ischcp , isstpp , iescap ,                                     &
+   ischcp , isstpp , iescap , imucpp ,                            &
    imgrp  , ncymxp , nitmfp , ipp    , iwarnp ,                   &
    blencp , epsilp , epsrsp , epsrgp , climgp , extrap ,          &
    relaxp , thetap ,                                              &
-   rtpa(1,ivar)    , uvwk(1,isou) ,                         &
+   rtpa(1,ivar)    , uvwk(1,isou) ,                               &
                      coefa(1,iclvar) , coefb(1,iclvar) ,          &
                      coefa(1,iclvaf) , coefb(1,iclvaf) ,          &
                      flumas , flumab ,                            &
    viscfi , viscbi , viscf  , viscb  ,                            &
-   rovsdt , smbr   , rtp(1,ivar)     ,                            &
-   eswork )
+   rovsdt , smbr   , rtp(1,ivar)     , dpvar  ,                   &
+   rvoid  , eswork )
 
     endif
 
@@ -1472,12 +1515,12 @@ do isou = 1, 3
       enddo
       iescap = 0
 
-      call codits                                                 &
+      call codits &
       !==========
  ( nvar   , nscal  ,                                              &
    idtvar , ivar   , iconvp , idiffp , ireslp , ndircp , nitmap , &
    imrgra , nswrsp , nswrgp , imligp , ircflp ,                   &
-   ischcp , isstpp , iescap ,                                     &
+   ischcp , isstpp , iescap , imucpp ,                            &
    imgrp  , ncymxp , nitmfp , ippt   , iwarnp ,                   &
    blencp , epsilp , epsrsp , epsrgp , climgp , extrap ,          &
    relaxp , thetap ,                                              &
@@ -1486,8 +1529,8 @@ do isou = 1, 3
                      coefa(1,iclvaf) , coefb(1,iclvaf) ,          &
                      flumas , flumab ,                            &
    viscfi , viscbi , viscf  , viscb  ,                            &
-   rovsdt , smbr   , tpucou(1,isou)  ,                            &
-   rvoid  )
+   rovsdt , smbr   , tpucou(1,isou)  , dpvar  ,                   &
+   rvoid  , rvoid  )
 
       do iel = 1, ncelet
         tpucou(iel,isou) = propce(iel,ipcrom)*tpucou(iel,isou)
@@ -1512,6 +1555,7 @@ do isou = 1, 3
 
     inc = 1
     iccocg = 1
+    imucpp = 0
 !     Pas de relaxation en stationnaire
     idtva0 = 0
 
@@ -1520,12 +1564,12 @@ do isou = 1, 3
  ( nvar   , nscal  ,                                              &
    idtva0 , ivar   , iconvp , idiffp , nswrgp , imligp , ircflp , &
    ischcp , isstpp , inc    , imrgra , iccocg ,                   &
-   ipp    , iwarnp ,                                              &
+   ipp    , iwarnp , imucpp ,                                     &
    blencp , epsrgp , climgp , extrap , relaxp , thetap ,          &
    rtp(1,ivar)     , rtp(1,ivar)     ,                            &
    coefa(1,iclvar) , coefb(1,iclvar) ,                            &
    coefa(1,iclvaf) , coefb(1,iclvaf) ,                            &
-   flumas , flumab , viscf  , viscb  ,                            &
+   flumas , flumab , viscf  , viscb  , rvoid  ,                   &
    smbr   )
 
     iestop = ipproc(iestim(iestot))
@@ -1563,18 +1607,19 @@ if(iappel.eq.1.and.irnpnw.eq.1) then
   extrap = extrag(iu )
 
   imaspe = 1
+  itypfl = 1
 
   call inimas &
   !==========
  ( nvar   , nscal  ,                                              &
-   iu  , iv  , iw  , imaspe ,                                     &
+   iu  , iv  , iw  , imaspe , itypfl ,                            &
    iflmb0 , init   , inc    , imrgra , iccocg , nswrp  , imligp , &
    iwarnp , nfecra ,                                              &
    epsrgp , climgp , extrap ,                                     &
    propce(1,ipcrom), propfb(1,ipbrom),                            &
    rtp(1,iu) , rtp(1,iv) , rtp(1,iw) ,                            &
-   coefa(1,icliup), coefa(1,iclivp), coefa(1,icliwp),             &
-   coefb(1,icliup), coefb(1,iclivp), coefb(1,icliwp),             &
+   coefa(1,iclu), coefa(1,iclv), coefa(1,iclw),                   &
+   coefb(1,iclu), coefb(1,iclv), coefb(1,iclw),                   &
    viscf  , viscb  )
 
   init = 0
@@ -1584,7 +1629,7 @@ if(iappel.eq.1.and.irnpnw.eq.1) then
 !     Calcul de la norme
 !       RNORMP qui servira dans resolp
   isqrt = 1
-  call prodsc(ncelet,ncel,isqrt,xnormp,xnormp,rnormp)
+  call prodsc(ncel,isqrt,xnormp,xnormp,rnormp)
 
 endif
 
@@ -1640,6 +1685,9 @@ elseif (iappel.eq.2) then
 
 endif
 
+! Free memory
+deallocate(dpvar)
+
 !--------
 ! FORMATS
 !--------
