@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2011 EDF S.A.
+! Copyright (C) 1998-2012 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -515,7 +515,7 @@ deallocate(smbrs, rovsdt)
 '@    il s agit de la variance des fluctuations du scalaire J ',/,&
 '@    dont le numero est ISCAVR(I)                            ',/,&
 '@                                                            ',/,&
-'@  Verifier usini1.                                          ',/,&
+'@  Verifier les parametres.                                  ',/,&
 '@  Contacter l''assistance.                                  ',/,&
 '@                                                            ',/,&
 '@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
@@ -541,7 +541,7 @@ deallocate(smbrs, rovsdt)
 '@    it is the variance of the fluctuations of the scalar J  ',/,&
 '@    whose number is ISCAVR(I)                               ',/,&
 '@                                                            ',/,&
-'@  Verify usini1.                                            ',/,&
+'@  Check parameters.                                         ',/,&
 '@  Contact support.                                          ',/,&
 '@                                                            ',/,&
 '@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
