@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2011 EDF S.A.
+! Copyright (C) 1998-2012 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -89,6 +89,7 @@ use ppincl
 use cpincl
 use coincl
 use atincl
+use atsoil
 use lagpar
 use lagdim
 use lagran
@@ -131,8 +132,7 @@ integer          ntrela
 
 integer          isvhb , isvtb
 integer          ii    , jj    , ippcp , ientha, ippcv
-integer          ipcrom, ipcroa
-integer          idimte, itenso
+integer          ipcrom, ipcroa, ipbrom, ipbroa
 integer          iflua , iflub
 integer          iterns, inslst, icvrge, ivsvdr
 integer          iflmas, iflmab
@@ -213,6 +213,13 @@ if(ipass.eq.1.and.ineedy.eq.1.and.abs(icdpar).eq.1.and.           &
   enddo
 endif
 
+!    Initialisation de pthera (pther est deja initialise ou lu dans
+!    un fichier suite pour l'algorithme a masse volumique variable
+
+if (idilat.eq.3) then
+  pthera = pther
+endif
+
 !===============================================================================
 ! 2.  AU DEBUT DU CALCUL ON REINITIALISE LA PRESSION
 !===============================================================================
@@ -226,7 +233,8 @@ endif
 !   hydrostatique, ni dans le cas du compressible
 
 if( ntcabs.le.2 .and. isuite.eq.0 .and. iphydr.eq.0               &
-                .and. ippmod(icompf).lt.0           ) then
+                .and. ippmod(icompf).lt.0                         &
+                .and. idilat .le.0                 ) then
 
   if(iwarni(ipr).ge.2) then
     write(nfecra,2000) ntcabs
@@ -278,70 +286,39 @@ endif
 
 
 
-! ---> Parallelisme
+! ---> Halo synchronization
 
-if(irangp.ge.0) then
+if (irangp.ge.0 .or. iperio.eq.1) then
 
   do ivar = 1, nvar
-    call parcve (rtp(1,ivar))
+    call synsce (rtp(1,ivar))
     !==========
   enddo
 
 endif
 
-! ---> Periodicite
+! ---> Periodicity of rotation
 
-if(iperio.eq.1) then
+if (iperio.eq.1) then
 
-!  -- Vitesse
+  !  -- Vitesse
 
-  idimte = 1
-  itenso = 0
-  call percve &
+  call perrve (rtp(1,iu), rtp(1,iv), rtp(1,iw))
   !==========
-( idimte , itenso ,                                  &
-  rtp(1,iu), rtp(1,iu), rtp(1,iu),                   &
-  rtp(1,iv), rtp(1,iv), rtp(1,iv),                   &
-  rtp(1,iw), rtp(1,iw), rtp(1,iw))
 
-!  -- Tenseur de Reynolds
+  !  -- Reynolds stress tensor
 
-  if(itytur.eq.3) then
-    idimte = 2
-    itenso = 0
-    call percve &
+  if (itytur.eq.3) then
+    call perrte &
     !==========
-  ( idimte , itenso ,                                     &
-    rtp(1,ir11), rtp(1,ir12), rtp(1,ir13),                &
-    rtp(1,ir12), rtp(1,ir22), rtp(1,ir23),                &
+  ( rtp(1,ir11), rtp(1,ir12), rtp(1,ir13),           &
+    rtp(1,ir12), rtp(1,ir22), rtp(1,ir23),           &
     rtp(1,ir13), rtp(1,ir23), rtp(1,ir33) )
   endif
 
-!  -- Remarque pour le v2f
-!     v2 (donc phi) est lie a une orientation locale, on peut donc le traiter
-!     comme un scalaire dans la periodicite de rotation
-
-
-!  -- Variables scalaires
-
-  do ivar = 1, nvar
-    if(ivar.ne.iu.and.ivar.ne.iv.and.ivar.ne.iw.and.       &
-         (itytur.ne.3.or.                                  &
-         (ivar.ne.ir11.and.ivar.ne.ir22.and.       &
-         ivar.ne.ir33.and.ivar.ne.ir12.and.       &
-         ivar.ne.ir13.and.ivar.ne.ir23))) then
-
-      idimte = 0
-      itenso = 0
-      call percve                                               &
-      !==========
-    ( idimte , itenso ,                                         &
-      rtp(1,ivar), rtp(1,ivar), rtp(1,ivar),                    &
-      rtp(1,ivar), rtp(1,ivar), rtp(1,ivar),                    &
-      rtp(1,ivar), rtp(1,ivar), rtp(1,ivar) )
-
-    endif
-  enddo
+  !  -- Note for v2f:
+  !     v2 (thus phi) is oriented locally, and is handled as a scalar
+  !     regarding periodicity of rotation
 
 endif
 
@@ -352,50 +329,34 @@ endif
 !     PROPCE(1,IPPROC(IROMA))
 !===============================================================================
 
-if(ipass.eq.1) then
+if (ipass.eq.1) then
 
 ! --- Communication de FRCXT
   if (iphydr.eq.1) then
 
-    if(irangp.ge.0) then
-      call parcve (frcxt(1,1))
+    if (irangp.ge.0 .or. iperio.eq.1) then
+      call synsce (frcxt(1,1))
       !==========
-      call parcve (frcxt(1,2))
+      call synsce (frcxt(1,2))
       !==========
-      call parcve (frcxt(1,3))
+      call synsce (frcxt(1,3))
       !==========
     endif
-    if(iperio.eq.1) then
-      idimte = 1
-      itenso = 0
-      call percve                                               &
+    if (iperio.eq.1) then
+      call perrve (frcxt(1,1), frcxt(1,2), frcxt(1,3))
       !==========
-    ( idimte , itenso ,                                           &
-      frcxt(1,1),frcxt(1,1),frcxt(1,1),         &
-      frcxt(1,2),frcxt(1,2),frcxt(1,2),         &
-      frcxt(1,3),frcxt(1,3),frcxt(1,3) )
     endif
 
   endif
 
 ! --- Communication de RHO
-  if (icalhy.eq.1) then
+  if (icalhy.eq.1 .or. idilat.eq.3) then
 
     ipcrom = ipproc(irom  )
-    if(irangp.ge.0) then
-      call parcve (propce(1,ipcrom))
+    if (irangp.ge.0 .or. iperio.eq.1) then
+      call synsce (propce(1,ipcrom))
       !==========
     endif
-    if(iperio.eq.1) then
-      idimte = 0
-      itenso = 0
-      call percve                                               &
-      !==========
-    ( idimte , itenso ,                                           &
-      propce(1,ipcrom),propce(1,ipcrom),propce(1,ipcrom),         &
-      propce(1,ipcrom),propce(1,ipcrom),propce(1,ipcrom),         &
-      propce(1,ipcrom),propce(1,ipcrom),propce(1,ipcrom) )
-    endif
 
   endif
 
@@ -415,7 +376,8 @@ do ivar = 1, nvar
   enddo
 enddo
 
-if (icalhy.eq.1) then
+! If required, the density at time step n-1 is updated
+if (icalhy.eq.1.or.idilat.gt.1) then
   ipcrom = ipproc(irom  )
   ipcroa = ipproc(iroma )
   do iel = 1, ncelet
@@ -610,6 +572,20 @@ if (nbaste.gt.0.and.itrale.gt.nalinf) then
   call astpdt(dt, ncelet, ntrela)
   !==========
 endif
+
+!===============================================================================
+!   RECALAGE DE LA PRESSION Pth ET MASSE VOLUMIQUE rho
+!     POUR L'AGORITHME A MASSE VOLUMIQUE VARIABLE.
+!===============================================================================
+
+if (idilat.eq.3) then
+  call pthrbm &
+  !==========
+ ( nvar   , nscal  , ncetsm ,        &
+   dt     , rtp    , rtpa   ,        &
+   propce , propfa , propfb , smacel )
+endif
+
 !===============================================================================
 ! 9.  CHARGEMENT ET TRADUCTION DES CONDITIONS AUX LIMITES
 !===============================================================================
@@ -703,25 +679,24 @@ if (nterup.gt.1) then
 
 endif
 
+! Allocate temporary arrays for boundary conditions
+allocate(icodcl(nfabor,nvar))
+allocate(rcodcl(nfabor,nvar,3))
+if (isvhb.gt.0) then
+  allocate(hbord(nfabor))
+endif
+if (isvtb.gt.0 .or. iirayo.gt.0) then
+  allocate(tbord(nfabor))
+endif
+if (itytur.eq.4 .and. idries.eq.1) then
+  allocate(visvdr(ncelet))
+endif
 
 icvrge = 0
 inslst = 0
 iterns = 1
 do while (iterns.le.nterup)
 
-  ! Allocate temporary arrays for boundary conditions
-  allocate(icodcl(nfabor,nvar))
-  allocate(rcodcl(nfabor,nvar,3))
-  if (isvhb.gt.0) then
-    allocate(hbord(nfabor))
-  endif
-  if (isvtb.gt.0 .or. iirayo.gt.0) then
-    allocate(tbord(nfabor))
-  endif
-  if (itytur.eq.4 .and. idries.eq.1) then
-    allocate(visvdr(ncelet))
-  endif
-
   call precli &
   !==========
 ( nvar   , nscal  ,                                              &
@@ -744,12 +719,15 @@ do while (iterns.le.nterup)
     !==========
   ( ntcabs, nfabor,                                                &
     nozppm, ncharm, ncharb, nclpch,                                &
-    iindef, ientre, iparoi, iparug, isymet, isolib,                &
-    iqimp,  icalke, ientat, ientcp, inmoxy, iprofm,                &
-    itypfb, izfppp, icodcl,                                    &
+    iindef, ientre, iesicf, isspcf, ierucf, isopcf,                &
+    iparoi, iparug, isymet, isolib, isca  ,                        &
+    ipr   , irho  , itempk, ienerg,                                &
+    iqimp,  icalke, ientat, ientcp, inmoxy, ientfu,                &
+    ientox, ientgb, ientgf, iprofm,                                &
+    itypfb, izfppp, icodcl,                                        &
     dtref,  ttcabs, surfbo, cdgfbo,                                &
     qimp,   qimpat, qimpcp, dh,     xintur,                        &
-    timpat, timpcp, distch, rcodcl)
+    timpat, timpcp, tkent ,  fment, distch, rcodcl)
 
     if (ippmod(iphpar).eq.0) then
 
@@ -781,28 +759,13 @@ do while (iterns.le.nterup)
   !     - Sous-programme utilisateur
   !       ==========================
 
-  if (ippmod(iphpar).eq.0) then
-
-    call usclim &
-    !==========
-  ( nvar   , nscal  ,                                              &
-    icodcl , itrifb , itypfb ,                                     &
-    dt     , rtp    , rtpa   , propce , propfa , propfb ,          &
-    coefa  , coefb  , rcodcl )
-
-  else
-
-    ! ON FAIT DE LA PHYSIQUE PARTICULIERE
-
-    call ppclim &
-    !==========
+  call cs_user_boundary_conditions &
+  !===============================
   ( nvar   , nscal  ,                                              &
     icodcl , itrifb , itypfb , izfppp ,                            &
     dt     , rtp    , rtpa   , propce , propfa , propfb ,          &
     coefa  , coefb  , rcodcl )
 
-  endif
-
   !     - Interface Code_Saturne
   !       ======================
 
@@ -811,7 +774,8 @@ do while (iterns.le.nterup)
     call uiclve &
     !==========
   ( nfabor, nozppm,                                                &
-    iindef, ientre, iparoi, iparug, isymet, isolib,                &
+    iindef, ientre, iesicf, ierucf, isspcf, isopcf,                &
+    iparoi, iparug, isymet, isolib,                                &
     itypfb, izfppp )
 
   endif
@@ -845,12 +809,28 @@ do while (iterns.le.nterup)
 
   endif
 
+! -- Synthetic Eddy Method en L.E.S. :
+!    (Transfert des structures dans les tableaux rcodcl)
+
+    call synthe &
+    !==========
+  ( nvar   , nscal  ,                                              &
+    iu     , iv     , iw     ,                                     &
+    ttcabs ,                                                       &
+    dt     , rtpa   , rtp    , propce , propfa , propfb ,          &
+    coefa  , coefb  , rcodcl )
+
   ! -- Methode ALE (CL de vitesse de maillage et deplacement aux noeuds)
 
   if (iale.eq.1) then
 
     do ii = 1, nnod
       impale(ii) = 0
+      if (ivelco.eq.1) then
+        disala(1,ii) = depale(ii,1)
+        disala(2,ii) = depale(ii,2)
+        disala(3,ii) = depale(ii,3)
+      endif
     enddo
 
     ! - Interface Code_Saturne
@@ -858,6 +838,8 @@ do while (iterns.le.nterup)
 
     if (iihmpr.eq.1) then
 
+      !TODO add ifresf for the free surface
+
       call uialcl &
       !==========
     ( nfabor, nozppm,                    &
@@ -909,9 +891,21 @@ do while (iterns.le.nterup)
   !     UNE FOIS CERTAINS CODES DE CONDITIONS LIMITES INITIALISES PAR
   !     L'UTILISATEUR, ON PEUT COMPLETER CES CODES PAR LES COUPLAGES
   !     AUX BORDS (TYPE SYRTHES), SAUF SI ON DOIT Y REPASSER ENSUITE
+  !     POUR CENTRALISER CE QUI EST RELATIF AU COUPLAGE AVEC SYRTHES
+  !     ON POSITIONNE ICI L'APPEL AU COUPLAGE VOLUMIQUE SYRTHES
+  !     UTILE POUR BENIFICER DE LA DERNIERE VITESSE CALCULEE SI ON
+  !     BOUCLE SUR U/P.
+  !     LE COUPLAGE VOLUMIQUE DOIT ETRE APPELE AVANT LE SURFACIQUE
+  !     POUR RESPECTER LE SCHEMA DE COMMUNICATION
 
   if (itrfin.eq.1 .and. itrfup.eq.1) then
 
+    call cpvosy &
+    !==========
+  ( nvar   , nscal  , isvtb  ,                                 &
+    dt     , rtp    , rtpa   , propce , propfa , propfb ,      &
+    hbord  , tbord  )
+
     call coupbi(nfabor, nvar, nscal, icodcl, rcodcl)
     !==========
 
@@ -945,7 +939,7 @@ do while (iterns.le.nterup)
 
   call condli &
   !==========
-( nvar   , nscal  ,                                              &
+( nvar   , nscal  , iterns ,                                     &
   isvhb  , isvtb  ,                                              &
   icodcl , isostd ,                                              &
   dt     , rtp    , rtpa   , propce , propfa , propfb ,          &
@@ -954,6 +948,16 @@ do while (iterns.le.nterup)
   hbord  , tbord  ,                                              &
   frcxt  )
 
+!     ==============================================
+!     Appel de l'interface sol-atmosphere
+!     ==============================================
+
+  if (ippmod(iatmos).eq.2.and.iatsoil.eq.1.and.nfmodsol.gt.0) then
+    ipcrom = ipproc(irom)
+    call solvar(rtp(1,isca(iscalt)),rtp(1,isca(itotwt)),rtp(1,ipr),  &
+                propce(1,ipcrom)   , dt ,                            &
+                rcodcl , rtp)
+  endif
 
   !     UNE FOIS LES COEFFICIENTS CALCULES, ON PEUT EN DEDUIRE PLUS
   !     FACILEMENT (I.E. SANS RECALCULS INUTILES) LES TERMES A
@@ -1158,12 +1162,6 @@ do while (iterns.le.nterup)
     write(nfecra,4010)tditot
   endif
 
-  ! Free memory
-  deallocate(icodcl, rcodcl)
-  if (allocated(hbord)) deallocate(hbord)
-  if (allocated(tbord)) deallocate(tbord)
-  if (allocated(visvdr)) deallocate(visvdr)
-
 !===============================================================================
 ! 10. DANS LE CAS  "zero pas de temps" EN "NON SUITE" DE CALCUL
 !      ON SORT ICI
@@ -1181,11 +1179,27 @@ do while (iterns.le.nterup)
 
     if (itrale.eq.0 .or. itrale.gt.nalinf) then
 
-      call alelap &
-      !==========
-    ( nvar   , nscal  ,                                              &
-      dt     , rtp    , rtpa   , propce , propfa , propfb ,          &
-      coefa  , coefb  )
+      if (ivelco.eq.0) then
+        call alelap &
+        !==========
+      ( nvar   , nscal  ,                                              &
+        dt     , rtp    , rtpa   , propce , propfa , propfb ,          &
+        coefa  , coefb  )
+
+      else
+
+        ! otherwise it is done in navstv.f90
+        if (itrale.eq.0) then
+
+          call alelav &
+          !==========
+        ( nvar   , nscal  ,                                              &
+          dt     , rtp    , rtpa   , propce , propfa , propfb ,          &
+          coefa  , coefb  )
+
+        endif
+
+      endif
 
     endif
 
@@ -1273,7 +1287,7 @@ do while (iterns.le.nterup)
 
          call navstv &
         !==========
-      ( nvar   , nscal  , iterns , icvrge ,                            &
+      ( nvar   , nscal  , iterns , icvrge , itrale ,                   &
         isostd ,                                                       &
         dt     , tpucou , rtp    , rtpa   , propce , propfa , propfb , &
         tslagr , coefa  , coefb  , frcxt  ,                            &
@@ -1316,8 +1330,7 @@ do while (iterns.le.nterup)
       !       masse a la derniere iteration
       !     Sinon on traite le flux de masse a toutes les iterations
 
-      !     On teste le flux de masse de la phase 1 (toutes les phases sont
-      !     necessairement traitees de la meme facon, cf. VERINI)
+      !     On teste le flux de masse
       if( (istmpf.eq.0.and.inslst.eq.0) .or. istmpf.ne.0) then
         iappel = 3
         call schtmp &
@@ -1341,6 +1354,10 @@ enddo
 100 continue
 
 ! Free memory
+if (allocated(hbord)) deallocate(hbord)
+if (allocated(tbord)) deallocate(tbord)
+if (allocated(visvdr)) deallocate(visvdr)
+
 if (nterup.gt.1) then
   deallocate(uvwk, trava)
   if (ivelco.eq.0) then
@@ -1350,7 +1367,7 @@ if (nterup.gt.1) then
   endif
 endif
 
-! Calcul sur champ de vitesse fige SUITE (a cause de la boule U/P)
+! Calcul sur champ de vitesse fige SUITE (a cause de la boucle U/P)
 if (iccvfg.eq.0) then
 !===============
 
@@ -1459,6 +1476,17 @@ if (iccvfg.eq.0) then
 
   else if(itytur.eq.3) then
 
+    ! Calcul de Alpha pour l'EBRSM
+    if (iturb.eq.32) then
+
+      call resalp &
+      !==========
+    ( nvar   , nscal  ,                                              &
+      dt     , rtp    , rtpa   , propce , propfa , propfb ,          &
+      coefa  , coefb  )
+
+    endif
+
     call turrij &
     !==========
   ( nvar   , nscal  ,                                              &
@@ -1523,16 +1551,16 @@ endif  ! Fin si calcul sur champ de vitesse fige SUITE
 
 if (nscal.ge.1 .and. iirayo.gt.0) then
 
-  if(iwarni(iu).ge.1 .and. mod(ntcabs,nfreqr).eq.0) then
+  if (iwarni(iu).ge.1 .and. mod(ntcabs,nfreqr).eq.0) then
     write(nfecra,1070)
   endif
 
-  call raydom                                                     &
+  call raydom &
   !==========
  ( nvar   , nscal  ,                                              &
-   itypfb ,                                                       &
+   itypfb , icodcl ,                                              &
    izfrad ,                                                       &
-   dt     , rtp    , rtpa   , propce , propfa , propfb ,          &
+   dt     , rtp    , rtpa   , propce , propfa , propfb , rcodcl , &
    coefa  , coefb  )
 
 endif
@@ -1552,6 +1580,9 @@ if (nscal.ge.1) then
 
 endif
 
+! Free memory
+deallocate(icodcl, rcodcl)
+
 !===============================================================================
 ! 17.  TRAITEMENT DU FLUX DE MASSE, DE LA VISCOSITE,
 !      DE LA MASSE VOLUMIQUE ET DE LA CHALEUR SPECIFIQUE POUR
