@@ -5,7 +5,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2011 EDF S.A.
+  Copyright (C) 1998-2012 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -24,9 +24,9 @@
 
 /*----------------------------------------------------------------------------*/
 
-#if defined(HAVE_CONFIG_H)
-#include "cs_config.h"
-#endif
+#include "cs_defs.h"
+
+/*-----------------------------------------------------------------------------*/
 
 /* On Solaris, procfs may not be compiled in a largefile environment,
  * so we redefine macros before including any system header file. */
@@ -39,8 +39,6 @@
 #define _FILE_OFFSET_BITS 32
 #endif
 
-#include "bft_config_defs.h"
-
 /*
  * Standard C library headers
  */
@@ -89,7 +87,7 @@
 #endif
 
 #if defined(HAVE_UNISTD_H) && defined(HAVE_SBRK)
-#if defined(__blrts__) || defined(__bgp_)
+#if defined(__blrts__) || defined(__bgp__)
 #define USE_SBRK 1
 #elif defined (__linux__)
 #define __USE_MISC 1
