@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2011 EDF S.A.
+! Copyright (C) 1998-2012 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -63,11 +63,6 @@ subroutine cfcdts &
 !  Y COMPRIS DANS LE HALO EN PERIODICITE (appel a promav pour
 !  le calcul de la norme)
 
-
-
-
-
-
 !-------------------------------------------------------------------------------
 ! Arguments
 !__________________.____._____.________________________________________________.
@@ -170,6 +165,7 @@ double precision viscfs(nfac), viscbs(nfabor)
 double precision rovsdt(ncelet), smbrp(ncelet)
 double precision pvar(ncelet)
 double precision eswork(ncelet)
+integer          imucpp
 
 ! Local variables
 
@@ -177,10 +173,12 @@ character*80     chaine
 character*16     cnom
 integer          isym,ireslp,ireslq,ipol,isqrt
 integer          inc,isweep,niterf,iccocg,iel,icycle,nswmod
-integer          idimte,itenso,iinvpe, iinvpp,ibsize
+integer          itenso,iinvpe, iinvpp,ibsize
 
 double precision residu,rnorm
 
+double precision rvoid(1)
+
 double precision, allocatable, dimension(:) :: dam
 double precision, allocatable, dimension(:,:) :: xam
 double precision, allocatable, dimension(:) :: dpvar, smbini, w1
@@ -232,10 +230,9 @@ iinvpe = 0
 if(iperio.eq.1) then
 
 
-!    Par defaut, toutes les periodicites seront traitees dans percom,
+!    Par defaut, toutes les periodicites seront traitees,
 !      les variables etant assimilees a des scalaires (meme si ce sont
 !      des composantes de vecteurs ou de tenseur)
-  idimte = 0
   itenso = 0
 
   iinvpe = 1
@@ -247,15 +244,14 @@ if(iperio.eq.1) then
 
     !    Pour la vitesse et les tensions de Reynolds
     !      seules seront echangees les informations sur les faces periodiques
-    !      de translation dans percom ; on ne touche pas aux informations
+    !      de translation ; on ne touche pas aux informations
     !      relatives aux faces de periodicite de rotation.
-    idimte = 0
     itenso = 1
 
     !      Lors de la resolution par increments, on echangera egalement les
     !      informations relatives aux faces de periodicite de translation.
     !      Pour les faces de periodicite de rotation, l'increment sera
-    !      annule dans percom (iinvpe=2).
+    !      annule en appelant syncmp au lieu de synsca (iinvpe=2).
     iinvpe = 2
 
   endif
@@ -265,16 +261,16 @@ endif
 !===============================================================================
 ! 1.  CONSTRUCTION MATRICE "SIMPLIFIEE" DE RESOLUTION
 !===============================================================================
+imucpp = 0
 
-call matrix                                                       &
+call matrix &
 !==========
  ( ncelet , ncel   , nfac   , nfabor ,                            &
    iconvp , idiffp , ndircp , isym   , nfecra ,                   &
-   thetap ,                                                       &
+   thetap , imucpp ,                                              &
    ifacel , ifabor ,                                              &
-   coefbp , rovsdt , flumas , flumab , viscfm , viscbm ,          &
-   dam    , xam    )
-
+   coefbp , cofbfp , rovsdt , flumas , flumab , viscfm , viscbm , &
+   rvoid  , dam    , xam    )
 
 !===============================================================================
 ! 2.  BOUCLES SUR LES NON ORTHOGONALITES
@@ -332,7 +328,7 @@ do 100 isweep = 1, nswmod
    flumas , flumab , viscfs , viscbs ,                            &
    smbrp  )
 
-  call prodsc(ncelet,ncel,isqrt,smbrp,smbrp,residu)
+  call prodsc(ncel,isqrt,smbrp,smbrp,residu)
 
 ! ---> RESIDU DE NORMALISATION CALCULE AU PREMIER SWEEP
 !    (NORME C.L +TERMES SOURCES+ TERMES DE NON ORTHOGONALITE)
@@ -354,12 +350,11 @@ do 100 isweep = 1, nswmod
     else
       iinvpp = iinvpe
     endif
-    call promav(ncelet,ncel,nfac,isym,iinvpp,ifacel,              &
-                dam,xam,pvar,w1)
+    call promav(isym,1,iinvpp,dam,xam,pvar,w1)
     do iel = 1, ncel
       w1(iel) = w1(iel) + smbrp(iel)
     enddo
-    call prodsc(ncelet,ncel,isqrt,w1,w1,rnorm)
+    call prodsc(ncel,isqrt,w1,w1,rnorm)
     rnsmbr(ipp) = rnorm
     ! Free memory
     deallocate(w1)
@@ -395,26 +390,22 @@ do 100 isweep = 1, nswmod
     pvar(iel) = pvar(iel)+dpvar(iel)
   enddo
 
-! ---> TRAITEMENT DU PARALLELISME
+! ---> Handle parallelism and periodicity
+!      (periodicity of rotation is not ensured here)
 
-if(irangp.ge.0) call parcom (pvar)
-                !==========
-
-! ---> TRAITEMENT DE LA PERIODICITE : SEULE LA PERIODICITE IMPLICITE
-!      EST ASSUREE (SCALAIRE ET TRANSLATION DE VECTEUR ET DE TENSEUR)
-
-if(iperio.eq.1) then
-  call percom                                                     &
-  !==========
-  ( idimte , itenso ,                                             &
-    pvar   , pvar   , pvar  ,                                     &
-    pvar   , pvar   , pvar  ,                                     &
-    pvar   , pvar   , pvar  )
-endif
+  if (irangp.ge.0 .or. iperio.eq.1) then
+    if (itenso.eq.0) then
+      call synsca (pvar)
+      !==========
+    else if (itenso.eq.1) then
+      call syncmp (pvar)
+      !==========
+    endif
+  endif
 
 ! ---> TEST DE CONVERGENCE
 
-call prodsc(ncelet,ncel,isqrt,smbrp,smbrp,residu)
+call prodsc(ncel,isqrt,smbrp,smbrp,residu)
 
 if( residu.le.epsrsp*rnorm ) then
    if(iwarnp.ge.1) then
