@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2011 EDF S.A.
+! Copyright (C) 1998-2012 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -122,7 +122,7 @@ integer          ircflp, ischcp, isstpp
 
 integer          iirom , iiromb
 integer          ivar0 , imvis1, iccfth, imodif, isou
-integer          imaspe, iflmb0
+integer          imaspe, iflmb0, itypfl
 integer          icliup, iclivp, icliwp, iclvar
 integer          itsqdm, iiun  , iextts
 
@@ -267,12 +267,13 @@ if(itsqdm.ne.0) then
     extrap = extrag(iu)
 
     imaspe = 1
+    itypfl = 1
 
 !     Calcul du flux de masse
     call inimas                                                   &
     !==========
  ( nvar   , nscal  ,                                              &
-   iu  , iv  , iw  , imaspe ,                                     &
+   iu  , iv  , iw  , imaspe , itypfl ,                            &
    iflmb0 , init   , inc    , imrgra , iccocg , nswrgp , imligp , &
    iwarnp , nfecra ,                                              &
    epsrgp , climgp , extrap ,                                     &
@@ -562,11 +563,12 @@ climgp = climgr(ivar)
 extrap = extrag(ivar)
 
 imaspe = 1
+itypfl = 1
 
 call inimas                                                       &
 !==========
  ( nvar   , nscal  ,                                              &
-   ivar0  , ivar0  , ivar0  , imaspe ,                            &
+   ivar0  , ivar0  , ivar0  , imaspe , itypfl ,                   &
    iflmb0 , init   , inc    , imrgra , iccocg , nswrgp , imligp , &
    iwarnp , nfecra ,                                              &
    epsrgp , climgp , extrap ,                                     &
