@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2011 EDF S.A.
+! Copyright (C) 1998-2012 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -131,6 +131,7 @@ double precision sclnor
 
 integer          iccfth, imodif
 integer          iij
+integer          imucpp
 double precision dijpfx, dijpfy, dijpfz, pnd
 double precision diipfx, diipfy, diipfz, djjpfx, djjpfy, djjpfz
 double precision diipbx, diipby, diipbz
@@ -146,6 +147,7 @@ double precision, allocatable, dimension(:) :: w7, w8, w9
 double precision, allocatable, dimension(:) :: w10
 double precision, allocatable, dimension(:) :: wflmas, wflmab
 double precision, allocatable, dimension(:) :: wfabg, wfbbg
+double precision, allocatable, dimension(:) :: dpvar
 
 !===============================================================================
 !===============================================================================
@@ -162,7 +164,7 @@ allocate(wfabg(nfac), wfbbg(nfabor))
 allocate(w1(ncelet))
 allocate(w7(ncelet), w8(ncelet), w9(ncelet))
 allocate(w10(ncelet))
-
+allocate(dpvar(ncelet))
 
 ! --- Numero de variable de calcul et de post associe au scalaire traite
 ivar   = isca(iscal)
@@ -417,6 +419,7 @@ ircflp = ircflu(ivar)
 ischcp = ischcv(ivar)
 isstpp = isstpc(ivar)
 iescap = 0
+imucpp = 0
 imgrp  = imgr  (ivar)
 ncymxp = ncymax(ivar)
 nitmfp = nitmgf(ivar)
@@ -431,12 +434,12 @@ extrap = extrag(ivar)
 relaxp = relaxv(ivar)
 thetv  = thetav(ivar)
 
-call codits                                                       &
+call codits &
 !==========
  ( nvar   , nscal  ,                                              &
    idtvar , ivar   , iconvp , idiffp , ireslp , ndircp , nitmap , &
    imrgra , nswrsp , nswrgp , imligp , ircflp ,                   &
-   ischcp , isstpp , iescap ,                                     &
+   ischcp , isstpp , iescap , imucpp ,                            &
    imgrp  , ncymxp , nitmfp , ipp    , iwarnp ,                   &
    blencp , epsilp , epsrsp , epsrgp , climgp , extrap ,          &
    relaxp , thetv  ,                                              &
@@ -445,8 +448,8 @@ call codits                                                       &
                      coefa(1,iclvaf) , coefb(1,iclvaf) ,          &
                      wflmas          , wflmab          ,          &
    viscf  , viscb  , viscf  , viscb  ,                            &
-   rovsdt , smbrs  , rtp(1,ivar)     ,                            &
-   rvoid  )
+   rovsdt , smbrs  , rtp(1,ivar)     , dpvar  ,                   &
+   rvoid  , rvoid  )
 
 !===============================================================================
 ! 5. IMPRESSIONS ET CLIPPINGS
@@ -486,7 +489,7 @@ if (iwarni(ivar).ge.2) then
                 * max(0,min(nswrsm(ivar)-2,1))
   enddo
   isqrt = 1
-  call prodsc(ncelet,ncel,isqrt,smbrs,smbrs,sclnor)
+  call prodsc(ncel,isqrt,smbrs,smbrs,sclnor)
   write(nfecra,1200)chaine(1:8) ,sclnor
 endif
 
@@ -586,6 +589,7 @@ deallocate(wflmas, wflmab)
 deallocate(w1)
 deallocate(w7, w8, w9)
 deallocate(w10)
+deallocate(dpvar)
 
 !--------
 ! FORMATS
