@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2011 EDF S.A.
+! Copyright (C) 1998-2012 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -59,6 +59,7 @@ use cstnum
 use ppppar
 use ppthch
 use ppincl
+use ihmpre
 
 !===============================================================================
 
@@ -138,6 +139,14 @@ if ( ippmod(icompf).ge.0 ) then
 !===============================================================================
 ! 3. ON REDONNE LA MAIN A L'UTILISATEUR
 !===============================================================================
+!   - Interface Code_Saturne
+!     ======================
+!     Construction de l'indirection entre la numerotation du noyau et XML
+if (iihmpr.eq.1) then
+   call uicfsc(irho, ienerg, itempk)
+endif
+
+  call csvvva(iviscv)
 
   call uscfx2
   !==========
