@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2011 EDF S.A.
+! Copyright (C) 1998-2012 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -71,6 +71,7 @@ use coincl
 use cpincl
 use ppincl
 use radiat
+use ihmpre
 
 !===============================================================================
 
@@ -510,6 +511,16 @@ if ( ippmod(icolwc).ge.0 ) then
 
 endif
 
+!   - Interface Code_Saturne
+!     ======================
+!     Construction de l'indirection entre la numerotation du noyau et XML
+if (iihmpr.eq.1) then
+  call uicopr (nsalpp, ippmod, ipppro, ipproc, icod3p, icoebu,      &
+               icolwc, iirayo, itemp, imam, iym, ickabs, it4m, it3m,&
+               ix2, itsc, irhol, iteml, ifmel, ifmal, iampl, itscl, &
+               imaml)
+
+endif
 
 return
 
