@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2011 EDF S.A.
+! Copyright (C) 1998-2012 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -292,8 +292,8 @@ do iel =1, ncel
 
 !---> Calcul de l'enthalpie
 
-      h(idirac) = ((hmax-hmin)*f(idirac) + hmin*fmin - hmax*fmax) &
-          / (fmin-fmax)
+      h(idirac) = ((hmax-hmin)*f(idirac) + hmin*fmax - hmax*fmin) &
+          / (fmax-fmin)
 
 ! ---> Calcul de la fraction massique des gaz (F, O et P)
 
@@ -505,7 +505,7 @@ do iel =1, ncel
 
     do idirac = 1, ndirac
       h(idirac) = ( (hmax-hmin)*f(idirac)                         &
-                   + hmin*fmin - hmax*fmax) / (fmin-fmax)
+                   + hmin*fmax - hmax*fmin) / (fmax-fmin)
 
 ! ---> Calcul de la fraction massique des gaz (F, O et P) en 1 et 2
 
