@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2011 EDF S.A.
+! Copyright (C) 1998-2012 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -32,6 +32,12 @@ module cs_coal_incl
 
   integer, save :: ihth2o , ighh2o(nclcpm)
 
+  ! Modele de NOx
+  ! qpr : % d'azote libere pendant la devol.% de MV libere pendant la devol.
+  ! fn : concentration en azote sur pur
+
+  double precision, save :: qpr(ncharm), fn(ncharm), ipci(ncharm), xashsec(ncharm)
+
   !=============================================================================
 
 end module cs_coal_incl
