@@ -6,7 +6,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2011 EDF S.A.
+  Copyright (C) 1998-2012 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -25,9 +25,7 @@
 
 /*----------------------------------------------------------------------------*/
 
-#if defined(HAVE_CONFIG_H)
-#include "cs_config.h"
-#endif
+#include "cs_defs.h"
 
 /*----------------------------------------------------------------------------
  * Standard C library headers
@@ -51,7 +49,6 @@
 #include <bft_error.h>
 #include <bft_printf.h>
 #include <bft_mem.h>
-#include <bft_file.h>
 
 /*----------------------------------------------------------------------------
  * FVM library headers
@@ -73,6 +70,7 @@
 #include "cs_ctwr_air_props.h"
 #include "cs_ctwr_halo.h"
 #include "cs_halo.h"
+#include "cs_mesh_location.h"
 #include "cs_post.h"
 #include "cs_restart.h"
 #include "cs_selector.h"
@@ -151,7 +149,7 @@ cs_loc_ctwr_opnsuite(const char              *nomsui,
   /* Name treatment for the C API */
   nombuf = cs_base_string_f_to_c_create(nomsui, *lngnom);
 
-  cs_glob_ctwr_suite = cs_restart_create(nombuf, ireawr);
+  cs_glob_ctwr_suite = cs_restart_create(nombuf, NULL, ireawr);
 
   /* Free the memory if necessary */
   cs_base_string_f_to_c_free(&nombuf);
@@ -453,15 +451,15 @@ void CS_PROCF (ecrctw, ECRCTW)
   cs_int_t  ict;
 
   cs_restart_t         *suite;
-  cs_restart_location_t location_id,support;
+  cs_mesh_location_type_t  location_id,support;
   cs_type_t             typ_val;
 
   cs_ctwr_zone_t  *ct;
   char            *location_name = NULL;
   cs_int_t         length        = 0;
-  fvm_gnum_t      *g_elt_num     = NULL;
+  cs_gnum_t       *g_elt_num     = NULL;
 
-  fvm_lnum_t n_g_elements, n_elements;
+  cs_lnum_t n_g_elements, n_elements;
 
   ierror = CS_RESTART_SUCCES;
 
@@ -477,7 +475,7 @@ void CS_PROCF (ecrctw, ECRCTW)
               _("Abort while opening the cooling tower module restart "
                 "file in write mode.\n"
                 "Verify the existence and the name of the restart file: %s\n"),
-              *nomsui);
+              nomsui);
 
   for (ict=0; ict < cs_glob_ct_nbr; ict++) {
 
@@ -490,7 +488,7 @@ void CS_PROCF (ecrctw, ECRCTW)
     n_g_elements = fvm_nodal_get_n_g_elements(ct->water_mesh, FVM_CELL_HEXA);
     n_elements = fvm_nodal_get_n_elements(ct->water_mesh, FVM_CELL_HEXA);
 
-    BFT_MALLOC(g_elt_num, n_g_elements, fvm_gnum_t);
+    BFT_MALLOC(g_elt_num, n_g_elements, cs_gnum_t);
 
     fvm_nodal_get_global_element_num(ct->water_mesh,
                                      FVM_CELL_HEXA,
@@ -519,7 +517,7 @@ void CS_PROCF (ecrctw, ECRCTW)
       tabvar[ 2 ] = ct->nelect; /* nb of node per segment*/
 
       nbvent  = 3;
-      support = CS_RESTART_LOCATION_NONE;
+      support = CS_MESH_LOCATION_NONE;
       typ_val = CS_TYPE_cs_int_t;
 
       cs_restart_write_section(suite,
@@ -549,7 +547,7 @@ void CS_PROCF (ecrctw, ECRCTW)
 
 
       nbvent  = 4;
-      support = CS_RESTART_LOCATION_NONE;
+      support = CS_MESH_LOCATION_NONE;
       typ_val = CS_TYPE_cs_real_t;
 
       cs_restart_write_section(suite,
@@ -627,21 +625,21 @@ void CS_PROCF (lecctw, LECCTW)
  const cs_int_t   *const lngnom
 )
 {
-  cs_bool_t           corresp_cel, corresp_fac, corresp_fbr, corresp_som;
+  bool                corresp_cel, corresp_fac, corresp_fbr, corresp_som;
   cs_int_t            nbvent;
   cs_int_t            i, ict,indfac, ierror;
 
-  cs_restart_t         *suite;
-  cs_restart_location_t location_id,support;
-  cs_type_t             typ_val;
+  cs_restart_t             *suite;
+  cs_mesh_location_type_t   location_id,support;
+  cs_type_t                 typ_val;
 
-  fvm_lnum_t n_g_elements, n_elements;
+  cs_lnum_t n_g_elements, n_elements;
 
   cs_ctwr_zone_t  *ct;
 
   char        *location_name = NULL;
   cs_int_t     length        = 0;
-  fvm_gnum_t  *g_elt_num     = NULL;
+  cs_gnum_t   *g_elt_num     = NULL;
 
   ierror = CS_RESTART_SUCCES;
 
@@ -655,7 +653,7 @@ void CS_PROCF (lecctw, LECCTW)
               _("Abort while opening the cooling tower AERO module restart file "
                 "in read mode.\n"
                 "Verify the existence and the name of the restart file: %s\n"),
-              *nomsui);
+              nomsui);
 
 
   /* Pointer to the global restart structure */
@@ -684,7 +682,7 @@ void CS_PROCF (lecctw, LECCTW)
     n_g_elements = fvm_nodal_get_n_g_elements(ct->water_mesh, FVM_CELL_HEXA);
     n_elements   = fvm_nodal_get_n_elements  (ct->water_mesh, FVM_CELL_HEXA);
 
-    BFT_MALLOC( g_elt_num , n_g_elements, fvm_gnum_t );
+    BFT_MALLOC( g_elt_num , n_g_elements, cs_gnum_t );
 
     fvm_nodal_get_global_element_num( ct->water_mesh ,
                                       FVM_CELL_HEXA  ,
@@ -707,7 +705,7 @@ void CS_PROCF (lecctw, LECCTW)
       BFT_MALLOC(tabvar, 3, cs_int_t);
 
       nbvent  = 3;
-      support = CS_RESTART_LOCATION_NONE;
+      support = CS_MESH_LOCATION_NONE;
       typ_val = CS_TYPE_cs_int_t;
 
       ierror = cs_restart_read_section(suite,
@@ -778,7 +776,7 @@ void CS_PROCF (lecctw, LECCTW)
       BFT_MALLOC(tabvar, 4, cs_real_t);
 
       nbvent  = 4;
-      support = CS_RESTART_LOCATION_NONE;
+      support = CS_MESH_LOCATION_NONE;
       typ_val = CS_TYPE_cs_real_t;
 
       ierror = cs_restart_read_section(suite,
@@ -936,6 +934,52 @@ void CS_PROCF (lecctw, LECCTW)
   cs_glob_ctwr_suite = NULL;
 }
 
+/*----------------------------------------------------------------------------
+ * Post process variables associated with exchange area
+ *
+ * parameters:
+ *   ct                  -->  Void pointer to cooling tower function
+ *   nt_cur_abs          -->  Current time step
+ *   t_cur_abs           -->  Current time value
+ *----------------------------------------------------------------------------*/
+
+static void
+_cs_ctwr_post_function(void       *ct,
+                       cs_int_t    nt_cur_abs,
+                       cs_real_t   t_cur_abs)
+{
+  const cs_ctwr_zone_t  *_ct = ct;
+
+  if (_ct->post_mesh_id != 0) {
+
+    cs_post_write_var(_ct->post_mesh_id,
+                      _("T water"),
+                      1,
+                      false,
+                      false,
+                      CS_POST_TYPE_cs_real_t,
+                      nt_cur_abs,
+                      t_cur_abs,
+                      _ct->teau,
+                      NULL,
+                      NULL);
+
+    cs_post_write_var(_ct->post_mesh_id,
+                      _("Flux water"),
+                      1,
+                      false,
+                      false,
+                      CS_POST_TYPE_cs_real_t,
+                      nt_cur_abs,
+                      t_cur_abs,
+                      _ct->fem,
+                      NULL,
+                      NULL);
+
+  }
+
+}
+
 /*============================================================================
  * Fonctions publiques
  *============================================================================*/
@@ -968,11 +1012,9 @@ void cs_ctwr_definit
 {
   cs_ctwr_zone_t  *ct;
   cs_int_t length;
-  bft_file_t *f;
+  FILE *f;
   char  *file_name = NULL;
-  bft_file_type_t file_type;
 
-  file_type = BFT_FILE_TYPE_TEXT;
   /* Definition d'une nouvelle zone d'echange */
 
   BFT_MALLOC(ct, 1, cs_ctwr_zone_t);
@@ -1052,11 +1094,11 @@ void cs_ctwr_definit
 
   /* Selection des cellules */
 
-  BFT_MALLOC(ct->ze_cell_list, cs_glob_mesh->n_b_faces, fvm_lnum_t);
+  BFT_MALLOC(ct->ze_cell_list, cs_glob_mesh->n_b_faces, cs_lnum_t);
 
   cs_selector_get_cell_list(ze_name, &(ct->nbevct), ct->ze_cell_list);
 
-  BFT_REALLOC(ct->ze_cell_list, ct->nbevct, fvm_lnum_t);
+  BFT_REALLOC(ct->ze_cell_list, ct->nbevct, cs_lnum_t);
 
   /* Redimensionnement du tableau des zones d'echange si necessaire */
 
@@ -1088,21 +1130,16 @@ void cs_ctwr_definit
     BFT_MALLOC(file_name, length, char);
     sprintf(file_name, "bltctc.%02d", ct->num);
 
-    f = bft_file_open(file_name,
-                      BFT_FILE_MODE_APPEND,
-                      file_type);
+    f = fopen(file_name, "a");
 
-    bft_file_printf(f, "# BILANS POUR LA ZONE D\'ECHANGES \n");
-    bft_file_printf(f, "# =================================\n");
-    bft_file_printf(f,"\tTEMP\tFLUX A/E\tTA MOY SOR\t TE MOY SOR");
-    bft_file_printf(f,"\tXA MOY SOR\tDEBI A ENT\tDEBI A SOR \n");
-    f = bft_file_free(f);
+    fprintf(f, "# BILANS POUR LA ZONE D'ECHANGES \n");
+    fprintf(f, "# ===============================\n");
+    fprintf(f, "\tTEMP\tFLUX A/E\tTA MOY SOR\t TE MOY SOR");
+    fprintf(f, "\tXA MOY SOR\tDEBI A ENT\tDEBI A SOR \n");
+    fclose(f);
     BFT_FREE(file_name);
-
   }
 
-
-
 }
 
 /*----------------------------------------------------------------------------
@@ -1154,8 +1191,8 @@ cs_ctwr_aeteau(cs_real_t   temp[],      /* Temperature air */
   cs_real_t   cpe, cpv, cpa, hv0, dgout, visc, conduc, rhoe;
 
 
-  fvm_lnum_t *lst_par_fac_sup_ct, *lst_par_fac_inf_ct_upw;
-  const fvm_lnum_t *locat_cel_upw = NULL;
+  cs_lnum_t *lst_par_fac_sup_ct, *lst_par_fac_inf_ct_upw;
+  const cs_lnum_t *locat_cel_upw = NULL;
 
   cs_ctwr_zone_t  *ct;
   cs_ctwr_zone_t  *ct_upw;
@@ -1281,7 +1318,7 @@ cs_ctwr_aeteau(cs_real_t   temp[],      /* Temperature air */
     * Calcul pour la face superieure ,           *
     * Introduction des conditions aux limites ct *
     *--------------------------------------------*/
-    BFT_MALLOC( lst_par_fac_sup_ct , ct->nnpsct, fvm_lnum_t );
+    BFT_MALLOC( lst_par_fac_sup_ct , ct->nnpsct, cs_lnum_t );
 
     fvm_nodal_get_parent_num(ct->face_sup_mesh,
                                       2,lst_par_fac_sup_ct);
@@ -1295,7 +1332,7 @@ cs_ctwr_aeteau(cs_real_t   temp[],      /* Temperature air */
 
         BFT_MALLOC( teau_upw_send  , nb_dist_upw, cs_real_t);
         BFT_MALLOC( fem_upw_send  , nb_dist_upw, cs_real_t);
-        BFT_MALLOC( lst_par_fac_inf_ct_upw , (ct_upw->nbfac_ict+ct_upw->nbfbr_ict), fvm_lnum_t );
+        BFT_MALLOC( lst_par_fac_inf_ct_upw , (ct_upw->nbfac_ict+ct_upw->nbfbr_ict), cs_lnum_t );
 
         fvm_nodal_get_parent_num(ct_upw->face_inf_mesh,
                                       2,lst_par_fac_inf_ct_upw);
@@ -1687,7 +1724,7 @@ void cs_ctwr_aetssc
   cs_real_t *tai_inter, *xai_inter, *rhoai_inter,*vx_inter, *vy_inter,*vz_inter,
             *tei_inter, *femei_inter, *vgin_inter;
   cs_real_t *tai, *xai, *rhoai,*vx, *vy, *vz, *tei, *femei, *vgin;
-  fvm_lnum_t  *lst_par_cel;
+  cs_lnum_t  *lst_par_cel;
   cs_ctwr_fluid_props_t  *ct_prop = cs_glob_ctwr_props;
 
   fax = 0.;
@@ -1796,7 +1833,7 @@ void cs_ctwr_aetssc
 
       nb = (int) fvm_nodal_get_n_entities(ct->cell_mesh, 3);
 
-      BFT_MALLOC( lst_par_cel , nb, fvm_lnum_t );
+      BFT_MALLOC( lst_par_cel , nb, cs_lnum_t );
       fvm_nodal_get_parent_num( ct->cell_mesh, 3, lst_par_cel);
 
       for (iseg = 0; iseg < ct->nnpsct; iseg++) {
@@ -1877,7 +1914,7 @@ void cs_ctwr_aetssc
     }
 
 
-    BFT_MALLOC( lst_par_cel , nb, fvm_lnum_t );
+    BFT_MALLOC( lst_par_cel , nb, cs_lnum_t );
     fvm_nodal_get_parent_num( ct->cell_mesh, 3, lst_par_cel);
     /*--------------------------------------------*
      * interpolation  eau->air                    *
@@ -2178,7 +2215,7 @@ void cs_ctwr_aetsvi
 
     nb = (int) fvm_nodal_get_n_entities(ct->cell_mesh, 3);
 
-    BFT_MALLOC( lst_par_cel , (nb*3), fvm_lnum_t );
+    BFT_MALLOC( lst_par_cel , (nb*3), cs_lnum_t );
     fvm_nodal_get_parent_num( ct->cell_mesh, 3, lst_par_cel);
     /*--------------------------------------------*
      * interpolation  eau->air                    *
@@ -2287,18 +2324,15 @@ void cs_ctwr_bilanct
   cs_real_t        xsata,debit,hair,n_sortant[3],vitair[3],aux,
                    surf,surf_e,surf_s;
 
-  fvm_lnum_t   *face_sup;      /* liste des faces  superieures de la ct */
-  fvm_lnum_t   *face_inf;      /* liste des faces  inferior de la ct */
-  fvm_lnum_t   *face_lat;      /* liste des faces  inferior de la ct */
+  cs_lnum_t  *face_sup;      /* liste des faces  superieures de la ct */
+  cs_lnum_t  *face_inf;      /* liste des faces  inferior de la ct */
+  cs_lnum_t  *face_lat;      /* liste des faces  inferior de la ct */
 
   cs_ctwr_zone_t  *ct;
-  bft_file_t *f;
+  FILE *f;
   char  *file_name = NULL;
-  bft_file_type_t file_type;
   cs_ctwr_fluid_props_t  *ct_prop = cs_glob_ctwr_props;
 
-  file_type = BFT_FILE_TYPE_TEXT;
-
   for (ict=0; ict < cs_glob_ct_nbr; ict++) {
 
     cs_int_t nbr_fbr_air[3][2];
@@ -2316,11 +2350,11 @@ void cs_ctwr_bilanct
     nbr_fbr_air[2][0] = ct->nbfbr_lct + ct->nbfac_lct;
     nbr_fbr_air[2][1] = ct->nbfbr_lct;
 
-    BFT_MALLOC( face_sup ,(ct->nbfac_sct + ct->nbfbr_sct) ,fvm_lnum_t );
+    BFT_MALLOC( face_sup ,(ct->nbfac_sct + ct->nbfbr_sct) ,cs_lnum_t );
     fvm_nodal_get_parent_num( ct->face_sup_mesh, 2, face_sup);
-    BFT_MALLOC( face_inf ,(ct->nbfac_ict + ct->nbfbr_ict) ,fvm_lnum_t );
+    BFT_MALLOC( face_inf ,(ct->nbfac_ict + ct->nbfbr_ict) ,cs_lnum_t );
     fvm_nodal_get_parent_num( ct->face_inf_mesh, 2, face_inf);
-    BFT_MALLOC( face_lat ,(ct->nbfbr_lct + ct->nbfac_lct) ,fvm_lnum_t );
+    BFT_MALLOC( face_lat ,(ct->nbfbr_lct + ct->nbfac_lct) ,cs_lnum_t );
     fvm_nodal_get_parent_num( ct->face_lat_mesh, 2, face_lat);
 
     ct->fem_e   = 0.0;
@@ -2532,22 +2566,19 @@ void cs_ctwr_bilanct
       sprintf(file_name, "bltctc.%02d", ct->num);
 
       if (CS_ABS(ct->heau_e-ct->heau_s)> 1.e-6){
-        f = bft_file_open(file_name,
-                        BFT_FILE_MODE_APPEND,
-                        file_type);
+        f = fopen(file_name, "a");
 
-        aux =CS_ABS( (ct->hair_s - ct->hair_e)/(ct->heau_e - ct->heau_s) );
-        bft_file_printf(f,
-            "%10f\t%10f\t%10f\t%10f\t%12.5e\t%10f\t%10f\n"
-                                          ,time
-                                          ,aux
-                                          ,ct->tair_s
-                                          ,ct->teau_s
-                                          ,ct->xair_s
-                                          ,ct->debit_e
-                                          ,ct->debit_s);
+        aux = CS_ABS((ct->hair_s - ct->hair_e)/(ct->heau_e - ct->heau_s));
+        fprintf(f, "%10f\t%10f\t%10f\t%10f\t%12.5e\t%10f\t%10f\n",
+                time,
+                aux,
+                ct->tair_s,
+                ct->teau_s,
+                ct->xair_s,
+                ct->debit_e,
+                ct->debit_s);
 
-        f = bft_file_free(f);
+        fclose(f);
       }
     }
 
@@ -2600,7 +2631,7 @@ cs_ctwr_post_init(cs_int_t  ct_id,
 
   /* Register post processing function */
 
-  cs_post_add_time_dep_var(cs_ctwr_post_function, ct_id);
+  cs_post_add_time_dep_output(_cs_ctwr_post_function, (void *)ct);
 
   /* Update start and end (negative) numbers associated with
      dedicated post processing meshes */
@@ -2611,52 +2642,6 @@ cs_ctwr_post_init(cs_int_t  ct_id,
   cs_glob_ct_post_mesh_ext[1] = mesh_id;
 }
 
-/*----------------------------------------------------------------------------
- * Post process variables associated with exchange area
- *
- * parameters:
- *   coupling_id         -->  Id of exchange area
- *   nt_cur_abs          -->  Current time step
- *   t_cur_abs           -->  Current time value
- *----------------------------------------------------------------------------*/
-
-void
-cs_ctwr_post_function(cs_int_t   ct_id,
-                      cs_int_t   nt_cur_abs,
-                      cs_real_t  t_cur_abs)
-{
-  cs_ctwr_zone_t * ct = cs_ctwr_by_id(ct_id);
-
-  if (ct->post_mesh_id != 0) {
-
-    cs_post_write_var(ct->post_mesh_id,
-                      _("T water"),
-                      1,
-                      false,
-                      false,
-                      CS_POST_TYPE_cs_real_t,
-                      nt_cur_abs,
-                      t_cur_abs,
-                      ct->teau,
-                      NULL,
-                      NULL);
-
-    cs_post_write_var(ct->post_mesh_id,
-                      _("Flux water"),
-                      1,
-                      false,
-                      false,
-                      CS_POST_TYPE_cs_real_t,
-                      nt_cur_abs,
-                      t_cur_abs,
-                      ct->fem,
-                      NULL,
-                      NULL);
-
-  }
-
-}
-
 /*----------------------------------------------------------------------------
  * Get pointer to exchange area.
  *
