@@ -6,7 +6,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2011 EDF S.A.
+  Copyright (C) 1998-2012 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -25,9 +25,7 @@
 
 /*----------------------------------------------------------------------------*/
 
-#if defined(HAVE_CONFIG_H)
-#include "cs_config.h"
-#endif
+#include "cs_defs.h"
 
 /*----------------------------------------------------------------------------
  * Standard C library headers
@@ -43,25 +41,6 @@
 #include <mpi.h>
 #endif
 
-
-/*----------------------------------------------------------------------------
- * BFT library headers
- *----------------------------------------------------------------------------*/
-
-#include <bft_error.h>
-#include <bft_printf.h>
-#include <bft_mem.h>
-#include <bft_file.h>
-
-/*----------------------------------------------------------------------------
- * FVM library headers
- *----------------------------------------------------------------------------*/
-
-#include <fvm_interface.h>
-#include <fvm_nodal_extract.h>
-#include <fvm_nodal_extrude.h>
-#include <fvm_nodal_project.h>
-
 /*----------------------------------------------------------------------------
  * PLE library headers
  *----------------------------------------------------------------------------*/
@@ -72,12 +51,21 @@
  * Local headers
  *----------------------------------------------------------------------------*/
 
+#include "bft_error.h"
+#include "bft_printf.h"
+#include "bft_mem.h"
+
+#include "fvm_nodal_extract.h"
+#include "fvm_nodal_extrude.h"
+#include "fvm_nodal_project.h"
+
 #include "cs_base.h"
 #include "cs_coupling.h"
 #include "cs_ctwr.h"
 #include "cs_ctwr_air_props.h"
 #include "cs_ctwr_halo.h"
 #include "cs_halo.h"
+#include "cs_interface.h"
 #include "cs_mesh_connect.h"
 
 /*----------------------------------------------------------------------------
@@ -183,7 +171,7 @@ _inverse_3x3(double  m[3][3],
         - m[1][0]*(m[0][1]*m[2][2] - m[2][1]*m[0][2])
         + m[2][0]*(m[0][1]*m[1][2] - m[1][1]*m[0][2]);
 
-  if (FVM_ABS(det) < _epsilon_denom)
+  if (CS_ABS(det) < _epsilon_denom)
     return 1;
   else
     det_inv = 1./det;
@@ -458,10 +446,10 @@ _search_height(cs_ctwr_zone_t   *ct,
   cs_real_t   *lst_xyz_fi;  /* coord des sommets proj de la face Inf*/
   cs_real_t   *lst_xyz_fs;  /* coord des sommets proj de la face Inf*/
   cs_real_t   *hmin_dist;
-  const fvm_coord_t *lst_xyz_dist = NULL;
+  const cs_coord_t *lst_xyz_dist = NULL;
 
   cs_real_t   aux;
-  const fvm_lnum_t  *location_fac = NULL;
+  const cs_lnum_t  *location_fac = NULL;
 
   cs_int_t  *faces_vtx_idx   = NULL;
   cs_int_t  *faces_vtx_lst   = NULL;
@@ -488,15 +476,15 @@ _search_height(cs_ctwr_zone_t   *ct,
   ple_locator_t   *locator = NULL;
 
   nb = (cs_int_t) fvm_nodal_get_n_entities(ct->face_sup_mesh, 0);
-  BFT_MALLOC(lst_xyz_sup, nb*3, fvm_coord_t);
+  BFT_MALLOC(lst_xyz_sup, nb*3, cs_coord_t);
   fvm_nodal_get_vertex_coords(ct->face_sup_mesh,
-                              FVM_INTERLACE,
+                              CS_INTERLACE,
                               lst_xyz_sup);
 
   nb = (cs_int_t) fvm_nodal_get_n_entities(ct->face_inf_mesh, 0);
-  BFT_MALLOC(lst_xyz_inf, nb*3, fvm_coord_t);
+  BFT_MALLOC(lst_xyz_inf, nb*3, cs_coord_t);
   fvm_nodal_get_vertex_coords(ct->face_inf_mesh,
-                              FVM_INTERLACE,
+                              CS_INTERLACE,
                               lst_xyz_inf);
 
   fs_tmp_mesh = fvm_nodal_copy(ct->face_sup_mesh);
@@ -528,16 +516,16 @@ _search_height(cs_ctwr_zone_t   *ct,
 
   nb = (cs_int_t) fvm_nodal_get_n_entities(fs_tmp_mesh, 0);
 
-  BFT_MALLOC(lst_xyz_fs, nb*2, fvm_coord_t);
+  BFT_MALLOC(lst_xyz_fs, nb*2, cs_coord_t);
 
-  fvm_nodal_get_vertex_coords(fs_tmp_mesh, FVM_INTERLACE, lst_xyz_fs);
+  fvm_nodal_get_vertex_coords(fs_tmp_mesh, CS_INTERLACE, lst_xyz_fs);
 
 
   nb = (cs_int_t) fvm_nodal_get_n_entities(fi_tmp_mesh, 0);
 
-  BFT_MALLOC(lst_xyz_fi, nb*2, fvm_coord_t);
+  BFT_MALLOC(lst_xyz_fi, nb*2, cs_coord_t);
 
-  fvm_nodal_get_vertex_coords(fi_tmp_mesh, FVM_INTERLACE, lst_xyz_fi);
+  fvm_nodal_get_vertex_coords(fi_tmp_mesh, CS_INTERLACE, lst_xyz_fi);
 
   /* Create locator on the proj surf  */
 
@@ -568,7 +556,7 @@ _search_height(cs_ctwr_zone_t   *ct,
 
   /* Construction de la connectivite Face->sommet du projete  */
 
-  BFT_MALLOC(hmin_dist, nb_dist, fvm_coord_t);
+  BFT_MALLOC(hmin_dist, nb_dist, cs_coord_t);
 
   cs_reverse_vtx_faces_connect(fi_tmp_mesh,
                                 &(faces_vtx_idx),
@@ -703,12 +691,12 @@ void cs_ctwr_maille(const cs_mesh_t             *mesh,
 {
   cs_int_t   icel_1, icel_2, ii, length, nb, rank,
              dist_rank, res_loc, res_dist;
-  cs_int_t   ifac, ict, icpt, icpti, icptl, icptla, icptfac,
+  cs_int_t   ifac, ict, icpt, icpti, icptla, icptfac,
              iaux, i, j;
   cs_real_t  aux, gravite[3], v_aux[3], alpha;
-  fvm_coord_t *extrusion_vectors, *lst_xyz_cel, *lst_xyz;
-  fvm_lnum_t  *lst_par_fac_sup;
-  fvm_gnum_t  *fsup_gb_vt_num = NULL;
+  cs_coord_t *extrusion_vectors, *lst_xyz_cel, *lst_xyz;
+  cs_lnum_t   *lst_par_fac_sup;
+  cs_gnum_t   *fsup_gb_vt_num = NULL;
   cs_real_t   *hmin_vect;
   cs_real_t   *hmax_vect;
 
@@ -716,7 +704,7 @@ void cs_ctwr_maille(const cs_mesh_t             *mesh,
   char  *export_name     = NULL;
   const double tolerance = 0.1;
 
-  fvm_lnum_t   n_vertices;
+  cs_lnum_t   n_vertices;
 
   cs_int_t   *face_sup;      /* liste des faces internes superieures de la ct
                                 de taille  (nbfac_sct) */
@@ -739,7 +727,7 @@ void cs_ctwr_maille(const cs_mesh_t             *mesh,
   const cs_real_t *i_face_normal = mesh_quantities->i_face_normal;
   const cs_real_t *b_face_normal = mesh_quantities->b_face_normal;
 
-  fvm_interface_set_t  *interface_set = NULL;
+  cs_interface_set_t  *interface_set = NULL;
   cs_ctwr_zone_t  *ct;
   cs_ctwr_fluid_props_t  *ct_prop = cs_glob_ctwr_props;
 
@@ -878,7 +866,6 @@ void cs_ctwr_maille(const cs_mesh_t             *mesh,
     icpt   = 0; /*indice tableau des faces  sup */
     icpti  = 0; /*indice tableau des faces  inf */
     icptla = 0; /*indice tableau des faces  laterales */
-    icptl  = 0; /*indice tableau des noeuds sup ct */
     icptfac  = 0; /*indice tableau des noeuds sup ct */
     /* Boucle sur les faces internes du domaine */
     for (ifac = 0; ifac < mesh->n_i_faces; ifac++) {
@@ -950,7 +937,6 @@ void cs_ctwr_maille(const cs_mesh_t             *mesh,
       }
     } /* fin contribution faces externes */
 
-
     /*---------------------------------------------------------*
     * Creation des maillages surfacique en connectivite nodale*
     *---------------------------------------------------------*/
@@ -1072,8 +1058,8 @@ void cs_ctwr_maille(const cs_mesh_t             *mesh,
     nb = (cs_int_t) fvm_nodal_get_n_entities(ct->face_sup_mesh, 0);
 
 
-    BFT_MALLOC(hmax_vect, nb, fvm_coord_t);
-    BFT_MALLOC(hmin_vect, nb, fvm_coord_t);
+    BFT_MALLOC(hmax_vect, nb, cs_coord_t);
+    BFT_MALLOC(hmin_vect, nb, cs_coord_t);
 
     _search_height(ct,
                    gravite,
@@ -1092,7 +1078,7 @@ void cs_ctwr_maille(const cs_mesh_t             *mesh,
     }
 
     /* loop on the sup faces for surface_in and surface_out */
-    BFT_MALLOC(lst_par_fac_sup, ct->nnpsct, fvm_lnum_t);
+    BFT_MALLOC(lst_par_fac_sup, ct->nnpsct, cs_lnum_t);
 
     fvm_nodal_get_parent_num(ct->face_sup_mesh, 2, lst_par_fac_sup);
 
@@ -1167,7 +1153,7 @@ void cs_ctwr_maille(const cs_mesh_t             *mesh,
 
 
 
-    BFT_MALLOC(extrusion_vectors, (nb*3), fvm_coord_t);
+    BFT_MALLOC(extrusion_vectors, (nb*3), cs_coord_t);
 
 
     for (i=0; i < nb; i++) {
@@ -1193,15 +1179,15 @@ void cs_ctwr_maille(const cs_mesh_t             *mesh,
 
     n_vertices = fvm_nodal_get_n_entities(ct->face_sup_mesh, 0);
 
-    BFT_MALLOC(fsup_gb_vt_num, n_vertices, fvm_gnum_t);
+    BFT_MALLOC(fsup_gb_vt_num, n_vertices, cs_gnum_t);
 
     fvm_nodal_get_global_vertex_num(ct->face_sup_mesh, fsup_gb_vt_num);
 
-    interface_set = fvm_interface_set_create(n_vertices, NULL, fsup_gb_vt_num,
-                                             NULL, 0, NULL, NULL, NULL);
+    interface_set = cs_interface_set_create(n_vertices, NULL, fsup_gb_vt_num,
+                                            NULL, 0, NULL, NULL, NULL);
 
 #if 0 && defined(DEBUG) && !defined(NDEBUG)
-    fvm_interface_set_dump(interface_set);
+    cs_interface_set_dump(interface_set);
 #endif
 
     /* Creation of the cs_mesh_halo_t structure. */
@@ -1216,7 +1202,7 @@ void cs_ctwr_maille(const cs_mesh_t             *mesh,
 
     cs_ctwr_halo_define(ct, interface_set);
 
-    fvm_interface_set_destroy(interface_set);
+    cs_interface_set_destroy(&interface_set);
 
     /* Create locator for interpolate */
 
@@ -1229,9 +1215,9 @@ void cs_ctwr_maille(const cs_mesh_t             *mesh,
     ct->locat_water_air = ple_locator_create(tolerance);
 #endif
 
-    BFT_MALLOC(lst_xyz_cel, ct->nbevct*3, fvm_coord_t);
+    BFT_MALLOC(lst_xyz_cel, ct->nbevct*3, cs_coord_t);
 
-    fvm_nodal_get_element_centers(ct->cell_mesh, FVM_INTERLACE, 3, lst_xyz_cel);
+    fvm_nodal_get_element_centers(ct->cell_mesh, CS_INTERLACE, 3, lst_xyz_cel);
 
     ple_locator_set_mesh(ct->locat_water_air,
                          ct->water_mesh,
@@ -1254,9 +1240,9 @@ void cs_ctwr_maille(const cs_mesh_t             *mesh,
     ct->locat_air_water = ple_locator_create(tolerance);
 #endif
 
-    BFT_MALLOC(lst_xyz, ct->nnpsct*ct->nelect*3, fvm_coord_t);
+    BFT_MALLOC(lst_xyz, ct->nnpsct*ct->nelect*3, cs_coord_t);
 
-    fvm_nodal_get_element_centers(ct->water_mesh, FVM_INTERLACE, 3, lst_xyz);
+    fvm_nodal_get_element_centers(ct->water_mesh, CS_INTERLACE, 3, lst_xyz);
 
     ple_locator_set_mesh(ct->locat_air_water,
                          ct->cell_mesh,
@@ -1392,19 +1378,19 @@ void cs_ctwr_adeau
   cs_int_t   ict, iwat,nb_node_water, ii, jj, iair, nbvois,
              nbn, ifac, icel_1, icel_2, lf, indice, dim;
   cs_int_t   nvois[cs_ctwr_nmaxvoi];
-  cs_real_t  dhi, dmin;
+  cs_real_t  dhi;
   cs_real_t  xwat, ywat, zwat, dx, dy, dz, dxx, dyy, dzz, ouv, aux;
   cs_real_t  coeff[cs_ctwr_nmaxvoi];
   cs_real_t  vectBase[3][3];
   cs_real_t  cx, cy, cz, epgauss, w,
              pp[4][4],ppInv[4][4];
 
-  const fvm_coord_t *lst_xyz_water = NULL;
-  fvm_coord_t *lst_xyz_cel ;
-  fvm_lnum_t  *lst_par_fac ;
-  fvm_lnum_t  *lst_par_cel ;
+  const cs_coord_t *lst_xyz_water = NULL;
+  cs_coord_t *lst_xyz_cel ;
+  cs_lnum_t   *lst_par_fac ;
+  cs_lnum_t   *lst_par_cel ;
 
-  const fvm_lnum_t  *location_cel = NULL;
+  const cs_lnum_t  *location_cel = NULL;
 
   /*--------------------------------------------*
    * parametres et initialisation               *
@@ -1447,13 +1433,13 @@ void cs_ctwr_adeau
     /* */
     lst_xyz_water   = ple_locator_get_dist_coords(ct->locat_air_water);
 
-    BFT_MALLOC(lst_xyz_cel, ct->nbevct*3, fvm_coord_t);
-    fvm_nodal_get_element_centers(ct->cell_mesh, FVM_INTERLACE, 3, lst_xyz_cel);
+    BFT_MALLOC(lst_xyz_cel, ct->nbevct*3, cs_coord_t);
+    fvm_nodal_get_element_centers(ct->cell_mesh, CS_INTERLACE, 3, lst_xyz_cel);
 
-    BFT_MALLOC(lst_par_cel, ct->nbevct, fvm_lnum_t);
+    BFT_MALLOC(lst_par_cel, ct->nbevct, cs_lnum_t);
     fvm_nodal_get_parent_num(ct->cell_mesh, 3, lst_par_cel);
 
-    BFT_MALLOC(lst_par_fac, ct->nbfac_ct, fvm_lnum_t);
+    BFT_MALLOC(lst_par_fac, ct->nbfac_ct, cs_lnum_t);
     fvm_nodal_get_parent_num(ct->fac_mesh, 2, lst_par_fac);
 
 
@@ -1473,7 +1459,6 @@ void cs_ctwr_adeau
        * boucle sur les cellules appartenant a la ct*
        * recherche du noeud air le plus proche      *
        *--------------------------------------------*/
-      dmin = 1000.;
       iair = location_cel[iwat] -1;
 
       /*--------------------------------------------*
@@ -1739,9 +1724,9 @@ void cs_ctwr_adair (void)
 {
   /* Coordonnees des centres des cellules  */
 
-  const fvm_coord_t  *lst_xyz_cel   = NULL;
-  fvm_coord_t  *lst_xyz_water = NULL;
-  const fvm_lnum_t   *location_cel  = NULL;
+  const cs_coord_t  *lst_xyz_cel   = NULL;
+  cs_coord_t  *lst_xyz_water = NULL;
+  const cs_lnum_t  *location_cel  = NULL;
   cs_int_t   ict,icol, ilig,ieau,ii,jj,iair,nbvois,nbn,lf,indice;
   cs_int_t   nvois[cs_ctwr_nmaxvoi];
   cs_int_t   dim, nb_air_node;
@@ -1751,7 +1736,7 @@ void cs_ctwr_adair (void)
   cs_real_t  cx,cy,cz,epgauss,w;
   cs_real_t  pp[4][4], ppInv[4][4];
   cs_real_t  vectBase[3][3];
-  fvm_lnum_t loca_cel;
+  cs_lnum_t loca_cel;
   cs_ctwr_zone_t  *ct;
 
    ieau = -1;
@@ -1783,11 +1768,11 @@ void cs_ctwr_adair (void)
     location_cel = ple_locator_get_dist_locations(ct->locat_water_air);
 
 
-    BFT_MALLOC(lst_xyz_water, (3*ct->nelect*ct->nnpsct), fvm_coord_t);
-    fvm_nodal_get_element_centers(ct->water_mesh,FVM_INTERLACE,3, lst_xyz_water);
+    BFT_MALLOC(lst_xyz_water, (3*ct->nelect*ct->nnpsct), cs_coord_t);
+    fvm_nodal_get_element_centers(ct->water_mesh, CS_INTERLACE,3, lst_xyz_water);
 
     if (ct->water_halo != NULL) {
-      BFT_REALLOC(lst_xyz_water, (3*ct->nelect*ct->nnpsct_with_ghosts), fvm_coord_t);
+      BFT_REALLOC(lst_xyz_water, (3*ct->nelect*ct->nnpsct_with_ghosts), cs_coord_t);
       cs_halo_sync_var_strided(ct->water_halo, ct->halo_type, lst_xyz_water, 3);
 
     }
@@ -2103,7 +2088,7 @@ cs_ctwr_stacking(void)
   cs_ctwr_zone_t  *ct, *ct_upw;
   cs_real_t tmp;
   cs_real_t gravite[3];
-  fvm_coord_t * lst_xyz;
+  cs_coord_t * lst_xyz;
   cs_ctwr_fluid_props_t  *ct_prop = cs_glob_ctwr_props;
   const double tolerance = 0.1;
 
@@ -2176,10 +2161,10 @@ cs_ctwr_stacking(void)
         ct_upw = cs_glob_ct_tab[cs_chain_ct[ict_uw]];
 
         BFT_MALLOC(lst_xyz,
-                   3*(ct_upw->nbfac_ict+ct_upw->nbfbr_ict), fvm_coord_t);
+                   3*(ct_upw->nbfac_ict+ct_upw->nbfbr_ict), cs_coord_t);
 
         fvm_nodal_get_element_centers
-          (ct_upw->face_inf_mesh,FVM_INTERLACE,2,lst_xyz);
+          (ct_upw->face_inf_mesh, CS_INTERLACE,2,lst_xyz);
 
         tmp  = CS_ABS(ct_upw->hmax - ct_upw->hmin)/(ct_upw->nelect-1);
         tmp /= CS_LOC_MODULE(gravite);
