@@ -6,7 +6,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2011 EDF S.A.
+  Copyright (C) 1998-2012 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -25,9 +25,7 @@
 
 /*----------------------------------------------------------------------------*/
 
-#if defined(HAVE_CONFIG_H)
-#include "cs_config.h"
-#endif
+#include "cs_defs.h"
 
 /*----------------------------------------------------------------------------
  * Standard C library headers
@@ -48,10 +46,7 @@
  *  Local headers
  *----------------------------------------------------------------------------*/
 
-#include "fvm_config_defs.h"
-#include "fvm_defs.h"
 #include "fvm_io_num.h"
-#include "fvm_parall.h"
 
 /*----------------------------------------------------------------------------
  *  Header for the current file
@@ -61,19 +56,16 @@
 
 /*----------------------------------------------------------------------------*/
 
-#ifdef __cplusplus
-extern "C" {
-#if 0
-} /* Fake brace to force back Emacs auto-indentation back to column 0 */
-#endif
-#endif /* __cplusplus */
+BEGIN_C_DECLS
 
-/*============================================================================
- * Local structure definitions
+/*=============================================================================
+ * Local Macro and Type definitions
  *============================================================================*/
 
 #if defined(HAVE_MPI)
 
+#define _GATHER_TAG      (int)('G'+'A'+'T'+'H'+'E'+'R') /* MPI tag */
+
 /*----------------------------------------------------------------------------
  * Structure keeping track of the status of a series of fvm_gather_...()
  * operations by slices of element global I/O number intervals.
@@ -86,26 +78,26 @@ struct _fvm_gather_slice_t {
 
   /* Initial and final global element numbers for all slices */
 
-  fvm_gnum_t  global_num_initial;
-  fvm_gnum_t  global_num_final;
+  cs_gnum_t   global_num_initial;
+  cs_gnum_t   global_num_final;
 
   /* First and past the last global element numbers for current slice */
 
-  fvm_gnum_t  ref_slice_size;
-  fvm_gnum_t  global_num_slice_start;
-  fvm_gnum_t  global_num_slice_end;
+  cs_gnum_t   ref_slice_size;
+  cs_gnum_t   global_num_slice_start;
+  cs_gnum_t   global_num_slice_end;
 
   /* Local indexes corresponding to first element of a series with
      global number >= global_num_slice_start initially, and
      global number > global_num_end after a gather operation
      (initialized to 0 before first of a series of calls) */
 
-  fvm_lnum_t  local_index_start;   /* Current start value */
-  fvm_lnum_t  local_index_last;    /* Last value reached, to advance */
+  cs_lnum_t   local_index_start;   /* Current start value */
+  cs_lnum_t   local_index_last;    /* Last value reached, to advance */
 
   /* Number of local entities (constant after initialization) */
 
-  fvm_lnum_t  local_index_end;
+  cs_lnum_t   local_index_end;
 
   /* Next global element number expected for each rank before and after
      current call (rank 0 only); initialized upon the first call of
@@ -114,8 +106,8 @@ struct _fvm_gather_slice_t {
      processors having no element in a given slice, which could
      represent the majority of MPI calls for high processor counts */
 
-  fvm_gnum_t  *next_global_num;      /* Current values */
-  fvm_gnum_t  *next_global_num_last; /* Next values, to advance */
+  cs_gnum_t   *next_global_num;      /* Current values */
+  cs_gnum_t   *next_global_num_last; /* Next values, to advance */
 
   /* We may only use the next global element number to avoid
      sending and receiving empty messages when it is up to date;
@@ -130,7 +122,7 @@ struct _fvm_gather_slice_t {
   void        *recv_buf;       /* Receive buffer */
 
   int         *blocklengths;   /* Required only for indexed operations */
-  fvm_gnum_t  *displacements;  /* Always required for all ranks; size
+  cs_gnum_t   *displacements;  /* Always required for all ranks; size
                                   slice_size + 1 (last position used to
                                   exchange next_global_num[] values) */
 
@@ -292,7 +284,7 @@ fvm_gather_slice_dump(fvm_gather_slice_t  * this_slice)
 
 fvm_gather_slice_t *
 fvm_gather_slice_create(const fvm_io_num_t  *entity_io_num,
-                        const fvm_gnum_t     slice_size,
+                        const cs_gnum_t      slice_size,
                         MPI_Comm             comm)
 {
   int i;
@@ -326,8 +318,8 @@ fvm_gather_slice_create(const fvm_io_num_t  *entity_io_num,
 
   if (local_rank == 0) {
 
-    BFT_MALLOC(this_slice->next_global_num, n_ranks, fvm_gnum_t);
-    BFT_MALLOC(this_slice->next_global_num_last, n_ranks, fvm_gnum_t);
+    BFT_MALLOC(this_slice->next_global_num, n_ranks, cs_gnum_t);
+    BFT_MALLOC(this_slice->next_global_num_last, n_ranks, cs_gnum_t);
 
     for (i = 0; i < n_ranks; i++) {
       this_slice->next_global_num[i] = 0;
@@ -349,7 +341,7 @@ fvm_gather_slice_create(const fvm_io_num_t  *entity_io_num,
 
   this_slice->blocklengths = NULL;
 
-  BFT_MALLOC(this_slice->displacements, slice_size + 1,  fvm_gnum_t);
+  BFT_MALLOC(this_slice->displacements, slice_size + 1, cs_gnum_t);
 
   return this_slice;
 }
@@ -407,8 +399,8 @@ fvm_gather_slice_destroy(fvm_gather_slice_t  * this_slice)
 
 int
 fvm_gather_slice_advance(fvm_gather_slice_t  *this_slice,
-                         fvm_gnum_t          *global_num_start,
-                         fvm_gnum_t          *global_num_end)
+                         cs_gnum_t           *global_num_start,
+                         cs_gnum_t           *global_num_end)
 {
   int retval = 0;
 
@@ -491,7 +483,7 @@ fvm_gather_slice_reinitialize(fvm_gather_slice_t  *this_slice)
 
 void
 fvm_gather_slice_limit(fvm_gather_slice_t  *this_slice,
-                       fvm_gnum_t          *global_num_end)
+                       cs_gnum_t           *global_num_end)
 {
   if (*global_num_end != this_slice->global_num_slice_end) {
 
@@ -540,31 +532,31 @@ fvm_gather_slice_limit(fvm_gather_slice_t  *this_slice,
  *----------------------------------------------------------------------------*/
 
 void
-fvm_gather_slice_index(const fvm_lnum_t     local_index[],
-                       fvm_gnum_t           slice_index[],
+fvm_gather_slice_index(const cs_lnum_t      local_index[],
+                       cs_gnum_t            slice_index[],
                        const fvm_io_num_t  *element_io_num,
                        MPI_Comm             comm,
                        fvm_gather_slice_t  *this_slice)
 {
   int  i, j;
   int  n_local_entities, n_distant_entities;
-  fvm_lnum_t  local_index_start, local_index_stop;
+  cs_lnum_t  local_index_start, local_index_stop;
 
   /* MPI related variables */
   MPI_Status status;
   int  distant_rank;
   const int local_rank = this_slice->local_rank;
   const int n_ranks = this_slice->n_ranks;
-  fvm_gnum_t *const displacements = this_slice->displacements;
+  cs_gnum_t *const displacements = this_slice->displacements;
 
   /* Local number of elements */
-  const fvm_lnum_t  local_index_end = this_slice->local_index_end;
+  const cs_lnum_t  local_index_end = this_slice->local_index_end;
 
   /* Global numbering */
-  const fvm_gnum_t global_num_start = this_slice->global_num_slice_start;
-  const fvm_gnum_t global_num_end = this_slice->global_num_slice_end;
-  const fvm_gnum_t *entity_global_num
-                      = fvm_io_num_get_global_num(element_io_num);
+  const cs_gnum_t global_num_start = this_slice->global_num_slice_start;
+  const cs_gnum_t global_num_end = this_slice->global_num_slice_end;
+  const cs_gnum_t *entity_global_num
+                     = fvm_io_num_get_global_num(element_io_num);
 
   /* Initialize blocklengths and displacements */
 
@@ -622,12 +614,12 @@ fvm_gather_slice_index(const fvm_lnum_t     local_index[],
       if (   this_slice->next_global_num[distant_rank] < global_num_end
           || this_slice->use_next_global_num == false) {
 
-        MPI_Send(&distant_rank, 1, MPI_INT, distant_rank, FVM_MPI_TAG, comm);
+        MPI_Send(&distant_rank, 1, MPI_INT, distant_rank, _GATHER_TAG, comm);
         MPI_Recv(&n_distant_entities, 1, MPI_INT,
-                 distant_rank, FVM_MPI_TAG, comm, &status);
+                 distant_rank, _GATHER_TAG, comm, &status);
 
-        MPI_Recv(displacements, n_distant_entities, FVM_MPI_GNUM,
-                 distant_rank, FVM_MPI_TAG, comm, &status);
+        MPI_Recv(displacements, n_distant_entities, CS_MPI_GNUM,
+                 distant_rank, _GATHER_TAG, comm, &status);
 
         n_distant_entities -= 1;
         this_slice->next_global_num_last[distant_rank]
@@ -635,15 +627,15 @@ fvm_gather_slice_index(const fvm_lnum_t     local_index[],
 
         if (n_distant_entities > 0) {
 
-          fvm_gnum_t *recv_buf = NULL;
+          cs_gnum_t *recv_buf = NULL;
 
           _slice_recv_buf_size_array(this_slice, n_distant_entities,
-                                     1, sizeof(fvm_gnum_t));
+                                     1, sizeof(cs_gnum_t));
 
           recv_buf = this_slice->recv_buf;
 
           MPI_Recv(this_slice->recv_buf, n_distant_entities,
-                   FVM_MPI_GNUM, distant_rank, FVM_MPI_TAG, comm, &status);
+                   CS_MPI_GNUM, distant_rank, _GATHER_TAG, comm, &status);
 
           for (i = 0 ; i < n_distant_entities ; i++)
             slice_index[displacements[i]] = recv_buf[i];
@@ -678,19 +670,19 @@ fvm_gather_slice_index(const fvm_lnum_t     local_index[],
 
       int buf_val;
 
-      MPI_Recv(&buf_val, 1, MPI_INT, 0, FVM_MPI_TAG, comm, &status);
+      MPI_Recv(&buf_val, 1, MPI_INT, 0, _GATHER_TAG, comm, &status);
 
       buf_val = n_local_entities + 1;
-      MPI_Send(&buf_val, 1, MPI_INT, 0, FVM_MPI_TAG, comm);
+      MPI_Send(&buf_val, 1, MPI_INT, 0, _GATHER_TAG, comm);
 
       MPI_Send(displacements, n_local_entities + 1,
-               FVM_MPI_GNUM, 0, FVM_MPI_TAG, comm);
+               CS_MPI_GNUM, 0, _GATHER_TAG, comm);
 
       /* Send local portion of lengths array to rank zero */
 
       if (n_local_entities > 0)
         MPI_Send(slice_index, (int)n_local_entities,
-                 FVM_MPI_GNUM, 0, FVM_MPI_TAG, comm);
+                 CS_MPI_GNUM, 0, _GATHER_TAG, comm);
 
     }
 
@@ -731,17 +723,17 @@ fvm_gather_slice_index(const fvm_lnum_t     local_index[],
  *----------------------------------------------------------------------------*/
 
 void
-fvm_gather_resize_indexed_slice(const fvm_gnum_t     n_elements_s_min,
-                                fvm_gnum_t          *global_num_end,
-                                fvm_gnum_t          *global_connect_s_size,
+fvm_gather_resize_indexed_slice(const cs_gnum_t      n_elements_s_min,
+                                cs_gnum_t           *global_num_end,
+                                cs_gnum_t           *global_connect_s_size,
                                 MPI_Comm             comm,
-                                const fvm_gnum_t     slice_index[],
+                                const cs_gnum_t      slice_index[],
                                 fvm_gather_slice_t  *this_slice)
 {
-  fvm_gnum_t  i_s;
-  fvm_gnum_t  buf[2];
+  cs_gnum_t  i_s;
+  cs_gnum_t  buf[2];
 
-  fvm_gnum_t global_num_start = this_slice->global_num_slice_start;
+  cs_gnum_t global_num_start = this_slice->global_num_slice_start;
 
   const int local_rank = this_slice->local_rank;
 
@@ -777,8 +769,8 @@ fvm_gather_resize_indexed_slice(const fvm_gnum_t     n_elements_s_min,
         *global_num_end = this_slice->global_num_slice_end;
 
       *global_connect_s_size =
-        FVM_MAX(*global_connect_s_size,
-                slice_index[*global_num_end - global_num_start]);
+        CS_MAX(*global_connect_s_size,
+               slice_index[*global_num_end - global_num_start]);
 
     }
 
@@ -786,7 +778,7 @@ fvm_gather_resize_indexed_slice(const fvm_gnum_t     n_elements_s_min,
 
   }
 
-  MPI_Bcast(buf, 2, FVM_MPI_GNUM, 0, comm);
+  MPI_Bcast(buf, 2, CS_MPI_GNUM, 0, comm);
 
   /* Modify (reduce) slice size limit if necessary */
 
@@ -843,7 +835,7 @@ fvm_gather_array(const void          *local_array,
   int  n_local_entities, n_distant_entities;
   size_t  i, j, k;
   size_t  size_mult;
-  fvm_lnum_t  local_index_start, local_index_stop;
+  cs_lnum_t  local_index_start, local_index_stop;
 
   const char *local_array_val = local_array;
   char *global_array_s_val = global_array_s;
@@ -853,16 +845,16 @@ fvm_gather_array(const void          *local_array,
   int  size, distant_rank;
   const int local_rank = this_slice->local_rank;
   const int n_ranks = this_slice->n_ranks;
-  fvm_gnum_t *const displacements = this_slice->displacements;
+  cs_gnum_t *const displacements = this_slice->displacements;
 
   /* Local number of elements */
-  const fvm_lnum_t  local_index_end = this_slice->local_index_end;
+  const cs_lnum_t  local_index_end = this_slice->local_index_end;
 
   /* Global numbering */
-  const fvm_gnum_t global_num_start = this_slice->global_num_slice_start;
-  const fvm_gnum_t global_num_end = this_slice->global_num_slice_end;
-  const fvm_gnum_t *entity_global_num
-                      = fvm_io_num_get_global_num(element_io_num);
+  const cs_gnum_t global_num_start = this_slice->global_num_slice_start;
+  const cs_gnum_t global_num_end = this_slice->global_num_slice_end;
+  const cs_gnum_t *entity_global_num
+                     = fvm_io_num_get_global_num(element_io_num);
 
   /* Get info on the current MPI communicator */
 
@@ -927,12 +919,12 @@ fvm_gather_array(const void          *local_array,
       if (   this_slice->next_global_num[distant_rank] < global_num_end
           || this_slice->use_next_global_num == false) {
 
-        MPI_Send(&distant_rank, 1, MPI_INT, distant_rank, FVM_MPI_TAG, comm);
+        MPI_Send(&distant_rank, 1, MPI_INT, distant_rank, _GATHER_TAG, comm);
         MPI_Recv(&n_distant_entities, 1, MPI_INT,
-                 distant_rank, FVM_MPI_TAG, comm, &status);
+                 distant_rank, _GATHER_TAG, comm, &status);
 
-        MPI_Recv(displacements, n_distant_entities, FVM_MPI_GNUM,
-                 distant_rank, FVM_MPI_TAG, comm, &status);
+        MPI_Recv(displacements, n_distant_entities, CS_MPI_GNUM,
+                 distant_rank, _GATHER_TAG, comm, &status);
 
         n_distant_entities -= 1;
         this_slice->next_global_num_last[distant_rank]
@@ -948,7 +940,7 @@ fvm_gather_array(const void          *local_array,
           _recv_buf = this_slice->recv_buf;
 
           MPI_Recv(this_slice->recv_buf, n_distant_entities*stride, datatype,
-                   distant_rank, FVM_MPI_TAG, comm, &status);
+                   distant_rank, _GATHER_TAG, comm, &status);
 
           for (i = 0 ; i < (size_t)n_distant_entities ; i++) {
             for (j = 0 ; j < size_mult ; j++) {
@@ -973,19 +965,19 @@ fvm_gather_array(const void          *local_array,
 
       int buf_val;
 
-      MPI_Recv(&buf_val, 1, MPI_INT, 0, FVM_MPI_TAG, comm, &status);
+      MPI_Recv(&buf_val, 1, MPI_INT, 0, _GATHER_TAG, comm, &status);
 
       buf_val = n_local_entities + 1;
-      MPI_Send(&buf_val, 1, MPI_INT, 0, FVM_MPI_TAG, comm);
+      MPI_Send(&buf_val, 1, MPI_INT, 0, _GATHER_TAG, comm);
 
-      MPI_Send(displacements, n_local_entities + 1, FVM_MPI_GNUM, 0,
-               FVM_MPI_TAG, comm);
+      MPI_Send(displacements, n_local_entities + 1, CS_MPI_GNUM, 0,
+               _GATHER_TAG, comm);
 
       /* Send local portion of connectivity array to rank zero */
 
       if (n_local_entities > 0)
         MPI_Send(global_array_s, (int)(n_local_entities * stride),
-                 datatype, 0, FVM_MPI_TAG, comm);
+                 datatype, 0, _GATHER_TAG, comm);
 
     }
 
@@ -1041,16 +1033,16 @@ void
 fvm_gather_indexed(const void          *local_array,
                    void                *global_array_s,
                    const MPI_Datatype   datatype,
-                   const fvm_lnum_t     local_index[],
+                   const cs_lnum_t      local_index[],
                    const fvm_io_num_t  *element_io_num,
                    MPI_Comm             comm,
-                   const fvm_gnum_t     slice_index[],
+                   const cs_gnum_t      slice_index[],
                    fvm_gather_slice_t  *this_slice)
 {
   int  i, j, k, l;
   int  n_local_entities, n_distant_entities;
   int  n_values_send = 0;
-  fvm_lnum_t  local_index_start, local_index_stop;
+  cs_lnum_t  local_index_start, local_index_stop;
 
   const char *local_array_val = local_array;
   char *global_array_s_val = global_array_s;
@@ -1061,16 +1053,16 @@ fvm_gather_indexed(const void          *local_array,
   const int local_rank = this_slice->local_rank;
   const int n_ranks = this_slice->n_ranks;
   int  *blocklengths = this_slice->blocklengths;
-  fvm_gnum_t *const displacements = this_slice->displacements;
+  cs_gnum_t *const displacements = this_slice->displacements;
 
   /* Local number of elements */
-  const fvm_lnum_t  local_index_end = this_slice->local_index_end;
+  const cs_lnum_t  local_index_end = this_slice->local_index_end;
 
   /* Global numbering */
-  const fvm_gnum_t global_num_start = this_slice->global_num_slice_start;
-  const fvm_gnum_t global_num_end = this_slice->global_num_slice_end;
-  const fvm_gnum_t *entity_global_num
-                      = fvm_io_num_get_global_num(element_io_num);
+  const cs_gnum_t global_num_start = this_slice->global_num_slice_start;
+  const cs_gnum_t global_num_end = this_slice->global_num_slice_end;
+  const cs_gnum_t *entity_global_num
+                     = fvm_io_num_get_global_num(element_io_num);
 
   MPI_Type_size(datatype, &size);
 
@@ -1148,14 +1140,14 @@ fvm_gather_indexed(const void          *local_array,
       if (   this_slice->next_global_num[distant_rank] < global_num_end
           || this_slice->use_next_global_num == false) {
 
-        MPI_Send(&distant_rank, 1, MPI_INT, distant_rank, FVM_MPI_TAG, comm);
+        MPI_Send(&distant_rank, 1, MPI_INT, distant_rank, _GATHER_TAG, comm);
         MPI_Recv(&n_distant_entities, 1, MPI_INT,
-                 distant_rank, FVM_MPI_TAG, comm, &status);
+                 distant_rank, _GATHER_TAG, comm, &status);
 
         /* Get index from distant rank */
 
-        MPI_Recv(displacements, n_distant_entities, FVM_MPI_GNUM,
-                 distant_rank, FVM_MPI_TAG, comm, &status);
+        MPI_Recv(displacements, n_distant_entities, CS_MPI_GNUM,
+                 distant_rank, _GATHER_TAG, comm, &status);
 
         n_distant_entities -= 1;
         this_slice->next_global_num_last[distant_rank]
@@ -1178,7 +1170,7 @@ fvm_gather_indexed(const void          *local_array,
                                        size);
 
           MPI_Recv(this_slice->recv_buf, (int)recv_size, datatype,
-                   distant_rank, FVM_MPI_TAG, comm, &status);
+                   distant_rank, _GATHER_TAG, comm, &status);
 
           _recv_buf = this_slice->recv_buf;
 
@@ -1205,19 +1197,19 @@ fvm_gather_indexed(const void          *local_array,
 
       int buf_val;
 
-      MPI_Recv(&buf_val, 1, MPI_INT, 0, FVM_MPI_TAG, comm, &status);
+      MPI_Recv(&buf_val, 1, MPI_INT, 0, _GATHER_TAG, comm, &status);
 
       buf_val = n_local_entities + 1;
-      MPI_Send(&buf_val, 1, MPI_INT, 0, FVM_MPI_TAG, comm);
+      MPI_Send(&buf_val, 1, MPI_INT, 0, _GATHER_TAG, comm);
 
-      MPI_Send(displacements, n_local_entities + 1, FVM_MPI_GNUM,
-               0, FVM_MPI_TAG, comm);
+      MPI_Send(displacements, n_local_entities + 1, CS_MPI_GNUM,
+               0, _GATHER_TAG, comm);
 
       /* Send local portion of numbers array to rank zero */
 
       if (n_local_entities > 0)
         MPI_Send(global_array_s, (int)n_values_send,
-                 datatype, 0, FVM_MPI_TAG, comm);
+                 datatype, 0, _GATHER_TAG, comm);
 
     }
 
@@ -1263,9 +1255,9 @@ fvm_gather_indexed(const void          *local_array,
  *----------------------------------------------------------------------------*/
 
 void
-fvm_gather_strided_connect(const fvm_lnum_t    local_connect[],
-                           fvm_gnum_t          global_connect_s[],
-                           const int           stride,
+fvm_gather_strided_connect(const cs_lnum_t      local_connect[],
+                           cs_gnum_t            global_connect_s[],
+                           const int            stride,
                            const fvm_io_num_t  *connected_io_num,
                            const fvm_io_num_t  *element_io_num,
                            MPI_Comm             comm,
@@ -1273,25 +1265,25 @@ fvm_gather_strided_connect(const fvm_lnum_t    local_connect[],
 {
   int  i, j, k;
   int  n_local_entities, n_distant_entities;
-  fvm_lnum_t  local_index_start, local_index_stop;
+  cs_lnum_t  local_index_start, local_index_stop;
 
   /* MPI related variables */
   MPI_Status status;
   int  distant_rank;
   const int local_rank = this_slice->local_rank;
   const int n_ranks = this_slice->n_ranks;
-  fvm_gnum_t *const displacements = this_slice->displacements;
+  cs_gnum_t *const displacements = this_slice->displacements;
 
   /* Local number of elements */
-  const fvm_lnum_t  local_index_end = this_slice->local_index_end;
+  const cs_lnum_t  local_index_end = this_slice->local_index_end;
 
   /* Global numbering */
-  const fvm_gnum_t global_num_start = this_slice->global_num_slice_start;
-  const fvm_gnum_t global_num_end = this_slice->global_num_slice_end;
-  const fvm_gnum_t *connected_global_num
-                      = fvm_io_num_get_global_num(connected_io_num);
-  const fvm_gnum_t *entity_global_num
-                      = fvm_io_num_get_global_num(element_io_num);
+  const cs_gnum_t global_num_start = this_slice->global_num_slice_start;
+  const cs_gnum_t global_num_end = this_slice->global_num_slice_end;
+  const cs_gnum_t *connected_global_num
+                     = fvm_io_num_get_global_num(connected_io_num);
+  const cs_gnum_t *entity_global_num
+                     = fvm_io_num_get_global_num(element_io_num);
 
   /* Initialize displacements */
 
@@ -1333,7 +1325,7 @@ fvm_gather_strided_connect(const fvm_lnum_t    local_connect[],
   }
   else {
     int n_local_values = n_local_entities * stride;
-    for (i = 0, j = (fvm_gnum_t)(local_index_start * stride);
+    for (i = 0, j = (cs_gnum_t)(local_index_start * stride);
          i < n_local_values;
          i++, j++) {
       global_connect_s[i] = connected_global_num[local_connect[j] - 1];
@@ -1351,12 +1343,12 @@ fvm_gather_strided_connect(const fvm_lnum_t    local_connect[],
       if (   this_slice->next_global_num[distant_rank] < global_num_end
           || this_slice->use_next_global_num == false) {
 
-        MPI_Send(&distant_rank, 1, MPI_INT, distant_rank, FVM_MPI_TAG, comm);
+        MPI_Send(&distant_rank, 1, MPI_INT, distant_rank, _GATHER_TAG, comm);
         MPI_Recv(&n_distant_entities, 1, MPI_INT,
-                 distant_rank, FVM_MPI_TAG, comm, &status);
+                 distant_rank, _GATHER_TAG, comm, &status);
 
-        MPI_Recv(displacements, n_distant_entities, FVM_MPI_GNUM,
-                 distant_rank, FVM_MPI_TAG, comm, &status);
+        MPI_Recv(displacements, n_distant_entities, CS_MPI_GNUM,
+                 distant_rank, _GATHER_TAG, comm, &status);
 
         n_distant_entities -= 1;
         this_slice->next_global_num_last[distant_rank]
@@ -1364,15 +1356,15 @@ fvm_gather_strided_connect(const fvm_lnum_t    local_connect[],
 
         if (n_distant_entities > 0) {
 
-          fvm_gnum_t *_recv_buf;
+          cs_gnum_t *_recv_buf;
 
           _slice_recv_buf_size_array(this_slice, n_distant_entities,
-                                     stride, sizeof(fvm_gnum_t));
+                                     stride, sizeof(cs_gnum_t));
 
           _recv_buf = this_slice->recv_buf;
 
           MPI_Recv(this_slice->recv_buf, (int)(n_distant_entities*stride),
-                   FVM_MPI_GNUM, distant_rank, FVM_MPI_TAG, comm, &status);
+                   CS_MPI_GNUM, distant_rank, _GATHER_TAG, comm, &status);
 
           for (i = 0 ; i < n_distant_entities ; i++) {
             for (j = 0 ; j < stride ; j++)
@@ -1396,19 +1388,19 @@ fvm_gather_strided_connect(const fvm_lnum_t    local_connect[],
 
       int buf_val;
 
-      MPI_Recv(&buf_val, 1, MPI_INT, 0, FVM_MPI_TAG, comm, &status);
+      MPI_Recv(&buf_val, 1, MPI_INT, 0, _GATHER_TAG, comm, &status);
 
       buf_val = n_local_entities + 1;
-      MPI_Send(&buf_val, 1, MPI_INT, 0, FVM_MPI_TAG, comm);
+      MPI_Send(&buf_val, 1, MPI_INT, 0, _GATHER_TAG, comm);
 
-      MPI_Send(displacements, n_local_entities + 1, FVM_MPI_GNUM, 0,
-               FVM_MPI_TAG, comm);
+      MPI_Send(displacements, n_local_entities + 1, CS_MPI_GNUM, 0,
+               _GATHER_TAG, comm);
 
       /* Send local portion of connectivity array to rank zero */
 
       if (n_local_entities > 0)
         MPI_Send(global_connect_s, (int)(n_local_entities * stride),
-                 FVM_MPI_GNUM, 0, FVM_MPI_TAG, comm);
+                 CS_MPI_GNUM, 0, _GATHER_TAG, comm);
 
     }
 
@@ -1466,19 +1458,19 @@ fvm_gather_strided_connect(const fvm_lnum_t    local_connect[],
  *----------------------------------------------------------------------------*/
 
 void
-fvm_gather_indexed_numbers(const fvm_lnum_t     local_index[],
-                           const fvm_lnum_t     local_numbers[],
-                           fvm_gnum_t           global_numbers_s[],
+fvm_gather_indexed_numbers(const cs_lnum_t      local_index[],
+                           const cs_lnum_t      local_numbers[],
+                           cs_gnum_t            global_numbers_s[],
                            const fvm_io_num_t  *connected_io_num,
                            const fvm_io_num_t  *element_io_num,
                            MPI_Comm             comm,
-                           const fvm_gnum_t     slice_index[],
+                           const cs_gnum_t      slice_index[],
                            fvm_gather_slice_t  *this_slice)
 {
   int  i, j, k, l;
   int  n_local_entities, n_distant_entities;
   int  n_values_send = 0;
-  fvm_lnum_t  local_index_start, local_index_stop;
+  cs_lnum_t  local_index_start, local_index_stop;
 
   /* MPI related variables */
   MPI_Status status;
@@ -1486,17 +1478,17 @@ fvm_gather_indexed_numbers(const fvm_lnum_t     local_index[],
   const int local_rank = this_slice->local_rank;
   const int n_ranks = this_slice->n_ranks;
   int  *blocklengths = this_slice->blocklengths;
-  fvm_gnum_t *const displacements = this_slice->displacements;
+  cs_gnum_t *const displacements = this_slice->displacements;
 
   /* Local number of elements */
-  const fvm_lnum_t  local_index_end = this_slice->local_index_end;
+  const cs_lnum_t  local_index_end = this_slice->local_index_end;
 
   /* Global numbering */
-  const fvm_gnum_t global_num_start = this_slice->global_num_slice_start;
-  const fvm_gnum_t global_num_end = this_slice->global_num_slice_end;
-  const fvm_gnum_t *connected_global_num = NULL;
-  const fvm_gnum_t *entity_global_num
-                      = fvm_io_num_get_global_num(element_io_num);
+  const cs_gnum_t global_num_start = this_slice->global_num_slice_start;
+  const cs_gnum_t global_num_end = this_slice->global_num_slice_end;
+  const cs_gnum_t *connected_global_num = NULL;
+  const cs_gnum_t *entity_global_num
+                     = fvm_io_num_get_global_num(element_io_num);
 
   if (connected_io_num != NULL)
     connected_global_num = fvm_io_num_get_global_num(connected_io_num);
@@ -1602,14 +1594,14 @@ fvm_gather_indexed_numbers(const fvm_lnum_t     local_index[],
 
         size_t  recv_size = 0;
 
-        MPI_Send(&distant_rank, 1, MPI_INT, distant_rank, FVM_MPI_TAG, comm);
+        MPI_Send(&distant_rank, 1, MPI_INT, distant_rank, _GATHER_TAG, comm);
         MPI_Recv(&n_distant_entities, 1, MPI_INT,
-                 distant_rank, FVM_MPI_TAG, comm, &status);
+                 distant_rank, _GATHER_TAG, comm, &status);
 
       /* Get index from distant rank */
 
-        MPI_Recv(displacements, n_distant_entities, FVM_MPI_GNUM,
-                 distant_rank, FVM_MPI_TAG, comm, &status);
+        MPI_Recv(displacements, n_distant_entities, CS_MPI_GNUM,
+                 distant_rank, _GATHER_TAG, comm, &status);
 
         n_distant_entities -= 1;
         this_slice->next_global_num_last[distant_rank]
@@ -1625,14 +1617,14 @@ fvm_gather_indexed_numbers(const fvm_lnum_t     local_index[],
         if (n_distant_entities > 0) {
 
           size_t  recv_id;
-          fvm_gnum_t  *_recv_buf = NULL;
+          cs_gnum_t  *_recv_buf = NULL;
 
           _slice_recv_buf_size_indexed(this_slice,
                                        recv_size,
-                                       sizeof(fvm_gnum_t));
+                                       sizeof(cs_gnum_t));
 
-          MPI_Recv(this_slice->recv_buf, recv_size, FVM_MPI_GNUM,
-                   distant_rank, FVM_MPI_TAG, comm, &status);
+          MPI_Recv(this_slice->recv_buf, recv_size, CS_MPI_GNUM,
+                   distant_rank, _GATHER_TAG, comm, &status);
 
           _recv_buf = this_slice->recv_buf;
 
@@ -1658,19 +1650,19 @@ fvm_gather_indexed_numbers(const fvm_lnum_t     local_index[],
 
       int buf_val;
 
-      MPI_Recv(&buf_val, 1, MPI_INT, 0, FVM_MPI_TAG, comm, &status);
+      MPI_Recv(&buf_val, 1, MPI_INT, 0, _GATHER_TAG, comm, &status);
 
       buf_val = n_local_entities + 1;
-      MPI_Send(&buf_val, 1, MPI_INT, 0, FVM_MPI_TAG, comm);
+      MPI_Send(&buf_val, 1, MPI_INT, 0, _GATHER_TAG, comm);
 
-      MPI_Send(displacements, n_local_entities + 1, FVM_MPI_GNUM,
-               0, FVM_MPI_TAG, comm);
+      MPI_Send(displacements, n_local_entities + 1, CS_MPI_GNUM,
+               0, _GATHER_TAG, comm);
 
       /* Send local portion of numbers array to rank zero */
 
       if (n_local_entities > 0)
         MPI_Send(global_numbers_s, (int)n_values_send,
-                 FVM_MPI_GNUM, 0, FVM_MPI_TAG, comm);
+                 CS_MPI_GNUM, 0, _GATHER_TAG, comm);
 
     }
 
@@ -1686,6 +1678,4 @@ fvm_gather_indexed_numbers(const fvm_lnum_t     local_index[],
 
 /*----------------------------------------------------------------------------*/
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+END_C_DECLS
