@@ -5,7 +5,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2011 EDF S.A.
+  Copyright (C) 1998-2012 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -24,9 +24,7 @@
 
 /*----------------------------------------------------------------------------*/
 
-#if defined(HAVE_CONFIG_H)
-#include "cs_config.h"
-#endif
+#include "cs_defs.h"
 
 /*----------------------------------------------------------------------------
  * Standard C library headers
@@ -49,10 +47,6 @@
  *  Local headers
  *----------------------------------------------------------------------------*/
 
-#include "fvm_defs.h"
-#include "fvm_config_defs.h"
-#include "fvm_parall.h"
-
 /*----------------------------------------------------------------------------
  *  Header for the current file
  *----------------------------------------------------------------------------*/
@@ -61,17 +55,18 @@
 
 /*----------------------------------------------------------------------------*/
 
-#ifdef __cplusplus
-extern "C" {
-#if 0
-} /* Fake brace to force Emacs auto-indentation back to column 0 */
-#endif
-#endif /* __cplusplus */
+BEGIN_C_DECLS
 
-/*============================================================================
- * Type definitions
+/*=============================================================================
+ * Local Macro and Type definitions
  *============================================================================*/
 
+#if defined(HAVE_MPI)
+
+#define _GROUP_TAG      (int)('G'+'R'+'O'+'U'+'P') /* MPI tag */
+
+#endif
+
 /*----------------------------------------------------------------------------
  * Opaque structure describing a group class
  *----------------------------------------------------------------------------*/
@@ -111,10 +106,10 @@ static int
 _compare_names(const void  *a,
                const void  *b)
 {
-  return strcmp(*((const char **)a), *((const char **)b));
+  return strcmp(*((const char *const *)a), *((const char *const *)b));
 }
 
-#if defined(HAVE_MPI)
+#if 0 && defined(HAVE_MPI)
 
 /*----------------------------------------------------------------------------
  * Send group class set definition to distant rank.
@@ -174,12 +169,12 @@ _group_class_set_send(const fvm_group_class_set_t  *class_set,
   assert(n_ints == send_count[1]);
   assert(n_chars == send_count[2]);
 
-  MPI_Send(send_count, 3, MPI_INT, dest_rank, FVM_MPI_TAG, comm);
+  MPI_Send(send_count, 3, MPI_INT, dest_rank, _GROUP_TAG, comm);
 
   if (n_ints > 0)
-    MPI_Send(send_ints, n_ints, MPI_INT, dest_rank, FVM_MPI_TAG, comm);
+    MPI_Send(send_ints, n_ints, MPI_INT, dest_rank, _GROUP_TAG, comm);
   if (n_chars > 0)
-    MPI_Send(send_chars, n_chars, MPI_CHAR, dest_rank, FVM_MPI_TAG, comm);
+    MPI_Send(send_chars, n_chars, MPI_CHAR, dest_rank, _GROUP_TAG, comm);
 
   BFT_FREE(send_ints);
   BFT_FREE(send_chars);
@@ -213,20 +208,20 @@ _group_class_set_recv(fvm_group_class_set_t  *class_set,
   assert(class_set != NULL);
   assert(class_set->size == 0);
 
-  MPI_Recv(recv_count, 3, MPI_INT, src_rank, FVM_MPI_TAG, comm, &status);
+  MPI_Recv(recv_count, 3, MPI_INT, src_rank, _GROUP_TAG, comm, &status);
 
   /* Allocate and receive buffers */
 
   if (recv_count[1] > 0) {
     BFT_MALLOC(recv_ints, recv_count[1], int);
     MPI_Recv(recv_ints, recv_count[1], MPI_INT,
-             src_rank, FVM_MPI_TAG, comm, &status);
+             src_rank, _GROUP_TAG, comm, &status);
   }
 
   if (recv_count[2] > 0) {
     BFT_MALLOC(recv_chars, recv_count[2], char);
     MPI_Recv(recv_chars, recv_count[2], MPI_CHAR,
-             src_rank, FVM_MPI_TAG, comm, &status);
+             src_rank, _GROUP_TAG, comm, &status);
   }
 
   /* Decode buffers */
@@ -305,7 +300,7 @@ _group_class_dump(const fvm_group_class_t  *this_group_class,
   bft_printf("\n"
              "    _group_class[%3d]: %p\n"
              "    n_groups:          %d\n",
-             id, this_group_class,
+             id, (const void *)this_group_class,
              this_group_class->n_groups);
 
   if (this_group_class->n_groups > 0) {
@@ -576,7 +571,7 @@ fvm_group_class_set_dump(const fvm_group_class_set_t  *this_group_class_set)
 
   bft_printf("  _group_class_set: %p\n"
              "  size:             %d\n",
-             class_set,
+             (const void *)class_set,
              class_set->size);
 
   if (class_set->size > 0) {
@@ -590,6 +585,4 @@ fvm_group_class_set_dump(const fvm_group_class_set_t  *this_group_class_set)
 
 /*----------------------------------------------------------------------------*/
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+END_C_DECLS
