@@ -8,7 +8,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2011 EDF S.A.
+  Copyright (C) 1998-2012 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -56,7 +56,7 @@ extern "C" {
 
 void
 fvm_nodal_triangulate(fvm_nodal_t  *this_nodal,
-                      fvm_lnum_t   *error_count);
+                      cs_lnum_t    *error_count);
 
 /*----------------------------------------------------------------------------
  * Triangulate polygonal sections of a nodal mesh.
@@ -68,7 +68,7 @@ fvm_nodal_triangulate(fvm_nodal_t  *this_nodal,
 
 void
 fvm_nodal_triangulate_polygons(fvm_nodal_t  *this_nodal,
-                               fvm_lnum_t   *error_count);
+                               cs_lnum_t    *error_count);
 
 /*----------------------------------------------------------------------------*/
 
