@@ -5,7 +5,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2011 EDF S.A.
+  Copyright (C) 1998-2012 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -24,9 +24,7 @@
 
 /*----------------------------------------------------------------------------*/
 
-#if defined(HAVE_CONFIG_H)
-#include "cs_config.h"
-#endif
+#include "cs_defs.h"
 
 /*----------------------------------------------------------------------------
  * Standard C library headers
@@ -49,7 +47,6 @@
  *  Local headers
  *----------------------------------------------------------------------------*/
 
-#include "fvm_config_defs.h"
 #include "fvm_defs.h"
 
 /*----------------------------------------------------------------------------
@@ -257,12 +254,12 @@ _combine_transforms_check(const fvm_periodicity_t  *this_periodicity,
     for (i = 0; i < 3; i++) {
       for (j = 0; j < 4; j++) {
 
-        if (  FVM_ABS(m0[i][j] - m1[i][j])
+        if (  CS_ABS(m0[i][j] - m1[i][j])
             > this_periodicity->equiv_tolerance) {
 
           if (abort_on_error) {
-            int ext0 = FVM_ABS(tr0->external_num);
-            int ext1 = FVM_ABS(tr1->external_num);
+            int ext0 = CS_ABS(tr0->external_num);
+            int ext1 = CS_ABS(tr1->external_num);
             if (ext1 != 0) {
               bft_error(__FILE__, __LINE__, 0,
                         _("Periodicity transforms %d and %d\n"
@@ -276,8 +273,8 @@ _combine_transforms_check(const fvm_periodicity_t  *this_periodicity,
               int j_1 = tr1->parent_ids[1];
               ext1 = (this_periodicity->transform[j_0])->external_num;
               ext2 = (this_periodicity->transform[j_1])->external_num;
-              ext1 = FVM_ABS(ext1);
-              ext2 = FVM_ABS(ext2);
+              ext1 = CS_ABS(ext1);
+              ext2 = CS_ABS(ext2);
               bft_error(__FILE__, __LINE__, 0,
                         _("Periodicity transforms %d and %d\n"
                           "(based on directions %d, %d %d)\n"
@@ -753,7 +750,7 @@ fvm_periodicity_add_by_matrix(fvm_periodicity_t       *this_periodicity,
       _Bool is_equiv = true;
       for (j = 0; j < 3; j++) {
         for (k = 0; k < 4; k++) {
-          if (  FVM_ABS(transform->m[j][k] - tr->m[j][k])
+          if (  CS_ABS(transform->m[j][k] - tr->m[j][k])
               > this_periodicity->equiv_tolerance)
             is_equiv = false;
         }
@@ -895,7 +892,7 @@ fvm_periodicity_add_rotation(fvm_periodicity_t  *this_periodicity,
   /* Clip "zero" values */
   for (i = 0; i < 3; i++) {
     for (j = 0; j < 4; j++) {
-      if (FVM_ABS(matrix[i][j]) < 1.e-16)
+      if (CS_ABS(matrix[i][j]) < 1.e-16)
         matrix[i][j] = 0.;
     }
   }
@@ -1343,7 +1340,7 @@ fvm_periodicity_dump(const fvm_periodicity_t  *this_periodicity)
   int  level = 0;
 
   bft_printf("\n"
-             "Periodicity:          %p\n", this_periodicity);
+             "Periodicity:          %p\n", (const void *)this_periodicity);
 
   if (this_periodicity == NULL) {
     bft_printf("\n");
