@@ -5,7 +5,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2011 EDF S.A.
+  Copyright (C) 1998-2012 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -24,9 +24,7 @@
 
 /*----------------------------------------------------------------------------*/
 
-#if defined(HAVE_CONFIG_H)
-#include "cs_config.h"
-#endif
+#include "cs_defs.h"
 
 /*----------------------------------------------------------------------------
  * Standard C library headers
@@ -39,25 +37,21 @@
 #include <math.h>
 
 /*----------------------------------------------------------------------------
- * BFT library headers
+ * Local headers
  *----------------------------------------------------------------------------*/
 
-#include <bft_mem.h>
-#include <bft_error.h>
-#include <bft_printf.h>
-#include <bft_timer.h>
+#include "bft_mem.h"
+#include "bft_error.h"
+#include "bft_printf.h"
 
-/*----------------------------------------------------------------------------
- *  Local headers
- *----------------------------------------------------------------------------*/
+#include "cs_timer.h"
 
 #include "fvm_defs.h"
-#include "fvm_config_defs.h"
 #include "fvm_group.h"
 #include "fvm_selector_postfix.h"
 
 /*----------------------------------------------------------------------------
- *  Header for the current file
+ * Header for the current file
  *----------------------------------------------------------------------------*/
 
 #include "fvm_selector.h"
@@ -110,7 +104,7 @@ typedef struct {
 struct _fvm_selector_t {
 
   int                dim;                      /* Spatial dimension */
-  fvm_lnum_t         n_elements;               /* Number of elements */
+  cs_lnum_t          n_elements;               /* Number of elements */
 
   const int         *group_class_id;           /* Element group class ids */
   int               *_group_class_id;          /* private group_class_id,
@@ -145,9 +139,9 @@ struct _fvm_selector_t {
                                                   previously interpreted
                                                   strings (operations) */
 
-  fvm_lnum_t        *_n_group_class_elements;  /* Number of elements per
+  cs_lnum_t         *_n_group_class_elements;  /* Number of elements per
                                                   group class */
-  fvm_lnum_t        **_group_class_elements;   /* Group class elements array */
+  cs_lnum_t         **_group_class_elements;   /* Group class elements array */
 
   int                 n_evals;                 /* Number of evaluations */
   double              eval_wtime;              /* Wall-clock time
@@ -768,7 +762,7 @@ _get_criteria_id(fvm_selector_t  *selector,
 
 fvm_selector_t *
 fvm_selector_create(int                           dim,
-                    fvm_lnum_t                    n_elements,
+                    cs_lnum_t                     n_elements,
                     const fvm_group_class_set_t  *group_class_set,
                     const int                     group_class_id[],
                     int                           group_class_id_base,
@@ -776,7 +770,7 @@ fvm_selector_create(int                           dim,
                     const double                  normals[])
 {
   int i;
-  fvm_lnum_t j;
+  cs_lnum_t j;
   fvm_selector_t *selector;
 
   int n_group_classes = fvm_group_class_set_size(group_class_set);
@@ -817,8 +811,8 @@ fvm_selector_create(int                           dim,
 
   if (group_class_id != NULL && n_group_classes > 0) {
 
-    BFT_MALLOC(selector->_n_group_class_elements, n_group_classes, fvm_lnum_t);
-    BFT_MALLOC(selector->_group_class_elements, n_group_classes, fvm_lnum_t *);
+    BFT_MALLOC(selector->_n_group_class_elements, n_group_classes, cs_lnum_t);
+    BFT_MALLOC(selector->_group_class_elements, n_group_classes, cs_lnum_t *);
 
     /* Counting loop and allocation */
 
@@ -934,15 +928,15 @@ fvm_selector_destroy(fvm_selector_t  *this_selector)
 int
 fvm_selector_get_list(fvm_selector_t  *this_selector,
                       const char      *str,
-                      fvm_lnum_t      *n_selected_elements,
-                      fvm_lnum_t      *selected_elements)
+                      cs_lnum_t       *n_selected_elements,
+                      cs_lnum_t       *selected_elements)
 
 {
   int  c_id, gc_id;
-  fvm_lnum_t  i;
+  cs_lnum_t   i;
   const fvm_selector_postfix_t *pf = NULL;
   fvm_selector_t  *ts = this_selector;
-  double t0 = bft_timer_wtime();
+  double t0 = cs_timer_wtime();
 
   assert(this_selector != NULL);
 
@@ -1038,7 +1032,7 @@ fvm_selector_get_list(fvm_selector_t  *this_selector,
   }
 
   ts->n_evals += 1;
-  ts->eval_wtime += (bft_timer_wtime() - t0);
+  ts->eval_wtime += (cs_timer_wtime() - t0);
 
   return c_id;
 }
@@ -1070,7 +1064,7 @@ fvm_selector_get_gc_list(fvm_selector_t  *this_selector,
   int  c_id, gc_id;
   const fvm_selector_postfix_t *pf = NULL;
   fvm_selector_t  *ts = this_selector;
-  double t0 = bft_timer_wtime();
+  double t0 = cs_timer_wtime();
 
   assert(this_selector != NULL);
 
@@ -1108,7 +1102,7 @@ fvm_selector_get_gc_list(fvm_selector_t  *this_selector,
   }
 
   ts->n_evals += 1;
-  ts->eval_wtime += (bft_timer_wtime() - t0);
+  ts->eval_wtime += (cs_timer_wtime() - t0);
 
   return c_id;
 }
@@ -1231,7 +1225,8 @@ fvm_selector_dump(const fvm_selector_t  *this_selector)
              "  Number of evaluations:              %d\n"
              "  Wall-clock time in evaluations:     %f\n",
              ts->dim, (int)ts->n_elements,
-             ts->group_class_id, ts->_group_class_id,
+             (const void *)ts->group_class_id,
+             (const void *)ts->_group_class_id,
              ts->group_class_id_base,
              ts->n_group_classes, ts->n_groups, ts->n_attributes,
              ts->n_evals, ts->eval_wtime);
@@ -1271,15 +1266,16 @@ fvm_selector_dump(const fvm_selector_t  *this_selector)
              "  Shared normals;                     %p\n"
              "  Private normals:                    %p\n"
              "  Operations list:                    %p\n",
-             ts->coords, ts->_coords, ts->normals, ts->_normals,
-             ts->_operations);
+             (const void *)ts->coords, (const void *)ts->_coords,
+             (const void *)ts->normals, (const void *)ts->_normals,
+             (const void *)ts->_operations);
 
   if (ts->n_group_classes > 0) {
     bft_printf("  Number of elements per group class:\n");
     for (i = 0; i < ts->n_group_classes; i++) {
       bft_printf("    %d (%p)\n",
                  (int)ts->_n_group_class_elements[i],
-                 ts->_group_class_elements[i]);
+                 (const void *)ts->_group_class_elements[i]);
     }
   }
 
