@@ -7,7 +7,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2011 EDF S.A.
+  Copyright (C) 1998-2012 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -26,9 +26,7 @@
 
 /*----------------------------------------------------------------------------*/
 
-#if defined(HAVE_CONFIG_H)
-#include "cs_config.h"
-#endif
+#include "cs_defs.h"
 
 /*----------------------------------------------------------------------------
  * Standard C library headers
@@ -53,7 +51,6 @@
  *----------------------------------------------------------------------------*/
 
 #include "fvm_defs.h"
-#include "fvm_config_defs.h"
 
 /*----------------------------------------------------------------------------
  *  Header for the current file
@@ -2488,7 +2485,7 @@ _eval_plane(const fvm_selector_postfix_t  *pf,
     double epsilon = *((double *)(pf->elements + *i));
     assert(pf_type == PF_FLOAT);
     *i += _postfix_float_size;
-    if (FVM_ABS(pfunc) < epsilon)
+    if (CS_ABS(pfunc) < epsilon)
       retval = true;
   }
 
@@ -3225,7 +3222,7 @@ fvm_selector_postfix_dump(const fvm_selector_postfix_t  *pf,
           else if (n_groups > 0)
             bft_printf("    %d (group: \"%s\")\n", val, group_name[val]);
           else
-            bft_printf("    %d (group id)\n");
+            bft_printf("    %d (group id)\n", val);
         }
         else if (type == PF_ATTRIBUTE_ID) {
           if (val < 0)
@@ -3233,7 +3230,7 @@ fvm_selector_postfix_dump(const fvm_selector_postfix_t  *pf,
           else if (n_attributes > 0)
             bft_printf("    %d (attribute: %d)\n", val, attribute[val]);
           else
-            bft_printf("    %d (attribute id)\n");
+            bft_printf("    %d (attribute id)\n", val);
         }
         else
           bft_printf("    %d\n", val);
