@@ -5,7 +5,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2011 EDF S.A.
+  Copyright (C) 1998-2012 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -24,9 +24,7 @@
 
 /*----------------------------------------------------------------------------*/
 
-#if defined(HAVE_CONFIG_H)
-#include "cs_config.h"
-#endif
+#include "cs_defs.h"
 
 /*----------------------------------------------------------------------------
  * Standard C library headers
@@ -34,6 +32,7 @@
 
 #include <assert.h>
 #include <ctype.h>  /* toupper() */
+#include <errno.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -44,16 +43,12 @@
 
 #include <bft_error.h>
 #include <bft_mem.h>
-#include <bft_file.h>
 
 /*----------------------------------------------------------------------------
  *  Local headers
  *----------------------------------------------------------------------------*/
 
-#include "fvm_config_defs.h"
-#include "fvm_defs.h"
 #include "fvm_gather.h"
-#include "fvm_parall.h"
 #include "fvm_writer.h"
 
 /*----------------------------------------------------------------------------
@@ -287,10 +282,9 @@ _add_var(fvm_to_ensight_case_t       *const this_case,
          const fvm_writer_var_loc_t         location,
          const int                          time_set)
 {
-  char line[80], description[20];
+  char line[1024], description[50];
   int i, l;
   int remain_len, prefix_len, base_len, postfix_len;
-  _Bool rename_file;
 
   fvm_to_ensight_case_var_t  *var;
 
@@ -302,10 +296,10 @@ _add_var(fvm_to_ensight_case_t       *const this_case,
   BFT_MALLOC(var->name, l + 1, char);
   strcpy(var->name, name);
 
-  /* Create description (19 chars max) */
+  /* Create description (49 chars max) */
 
-  if (l > 19)
-      l = 19;
+  if (l > 49)
+      l = 49;
 
   strncpy(description, name, l);
   description[l] = '\0';
@@ -332,7 +326,7 @@ _add_var(fvm_to_ensight_case_t       *const this_case,
       description[i] = '_';
       break;
     default:
-      break;
+       break;
     }
   }
 
@@ -346,7 +340,7 @@ _add_var(fvm_to_ensight_case_t       *const this_case,
 
   /* Create associated case file line, up to file name
      (which may depend on the number of remaining characters,
-     so as to avoid going beyond 79 characters if possible) */
+     so as to avoid going beyond 1024 characters if possible) */
 
   switch(var->dim) {
   case 0:
@@ -391,78 +385,57 @@ _add_var(fvm_to_ensight_case_t       *const this_case,
                         time set number < 100 (EnSight maximum:
                         16, apparently only for measured data) */
 
-  sprintf(line + l, "%19s ", description); /* Description max 19 chars,
-                                              so 79 char line limit not
+  sprintf(line + l, "%32s ", description); /* Description max 49 chars,
+                                              (32 recommended for compatibility
+                                              with other formats)
+                                              so 1024 char line limit not
                                               exceeded here */
 
-  for (l = strlen(line) ; l < 48 ; l++)
+  for (l = strlen(line); l < 61; l++)
     line[l] = ' ';
-  line[l] = '\0'; /* Line length = 35 + 19 + 1 = 55 max at this stage,
-                     usually 48 */
+  line[l] = '\0'; /* Line length = 35 + 49 + 1 = 85 max at this stage,
+                     usually 31 + 32 + 1 = 64 */
 
-  /* Create (current) file name.
-     To avoid lines longer than 79 characters in the case file, we limit the
-     local file name to 79 - l characters. If this limit should be exceeded,
-     we try to assign a file name based on the variable index :
-     '<case_prefix>.var_***'. If this is not possible due to the length
-     of the file name prefix (based on the case name), we choose to
-     allow generation of an "incorrect" case file and which can be
-     corrected by the user (who will need to rename files) rather than risk
-     the possibility of confusing EnSight cases in a same directory due to
-     name truncation. */
+  /* Create (current) file name. */
 
-  remain_len = 79 - strlen(line);
+  remain_len = 1024 - strlen(line);
   prefix_len =   strlen(this_case->file_name_prefix)
                - this_case->dir_name_length + 1;
   base_len = strlen(name);
   if (var->time_set > -1)
-    postfix_len = 5;
+    postfix_len = 6;
   else
     postfix_len = 0;
 
-  if (   (prefix_len + base_len + postfix_len > remain_len)
-      && (prefix_len + 7 + postfix_len <= remain_len)
-      && (this_case->n_vars < 1000)) {
-    base_len = 7;
-    rename_file = true;
-  }
-  else
-    rename_file = false;
-
   BFT_MALLOC(var->file_name,
              (  this_case->dir_name_length + prefix_len
               + base_len + postfix_len + 1),
              char);
   sprintf(var->file_name, "%s.", this_case->file_name_prefix);
 
-  if (rename_file == true)
-    sprintf(var->file_name + strlen(var->file_name),
-            "var_%03d", this_case->n_vars);
-  else {
-    strcat(var->file_name, name);
-    for (i = this_case->dir_name_length + prefix_len ;
-         i < this_case->dir_name_length + prefix_len + base_len ;
-         i++) {
-      switch (var->file_name[i]) {
-      case '@':
-      case ' ':
-      case '\t':
-      case '!':
-      case '#':
-      case '*':
-      case '^':
-      case '$':
-      case '/':
-        var->file_name[i] = '_';
-      default:
-        var->file_name[i] = tolower(var->file_name[i]);
-      }
+  strcat(var->file_name, name);
+  for (i = this_case->dir_name_length + prefix_len ;
+       i < this_case->dir_name_length + prefix_len + base_len ;
+       i++) {
+    switch (var->file_name[i]) {
+    case '@':
+    case ' ':
+    case '\t':
+    case '!':
+    case '#':
+    case '*':
+    case '^':
+    case '$':
+    case '/':
+      var->file_name[i] = '_';
+    default:
+      var->file_name[i] = tolower(var->file_name[i]);
     }
   }
 
   if (var->time_set > -1) {
     sprintf(var->file_name + strlen(var->file_name),
-            ".%04d", (this_case->time_set[var->time_set])->n_time_values);
+            ".%05d", (this_case->time_set[var->time_set])->n_time_values);
   }
 
   /* Now we may finish associated case file line */
@@ -478,10 +451,19 @@ _add_var(fvm_to_ensight_case_t       *const this_case,
   /* Replace current time index by wildcards */
 
   if (var->time_set > -1)
-    strcpy(var->case_line + strlen(var->case_line) -4, "****");
+    strcpy(var->case_line + strlen(var->case_line) -5, "*****");
 
   /* Finally, associate variable entry in case file */
 
+  if (strlen(var->case_line) > 1024) {
+    bft_printf
+      (_("Line of the EnSight case file \"%s\"\n"
+         "for variable \"%s\",\n"
+         "exceeds 1024 characters, so this file must be edited and variable\n"
+         "descriptions or referenced files renamed so as to be readable.\n"),
+       this_case->case_file_name, name);
+  }
+
   BFT_REALLOC(this_case->var, this_case->n_vars, fvm_to_ensight_case_var_t *);
 
   this_case->var[this_case->n_vars - 1] = var;
@@ -542,7 +524,7 @@ _update_geom_file_name(fvm_to_ensight_case_t  *const this_case)
       if (this_case->geom_time_set > -1)
         geom_index =
           (this_case->time_set[this_case->geom_time_set])->n_time_values;
-      sprintf(extension, ".geo.%04d", geom_index);
+      sprintf(extension, ".geo.%05d", geom_index);
     }
 
     BFT_MALLOC(this_case->geom_file_name,
@@ -559,8 +541,8 @@ _update_geom_file_name(fvm_to_ensight_case_t  *const this_case)
     if (this_case->geom_time_set > -1) {
       geom_index =
         (this_case->time_set[this_case->geom_time_set])->n_time_values;
-      sprintf(this_case->geom_file_name + strlen(this_case->geom_file_name) - 4,
-              "%04d", geom_index);
+      sprintf(this_case->geom_file_name + strlen(this_case->geom_file_name) - 5,
+              "%05d", geom_index);
     }
   }
 
@@ -972,7 +954,7 @@ fvm_to_ensight_case_get_var_file(fvm_to_ensight_case_t       *const this_case,
     retval.name = var->file_name;
     if (var->time_set > -1) {  /* if variable is time-dependant */
       var_index = (this_case->time_set[var->time_set])->n_time_values;
-      sprintf(var->file_name + strlen(var->file_name) - 4, "%04d", var_index);
+      sprintf(var->file_name + strlen(var->file_name) - 5, "%05d", var_index);
       if (var->last_time_step == time_step)
         retval.queried = true;
       else
@@ -1007,9 +989,9 @@ void
 fvm_to_ensight_case_write_case(fvm_to_ensight_case_t  *this_case,
                                int                     rank)
 {
-  int          i, j;
-  bft_file_t  *f;
-  _Bool        write_time_sets = false;
+  int      i, j;
+  FILE    *f;
+  _Bool    write_time_sets = false;
 
   /*xxxxxxxxxxxxxxxxxxxxxxxxxxx Instructions xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx*/
 
@@ -1023,47 +1005,50 @@ fvm_to_ensight_case_write_case(fvm_to_ensight_case_t  *this_case,
 
   /* Open case file (overwrite it if present) */
 
-  f = bft_file_open(this_case->case_file_name,
-                    BFT_FILE_MODE_WRITE,
-                    BFT_FILE_TYPE_TEXT);
+  f = fopen(this_case->case_file_name, "w");
+
+  if (f == NULL)
+    bft_error(__FILE__, __LINE__, 0,
+              _("Error opening file \"%s\":\n\n"
+                "  %s"), this_case->case_file_name, strerror(errno));
 
   /* Output FORMAT */
 
-  bft_file_printf(f,
-                  "FORMAT\n"
-                  "type: ensight gold\n");
+  fprintf(f,
+          "FORMAT\n"
+          "type: ensight gold\n");
 
   /* Output geometry */
 
-  bft_file_printf(f,
-                  "\n"
-                  "GEOMETRY\n");
+  fprintf(f,
+          "\n"
+          "GEOMETRY\n");
 
   if (this_case->time_dependency == FVM_WRITER_FIXED_MESH)
-    bft_file_printf(f, "model: %s.geo\n",
-                    this_case->file_name_prefix + this_case->dir_name_length);
+    fprintf(f, "model: %s.geo\n",
+            this_case->file_name_prefix + this_case->dir_name_length);
 
   else if (this_case->time_dependency == FVM_WRITER_TRANSIENT_COORDS)
-    bft_file_printf(f, "model: %d %s.geo.****  change_coords_only\n",
-                    this_case->geom_time_set + 1,
-                    this_case->file_name_prefix + this_case->dir_name_length);
+    fprintf(f, "model: %d %s.geo.*****  change_coords_only\n",
+            this_case->geom_time_set + 1,
+            this_case->file_name_prefix + this_case->dir_name_length);
 
   else
-    bft_file_printf(f, "model: %d %s.geo.****\n",
-                    this_case->geom_time_set + 1,
-                    this_case->file_name_prefix + this_case->dir_name_length);
+    fprintf(f, "model: %d %s.geo.*****\n",
+            this_case->geom_time_set + 1,
+            this_case->file_name_prefix + this_case->dir_name_length);
 
   /* Output variables */
 
   if (this_case->n_vars > 0) {
 
-    bft_file_printf(f,
-                    "\n"
-                    "VARIABLE\n");
+    fprintf(f,
+            "\n"
+            "VARIABLE\n");
 
     for (i = 0 ; i < this_case->n_vars ; i++) {
       const fvm_to_ensight_case_var_t  *var = this_case->var[i];
-      bft_file_printf(f, "%s\n", var->case_line);
+      fprintf(f, "%s\n", var->case_line);
     }
 
   }
@@ -1081,22 +1066,22 @@ fvm_to_ensight_case_write_case(fvm_to_ensight_case_t  *this_case,
 
   if (write_time_sets == true) {
 
-    bft_file_printf(f,
-                    "\n"
-                    "TIME\n");
+    fprintf(f,
+            "\n"
+            "TIME\n");
 
     for (i = 0 ; i < this_case->n_time_sets ; i++) {
 
       const fvm_to_ensight_case_time_t  *ts = this_case->time_set[i];
 
-      bft_file_printf(f, "time set:              %d\n", i+1);
-      bft_file_printf(f, "number of steps:       %d\n", ts->n_time_values);
-      bft_file_printf(f, "filename start number: 1\n");
-      bft_file_printf(f, "filename increment:    1\n");
-      bft_file_printf(f, "time values:\n");
+      fprintf(f, "time set:              %d\n", i+1);
+      fprintf(f, "number of steps:       %d\n", ts->n_time_values);
+      fprintf(f, "filename start number: 1\n");
+      fprintf(f, "filename increment:    1\n");
+      fprintf(f, "time values:\n");
 
       for (j = 0 ; j < ts->n_time_values ; j++)
-        bft_file_printf(f, "            %g\n", ts->time_value[j]);
+        fprintf(f, "            %g\n", ts->time_value[j]);
 
     }
 
@@ -1104,7 +1089,10 @@ fvm_to_ensight_case_write_case(fvm_to_ensight_case_t  *this_case,
 
   /* Close case file */
 
-  bft_file_free(f);
+  if (fclose(f) != 0)
+    bft_error(__FILE__, __LINE__, 0,
+              _("Error closing file \"%s\":\n\n"
+                "  %s"), this_case->case_file_name, strerror(errno));
 }
 
 /*----------------------------------------------------------------------------*/
