@@ -8,7 +8,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2011 EDF S.A.
+  Copyright (C) 1998-2012 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -129,11 +129,11 @@ fvm_triangulate_state_destroy(fvm_triangulate_state_t  *this_state);
 int
 fvm_triangulate_polygon(int                             dim,
                         int                             n_vertices,
-                        const fvm_coord_t               coords[],
-                        const fvm_lnum_t                parent_vertex_num[],
-                        const fvm_lnum_t                polygon_vertices[],
+                        const cs_coord_t                coords[],
+                        const cs_lnum_t                 parent_vertex_num[],
+                        const cs_lnum_t                 polygon_vertices[],
                         fvm_triangulate_def_t           mode,
-                        fvm_lnum_t                      triangle_vertices[],
+                        cs_lnum_t                       triangle_vertices[],
                         fvm_triangulate_state_t  *const state);
 
 /*----------------------------------------------------------------------------
@@ -158,11 +158,11 @@ fvm_triangulate_polygon(int                             dim,
  *----------------------------------------------------------------------------*/
 
 int
-fvm_triangulate_quadrangle(int                dim,
-                           const fvm_coord_t  coords[],
-                           const fvm_lnum_t   parent_vertex_num[],
-                           const fvm_lnum_t   quadrangle_vertices[],
-                           fvm_lnum_t         triangle_vertices[]);
+fvm_triangulate_quadrangle(int               dim,
+                           const cs_coord_t  coords[],
+                           const cs_lnum_t   parent_vertex_num[],
+                           const cs_lnum_t   quadrangle_vertices[],
+                           cs_lnum_t         triangle_vertices[]);
 
 /*----------------------------------------------------------------------------*/
 
