@@ -5,7 +5,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2011 EDF S.A.
+  Copyright (C) 1998-2012 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -24,9 +24,7 @@
 
 /*----------------------------------------------------------------------------*/
 
-#if defined(HAVE_CONFIG_H)
-#include "cs_config.h"
-#endif
+#include "cs_defs.h"
 
 /*----------------------------------------------------------------------------
  * Standard C library headers
@@ -38,25 +36,23 @@
 #include <stdlib.h>
 #include <string.h>
 
-/*----------------------------------------------------------------------------
- * BFT library headers
- *----------------------------------------------------------------------------*/
-
-#include <bft_mem.h>
-#include <bft_error.h>
-#include <bft_file.h>
-#include <bft_printf.h>
-#include <bft_timer.h>
+#if defined(HAVE_DLOPEN)
+#include <dlfcn.h>
+#endif
 
 /*----------------------------------------------------------------------------
  *  Local headers
  *----------------------------------------------------------------------------*/
 
-#include "fvm_config_defs.h"
-#include "fvm_defs.h"
+#include "bft_mem.h"
+#include "bft_error.h"
+#include "bft_printf.h"
+
 #include "fvm_nodal.h"
 #include "fvm_nodal_priv.h"
-#include "fvm_parall.h"
+
+#include "cs_file.h"
+#include "cs_timer.h"
 
 /*----------------------------------------------------------------------------
  *  Header for the current file
@@ -84,15 +80,25 @@ extern "C" {
  * Local Type Definitions
  *============================================================================*/
 
+/*============================================================================
+ * Local macro definitions
+ *============================================================================*/
+
+/* Directory name separator
+   (historically, '/' for Unix/Linux, '\' for Windows, ':' for Mac
+   but '/' should work for all on modern systems) */
+
+#define DIR_SEPARATOR '/'
+
 /*============================================================================
  * Static and constant variables
  *============================================================================*/
 
 /* Number and status of defined formats */
 
-static const int _fvm_writer_n_formats = 3;
+static const int _fvm_writer_n_formats = 4;
 
-static fvm_writer_format_t _fvm_writer_format_list[3] = {
+static fvm_writer_format_t _fvm_writer_format_list[4] = {
 
   /* Built-in EnSight Gold writer */
   {
@@ -101,6 +107,10 @@ static fvm_writer_format_t _fvm_writer_format_list[3] = {
     (  FVM_WRITER_FORMAT_HAS_POLYGON
      | FVM_WRITER_FORMAT_HAS_POLYHEDRON),
     FVM_WRITER_TRANSIENT_CONNECT,
+    0,                                 /* dynamic library count */
+    NULL,                              /* dynamic library */
+    NULL,                              /* dynamic library name */
+    NULL,                              /* dynamic library prefix */
     NULL,                              /* n_version_strings_func */
     NULL,                              /* version_string_func */
     fvm_to_ensight_init_writer,        /* init_func */
@@ -120,6 +130,10 @@ static fvm_writer_format_t _fvm_writer_format_list[3] = {
      | FVM_WRITER_FORMAT_HAS_POLYGON
      | FVM_WRITER_FORMAT_HAS_POLYHEDRON),
     FVM_WRITER_FIXED_MESH,
+    0,                                 /* dynamic library count */
+    NULL,                              /* dynamic library */
+    NULL,                              /* dynamic library name */
+    NULL,                              /* dynamic library prefix */
 #if defined(HAVE_MED)
     fvm_to_med_n_version_strings,      /* n_version_strings_func */
     fvm_to_med_version_string,         /* version_string_func */
@@ -150,6 +164,10 @@ static fvm_writer_format_t _fvm_writer_format_list[3] = {
     (  FVM_WRITER_FORMAT_USE_EXTERNAL
      | FVM_WRITER_FORMAT_HAS_POLYGON),
     FVM_WRITER_FIXED_MESH,
+    0,                                 /* dynamic library count */
+    NULL,                              /* dynamic library */
+    NULL,                              /* dynamic library name */
+    NULL,                              /* dynamic library prefix */
 #if defined(HAVE_CGNS)
     fvm_to_cgns_n_version_strings,     /* n_version_strings_func */
     fvm_to_cgns_version_string,        /* version_string_func */
@@ -171,6 +189,28 @@ static fvm_writer_format_t _fvm_writer_format_list[3] = {
     NULL,
     NULL
 #endif
+  },
+
+  /* MEDCoupling writer (plugin) */
+  {
+    "MEDCoupling",
+    "6.3 +",
+    (  FVM_WRITER_FORMAT_USE_EXTERNAL
+     | FVM_WRITER_FORMAT_HAS_POLYGON),
+    FVM_WRITER_FIXED_MESH,
+    0,                                 /* dynamic library count */
+    NULL,                              /* dynamic library */
+    "fvm_medcoupling",                 /* dynamic library name */
+    "fvm_to_medcoupling_",             /* dynamic library prefix */
+    NULL,
+    NULL,
+    NULL,
+    NULL,
+    NULL,
+    NULL,
+    NULL,
+    NULL,
+    NULL
   }
 
 };
@@ -235,6 +275,157 @@ _fvm_writer_option_list(const char  *const option_list)
   return ret_list;
 }
 
+#if defined(HAVE_DLOPEN)
+
+/*----------------------------------------------------------------------------
+ * Get a shared library function pointer for a writer plugin
+ *
+ * parameters:
+ *   wf               <-- pointer to writer format structure
+ *   name             <-- name of function symbol in library
+ *   errors_are_fatal <-- abort if true, silently ignore if false
+ *
+ * returns:
+ *   pointer to function in shared library
+ *----------------------------------------------------------------------------*/
+
+static void *
+_get_dl_function_pointer(fvm_writer_format_t  *wf,
+                         const char           *name,
+                         bool                  errors_are_fatal)
+{
+  void  *retval = NULL;
+  char  *error = NULL;
+
+  assert(wf != NULL);
+  assert(wf->dl_lib != NULL);
+
+  dlerror();    /* Clear any existing error */
+
+  if (wf->dl_name == NULL)
+    retval = dlsym(wf->dl_lib, name);
+  else {
+    char *_name;
+    BFT_MALLOC(_name, strlen(wf->dl_prefix) + strlen(name) + 1, char);
+    sprintf(_name, "%s%s", wf->dl_prefix, name);
+    retval = dlsym(wf->dl_lib, _name);
+    BFT_FREE(_name);
+  }
+  error = dlerror();
+
+  if (error != NULL && errors_are_fatal)
+    bft_error(__FILE__, __LINE__, 0,
+              _("Error calling dlsym: %s\n"), error);
+
+  return retval;
+}
+
+/*----------------------------------------------------------------------------
+ * Load Plugin writer.
+ *
+ * parameters:
+ *   wf <-> pointer to library format writer.
+ *----------------------------------------------------------------------------*/
+
+static void
+_load_plugin(fvm_writer_format_t  *wf)
+{
+  char  *lib_path = NULL;
+
+  /* Open from shared library */
+
+  BFT_MALLOC(lib_path, 3 + strlen(wf->dl_name) + 3 + 1, char);
+  sprintf(lib_path, "%s.so", wf->dl_name);
+
+  wf->dl_lib = dlopen(lib_path, RTLD_LAZY);
+
+  BFT_FREE(lib_path);
+
+  /* Increment reference count */
+
+  wf->dl_count += 1;
+
+  /* Load symbols from shared library */
+
+  if (wf->dl_lib == NULL)
+    bft_error(__FILE__, __LINE__, 0,
+              _("Error loading %s: %s."), lib_path, dlerror());
+
+  /* Function pointers need to be double-casted so as to first convert
+     a (void *) type to a memory address and then convert it back to the
+     original type. Otherwise, the compiler may issue a warning.
+     This is a valid ISO C construction. */
+
+  wf->n_version_strings_func = (fvm_writer_n_version_strings_t *) (intptr_t)
+    _get_dl_function_pointer(wf, "n_version_strings", false);
+
+  wf->version_string_func = (fvm_writer_version_string_t *) (intptr_t)
+    _get_dl_function_pointer(wf, "version_string", false);
+
+  wf->init_func = (fvm_writer_init_t *) (intptr_t)
+    _get_dl_function_pointer(wf, "init_writer", true);
+
+  wf->finalize_func = (fvm_writer_finalize_t *) (intptr_t)
+    _get_dl_function_pointer(wf, "finalize_writer", true);
+
+  wf->set_mesh_time_func = (fvm_writer_set_mesh_time_t *) (intptr_t)
+    _get_dl_function_pointer(wf, "set_mesh_time", true);
+
+  wf->needs_tesselation_func = (fvm_writer_needs_tesselation_t *) (intptr_t)
+    _get_dl_function_pointer(wf, "needs_tesselation", false);
+
+  wf->export_nodal_func = (fvm_writer_export_nodal_t *) (intptr_t)
+    _get_dl_function_pointer(wf, "export_nodal", true);
+
+  wf->export_field_func = (fvm_writer_export_field_t *) (intptr_t)
+    _get_dl_function_pointer(wf, "export_field", true);
+
+  wf->flush_func = (fvm_writer_flush_t *) (intptr_t)
+    _get_dl_function_pointer(wf, "flush", false);
+}
+
+/*----------------------------------------------------------------------------
+ * Unload Plugin writer.
+ *
+ * parameters:
+ *   wf <-> pointer to library format writer.
+ *----------------------------------------------------------------------------*/
+
+static void
+_close_plugin(fvm_writer_format_t  *wf)
+{
+  /* Open from shared library */
+
+  if (wf->dl_lib == NULL)
+    return;
+
+  if (dlclose(wf->dl_lib) != 0)
+    bft_error(__FILE__, __LINE__, 0,
+              _("Error unloading library: %s."), dlerror());
+
+  wf->dl_lib = NULL;
+
+  /* Decrement reference count */
+
+  wf->dl_count -= 1;
+
+  /* Reset pointers */
+
+  if (wf->dl_count == 0) {
+    wf->n_version_strings_func = NULL;
+    wf->version_string_func = NULL;
+    wf->init_func = NULL;
+    wf->finalize_func = NULL;
+    wf->set_mesh_time_func = NULL;
+    wf->needs_tesselation_func = NULL;
+    wf->export_nodal_func = NULL;
+    wf->export_field_func = NULL;
+    wf->flush_func = NULL;
+  }
+}
+
+#endif /* defined(HAVE_DLOPEN)*/
+
 /*============================================================================
  * Semi-private function definitions (prototypes in fvm_writer_priv.h)
  *============================================================================*/
@@ -282,25 +473,25 @@ fvm_writer_def_nodal_buf_size(const fvm_nodal_t  *this_nodal,
                               int                 n_slices,
                               int                 n_polyhedron_vertices_mean,
                               int                 n_polygon_vertices_mean,
-                              fvm_gnum_t         *n_g_vertices,
-                              fvm_gnum_t          n_g_elements_section[],
-                              fvm_gnum_t         *global_s_size,
-                              fvm_gnum_t         *global_connect_s_size)
+                              cs_gnum_t          *n_g_vertices,
+                              cs_gnum_t           n_g_elements_section[],
+                              cs_gnum_t          *global_s_size,
+                              cs_gnum_t          *global_connect_s_size)
 {
   int  i;
-  fvm_gnum_t  n_g_elements = 0;
-  fvm_gnum_t  n_g_cells = 0, n_g_faces = 0, n_g_edges = 0;
-  fvm_gnum_t  _n_g_vertices = 0;
+  cs_gnum_t   n_g_elements = 0;
+  cs_gnum_t   n_g_cells = 0, n_g_faces = 0, n_g_edges = 0;
+  cs_gnum_t   _n_g_vertices = 0;
 
-  fvm_gnum_t  connect_size = 0;
-  fvm_gnum_t  *_n_g_elements_section = NULL;
+  cs_gnum_t   connect_size = 0;
+  cs_gnum_t   *_n_g_elements_section = NULL;
 
   const fvm_nodal_section_t  *section = NULL;
 
   assert(this_nodal != NULL);
 
   if (n_g_elements_section == NULL)
-    BFT_MALLOC(_n_g_elements_section, this_nodal->n_sections, fvm_gnum_t);
+    BFT_MALLOC(_n_g_elements_section, this_nodal->n_sections, cs_gnum_t);
   else
     _n_g_elements_section = n_g_elements_section;
 
@@ -339,7 +530,7 @@ fvm_writer_def_nodal_buf_size(const fvm_nodal_t  *this_nodal,
 
   /* Define global slice size as (global_size / n_ranks) +  1 */
 
-  *global_s_size = FVM_MAX(n_g_cells, n_g_faces);
+  *global_s_size = CS_MAX(n_g_cells, n_g_faces);
 
   if (*global_s_size == 0)
     *global_s_size = n_g_edges;
@@ -362,10 +553,10 @@ fvm_writer_def_nodal_buf_size(const fvm_nodal_t  *this_nodal,
     case FVM_FACE_POLY:
     case FVM_CELL_POLY:
       if (section->type == FVM_FACE_POLY)
-        connect_size =   FVM_MIN(_n_g_elements_section[i], *global_s_size)
+        connect_size =   CS_MIN(_n_g_elements_section[i], *global_s_size)
                        * n_polygon_vertices_mean;
       else if (section->type == FVM_CELL_POLY)
-        connect_size =   FVM_MIN(_n_g_elements_section[i], *global_s_size)
+        connect_size =   CS_MIN(_n_g_elements_section[i], *global_s_size)
                        * n_polyhedron_vertices_mean;
 
       if (section->tesselation != NULL) {
@@ -378,7 +569,7 @@ fvm_writer_def_nodal_buf_size(const fvm_nodal_t  *this_nodal,
         for (i_type = 0; i_type < n_sub_types; i_type++) {
 
           int  stride;
-          fvm_lnum_t  n_sub_elements_max;
+          cs_lnum_t   n_sub_elements_max;
 
           fvm_element_t  sub_type = fvm_tesselation_sub_type(tesselation,
                                                              i_type);
@@ -391,8 +582,8 @@ fvm_writer_def_nodal_buf_size(const fvm_nodal_t  *this_nodal,
           stride = fvm_nodal_n_vertices_element[sub_type];
 
 
-          connect_size = FVM_MAX(connect_size,
-                                 (fvm_gnum_t)n_sub_elements_max * stride);
+          connect_size = CS_MAX(connect_size,
+                                (cs_gnum_t)n_sub_elements_max * stride);
 
         }
 
@@ -401,15 +592,15 @@ fvm_writer_def_nodal_buf_size(const fvm_nodal_t  *this_nodal,
       break;
       break;
     default:
-      connect_size =   FVM_MIN(_n_g_elements_section[i], *global_s_size)
+      connect_size =   CS_MIN(_n_g_elements_section[i], *global_s_size)
                      * section->stride;
     }
 
     /* Buffer size is that required for the entity type
        requiring the largest buffer size */
 
-    *global_connect_s_size = FVM_MAX(*global_connect_s_size,
-                                     connect_size);
+    *global_connect_s_size = CS_MAX(*global_connect_s_size,
+                                    connect_size);
 
   }
 
@@ -456,6 +647,8 @@ fvm_writer_get_format_id(const char  *format_name)
 
   if (strncmp(tmp_name, "ensight", 7) == 0)
     strcpy(closest_name, "EnSight Gold");
+  else if (strncmp(tmp_name, "medcoupling", 11) == 0)
+    strcpy(closest_name, "MEDCoupling");
   else if (strncmp(tmp_name, "med", 3) == 0)
     strcpy(closest_name, "MED");
   else if (strncmp(tmp_name, "cgns", 4) == 0)
@@ -516,8 +709,15 @@ fvm_writer_format_available(int format_index)
   int retval = 0;
 
   if (format_index >= 0 && format_index < _fvm_writer_n_formats) {
+
     if (_fvm_writer_format_list[format_index].init_func != NULL)
       retval = 1;
+
+#if defined(HAVE_DLOPEN)
+    else if (_fvm_writer_format_list[format_index].dl_name != NULL)
+      retval = 1;
+#endif
+
   }
   return retval;
 }
@@ -658,7 +858,6 @@ fvm_writer_init(const char             *name,
               _("Format type \"%s\" required for case \"%s\" is not available"),
               format_name, name);
 
-
   /* Create directory */
 
   if (path != NULL) {
@@ -668,13 +867,13 @@ fvm_writer_init(const char             *name,
     if (l > 0) {
       BFT_MALLOC(tmp_path, l + 2, char);
       strcpy(tmp_path, path);
-      if (tmp_path[l - 1] == FVM_DIR_SEPARATOR)
+      if (tmp_path[l - 1] == DIR_SEPARATOR)
         tmp_path[l - 1] = '\0';
-      if (bft_file_mkdir_default(path) == 1)
+      if (cs_file_mkdir_default(path) == 1)
         tmp_path[0] = '\0';
       else {
         l = strlen(tmp_path);
-        tmp_path[l]   = FVM_DIR_SEPARATOR;
+        tmp_path[l]   = DIR_SEPARATOR;
         tmp_path[l+1] = '\0';
       }
     }
@@ -694,6 +893,13 @@ fvm_writer_init(const char             *name,
 
   this_writer->format = &(_fvm_writer_format_list[i]);
 
+  /* Load plugin if required */
+
+#if defined(HAVE_DLOPEN)
+  if (this_writer->format->dl_name != NULL)
+    _load_plugin(this_writer->format);
+#endif
+
   if (path) {
     BFT_MALLOC(this_writer->path, strlen(path) + 1, char);
     strcpy(this_writer->path, path);
@@ -704,8 +910,8 @@ fvm_writer_init(const char             *name,
   this_writer->options = tmp_options;
   tmp_options = NULL;
 
-  this_writer->time_dep = FVM_MIN(time_dependency,
-                                  this_writer->format->max_time_dep);
+  this_writer->time_dep = CS_MIN(time_dependency,
+                                 this_writer->format->max_time_dep);
 
   this_writer->mesh_wtime = 0.;
   this_writer->mesh_cpu_time = 0.;
@@ -722,7 +928,7 @@ fvm_writer_init(const char             *name,
                                            tmp_path,
                                            this_writer->options,
                                            this_writer->time_dep,
-                                           fvm_parall_get_mpi_comm());
+                                           cs_glob_mpi_comm);
 #else
     this_writer->format_writer = init_func(name,
                                            tmp_path,
@@ -770,6 +976,13 @@ fvm_writer_finalize(fvm_writer_t  *this_writer)
   else
     this_writer->format_writer = NULL;
 
+  /* Unload plugin if required */
+
+#if defined(HAVE_DLOPEN)
+  if (this_writer->format->dl_lib != NULL)
+    _close_plugin(this_writer->format);
+#endif
+
   BFT_FREE(this_writer);
 
   return NULL;
@@ -938,8 +1151,8 @@ fvm_writer_export_nodal(fvm_writer_t        *this_writer,
   assert(this_writer != NULL);
   assert(this_writer->format != NULL);
 
-  w_start = bft_timer_wtime();
-  cpu_start = bft_timer_cpu_time();
+  w_start = cs_timer_wtime();
+  cpu_start = cs_timer_cpu_time();
 
   export_nodal_func = this_writer->format->export_nodal_func;
 
@@ -947,8 +1160,8 @@ fvm_writer_export_nodal(fvm_writer_t        *this_writer,
     export_nodal_func(this_writer->format_writer,
                       mesh);
 
-  w_end = bft_timer_wtime();
-  cpu_end = bft_timer_cpu_time();
+  w_end = cs_timer_wtime();
+  cpu_end = cs_timer_cpu_time();
 
   this_writer->mesh_wtime += (w_end - w_start);
   this_writer->mesh_cpu_time += (cpu_end - cpu_start);
@@ -985,10 +1198,10 @@ fvm_writer_export_field(fvm_writer_t                 *this_writer,
                         const char                   *name,
                         fvm_writer_var_loc_t          location,
                         int                           dimension,
-                        fvm_interlace_t               interlace,
+                        cs_interlace_t                interlace,
                         int                           n_parent_lists,
-                        const fvm_lnum_t              parent_num_shift[],
-                        fvm_datatype_t                datatype,
+                        const cs_lnum_t               parent_num_shift[],
+                        cs_datatype_t                 datatype,
                         int                           time_step,
                         double                        time_value,
                         const void             *const field_values[])
@@ -1000,8 +1213,8 @@ fvm_writer_export_field(fvm_writer_t                 *this_writer,
   assert(this_writer != NULL);
   assert(this_writer->format != NULL);
 
-  w_start = bft_timer_wtime();
-  cpu_start = bft_timer_cpu_time();
+  w_start = cs_timer_wtime();
+  cpu_start = cs_timer_cpu_time();
 
   export_field_func = this_writer->format->export_field_func;
 
@@ -1019,8 +1232,8 @@ fvm_writer_export_field(fvm_writer_t                 *this_writer,
                       time_value,
                       field_values);
 
-  w_end = bft_timer_wtime();
-  cpu_end = bft_timer_cpu_time();
+  w_end = cs_timer_wtime();
+  cpu_end = cs_timer_cpu_time();
 
   this_writer->field_wtime += (w_end - w_start);
   this_writer->field_cpu_time += (cpu_end - cpu_start);
