@@ -8,7 +8,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2011 EDF S.A.
+  Copyright (C) 1998-2012 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -194,9 +194,11 @@ fvm_writer_version_string(int format_index,
  *
  * Allowed options depend on what is applicable to a given format. Those
  * not relevant to a given writer are ignored. Possible options include:
- *   text                output text files
- *   binary              output binary files (default)
- *   big_endian          force binary files to big-endian
+ *   text                output text files (EnSight)
+ *   binary              output binary files (EnSight, default)
+ *   big_endian          force binary files to big-endian (EnSight)
+ *   adf                 use ADF file type (CGNS)
+ *   hdf5                use HDF5 file type (CGNS, default if available)
  *   discard_polygons    do not output polygons or related values
  *   discard_polyhedra   do not output polyhedra or related values
  *   divide_polygons     tesselate polygons with triangles
@@ -379,10 +381,10 @@ fvm_writer_export_field(fvm_writer_t                 *this_writer,
                         const char                   *name,
                         fvm_writer_var_loc_t          location,
                         int                           dimension,
-                        fvm_interlace_t               interlace,
+                        cs_interlace_t                interlace,
                         int                           n_parent_lists,
-                        const fvm_lnum_t              parent_num_shift[],
-                        fvm_datatype_t                datatype,
+                        const cs_lnum_t               parent_num_shift[],
+                        cs_datatype_t                 datatype,
                         int                           time_step,
                         double                        time_value,
                         const void             *const field_values[]);
