@@ -5,7 +5,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2011 EDF S.A.
+  Copyright (C) 1998-2012 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -24,9 +24,7 @@
 
 /*----------------------------------------------------------------------------*/
 
-#if defined(HAVE_CONFIG_H)
-#include "cs_config.h"
-#endif
+#include "cs_defs.h"
 
 /*----------------------------------------------------------------------------
  * Standard C library headers
@@ -44,19 +42,15 @@
 
 #include <bft_mem.h>
 #include <bft_error.h>
-#include <bft_file.h>
 #include <bft_printf.h>
 
 /*----------------------------------------------------------------------------
  *  Local headers
  *----------------------------------------------------------------------------*/
 
-#include "fvm_config_defs.h"
 #include "fvm_convert_array.h"
-#include "fvm_defs.h"
 #include "fvm_nodal.h"
 #include "fvm_nodal_priv.h"
-#include "fvm_parall.h"
 
 /*----------------------------------------------------------------------------
  *  Header for the current file
@@ -93,34 +87,34 @@ extern "C" {
 struct _fvm_writer_field_helper_t {
 
   int                         field_dim;       /* Field dimension */
-  fvm_interlace_t             interlace;       /* Field interlaced or not */
-  fvm_datatype_t              datatype;        /* Output datatype */
+  cs_interlace_t              interlace;       /* Field interlaced or not */
+  cs_datatype_t               datatype;        /* Output datatype */
   fvm_writer_var_loc_t        location;        /* Variable location */
 
-  fvm_gnum_t                  input_size;     /* Total input support size
+  cs_gnum_t                   input_size;     /* Total input support size
                                                  (field values / dimension) */
-  fvm_gnum_t                  output_size;     /* Total output support size
+  cs_gnum_t                   output_size;     /* Total output support size
                                                   (field values / dimension) */
 
   /* Local dimensions */
 
-  fvm_lnum_t  n_vertices;                  /* Local number of base vertices */
-  fvm_lnum_t  n_vertices_add;              /* Local number of added vertices */
-  fvm_lnum_t  max_vertices_add;            /* Maximum local number of added
+  cs_lnum_t   n_vertices;                  /* Local number of base vertices */
+  cs_lnum_t   n_vertices_add;              /* Local number of added vertices */
+  cs_lnum_t   max_vertices_add;            /* Maximum local number of added
                                               vertices per mesh section */
 
-  fvm_lnum_t  max_grouped_elements;        /* Maximum local number of elements
+  cs_lnum_t   max_grouped_elements;        /* Maximum local number of elements
                                               per grouped sections */
-  fvm_lnum_t  max_grouped_elements_out;    /* Maximum local number of output
+  cs_lnum_t   max_grouped_elements_out;    /* Maximum local number of output
                                               elements per grouped sections */
 
-  fvm_lnum_t  max_section_elements;        /* Maximum local number of elements
+  cs_lnum_t   max_section_elements;        /* Maximum local number of elements
                                               per section */
-  fvm_lnum_t  max_section_elements_out;    /* Maximum local number of
+  cs_lnum_t   max_section_elements_out;    /* Maximum local number of
                                               output elements per section
                                               (= max_section_elements if
                                               no tesselation is used) */
-  fvm_lnum_t  n_sub_elements_max;          /* Maximum number of sub-elements
+  cs_lnum_t   n_sub_elements_max;          /* Maximum number of sub-elements
                                               per element (1 if no tesselation
                                               is used, global maximum in
                                               parallel mode) */
@@ -133,7 +127,7 @@ struct _fvm_writer_field_helper_t {
 
   /* State related fields */
 
-  fvm_lnum_t                  start_id;      /* Local section start */
+  cs_lnum_t                   start_id;      /* Local section start */
   const fvm_writer_section_t *last_section;  /* Current section pointer */
 
   int         last_added_vertex_section;     /* Index of current added vertex
@@ -143,19 +137,19 @@ struct _fvm_writer_field_helper_t {
 
   /* Global dimensions */
 
-  fvm_gnum_t  n_vertices_g;                /* Global number of base vertices */
-  fvm_gnum_t  n_vertices_add_g;            /* Global number of added vertices */
-  fvm_gnum_t  max_vertices_add_g;          /* Maximum global number of added
+  cs_gnum_t   n_vertices_g;                /* Global number of base vertices */
+  cs_gnum_t   n_vertices_add_g;            /* Global number of added vertices */
+  cs_gnum_t   max_vertices_add_g;          /* Maximum global number of added
                                               vertices per mesh section */
 
-  fvm_gnum_t  max_grouped_elements_g;      /* Maximum global number of elements
+  cs_gnum_t   max_grouped_elements_g;      /* Maximum global number of elements
                                               per grouped sections */
-  fvm_gnum_t  max_grouped_elements_out_g;  /* Maximum global number of output
+  cs_gnum_t   max_grouped_elements_out_g;  /* Maximum global number of output
                                               elements per grouped sections */
 
-  fvm_gnum_t  max_section_elements_g;      /* Maximum global number of elements
+  cs_gnum_t   max_section_elements_g;      /* Maximum global number of elements
                                               per section */
-  fvm_gnum_t  max_section_elements_out_g;  /* Maximum global number of
+  cs_gnum_t   max_section_elements_out_g;  /* Maximum global number of
                                               output elements per section
                                               (= max_section_elements_g if
                                               no tesselation is used) */
@@ -167,8 +161,8 @@ struct _fvm_writer_field_helper_t {
   size_t          local_index_size;         /* Max. values in local index */
   size_t          global_index_size_g;      /* Max. values in global index */
 
-  fvm_lnum_t  *local_idx;                   /* Local tesselation index */
-  fvm_gnum_t  *global_idx;                  /* Global tesselation index */
+  cs_lnum_t   *local_idx;                   /* Local tesselation index */
+  cs_gnum_t   *global_idx;                  /* Global tesselation index */
 
   void *local_buffer;                       /* Local buffer (parallel mode) */
 
@@ -179,7 +173,7 @@ struct _fvm_writer_field_helper_t {
   fvm_gather_slice_t         *slice;        /* Slice structure for
                                                partial gathers */
 
-  fvm_gnum_t                  start_num_g;  /* Global section start */
+  cs_gnum_t                   start_num_g;  /* Global section start */
 
 #endif
 };
@@ -228,12 +222,12 @@ _compare_sections(const void *s1_p,
 
 static inline void
 _limit_end_id_g(const fvm_nodal_section_t  *this_section,
-                fvm_lnum_t                 *end_id,
-                fvm_gnum_t                  global_num_end)
+                cs_lnum_t                  *end_id,
+                cs_gnum_t                   global_num_end)
 {
   int last_id;
 
-  const fvm_gnum_t *global_element_num
+  const cs_gnum_t *global_element_num
     = fvm_io_num_get_global_num(this_section->global_element_num);
 
   for (last_id = *end_id - 1;
@@ -279,10 +273,10 @@ _field_helper_step_eg(fvm_writer_field_helper_t   *helper,
                       const fvm_writer_section_t  *export_section,
                       int                          src_dim,
                       int                          src_dim_shift,
-                      fvm_interlace_t              src_interlace,
+                      cs_interlace_t               src_interlace,
                       int                          n_parent_lists,
-                      const fvm_lnum_t             parent_num_shift[],
-                      fvm_datatype_t               datatype,
+                      const cs_lnum_t              parent_num_shift[],
+                      cs_datatype_t                datatype,
                       const void            *const field_values[],
                       void                        *output_buffer,
                       size_t                       output_buffer_size,
@@ -292,18 +286,18 @@ _field_helper_step_eg(fvm_writer_field_helper_t   *helper,
 
   int  retval = 0;
 
-  fvm_gnum_t  slice_output_size = 0;
-  fvm_gnum_t  end_num_g = 0;
+  cs_gnum_t   slice_output_size = 0;
+  cs_gnum_t   end_num_g = 0;
 
   int  stride = 1;
-  fvm_lnum_t  num_shift = 0;
+  cs_lnum_t   num_shift = 0;
 
   const fvm_nodal_section_t  *section = export_section->section;
-  const fvm_lnum_t  *parent_entity_num = section->parent_element_num;
+  const cs_lnum_t   *parent_entity_num = section->parent_element_num;
 
   /* If output data is interlaced, set stride */
 
-  if (h->field_dim > 1 && h->interlace == FVM_INTERLACE)
+  if (h->field_dim > 1 && h->interlace == CS_INTERLACE)
     stride = h->field_dim;
 
   if (n_parent_lists == 0)
@@ -329,7 +323,7 @@ _field_helper_step_eg(fvm_writer_field_helper_t   *helper,
                                          output_buffer_base_size,
                                          h->comm);
       if (export_section->type != section->type)
-        BFT_MALLOC(h->global_idx, output_buffer_base_size + 1, fvm_gnum_t);
+        BFT_MALLOC(h->global_idx, output_buffer_base_size + 1, cs_gnum_t);
     }
 
     else /* if we are here, we have changed dimension index, not section */
@@ -373,7 +367,7 @@ _field_helper_step_eg(fvm_writer_field_helper_t   *helper,
 
       fvm_gather_array(h->local_buffer,
                        output_buffer,
-                       fvm_datatype_to_mpi[h->datatype],
+                       cs_datatype_to_mpi[h->datatype],
                        stride,
                        section->global_element_num,
                        h->comm,
@@ -391,9 +385,9 @@ _field_helper_step_eg(fvm_writer_field_helper_t   *helper,
 
     else if (export_section->type != section->type) {
 
-      fvm_lnum_t  end_id;
-      fvm_gnum_t  local_buffer_base_size = h->local_buffer_size / stride;
-      fvm_gnum_t  global_s_size_loc = output_buffer_size;
+      cs_lnum_t   end_id;
+      cs_gnum_t   local_buffer_base_size = h->local_buffer_size / stride;
+      cs_gnum_t   global_s_size_loc = output_buffer_size;
 
       const fvm_tesselation_t  *tesselation = section->tesselation;
 
@@ -471,14 +465,14 @@ _field_helper_step_eg(fvm_writer_field_helper_t   *helper,
                                  export_section->type,
                                  h->start_id,
                                  end_id,
-                                 fvm_datatype_size[h->datatype] * stride,
+                                 cs_datatype_size[h->datatype] * stride,
                                  h->local_buffer);
 
       /* Now gather distributed values */
 
       fvm_gather_indexed(h->local_buffer,
                          output_buffer,
-                         fvm_datatype_to_mpi[h->datatype],
+                         cs_datatype_to_mpi[h->datatype],
                          h->local_idx,
                          section->global_element_num,
                          h->comm,
@@ -550,10 +544,10 @@ _field_helper_step_el(fvm_writer_field_helper_t   *helper,
                       const fvm_writer_section_t  *export_section,
                       int                          src_dim,
                       int                          src_dim_shift,
-                      fvm_interlace_t              src_interlace,
+                      cs_interlace_t               src_interlace,
                       int                          n_parent_lists,
-                      const fvm_lnum_t             parent_num_shift[],
-                      fvm_datatype_t               datatype,
+                      const cs_lnum_t              parent_num_shift[],
+                      cs_datatype_t                datatype,
                       const void            *const field_values[],
                       void                        *output_buffer,
                       size_t                       output_buffer_size,
@@ -563,20 +557,20 @@ _field_helper_step_el(fvm_writer_field_helper_t   *helper,
 
   int  retval = 0;
 
-  fvm_gnum_t  slice_output_size = 0;
+  cs_gnum_t   slice_output_size = 0;
 
   int  stride = 1;
-  fvm_lnum_t  end_id = 0;
-  fvm_lnum_t  num_shift = 0;
+  cs_lnum_t   end_id = 0;
+  cs_lnum_t   num_shift = 0;
 
   size_t output_buffer_base_size = output_buffer_size;
 
   const fvm_nodal_section_t  *section = export_section->section;
-  const fvm_lnum_t  *parent_entity_num = section->parent_element_num;
+  const cs_lnum_t   *parent_entity_num = section->parent_element_num;
 
   /* If output data is interlaced, set stride */
 
-  if (h->field_dim > 1 && h->interlace == FVM_INTERLACE) {
+  if (h->field_dim > 1 && h->interlace == CS_INTERLACE) {
     stride = h->field_dim;
     output_buffer_base_size /= h->field_dim;
   }
@@ -594,8 +588,8 @@ _field_helper_step_el(fvm_writer_field_helper_t   *helper,
 
     if (export_section->type == section->type) {
 
-      end_id = FVM_MIN(h->start_id + (fvm_lnum_t)output_buffer_base_size,
-                       section->n_elements);
+      end_id = CS_MIN(h->start_id + (cs_lnum_t)output_buffer_base_size,
+                      section->n_elements);
 
       fvm_convert_array(src_dim,
                         src_dim_shift,
@@ -620,14 +614,14 @@ _field_helper_step_el(fvm_writer_field_helper_t   *helper,
 
     else if (export_section->type != section->type) {
 
-      fvm_lnum_t  n_sub_elements_max = 0;
+      cs_lnum_t   n_sub_elements_max = 0;
 
       const fvm_tesselation_t  *tesselation = section->tesselation;
-      const fvm_lnum_t *sub_element_idx
+      const cs_lnum_t *sub_element_idx
         = fvm_tesselation_sub_elt_index(section->tesselation,
                                         export_section->type);
 
-      fvm_lnum_t  output_buffer_size_min
+      cs_lnum_t   output_buffer_size_min
         = fvm_tesselation_n_sub_elements(section->tesselation,
                                          export_section->type);
 
@@ -636,9 +630,9 @@ _field_helper_step_el(fvm_writer_field_helper_t   *helper,
                                       NULL,
                                       &n_sub_elements_max);
 
-      output_buffer_size_min = FVM_MIN(output_buffer_size_min,
-                                       (  n_sub_elements_max
-                                        * FVM_WRITER_MIN_SUB_ELEMENTS));
+      output_buffer_size_min = CS_MIN(output_buffer_size_min,
+                                      (  n_sub_elements_max
+                                       * FVM_WRITER_MIN_SUB_ELEMENTS));
 
       /* The buffer passed to this function should not be too small,
          as its size should have been computed in a consistent manner,
@@ -657,11 +651,11 @@ _field_helper_step_el(fvm_writer_field_helper_t   *helper,
 
       for (end_id = h->start_id;
            (   end_id < section->n_elements
-            &&  (sub_element_idx[end_id] <   (fvm_lnum_t)output_buffer_base_size
+            &&  (sub_element_idx[end_id] <   (cs_lnum_t)output_buffer_base_size
                                            + sub_element_idx[h->start_id]));
            end_id++);
       if (  sub_element_idx[end_id] - sub_element_idx[h->start_id]
-          > (fvm_lnum_t)output_buffer_base_size)
+          > (cs_lnum_t)output_buffer_base_size)
         end_id--;
 
       /* Extract data from parent; note that the following call to
@@ -688,7 +682,7 @@ _field_helper_step_el(fvm_writer_field_helper_t   *helper,
                                  export_section->type,
                                  h->start_id,
                                  end_id,
-                                 fvm_datatype_size[h->datatype] * stride,
+                                 cs_datatype_size[h->datatype] * stride,
                                  output_buffer);
 
       slice_output_size = (  sub_element_idx[end_id]
@@ -754,10 +748,10 @@ _field_helper_step_ng(fvm_writer_field_helper_t   *helper,
                       const fvm_nodal_t           *mesh,
                       int                          src_dim,
                       int                          src_dim_shift,
-                      fvm_interlace_t              src_interlace,
+                      cs_interlace_t               src_interlace,
                       int                          n_parent_lists,
-                      const fvm_lnum_t             parent_num_shift[],
-                      fvm_datatype_t               datatype,
+                      const cs_lnum_t              parent_num_shift[],
+                      cs_datatype_t                datatype,
                       const void            *const field_values[],
                       void                        *output_buffer,
                       size_t                       output_buffer_size,
@@ -767,17 +761,17 @@ _field_helper_step_ng(fvm_writer_field_helper_t   *helper,
 
   int  retval = 0;
 
-  fvm_gnum_t  slice_output_size = 0;
-  fvm_gnum_t  end_num_g = 0;
+  cs_gnum_t   slice_output_size = 0;
+  cs_gnum_t   end_num_g = 0;
 
   int  stride = 1;
 
-  const fvm_lnum_t  *parent_entity_num = mesh->parent_vertex_num;
+  const cs_lnum_t   *parent_entity_num = mesh->parent_vertex_num;
   const fvm_io_num_t  *global_entity_num = mesh->global_vertex_num;
 
   /* If output data is interlaced, set stride */
 
-  if (h->field_dim > 1 && h->interlace == FVM_INTERLACE)
+  if (h->field_dim > 1 && h->interlace == CS_INTERLACE)
     stride = h->field_dim;
 
   /* When at the beginning of a slice, setup state */
@@ -842,7 +836,7 @@ _field_helper_step_ng(fvm_writer_field_helper_t   *helper,
 
     fvm_gather_array(h->local_buffer,
                      output_buffer,
-                     fvm_datatype_to_mpi[h->datatype],
+                     cs_datatype_to_mpi[h->datatype],
                      stride,
                      global_entity_num,
                      h->comm,
@@ -860,7 +854,7 @@ _field_helper_step_ng(fvm_writer_field_helper_t   *helper,
 
   else if (h->last_added_vertex_section < h->n_added_vertex_sections) {
 
-    fvm_gnum_t n_g_vertices_section;
+    cs_gnum_t n_g_vertices_section;
 
     const fvm_nodal_section_t  *section
       = mesh->sections[h->added_vertex_section[h->last_added_vertex_section]];
@@ -873,8 +867,8 @@ _field_helper_step_ng(fvm_writer_field_helper_t   *helper,
 
     /* Interpolate values if both source and destination are floating point */
 
-    if (   (h->datatype == FVM_DOUBLE || h->datatype == FVM_FLOAT)
-        && (datatype == FVM_DOUBLE || datatype == FVM_FLOAT)) {
+    if (   (h->datatype == CS_DOUBLE || h->datatype == CS_FLOAT)
+        && (datatype == CS_DOUBLE || datatype == CS_FLOAT)) {
 
       /* Build a new slice if changing section */
 
@@ -900,7 +894,7 @@ _field_helper_step_ng(fvm_writer_field_helper_t   *helper,
 
         if (h->start_num_g == 1) {
 
-          fvm_lnum_t n_vertices_section
+          cs_lnum_t n_vertices_section
             = fvm_tesselation_n_vertices_add(section->tesselation);
 
           fvm_tesselation_vertex_values(section->tesselation,
@@ -924,7 +918,7 @@ _field_helper_step_ng(fvm_writer_field_helper_t   *helper,
 
         fvm_gather_array(h->local_buffer,
                          output_buffer,
-                         fvm_datatype_to_mpi[h->datatype],
+                         cs_datatype_to_mpi[h->datatype],
                          stride,
                          global_entity_num,
                          h->comm,
@@ -951,7 +945,7 @@ _field_helper_step_ng(fvm_writer_field_helper_t   *helper,
         size_t ii;
         size_t slice_output_size_c = slice_output_size * stride;
 
-        slice_output_size_c *= fvm_datatype_size[datatype];
+        slice_output_size_c *= cs_datatype_size[datatype];
         for (ii = 0; ii < slice_output_size_c; ii++)
           output_buffer_v[ii] = 0.;
 
@@ -1033,10 +1027,10 @@ _field_helper_step_nl(fvm_writer_field_helper_t   *helper,
                       const fvm_nodal_t           *mesh,
                       int                          src_dim,
                       int                          src_dim_shift,
-                      fvm_interlace_t              src_interlace,
+                      cs_interlace_t               src_interlace,
                       int                          n_parent_lists,
-                      const fvm_lnum_t             parent_num_shift[],
-                      fvm_datatype_t               datatype,
+                      const cs_lnum_t              parent_num_shift[],
+                      cs_datatype_t                datatype,
                       const void            *const field_values[],
                       void                        *output_buffer,
                       size_t                       output_buffer_size,
@@ -1046,16 +1040,16 @@ _field_helper_step_nl(fvm_writer_field_helper_t   *helper,
 
   int  retval = 0;
 
-  fvm_gnum_t  slice_output_size = 0;
-  fvm_lnum_t  end_id = 0;
+  cs_gnum_t   slice_output_size = 0;
+  cs_lnum_t   end_id = 0;
 
   int  stride = 1;
 
-  const fvm_lnum_t  *parent_entity_num = mesh->parent_vertex_num;
+  const cs_lnum_t   *parent_entity_num = mesh->parent_vertex_num;
 
   /* If output data is interlaced, set stride */
 
-  if (h->field_dim > 1 && h->interlace == FVM_INTERLACE)
+  if (h->field_dim > 1 && h->interlace == CS_INTERLACE)
     stride = h->field_dim;
 
   /* Main vertices */
@@ -1063,10 +1057,10 @@ _field_helper_step_nl(fvm_writer_field_helper_t   *helper,
 
   if (h->start_id < mesh->n_vertices) {
 
-    fvm_lnum_t n_entities = mesh->n_vertices;
+    cs_lnum_t n_entities = mesh->n_vertices;
 
     end_id = h->start_id + (output_buffer_size / stride);
-    end_id = FVM_MIN(end_id, n_entities);
+    end_id = CS_MIN(end_id, n_entities);
 
     fvm_convert_array(src_dim,
                       src_dim_shift,
@@ -1095,7 +1089,7 @@ _field_helper_step_nl(fvm_writer_field_helper_t   *helper,
 
     size_t ii;
     size_t slice_output_size_c;
-    fvm_lnum_t n_vertices_section;
+    cs_lnum_t n_vertices_section;
 
     const fvm_nodal_section_t  *section
       = mesh->sections[h->added_vertex_section[h->last_added_vertex_section]];
@@ -1113,8 +1107,8 @@ _field_helper_step_nl(fvm_writer_field_helper_t   *helper,
     slice_output_size = end_id - h->start_id;
     slice_output_size_c = slice_output_size * stride;
 
-    if (   (h->datatype == FVM_DOUBLE || h->datatype == FVM_FLOAT)
-        && (datatype == FVM_DOUBLE || datatype == FVM_FLOAT)) {
+    if (   (h->datatype == CS_DOUBLE || h->datatype == CS_FLOAT)
+        && (datatype == CS_DOUBLE || datatype == CS_FLOAT)) {
 
       fvm_tesselation_vertex_values(section->tesselation,
                                     src_dim,
@@ -1134,7 +1128,7 @@ _field_helper_step_nl(fvm_writer_field_helper_t   *helper,
     }
     else {
       unsigned char *output_buffer_v = output_buffer;
-      slice_output_size_c *= fvm_datatype_size[datatype];
+      slice_output_size_c *= cs_datatype_size[datatype];
       for (ii = 0; ii < slice_output_size_c; ii++)
         output_buffer_v[ii] = 0.;
     }
@@ -1213,8 +1207,8 @@ fvm_writer_export_list(const fvm_nodal_t  *mesh,
   fvm_element_t sub_type[FVM_TESSELATION_N_SUB_TYPES_MAX];
   fvm_writer_section_t *export_list = NULL;
 
-  fvm_lnum_t  num_shift = 0;
-  fvm_gnum_t  extra_vertex_base = fvm_nodal_n_g_vertices(mesh) + 1;
+  cs_lnum_t   num_shift = 0;
+  cs_gnum_t   extra_vertex_base = fvm_nodal_n_g_vertices(mesh) + 1;
 
   /* Initial count and allocation */
 
@@ -1371,8 +1365,8 @@ fvm_writer_field_helper_t *
 fvm_writer_field_helper_create(const fvm_nodal_t          *mesh,
                                const fvm_writer_section_t *section_list,
                                int                         field_dim,
-                               fvm_interlace_t             interlace,
-                               fvm_datatype_t              datatype,
+                               cs_interlace_t              interlace,
+                               cs_datatype_t               datatype,
                                fvm_writer_var_loc_t        location)
 {
   fvm_writer_field_helper_t *h = NULL;
@@ -1447,16 +1441,16 @@ fvm_writer_field_helper_create(const fvm_nodal_t          *mesh,
 
     const fvm_writer_section_t *export_section = section_list;
 
-    fvm_lnum_t n_grouped_elements = 0;
-    fvm_lnum_t n_grouped_elements_out = 0;
+    cs_lnum_t n_grouped_elements = 0;
+    cs_lnum_t n_grouped_elements_out = 0;
 
     while (export_section != NULL) {
 
       const fvm_nodal_section_t *section = export_section->section;
 
-      fvm_lnum_t n_elements;
-      fvm_lnum_t n_sub_elements;
-      fvm_lnum_t n_sub_elements_max = 1;
+      cs_lnum_t n_elements;
+      cs_lnum_t n_sub_elements;
+      cs_lnum_t n_sub_elements_max = 1;
 
       if (export_section->continues_previous == false) {
         n_grouped_elements = 0;
@@ -1485,18 +1479,18 @@ fvm_writer_field_helper_create(const fvm_nodal_t          *mesh,
       h->input_size  += section->n_elements;
       h->output_size += n_sub_elements;
 
-      h->max_grouped_elements     = FVM_MAX(h->max_grouped_elements,
-                                            n_grouped_elements);
-      h->max_grouped_elements_out = FVM_MAX(h->max_grouped_elements_out,
-                                            n_grouped_elements_out);
+      h->max_grouped_elements     = CS_MAX(h->max_grouped_elements,
+                                           n_grouped_elements);
+      h->max_grouped_elements_out = CS_MAX(h->max_grouped_elements_out,
+                                           n_grouped_elements_out);
 
-      h->max_section_elements     = FVM_MAX(h->max_section_elements,
-                                            section->n_elements);
-      h->max_section_elements_out = FVM_MAX(h->max_section_elements_out,
-                                            n_sub_elements);
+      h->max_section_elements     = CS_MAX(h->max_section_elements,
+                                           section->n_elements);
+      h->max_section_elements_out = CS_MAX(h->max_section_elements_out,
+                                           n_sub_elements);
 
-      h->n_sub_elements_max = FVM_MAX(h->n_sub_elements_max,
-                                      n_sub_elements_max);
+      h->n_sub_elements_max = CS_MAX(h->n_sub_elements_max,
+                                     n_sub_elements_max);
 
       /* continue with next section */
 
@@ -1551,14 +1545,14 @@ fvm_writer_field_helper_create(const fvm_nodal_t          *mesh,
 
         if (section->type == FVM_CELL_POLY) {
 
-          fvm_lnum_t n_vertices_add
+          cs_lnum_t n_vertices_add
             = fvm_tesselation_n_vertices_add(section->tesselation);
 
           h->output_size += n_vertices_add;
 
           h->n_vertices_add += n_vertices_add;
-          h->max_vertices_add = FVM_MAX(h->max_vertices_add,
-                                        n_vertices_add);
+          h->max_vertices_add = CS_MAX(h->max_vertices_add,
+                                       n_vertices_add);
 
           h->added_vertex_section[jj] = ii;
           jj++;
@@ -1643,16 +1637,16 @@ fvm_writer_field_helper_init_g(fvm_writer_field_helper_t   *helper,
 
     const fvm_writer_section_t *export_section = section_list;
 
-    fvm_gnum_t n_grouped_elements_g = 0;
-    fvm_gnum_t n_grouped_elements_out_g = 0;
+    cs_gnum_t n_grouped_elements_g = 0;
+    cs_gnum_t n_grouped_elements_out_g = 0;
 
     while (export_section != NULL) {
 
       const fvm_nodal_section_t *section = export_section->section;
 
-      fvm_gnum_t n_g_elements;
-      fvm_gnum_t n_g_sub_elements;
-      fvm_lnum_t n_sub_elements_max = 1;
+      cs_gnum_t n_g_elements;
+      cs_gnum_t n_g_sub_elements;
+      cs_lnum_t n_sub_elements_max = 1;
 
       size_t local_buffer_size = section->n_elements;
       size_t local_index_size = 0;
@@ -1689,34 +1683,34 @@ fvm_writer_field_helper_init_g(fvm_writer_field_helper_t   *helper,
       h->input_size += n_g_elements;
       h->output_size += n_g_sub_elements;
 
-      h->max_grouped_elements_g     = FVM_MAX(h->max_grouped_elements_g,
-                                              n_grouped_elements_g);
-      h->max_grouped_elements_out_g = FVM_MAX(h->max_grouped_elements_out_g,
-                                              n_grouped_elements_out_g);
+      h->max_grouped_elements_g     = CS_MAX(h->max_grouped_elements_g,
+                                             n_grouped_elements_g);
+      h->max_grouped_elements_out_g = CS_MAX(h->max_grouped_elements_out_g,
+                                             n_grouped_elements_out_g);
 
-      h->max_section_elements_g     = FVM_MAX(h->max_section_elements_g,
-                                              n_g_elements);
-      h->max_section_elements_out_g = FVM_MAX(h->max_section_elements_out_g,
-                                              n_g_sub_elements);
+      h->max_section_elements_g     = CS_MAX(h->max_section_elements_g,
+                                             n_g_elements);
+      h->max_section_elements_out_g = CS_MAX(h->max_section_elements_out_g,
+                                             n_g_sub_elements);
 
       /* Update buffer sizes */
 
-      h->local_buffer_size = FVM_MAX(h->local_buffer_size,
-                                     (size_t)section->n_elements);
+      h->local_buffer_size = CS_MAX(h->local_buffer_size,
+                                    (size_t)section->n_elements);
 
       if (export_section->type != section->type) { /* Tesselated section */
-        local_buffer_size = FVM_MAX(section->n_elements,
-                                    (  n_sub_elements_max
-                                     * FVM_WRITER_MIN_SUB_ELEMENTS));
+        local_buffer_size = CS_MAX(section->n_elements,
+                                   (  n_sub_elements_max
+                                    * FVM_WRITER_MIN_SUB_ELEMENTS));
         local_index_size = section->n_elements + 1;
         global_index_size_g = n_g_elements + 1;
       }
-      h->local_buffer_size = FVM_MAX(h->local_buffer_size,
-                                     local_buffer_size);
-      h->local_index_size = FVM_MAX(h->local_index_size,
-                                    local_index_size);
-      h->global_index_size_g = FVM_MAX(h->global_index_size_g,
-                                       global_index_size_g);
+      h->local_buffer_size = CS_MAX(h->local_buffer_size,
+                                    local_buffer_size);
+      h->local_index_size = CS_MAX(h->local_index_size,
+                                   local_index_size);
+      h->global_index_size_g = CS_MAX(h->global_index_size_g,
+                                      global_index_size_g);
 
       /* continue with next section */
 
@@ -1743,7 +1737,7 @@ fvm_writer_field_helper_init_g(fvm_writer_field_helper_t   *helper,
 
       for (ii = 0; ii < h->n_added_vertex_sections; ii++) {
 
-        fvm_gnum_t n_g_vertices_add;
+        cs_gnum_t n_g_vertices_add;
 
         const fvm_nodal_section_t  *section
           = mesh->sections[h->added_vertex_section
@@ -1755,13 +1749,13 @@ fvm_writer_field_helper_init_g(fvm_writer_field_helper_t   *helper,
         h->output_size += n_g_vertices_add;
 
         h->n_vertices_add_g += n_g_vertices_add;
-        h->max_vertices_add_g = FVM_MAX(h->max_vertices_add_g,
-                                        n_g_vertices_add);
+        h->max_vertices_add_g = CS_MAX(h->max_vertices_add_g,
+                                       n_g_vertices_add);
 
         /* Update buffer sizes */
 
-        h->local_buffer_size = FVM_MAX(h->local_buffer_size,
-                                       (size_t)section->n_elements);
+        h->local_buffer_size = CS_MAX(h->local_buffer_size,
+                                      (size_t)section->n_elements);
 
       }
     }
@@ -1771,7 +1765,7 @@ fvm_writer_field_helper_init_g(fvm_writer_field_helper_t   *helper,
   /* With interlaced multidimensional arrays,
      multiply local buffer size by the stride */
 
-  if (h->field_dim > 1 && h->interlace == FVM_INTERLACE) {
+  if (h->field_dim > 1 && h->interlace == CS_INTERLACE) {
     h->local_buffer_size *= h->field_dim;
   }
 
@@ -1798,11 +1792,11 @@ fvm_writer_field_helper_init_g(fvm_writer_field_helper_t   *helper,
   }
 
   BFT_MALLOC(h->local_buffer,
-             h->local_buffer_size*fvm_datatype_size[h->datatype],
+             h->local_buffer_size*cs_datatype_size[h->datatype],
              char);
 
   if (h->n_sub_elements_max > 1)
-    BFT_MALLOC(h->local_idx, h->local_index_size, fvm_lnum_t);
+    BFT_MALLOC(h->local_idx, h->local_index_size, cs_lnum_t);
 
 }
 
@@ -1858,11 +1852,11 @@ fvm_writer_field_helper_get_size(const fvm_writer_field_helper_t  *helper,
 
     if (h->n_sub_elements_max > 1) {
       min_size = h->n_sub_elements_max * FVM_WRITER_MIN_SUB_ELEMENTS;
-      min_size = FVM_MIN(min_size, h->output_size);
+      min_size = CS_MIN(min_size, h->output_size);
     }
 
     if (h->output_size > 0)
-      min_size = FVM_MAX(FVM_WRITER_MIN_ELEMENTS, min_size);
+      min_size = CS_MAX(FVM_WRITER_MIN_ELEMENTS, min_size);
 
     if (min_size > h->output_size)
       min_size = h->output_size;
@@ -1870,7 +1864,7 @@ fvm_writer_field_helper_get_size(const fvm_writer_field_helper_t  *helper,
     /* With interlaced multidimensional arrays,
        multiply buffer sizes by the stride */
 
-    if (h->field_dim > 1 && h->interlace == FVM_INTERLACE)
+    if (h->field_dim > 1 && h->interlace == CS_INTERLACE)
       min_size *= h->field_dim;
 
     *min_output_buffer_size = min_size;
@@ -1905,7 +1899,7 @@ fvm_writer_field_helper_field_dim(const fvm_writer_field_helper_t  *helper)
  *   output datatype associated with helper
  *----------------------------------------------------------------------------*/
 
-fvm_datatype_t
+cs_datatype_t
 fvm_writer_field_helper_datatype(const fvm_writer_field_helper_t  *helper)
 {
   return helper->datatype;
@@ -1944,10 +1938,10 @@ fvm_writer_field_helper_step_e(fvm_writer_field_helper_t   *helper,
                                const fvm_writer_section_t  *export_section,
                                int                          src_dim,
                                int                          src_dim_shift,
-                               fvm_interlace_t              src_interlace,
+                               cs_interlace_t               src_interlace,
                                int                          n_parent_lists,
-                               const fvm_lnum_t             parent_num_shift[],
-                               fvm_datatype_t               datatype,
+                               const cs_lnum_t              parent_num_shift[],
+                               cs_datatype_t                datatype,
                                const void            *const field_values[],
                                void                        *output_buffer,
                                size_t                       output_buffer_size,
@@ -2023,10 +2017,10 @@ fvm_writer_field_helper_step_n(fvm_writer_field_helper_t   *helper,
                                const fvm_nodal_t           *mesh,
                                int                          src_dim,
                                int                          src_dim_shift,
-                               fvm_interlace_t              src_interlace,
+                               cs_interlace_t               src_interlace,
                                int                          n_parent_lists,
-                               const fvm_lnum_t             parent_num_shift[],
-                               fvm_datatype_t               datatype,
+                               const cs_lnum_t              parent_num_shift[],
+                               cs_datatype_t                datatype,
                                const void            *const field_values[],
                                void                        *output_buffer,
                                size_t                       output_buffer_size,
