@@ -8,7 +8,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2011 EDF S.A.
+  Copyright (C) 1998-2012 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -118,10 +118,10 @@ typedef void
                              const char             *name,
                              fvm_writer_var_loc_t    location,
                              int                     dimension,
-                             fvm_interlace_t         interlace,
+                             cs_interlace_t          interlace,
                              int                     n_parent_lists,
-                             const fvm_lnum_t        parent_num_shift[],
-                             fvm_datatype_t          datatype,
+                             const cs_lnum_t         parent_num_shift[],
+                             cs_datatype_t           datatype,
                              int                     time_step,
                              double                  time_value,
                              const void       *const field_values[]);
@@ -141,6 +141,17 @@ typedef struct {
   fvm_writer_time_dep_t    max_time_dep; /* Maximum time dependency level
                                             possible with this format */
 
+  int                      dl_count;     /* Number of writers using the
+                                            dynamically loadable library
+                                            for this format, if relevant */
+  void                    *dl_lib;       /* Pointer to dynamically loadable
+                                            library, if used */
+  const char              *dl_name;      /* Prefix for name of dynamically
+                                            loadable library, or NULL */
+  const char              *dl_prefix;    /* Prefix for exported symbols of
+                                            dynamically loadable library,
+                                            or NULL */
+
   fvm_writer_n_version_strings_t  *n_version_strings_func;
   fvm_writer_version_string_t     *version_string_func;
   fvm_writer_init_t               *init_func;
@@ -220,10 +231,10 @@ fvm_writer_def_nodal_buf_size(const fvm_nodal_t  *this_nodal,
                               int                 n_slices,
                               int                 n_polyhedron_vertices_mean,
                               int                 n_polygon_vertices_mean,
-                              fvm_gnum_t         *n_g_vertices,
-                              fvm_gnum_t          n_g_elements_section[],
-                              fvm_gnum_t         *global_s_size,
-                              fvm_gnum_t         *global_connect_s_size);
+                              cs_gnum_t          *n_g_vertices,
+                              cs_gnum_t           n_g_elements_section[],
+                              cs_gnum_t          *global_s_size,
+                              cs_gnum_t          *global_connect_s_size);
 
 /*----------------------------------------------------------------------------*/
 
