@@ -8,7 +8,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2011 EDF S.A.
+  Copyright (C) 1998-2012 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -90,6 +90,19 @@ void CS_PROCF (csturb, CSTURB) (int *const iturb,
 
 void CS_PROCF (cscpva, CSCPVA) (int *const icp);
 
+/*----------------------------------------------------------------------------
+ * Volumic viscosity variable or constant indicator.
+ *
+ * Fortran Interface:
+ *
+ * SUBROUTINE CSCVVVA (ICP)
+ * *****************
+ *
+ * INTEGER          IVISCV     <--   specific heat variable or constant indicator
+ *----------------------------------------------------------------------------*/
+
+void CS_PROCF (csvvva, CSVVVA) (int *const iviscv);
+
 /*----------------------------------------------------------------------------
  * User scalars number.
  *
@@ -161,6 +174,19 @@ void CS_PROCF(csidtv, CSIDTV) (int *const idtvar);
 
 void CS_PROCF (csiphy, CSIPHY) (int *const iphydr);
 
+/*----------------------------------------------------------------------------
+ * Hydrostatic equilibrium parameter.
+ *
+ * Fortran Interface:
+ *
+ * SUBROUTINE CSCFGP (ICFGRP)
+ * *****************
+ *
+ * INTEGER          ICFGRP  <--   hydrostatic equilibrium
+ *----------------------------------------------------------------------------*/
+
+void CS_PROCF (cscfgp, CSCFGP) (int *const icfgrp);
+
 /*----------------------------------------------------------------------------
  *
  * SUBROUTINE CSVNUM()
@@ -276,7 +302,10 @@ void CS_PROCF (uinum1, UINUM1) (const    int *const isca,
                                          int *const ircflu,
                                       double *const cdtvar,
                                          int *const nitmax,
-                                      double *const epsilo);
+                                      double *const epsilo,
+                                         int *const iresol,
+                                         int *const imgrpr,
+                                         int *const nswrsm);
 
 /*----------------------------------------------------------------------------
  * Global numerical parameters.
@@ -291,7 +320,7 @@ void CS_PROCF (uinum1, UINUM1) (const    int *const isca,
  * INTEGER          IPUCOU  <--   velocity pressure coupling
  * INTEGER          EXTRAG  <--   wall pressure extrapolation
  * INTEGER          IMRGRA  <--   gradient reconstruction
- * INTEGER          IMGR    <--   multigrid algorithm for pressure
+ * INTEGER          NTERUP  <--   piso sweep number
  *----------------------------------------------------------------------------*/
 
 void CS_PROCF (csnum2, CSNUM2) (   int *const ivisse,
@@ -299,7 +328,7 @@ void CS_PROCF (csnum2, CSNUM2) (   int *const ivisse,
                                    int *const ipucou,
                                 double *const extrag,
                                    int *const imrgra,
-                                   int *const imgrpr);
+                                   int *const nterup);
 
 void CS_PROCF (csphys, CSPHYS) (const    int *const nmodpp,
                                          int *const irovar,
@@ -313,9 +342,11 @@ void CS_PROCF (csphys, CSPHYS) (const    int *const nmodpp,
                                       double *const omegaz,
                                       double *const ro0,
                                       double *const viscl0,
+                                      double *const viscv0,
                                       double *const cp0,
                                       double *const t0,
-                                      double *const p0);
+                                      double *const p0,
+                                      double *const xmasmr);
 
 /*----------------------------------------------------------------------------
  * User scalar min and max values for clipping.
@@ -335,6 +366,7 @@ void CS_PROCF (cssca2, CSSCA2) ( const    int *const iscavr,
                                        double *const scamax);
 
 void CS_PROCF (cssca3, CSSCA3) (const    int *const iscalt,
+                                const    int *const iscsth,
                                 const    int *const iscavr,
                                       double *const visls0,
                                       double *const t0,
@@ -410,6 +442,27 @@ void CS_PROCF(cfnmva, CFNMVA)
 
 void CS_PROCF(nvamem, NVAMEM) (void);
 
+/*----------------------------------------------------------------------------
+ * Variables and user scalars initialization.
+ *
+ * Fortran Interface:
+ *
+ * subroutine uisterm (ncelet, isuite, isca, iscold, rtp)
+ * *****************
+ *
+ * integer          ncelet   -->  number of cells with halo
+ * integer          isuite   -->  restart indicator
+ * integer          isca     -->  indirection array for scalar number
+ * integer          iscold   -->  scalar number for restart
+ * DOUBLE PRECISION XYZCEN   -->  cell's gravity center
+ *----------------------------------------------------------------------------*/
+
+void CS_PROCF(uisterm, UISTERM) (const int          *ncelet,
+                                 const int          *isuite,
+                                 const int           isca[],
+                                 const int           iscold[],
+                                 const double *const xyzcen);
+
 /*----------------------------------------------------------------------------
  * Variables and user scalars initialization.
  *
@@ -422,14 +475,38 @@ void CS_PROCF(nvamem, NVAMEM) (void);
  * integer          isuite   -->  restart indicator
  * integer          isca     -->  indirection array for scalar number
  * integer          iscold   -->  scalar number for restart
+ * integer          iccfth   -->  type of initialisation(compressible model)
+ * integer          ipr      -->  rtp index for pressure
+ * integer          irho     -->  rtp index for density
+ * integer          itempk   -->  rtp index for temperature (in K)
+ * integer          ienerg   -->  rtp index for energy total
+ * DOUBLE PRECISION RO0      -->  value of density if IROVAR=0
+ * DOUBLE PRECISION CP0      -->  value of specific heat if ICP=0
+ * DOUBLE PRECISION VISCL0   -->  value of viscosity if IVIVAR=0
+ * DOUBLE PRECISION VISLS0   -->  value of reference molecular diffusivity
+ * DOUBLE PRECISION UREF     -->  value of reference velocity
+ * DOUBLE PRECISION ALMAX    -->  value of reference length
+ * DOUBLE PRECISION XYZCEN   -->  cell's gravity center
  * double precision rtp     <--   variables and scalars array
  *----------------------------------------------------------------------------*/
 
-void CS_PROCF(uiiniv, UIINIV) (const int    *ncelet,
-                               const int    *isuite,
-                               const int     isca[],
-                               const int     iscold[],
-                                     double  rtp[]);
+void CS_PROCF(uiiniv, UIINIV) (const int         *ncelet,
+                               const int         *isuite,
+                               const int          isca[],
+                               const int          iscold[],
+                                     int         *iccfth,
+                               const int *const   ipr,
+                               const int *const   irho,
+                               const int *const   itempk,
+                               const int *const   ienerg,
+                              const cs_real_t    *ro0,
+                              const cs_real_t    *cp0,
+                              const cs_real_t    *viscl0,
+                              const cs_real_t    *visls0,
+                              const cs_real_t    *uref,
+                              const cs_real_t    *almax,
+                              const double *const xyzcen,
+                                     double       rtp[]);
 
 /*----------------------------------------------------------------------------
  * User law for material Properties
@@ -452,6 +529,8 @@ void CS_PROCF(uiiniv, UIINIV) (const int    *ncelet,
  * INTEGER          ISCALT   -->  pointer for the thermal scalar in ISCA
  * INTEGER          ISCAVR   -->  scalars that are variance
  * INTEGER          IPPROC   -->  indirection array for cell properties
+ * INTEGER          IVISCV   -->  pointer for volumic viscosity viscv
+ * INTEGER          ITEMPK   -->  pointer for temperature (in K)
  * DOUBLE PRECISION P0       -->  pressure reference value
  * DOUBLE PRECISION T0       -->  temperature reference value
  * DOUBLE PRECISION RO0      -->  density reference value
@@ -473,8 +552,11 @@ void CS_PROCF(uiphyv, UIPHYV)(const cs_int_t  *const ncel,
                               const cs_int_t         ivivar[],
                               const cs_int_t         isca[],
                               const cs_int_t         iscalt[],
+                              const cs_int_t         iscsth[],
                               const cs_int_t         iscavr[],
                               const cs_int_t         ipproc[],
+                              const cs_int_t         iviscv[],
+                              const cs_int_t         itempk[],
                               const cs_real_t        p0[],
                               const cs_real_t        t0[],
                               const cs_real_t        ro0[],
@@ -552,14 +634,35 @@ void CS_PROCF (memui1, MEMUI1) (const int *const ncharb);
  *============================================================================*/
 
 /*-----------------------------------------------------------------------------
- * Return value of partitioning option.
+ * Get initial value from property markup.
  *
- * returns:
- *   id of selected (or default) partitioning type (0-3)
+ * parameters:
+ *   property_name       -->  name of the property
+ *   value              <--   new initial value of the property
  *----------------------------------------------------------------------------*/
 
-int
-cs_gui_get_sfc_partition_type(void);
+void
+cs_gui_properties_value(const char   *const property_name,
+                              double *const value);
+
+/*-----------------------------------------------------------------------------
+ * Initialization choice of the reference variables parameters.
+ *
+ * parameters:
+ *   name            <--   parameter name
+ *   value           -->   parameter value
+ *----------------------------------------------------------------------------*/
+
+void
+cs_gui_reference_initialization(const char   *const param,
+                                      double *const value);
+
+/*-----------------------------------------------------------------------------
+ * Set partitioning options.
+ *----------------------------------------------------------------------------*/
+
+void
+cs_gui_partition(void);
 
 /*-----------------------------------------------------------------------------
  * Free memory: clean global private variables and libxml2 variables
