@@ -5,7 +5,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2011 EDF S.A.
+  Copyright (C) 1998-2012 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -24,9 +24,7 @@
 
 /*----------------------------------------------------------------------------*/
 
-#if defined(HAVE_CONFIG_H)
-#include "cs_config.h"
-#endif
+#include "cs_defs.h"
 
 /*----------------------------------------------------------------------------
  * Standard C library headers
@@ -68,6 +66,7 @@
 #include "cs_join_perio.h"
 #include "cs_mesh.h"
 #include "cs_mesh_warping.h"
+#include "cs_mesh_smoother.h"
 #include "cs_prototypes.h"
 
 /*----------------------------------------------------------------------------
@@ -424,6 +423,7 @@ cs_gui_mesh_define_joinings(void)
     BFT_FREE(selector_s);
     BFT_FREE(fraction_s);
     BFT_FREE(plane_s);
+    BFT_FREE(verbosity_s);
     BFT_FREE(visu_s);
   }
 }
@@ -463,7 +463,7 @@ cs_gui_mesh_define_periodicities(void)
 
   if (n_modes != n_perio)
     bft_error(__FILE__, __LINE__, 0,
-              _("Number of periodicities (%d) and modes (%) do not match."),
+              _("Number of periodicities (%d) and modes (%d) do not match."),
               n_perio, n_modes);
 
   BFT_FREE(path);
@@ -540,6 +540,71 @@ cs_gui_mesh_define_periodicities(void)
   BFT_FREE(modes);
 }
 
+/*----------------------------------------------------------------------------
+ * Mesh smoothing.
+ *
+ * parameters:
+ *   mesh <-> pointer to mesh structure to smoothe
+ *----------------------------------------------------------------------------*/
+
+void
+cs_gui_mesh_smoothe(cs_mesh_t  *mesh)
+{
+  char  *path = NULL;
+  int mesh_smooting = 0;
+  double angle = 25.;
+
+  if (!cs_gui_file_is_loaded())
+    return;
+
+  path = cs_xpath_init_path();
+  cs_xpath_add_elements(&path, 2, "solution_domain", "mesh_smoothing");
+  cs_xpath_add_attribute(&path, "status");
+
+  cs_gui_get_status(path, &mesh_smooting);
+
+  if (mesh_smooting) {
+
+    BFT_FREE(path);
+
+    path = cs_xpath_init_path();
+    cs_xpath_add_elements(&path, 3,
+                          "solution_domain",
+                          "mesh_smoothing",
+                          "smooth_angle");
+    cs_xpath_add_function_text(&path);
+
+    if (!cs_gui_get_double(path, &angle))
+      angle = 25.;
+
+#if _XML_DEBUG_
+  bft_printf("==> uicwf\n");
+  bft_printf("--mesh_smoothing = %d\n"
+             "--angle          = %f\n",
+             mesh_smooting, angle);
+#endif
+
+    int *vtx_is_fixed = NULL;
+
+    BFT_MALLOC(vtx_is_fixed, mesh->n_vertices, int);
+
+    /* Get fixed boundary vertices flag */
+
+    cs_mesh_smoother_fix_by_feature(mesh,
+                                    angle,
+                                    vtx_is_fixed);
+
+    /* Call unwarping smoother */
+
+    cs_mesh_smoother_unwarp(mesh, vtx_is_fixed);
+
+    /* Free memory */
+
+    BFT_FREE(vtx_is_fixed);
+  }
+  BFT_FREE(path);
+}
+
 /*----------------------------------------------------------------------------*/
 
 END_C_DECLS
