@@ -5,7 +5,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2011 EDF S.A.
+  Copyright (C) 1998-2012 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -24,9 +24,7 @@
 
 /*----------------------------------------------------------------------------*/
 
-#if defined(HAVE_CONFIG_H)
-#include "cs_config.h"
-#endif
+#include "cs_defs.h"
 
 /*----------------------------------------------------------------------------
  * Standard C library headers
@@ -400,6 +398,10 @@ static void
 _gui_copy_varname(const char *varname, int ipp)
 {
   size_t l;
+
+  if (varname == NULL)
+    return;
+
   if (ipp < 1 || ipp > cs_glob_label->_cs_gui_last_var)
     bft_error(__FILE__, __LINE__, 0,
               _("Variable index %d out of bounds (1 to %d)"),
@@ -1522,11 +1524,16 @@ void CS_PROCF (uinpst, UINPST) ( const cs_int_t  *ntcabs,
   int i, id, nwriter;
   int iactive;
   char *frequency_choice;
+  char *id_s;
   mei_tree_t *ev_formula  = NULL;
   nwriter = cs_gui_get_tag_number("/analysis_control/output/writer", 1);
   for (i=1; i <= nwriter; i++) {
     id = 0;
-    id = atoi(cs_gui_output_type_choice("writer","id",i));
+    id_s = cs_gui_output_type_choice("writer","id",i);
+    if (id_s != NULL) {
+      id = atoi(id_s);
+      BFT_FREE(id_s);
+    }
     frequency_choice
       = cs_gui_output_type_options("writer", "period", "frequency", i);
     if (cs_gui_strcmp(frequency_choice, "formula")) {
@@ -1709,10 +1716,11 @@ void
 cs_gui_postprocess_meshes(void)
 {
   int i, j, id, id_writer;
+  char *id_s = NULL;
   char *label = NULL;
   char *all_variables = NULL;
-  cs_bool_t auto_vars = true;
-  cs_bool_t add_groups = true;
+  bool auto_vars = true;
+  bool add_groups = true;
   char *location = NULL;
   int n_writers, nmesh;
   char *type = NULL;
@@ -1725,7 +1733,8 @@ cs_gui_postprocess_meshes(void)
   nmesh = cs_gui_get_tag_number("/analysis_control/output/mesh", 1);
 
   for (i = 1; i <= nmesh; i++) {
-    id = atoi(cs_gui_output_type_choice("mesh","id",i));
+    id_s = cs_gui_output_type_choice("mesh","id",i);
+    id = atoi(id_s);
     label = cs_gui_output_type_choice("mesh","label",i);
     all_variables
       = cs_gui_output_type_options("mesh", "status", "all_variables",i);
@@ -1759,6 +1768,7 @@ cs_gui_postprocess_meshes(void)
     }
 
     BFT_FREE(writer_ids);
+    BFT_FREE(id_s);
     BFT_FREE(label);
     BFT_FREE(all_variables);
     BFT_FREE(location);
@@ -1781,7 +1791,8 @@ cs_gui_postprocess_writers(void)
   char *format_options = NULL;
   char *time_dependency = NULL;
   char *frequency_choice = NULL;
-  char *output_end_st = NULL;
+  char *output_end_s = NULL;
+  char *id_s = NULL;
 
   int n_writers = 0;
 
@@ -1794,16 +1805,17 @@ cs_gui_postprocess_writers(void)
 
     int id = 0;
     fvm_writer_time_dep_t  time_dep = FVM_WRITER_FIXED_MESH;
-    cs_bool_t output_at_end = true;
+    bool output_at_end = true;
     cs_int_t time_step = -1;
     cs_real_t time_value = -1.0;
 
-    id = atoi(cs_gui_output_type_choice("writer", "id", i));
+    id_s = cs_gui_output_type_choice("writer", "id", i);
+    id = atoi(id_s);
     label = cs_gui_output_type_choice("writer", "label", i);
     directory = cs_gui_output_type_options("writer", "name", "directory", i);
     frequency_choice
       = cs_gui_output_type_options("writer", "period", "frequency", i);
-    output_end_st
+    output_end_s
       = cs_gui_output_type_options("writer", "status", "output_at_end", i);
     if (cs_gui_strcmp(frequency_choice, "none")) {
       time_step = -1;
@@ -1818,7 +1830,7 @@ cs_gui_postprocess_writers(void)
       time_step = -1;
       time_value = -1.;
     }
-    if (cs_gui_strcmp(output_end_st, "off"))
+    if (cs_gui_strcmp(output_end_s, "off"))
       output_at_end = false;
     format_name = cs_gui_output_type_options("writer", "name", "format",i);
     format_options
@@ -1840,11 +1852,12 @@ cs_gui_postprocess_writers(void)
                           output_at_end,
                           time_step,
                           time_value);
+    BFT_FREE(id_s);
     BFT_FREE(label);
     BFT_FREE(format_name);
     BFT_FREE(format_options);
     BFT_FREE(time_dependency);
-    BFT_FREE(output_end_st);
+    BFT_FREE(output_end_s);
     BFT_FREE(frequency_choice);
     BFT_FREE(directory);
   }
