@@ -5,7 +5,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2011 EDF S.A.
+  Copyright (C) 1998-2012 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -24,9 +24,7 @@
 
 /*----------------------------------------------------------------------------*/
 
-#if defined(HAVE_CONFIG_H)
-#include "cs_config.h"
-#endif
+#include "cs_defs.h"
 
 /*----------------------------------------------------------------------------
  * Standard C library headers
@@ -82,7 +80,7 @@ BEGIN_C_DECLS
   C  : &iuslag[i][izone][iclas] = &iuslag[ i*(*nclagm)*(*nflagm) + izone*(*nclagm) + iclas]
 */
 
-/* simplfied access for fortran arrays */
+/* simplified access for fortran arrays */
 #define IUSLAG(I_,J_,K_) (*(iuslag +I_*(*nclagm)*(*nflagm) +J_*(*nclagm) +K_))
 #define RUSLAG(I_,J_,K_) (*(ruslag +I_*(*nclagm)*(*nflagm) +J_*(*nclagm) +K_))
 
@@ -408,14 +406,12 @@ _get_coal_double(double *const param, const char *const name, int icoal)
 static char*
 _get_char_post(const char *const type,
                const char *const name,
-               int  *list_value,
                int  *record_value)
 {
   char *path, *path1, *path2 = NULL;
   char *label = NULL;
   int result;
 
-  *list_value = 1;
   *record_value = 1;
 
   path = cs_xpath_init_path();
@@ -430,23 +426,18 @@ _get_char_post(const char *const type,
 
   if (cs_gui_strcmp(type, "volume")) {
 
-    cs_xpath_add_element(&path1, "monitoring_point");
+    cs_xpath_add_element(&path1, "postprocessing_recording");
     cs_xpath_add_attribute(&path1, "status");
     if (cs_gui_get_status(path1, &result))
-      *list_value = result;
+      *record_value = result;
   }
 
   else if (cs_gui_strcmp(type, "boundary")) {
 
-    cs_xpath_add_element(&path1, "listing_printing");
-    cs_xpath_add_attribute(&path1, "status");
-    if (cs_gui_get_status(path1, &result))
-      *list_value = result;
-
     cs_xpath_add_element(&path2, "postprocessing_recording");
     cs_xpath_add_attribute(&path2, "status");
     if (cs_gui_get_status(path2, &result))
-      *record_value = -1;
+      *record_value = result;
   }
 
   BFT_FREE(path);
@@ -465,7 +456,7 @@ _get_char_post(const char *const type,
  *----------------------------------------------------------------------------*/
 
 static void
-_copy_mean_varname(char *varname, int ipp)
+_copy_mean_varname(const char *varname, int ipp)
 {
   size_t  l;
   assert(ipp > 0);
@@ -495,7 +486,7 @@ _copy_mean_varname(char *varname, int ipp)
  *----------------------------------------------------------------------------*/
 
 static void
-_copy_variance_varname(char *varname, int ipp)
+_copy_variance_varname(const char *varname, int ipp)
 {
   size_t  l;
   assert(ipp > 0);
@@ -525,7 +516,7 @@ _copy_variance_varname(char *varname, int ipp)
  *----------------------------------------------------------------------------*/
 
 static void
-_copy_boundary_varname(char *varname, int ipp)
+_copy_boundary_varname(const char *varname, int ipp)
 {
   size_t  l;
   assert(ipp > 0);
@@ -556,11 +547,11 @@ _copy_boundary_varname(char *varname, int ipp)
 
 void CS_PROCF(fclag1, FCLAG1)
 (
- const char          *const fstr,    /* --> Fortran string */
- int                 *const len,     /* --> String Length  */
- int                 *const var_id   /* --> Variable Id (1 to n) */
- CS_ARGF_SUPP_CHAINE
-)
+  const char          *const fstr,    /* --> Fortran string */
+  int                 *const len,     /* --> String Length  */
+  int                 *const var_id   /* --> Variable Id (1 to n) */
+  CS_ARGF_SUPP_CHAINE
+  )
 {
   int i, i1, i2, l;
   char *cstr = NULL;
@@ -621,11 +612,11 @@ void CS_PROCF(fclag1, FCLAG1)
 
 void CS_PROCF(fclag2, FCLAG2)
 (
- const char          *const fstr,    /* --> Fortran string */
- int                 *const len,     /* --> String Length  */
- int                 *const var_id   /* --> Variable Id (1 to n) */
- CS_ARGF_SUPP_CHAINE
-)
+  const char          *const fstr,    /* --> Fortran string */
+  int                 *const len,     /* --> String Length  */
+  int                 *const var_id   /* --> Variable Id (1 to n) */
+  CS_ARGF_SUPP_CHAINE
+  )
 {
   int i, i1, i2, l;
   char *cstr = NULL;
@@ -687,11 +678,11 @@ void CS_PROCF(fclag2, FCLAG2)
 
 void CS_PROCF(fclag3, FCLAG3)
 (
- const char          *const fstr,    /* --> Fortran string */
- int                 *const len,     /* --> String Length  */
- int                 *const var_id   /* --> Variable Id (1 to n) */
- CS_ARGF_SUPP_CHAINE
-)
+  const char          *const fstr,    /* --> Fortran string */
+  int                 *const len,     /* --> String Length  */
+  int                 *const var_id   /* --> Variable Id (1 to n) */
+  CS_ARGF_SUPP_CHAINE
+  )
 {
   int i, i1, i2, l;
   char *cstr = NULL;
@@ -753,12 +744,12 @@ void CS_PROCF(fclag3, FCLAG3)
 
 void CS_PROCF(cfname, CFNAME)
 (
- int           *const flag,    /* --> flag for array = 1, 2, or 3 */
- char          *const fstr,    /* --> Fortran string */
- int           *const len,     /* --> String Length  */
- int           *const var_id   /* --> Variable Id (1 to n) */
- CS_ARGF_SUPP_CHAINE
-)
+  int           *const flag,    /* --> flag for array = 1, 2, or 3 */
+  char          *const fstr,    /* --> Fortran string */
+  int           *const len,     /* --> String Length  */
+  int           *const var_id   /* --> Variable Id (1 to n) */
+  CS_ARGF_SUPP_CHAINE
+  )
 {
   int i;
   int l = 0;
@@ -791,11 +782,11 @@ void CS_PROCF(cfname, CFNAME)
 
   if (cstr != NULL) {
 
-  /* Compute string length (removing start or end blanks) */
+    /* Compute string length (removing start or end blanks) */
 
-  l = strlen(cstr);
-  if (l > *len)
-    l = *len;
+    l = strlen(cstr);
+    if (l > *len)
+      l = *len;
 
     for (i = 0; i < l; i++)
       fstr[i] = cstr[i];
@@ -857,6 +848,7 @@ void CS_PROCF(cfname, CFNAME)
  * INTEGER          NBCLST     <--   number of particle clusters
  * INTEGER          SEUIL      <--   limit statistical weight value for volumic stat.
  * INTEGER          IDSTNT     <--   iteration number for volumic statistics
+ * INTEGER          NSTIST     <--   iteration number for steady-state volumic statistics
  * CHAR             NOMLAG     <--   mean variable name of volumic statistics
  * CHAR             NOMLAV     <--   variance variable name of volumic statistics
  * INTEGER          IHSLAG     <--   output of variable
@@ -915,6 +907,7 @@ void CS_PROCF (uilag1, UILAG1) (int *const iilagr,
                                 int *const nbclst,
                                 double *const seuil,
                                 int *const idstnt,
+                                int *const nstist,
                                 int ihslag[],
                                 int *const iensi3,
                                 double *const seuilf,
@@ -924,10 +917,16 @@ void CS_PROCF (uilag1, UILAG1) (int *const iilagr,
                                 int *const iangbd,
                                 int *const ivitbd,
                                 int *const iencbd,
-                                int imoybr[])
+                                int imoybr[],
+                                int *const iactfv,
+                                int *const iactvx,
+                                int *const iactvy,
+                                int *const iactvz,
+                                int *const iactts)
 {
   int i, icoal, ncoals = 0;
-  int list_ind, record_ind = 1;
+  int list_ind = 1;
+  int record_ind = 1;
   char *label = NULL;
   char *attr = NULL;
   char *path1 = NULL;
@@ -936,13 +935,13 @@ void CS_PROCF (uilag1, UILAG1) (int *const iilagr,
   attr = _get_attr("model", 1, "lagrangian");
   if (attr == NULL || cs_gui_strcmp(attr, "off"))
   {
-      *iilagr = 0;
+    *iilagr = 0;
 #if _XML_DEBUG_
-      bft_printf("==>UILAG1\n");
-      bft_printf("--iilagr = %i\n", *iilagr);
+    bft_printf("==>UILAG1\n");
+    bft_printf("--iilagr = %i\n", *iilagr);
 #endif
-      BFT_FREE(attr);
-      return;
+    BFT_FREE(attr);
+    return;
   }
 
   /* Global settings */
@@ -964,8 +963,8 @@ void CS_PROCF (uilag1, UILAG1) (int *const iilagr,
     _get_status(itpvar, 3, "lagrangian", "particles_models", "thermal");
     /*
     if (*itpvar == 1) {
-        _get_double(tpart,  4, "lagrangian", "particles_models", "thermal", "particle_temperature");
-        _get_double(cppart, 4, "lagrangian", "particles_models", "thermal", "particle_specific_heat");
+      _get_double(tpart,  4, "lagrangian", "particles_models", "thermal", "particle_temperature");
+      _get_double(cppart, 4, "lagrangian", "particles_models", "thermal", "particle_specific_heat");
     }
     */
     break;
@@ -978,10 +977,10 @@ void CS_PROCF (uilag1, UILAG1) (int *const iilagr,
 
     for (icoal=1; icoal <= ncoals; icoal++)
     {
-        _get_coal_double(&tprenc[icoal-1], "threshold_temperature", icoal);
-        _get_coal_double(&visref[icoal-1], "critical_viscosity",    icoal);
-        _get_coal_double(&enc1[icoal-1], "fouling_coefficient_1", icoal);
-        _get_coal_double(&enc2[icoal-1], "fouling_coefficient_2", icoal);
+      _get_coal_double(&tprenc[icoal-1], "threshold_temperature", icoal);
+      _get_coal_double(&visref[icoal-1], "critical_viscosity",    icoal);
+      _get_coal_double(&enc1[icoal-1], "fouling_coefficient_1", icoal);
+      _get_coal_double(&enc2[icoal-1], "fouling_coefficient_2", icoal);
     }
     break;
   }
@@ -1046,65 +1045,76 @@ void CS_PROCF (uilag1, UILAG1) (int *const iilagr,
   if (*istala == 1) {
     _get_double(seuil, 4, "lagrangian", "statistics", "volume", "threshold_volume");
     _get_int(idstnt, 4, "lagrangian", "statistics", "volume", "iteration_start_volume");
+    _get_int(nstist, 4, "lagrangian", "statistics", "volume", "iteration_steady_start_volume");
 
     /* labels */
 
-    label = _get_char_post("volume", "mean_velocity_U", &list_ind, &record_ind);
-    if (label) _copy_mean_varname(label, 1);
-    ihslag[1] = list_ind;
+    i  = 0;
 
-    label = _get_char_post("volume", "variance_velocity_U", &list_ind, &record_ind);
-    if (label) _copy_variance_varname(label, 1);
+    _get_char_post("volume", "Part_vol_frac", iactfv);
+    if (*iactfv)
+    {
+      i++;
+      _copy_mean_varname("Part_vol_frac", i);
+      _copy_variance_varname("var_Part_vol_frac", i);
+      ihslag[i] = 1;
+    }
 
-    label = _get_char_post("volume", "mean_velocity_V", &list_ind, &record_ind);
-    if (label) _copy_mean_varname(label, 2);
-    ihslag[2] = list_ind;
+    _get_char_post("volume", "Part_velocity_X", iactvx);
+    if (*iactvx)
+    {
+      i++;
+      _copy_mean_varname("Part_velocity_X", i);
+      _copy_variance_varname("var_Part_velocity_X", i);
+      ihslag[i] = 1;
+    }
 
-    label = _get_char_post("volume", "variance_velocity_V", &list_ind, &record_ind);
-    if (label) _copy_variance_varname(label, 2);
+    _get_char_post("volume", "Part_velocity_Y", iactvy);
+    if (*iactvy)
+    {
+      i++;
+      _copy_mean_varname("Part_velocity_Y", i);
+      _copy_variance_varname("var_Part_velocity_X", i);
+      ihslag[i] = 1;
+    }
 
-    label = _get_char_post("volume", "mean_velocity_W", &list_ind, &record_ind);
-    if (label) _copy_mean_varname(label, 3);
-    ihslag[3] = list_ind;
+    _get_char_post("volume", "Part_velocity_Z", iactvz);
+    if (*iactvz)
+    {
+      i++;
+      _copy_mean_varname("Part_velocity_Z", i);
+      _copy_variance_varname("var_Part_velocity_Z", i);
+      ihslag[i] = 1;
+    }
 
-    label = _get_char_post("volume", "variance_velocity_W", &list_ind, &record_ind);
-    if (label) _copy_variance_varname(label, 3);
-
-    label = _get_char_post("volume", "mean_volume_fraction", &list_ind, &record_ind);
-    if (label) _copy_mean_varname(label, 4);
-    ihslag[4] = list_ind;
-
-    label = _get_char_post("volume", "variance_volume_fraction", &list_ind, &record_ind);
-    if (label) _copy_variance_varname(label, 4);
-
-    label = _get_char_post("volume", "mean_resident_time", &list_ind, &record_ind);
-    if (label) _copy_mean_varname(label, 5);
-    ihslag[5] = list_ind;
-
-    label = _get_char_post("volume", "variance_resident_time", &list_ind, &record_ind);
-    if (label) _copy_variance_varname(label, 5);
-
-    i = 5;
+    _get_char_post("volume", "Part_resid_time", iactts);
+    if (*iactts)
+    {
+      i++;
+      _copy_mean_varname("Part_resid_time", i);
+      _copy_variance_varname("var_Part_resid_time", i);
+      ihslag[i] = 1;
+    }
 
     if (*iphyla == 1) {
 
       if (*itpvar == 1) {
         i++;
-        label = _get_char_post("volume",  "mean_temperature", &list_ind, &record_ind);
+        label = _get_char_post("volume",  "mean_temperature",  &record_ind);
         if (label) _copy_mean_varname(label, i);
         ihslag[i] = list_ind;
 
-        label = _get_char_post("volume", "variance_temperature", &list_ind, &record_ind);
+        label = _get_char_post("volume", "variance_temperature",  &record_ind);
         if (label) _copy_variance_varname(label, i);
       }
 
       if (*idpvar == 1) {
         i++;
-        label = _get_char_post("volume", "mean_diameter", &list_ind, &record_ind);
+        label = _get_char_post("volume", "mean_diameter",  &record_ind);
         if (label) _copy_mean_varname(label, i);
         ihslag[i] = list_ind;
 
-        label = _get_char_post("volume", "variance_diameter", &list_ind, &record_ind);
+        label = _get_char_post("volume", "variance_diameter",  &record_ind);
         if (label) _copy_variance_varname(label, i);
       }
     }
@@ -1119,34 +1129,34 @@ void CS_PROCF (uilag1, UILAG1) (int *const iilagr,
       if (label) _copy_variance_varname(label, i);
       */
       i++;
-      label = _get_char_post("volume", "mean_shrinking_core_diameter", &list_ind, &record_ind);
+      label = _get_char_post("volume", "mean_shrinking_core_diameter",  &record_ind);
       if (label) _copy_mean_varname(label, i);
       ihslag[i] = list_ind;
 
-      label = _get_char_post("volume", "variance_shrinking_core_diameter", &list_ind, &record_ind);
+      label = _get_char_post("volume", "variance_shrinking_core_diameter", &record_ind);
       if (label) _copy_variance_varname(label, i);
 
       i++;
-      label = _get_char_post("volume", "mean_raw_coal_mass_fraction", &list_ind, &record_ind);
+      label = _get_char_post("volume", "mean_raw_coal_mass_fraction",  &record_ind);
       if (label) _copy_mean_varname(label, i);
       ihslag[i] = list_ind;
 
-      label = _get_char_post("volume", "variance_raw_coal_mass_fraction", &list_ind, &record_ind);
+      label = _get_char_post("volume", "variance_raw_coal_mass_fraction",  &record_ind);
       if (label) _copy_variance_varname(label, i);
 
       i++;
-      label = _get_char_post("volume", "mean_char_mass_fraction", &list_ind, &record_ind);
+      label = _get_char_post("volume", "mean_char_mass_fraction",  &record_ind);
       if (label) _copy_mean_varname(label, i);
       ihslag[i] = list_ind;
 
-      label = _get_char_post("volume", "variance_char_mass_fraction", &list_ind, &record_ind);
+      label = _get_char_post("volume", "variance_char_mass_fraction",  &record_ind);
       if (label) _copy_variance_varname(label, i);
     }
 
     i++;
-    label = _get_char_post("volume", "statistical_weight", &list_ind, &record_ind);
-    if (label) _copy_mean_varname(label, i);
-    ihslag[i] = list_ind;
+    _get_char_post("volume", "Part_statis_weight",  &record_ind);
+    _copy_mean_varname("Part_statis_weight", i);
+    ihslag[i] = 1;
   }
 
   _get_status(iensi3, 3, "lagrangian", "statistics", "boundary");
@@ -1158,38 +1168,38 @@ void CS_PROCF (uilag1, UILAG1) (int *const iilagr,
 
     i = 0;
 
-    label = _get_char_post("boundary", "impacts", inbrbd, &record_ind);
+    _get_char_post("boundary", "Part_impact_number", inbrbd);
     if (*inbrbd) {
       i++;
-      if (label) _copy_boundary_varname(label, i);
-      imoybr[i] = record_ind;
+      _copy_boundary_varname("Part_impact_number", i);
+      imoybr[i] = 0;
     }
 
-    label = _get_char_post("boundary", "mass_flux", iflmbd, &record_ind);
+    label = _get_char_post("boundary", "Part_bndy_mass_flux", iflmbd);
     if (*iflmbd) {
       i++;
-      if (label) _copy_boundary_varname(label, i);
-      imoybr[i] = record_ind;
+      _copy_boundary_varname("Part_bndy_mass_flux", i);
+      imoybr[i] = 1;
     }
 
-    label = _get_char_post("boundary", "angle", iangbd, &record_ind);
+    label = _get_char_post("boundary", "Part_impact_angle", iangbd);
     if (*iangbd) {
       i++;
-      if (label) _copy_boundary_varname(label, i);
-      imoybr[i] = record_ind;
+      _copy_boundary_varname("Part_impact_angle", i);
+      imoybr[i] = 2;
     }
 
-    label = _get_char_post("boundary", "velocity", ivitbd, &record_ind);
+    label = _get_char_post("boundary", "Part_impact_velocity", ivitbd);
     if (*ivitbd) {
       i++;
-      if (label) _copy_boundary_varname(label, i);
-      imoybr[i] = record_ind;
+      _copy_boundary_varname("Part_impact_velocity", i);
+      imoybr[i] = 2;
     }
-    label = _get_char_post("boundary", "coal_fouling", iencbd, &record_ind);
+    label = _get_char_post("boundary", "coal_fouling", iencbd);
     if (*iencbd) {
       i++;
       if (label) _copy_boundary_varname(label, i);
-      imoybr[i] = record_ind;
+      imoybr[i] = 0;
     }
   }
   BFT_FREE(label);
@@ -1214,12 +1224,12 @@ void CS_PROCF (uilag1, UILAG1) (int *const iilagr,
   case 2:
     bft_printf("--iencra = %i\n", *iencra);
     for (icoal=1; icoal<=ncoals; icoal++)
-      {
-        bft_printf("--tprenc[%i] = %f\n", icoal, tprenc[icoal-1]);
-        bft_printf("--visref[%i] = %f\n", icoal, visref[icoal-1]);
-        bft_printf("--enc1[%i] = %f\n", icoal, enc1[icoal-1]);
-        bft_printf("--enc2[%i] = %f\n", icoal, enc2[icoal-1]);
-      }
+    {
+      bft_printf("--tprenc[%i] = %f\n", icoal, tprenc[icoal-1]);
+      bft_printf("--visref[%i] = %f\n", icoal, visref[icoal-1]);
+      bft_printf("--enc1[%i] = %f\n", icoal, enc1[icoal-1]);
+      bft_printf("--enc2[%i] = %f\n", icoal, enc2[icoal-1]);
+    }
     break;
   }
 
@@ -1261,6 +1271,7 @@ void CS_PROCF (uilag1, UILAG1) (int *const iilagr,
   bft_printf("--istala = %i\n", *istala);
   if (*istala == 1) {
     bft_printf("--idstnt = %i\n", *idstnt);
+    bft_printf("--nstist = %i\n", *nstist);
     bft_printf("--seuil  = %f\n", *seuil);
 
     /*
@@ -1335,7 +1346,6 @@ void CS_PROCF (uilag2, UILAG2) (const int *const nfabor,
                                 const int *const isortl,
                                 const int *const idepo1,
                                 const int *const idepo2,
-                                const int *const idepo3,
                                 const int *const idepfa,
                                 const int *const iencrl,
                                 const int *const irebol,
@@ -1559,9 +1569,6 @@ void CS_PROCF (uilag2, UILAG2) (const int *const nfabor,
       else if(cs_gui_strcmp(interaction, "deposit2"))
         iusclb[izone] = *idepo2;
 
-      else if(cs_gui_strcmp(interaction, "deposit3"))
-        iusclb[izone] = *idepo3;
-
       else if(cs_gui_strcmp(interaction, "fouling") && *iphyla == 2)
         iusclb[izone] = *iencrl;
 
