@@ -8,7 +8,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2011 EDF S.A.
+  Copyright (C) 1998-2012 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -143,6 +143,7 @@ void CS_PROCF (uilag1, UILAG1) (int *const iilagr,
                                 int *const nbclst,
                                 double *const seuil,
                                 int *const idstnt,
+                                int *const nstist,
                                 int ihslag[],
                                 int *const iensi3,
                                 double *const seuilf,
@@ -152,7 +153,12 @@ void CS_PROCF (uilag1, UILAG1) (int *const iilagr,
                                 int *const iangbd,
                                 int *const ivitbd,
                                 int *const iencbd,
-                                int imoybr[]);
+                                int imoybr[],
+                                int *const iactfv,
+                                int *const iactvx,
+                                int *const iactvy,
+                                int *const iactvz,
+                                int *const iactts);
 
 /*-----------------------------------------------------------------------------
  * Fortran Interface:
@@ -180,7 +186,6 @@ void CS_PROCF (uilag2, UILAG2) (const int *const nfabor,
                                 const int *const isortl,
                                 const int *const idepo1,
                                 const int *const idepo2,
-                                const int *const idepo3,
                                 const int *const idepfa,
                                 const int *const iencrl,
                                 const int *const irebol,
