@@ -5,7 +5,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2011 EDF S.A.
+  Copyright (C) 1998-2012 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -24,9 +24,7 @@
 
 /*----------------------------------------------------------------------------*/
 
-#if defined(HAVE_CONFIG_H)
-#include "cs_config.h"
-#endif
+#include "cs_defs.h"
 
 /*----------------------------------------------------------------------------
  * Standard C library headers
@@ -521,7 +519,7 @@ void CS_PROCF (uiray4, UIRAY4) (int *const nbrayf,
         "wall_temp",
         "flux_incident",
         "thickness",
-        "thermal_conductivity",
+        "wall_thermal_conductivity",
         "emissivity",
         "flux_net",
         "flux_convectif",
@@ -590,37 +588,37 @@ void CS_PROCF (uirapr, UIRAPR) (const int *const nprayc,
     BFT_REALLOC(vars->properties_name, vars->nprop, char*);
 
     /* ILUMIN */
-    vars->properties_ipp[n] = ipppro[ ipproc[ *ilumin -1 ]-1 ];
-    vars->propce[n] = *ilumin;
-    BFT_MALLOC(vars->properties_name[n], strlen("intensity")+1, char);
+    vars->properties_ipp[n] = ipppro[ipproc[ *ilumin -1] -1];
+    vars->propce[n] = ipproc[ *ilumin -1] -1;
+    BFT_MALLOC(vars->properties_name[n], strlen("intensity") +1, char);
     strcpy(vars->properties_name[n++], "intensity");
 
     /* IQX */
-    vars->properties_ipp[n] = ipppro[ ipproc[ *iqx -1 ]-1 ];
-    vars->propce[n] = *iqx;
-    BFT_MALLOC(vars->properties_name[n], strlen("qrad_x")+1, char);
+    vars->properties_ipp[n] = ipppro[ipproc[ *iqx -1] -1];
+    vars->propce[n] = ipproc[ *iqx -1] -1;
+    BFT_MALLOC(vars->properties_name[n], strlen("qrad_x") +1, char);
     strcpy(vars->properties_name[n++], "qrad_x");
 
     /* IQY */
-    vars->properties_ipp[n] = ipppro[ ipproc[ *iqy -1 ]-1 ];
-    vars->propce[n] = *iqy;
-    BFT_MALLOC(vars->properties_name[n], strlen("qrad_y")+1, char);
+    vars->properties_ipp[n] = ipppro[ipproc[ *iqy -1] -1];
+    vars->propce[n] = ipproc[ *iqy -1] -1;
+    BFT_MALLOC(vars->properties_name[n], strlen("qrad_y") +1, char);
     strcpy(vars->properties_name[n++], "qrad_y");
 
     /* IQZ */
-    vars->properties_ipp[n] = ipppro[ ipproc[ *iqz -1 ]-1 ];
-    vars->propce[n] = *iqz;
-    BFT_MALLOC(vars->properties_name[n], strlen("qrad_z")+1, char);
+    vars->properties_ipp[n] = ipppro[ipproc[ *iqz -1] -1];
+    vars->propce[n] = ipproc[ *iqz -1] -1;
+    BFT_MALLOC(vars->properties_name[n], strlen("qrad_z") +1, char);
     strcpy(vars->properties_name[n++], "qrad_z");
 
     /* ITSRE */
-    vars->properties_ipp[n] = ipppro[ ipproc[ itsre[0] -1 ]-1 ];
-    vars->propce[n] = itsre[0];
-    BFT_MALLOC(vars->properties_name[n], strlen("radiative_source_term")+1, char);
+    vars->properties_ipp[n] = ipppro[ipproc[itsre[0] -1] -1];
+    vars->propce[n] = ipproc[itsre[0] -1] -1;
+    BFT_MALLOC(vars->properties_name[n], strlen("radiative_source_term") +1, char);
     strcpy(vars->properties_name[n++], "radiative_source_term");
 
     /* ITSRE loop on classes */
-    BFT_MALLOC(name, strlen("radiative_source_term_")+1 + 2, char);
+    BFT_MALLOC(name, strlen("radiative_source_term_") +1 +2, char);
     BFT_MALLOC(snumpp, 1 + 2, char);
     strcpy(name, "radiative_source_term_");
     for (i = 1; i < *nrphas; i++)
@@ -628,52 +626,52 @@ void CS_PROCF (uirapr, UIRAPR) (const int *const nprayc,
         sprintf(snumpp, "%2.2i", i);
         strcat(name, snumpp);
 
-        vars->properties_ipp[n] = ipppro[ ipproc[ itsre[i] -1 ]-1 ];
-        vars->propce[n] = itsre[i];
-        BFT_MALLOC(vars->properties_name[n], strlen(name)+1, char);
+        vars->properties_ipp[n] = ipppro[ipproc[itsre[i] -1] -1];
+        vars->propce[n] = ipproc[itsre[i] -1] -1;
+        BFT_MALLOC(vars->properties_name[n], strlen(name) +1, char);
         strcpy(vars->properties_name[n++], name);
 
         strcpy(name, "radiative_source_term_");
     }
 
     /* ITSRI */
-    vars->properties_ipp[n] = ipppro[ ipproc[ itsri[0] -1 ]-1 ];
-    vars->propce[n] = itsri[0];
-    BFT_MALLOC(vars->properties_name[n], strlen("implicit_source_term")+1, char);
+    vars->properties_ipp[n] = ipppro[ipproc[itsri[0] -1] -1];
+    vars->propce[n] = ipproc[itsri[0] -1] -1;
+    BFT_MALLOC(vars->properties_name[n], strlen("implicit_source_term") +1, char);
     strcpy(vars->properties_name[n++], "implicit_source_term");
 
     /* ITSRI loop on classes */
-    BFT_REALLOC(name, strlen("implicit_source_term_")+1 + 2, char);
+    BFT_REALLOC(name, strlen("implicit_source_term_") +1 +2, char);
     strcpy(name, "implicit_source_term_");
     for (i = 1; i < *nrphas; i++)
     {
         sprintf(snumpp, "%2.2i", i);
         strcat(name, snumpp);
 
-        vars->properties_ipp[n] = ipppro[ ipproc[ itsri[i] -1 ]-1 ];
-        vars->propce[n] = itsri[i];
-        BFT_MALLOC(vars->properties_name[n], strlen(name)+1, char);
+        vars->properties_ipp[n] = ipppro[ipproc[itsri[i] -1] -1];
+        vars->propce[n] = ipproc[itsri[i] -1] -1;
+        BFT_MALLOC(vars->properties_name[n], strlen(name) +1, char);
         strcpy(vars->properties_name[n++], name);
 
         strcpy(name, "implicit_source_term_");
     }
 
     /* IABS */
-    vars->properties_ipp[n] = ipppro[ ipproc[ iabs[0] -1 ]-1 ];
-    vars->propce[n] = iabs[0];
-    BFT_MALLOC(vars->properties_name[n], strlen("absorption")+1, char);
+    vars->properties_ipp[n] = ipppro[ipproc[iabs[0] -1 ] -1];
+    vars->propce[n] = ipproc[iabs[0] -1] -1;
+    BFT_MALLOC(vars->properties_name[n], strlen("absorption") +1, char);
     strcpy(vars->properties_name[n++], "absorption");
 
     /* IABS loop on classes */
-    BFT_REALLOC(name, strlen("absorption_")+1 + 2, char);
+    BFT_REALLOC(name, strlen("absorption_") +1 + 2, char);
     strcpy(name, "absorption_");
     for (i = 1; i < *nrphas; i++)
     {
         sprintf(snumpp, "%2.2i", i);
         strcat(name, snumpp);
 
-        vars->properties_ipp[n] = ipppro[ ipproc[ iabs[i] -1 ]-1 ];
-        vars->propce[n] = iabs[i];
+        vars->properties_ipp[n] = ipppro[ipproc[iabs[i] -1] -1];
+        vars->propce[n] = ipproc[iabs[i] -1] -1;
         BFT_MALLOC(vars->properties_name[n], strlen(name)+1, char);
         strcpy(vars->properties_name[n++], name);
 
@@ -681,44 +679,44 @@ void CS_PROCF (uirapr, UIRAPR) (const int *const nprayc,
     }
 
     /* IEMI */
-    vars->properties_ipp[n] = ipppro[ ipproc[ iemi[0] -1 ]-1 ];
-    vars->propce[n] = iemi[0];
-    BFT_MALLOC(vars->properties_name[n], strlen("emission")+1, char);
+    vars->properties_ipp[n] = ipppro[ipproc[iemi[0] -1] -1];
+    vars->propce[n] = ipproc[iemi[0] -1] -1;
+    BFT_MALLOC(vars->properties_name[n], strlen("emission") +1, char);
     strcpy(vars->properties_name[n++], "emission");
 
     /* IEMI loop on classes */
-    BFT_REALLOC(name, strlen("emission_")+1 + 2, char);
+    BFT_REALLOC(name, strlen("emission_") +1 + 2, char);
     strcpy(name, "emission_");
     for (i = 1; i < *nrphas; i++)
     {
         sprintf(snumpp, "%2.2i", i);
         strcat(name, snumpp);
 
-        vars->properties_ipp[n] = ipppro[ ipproc[ iemi[i] -1 ]-1 ];
-        vars->propce[n] = iemi[i];
-        BFT_MALLOC(vars->properties_name[n], strlen(name)+1, char);
+        vars->properties_ipp[n] = ipppro[ipproc[iemi[i] -1] -1];
+        vars->propce[n] = ipproc[iemi[i] -1] -1;
+        BFT_MALLOC(vars->properties_name[n], strlen(name) +1, char);
         strcpy(vars->properties_name[n++], name);
 
         strcpy(name, "emission_");
     }
 
     /* ICAK */
-    vars->properties_ipp[n] = ipppro[ ipproc[ icak[0] -1 ]-1 ];
-    vars->propce[n] = icak[0];
+    vars->properties_ipp[n] = ipppro[ipproc[icak[0] -1] -1];
+    vars->propce[n] = ipproc[icak[0] -1] -1;
     BFT_MALLOC(vars->properties_name[n], strlen("absorption_coefficient")+1, char);
     strcpy(vars->properties_name[n++], "absorption_coefficient");
 
     /* ICAK loop on classes */
-    BFT_REALLOC(name, strlen("absorption_coefficient_")+1 + 2, char);
+    BFT_REALLOC(name, strlen("absorption_coefficient_") +1 +2, char);
     strcpy(name, "absorption_coefficient_");
     for (i = 1; i < *nrphas; i++)
     {
         sprintf(snumpp, "%2.2i", i);
         strcat(name, snumpp);
 
-        vars->properties_ipp[n] = ipppro[ ipproc[ icak[i] -1 ]-1 ];
-        vars->propce[n] = icak[i];
-        BFT_MALLOC(vars->properties_name[n], strlen(name)+1, char);
+        vars->properties_ipp[n] = ipppro[ipproc[icak[i] -1] -1];
+        vars->propce[n] = ipproc[icak[i] -1] -1;
+        BFT_MALLOC(vars->properties_name[n], strlen(name) +1, char);
         strcpy(vars->properties_name[n++], name);
 
         strcpy(name, "absorption_coefficient_");
@@ -931,10 +929,6 @@ void CS_PROCF (uiray2, UIRAY2)
         BFT_MALLOC(boundary->nature[izone], strlen(nature)+1, char);
         strcpy(boundary->nature[izone], nature);
 
-        faces_list = cs_gui_get_faces_list(izone,
-                                           boundaries->label[izone],
-                                           *nfabor, *nozppm, &faces);
-
         /* Default initialization: these values are the same that in raycli
            but given on each face in raycli whereas here one does not
            necessarily have boundary faces (parallism) -> duplication */
@@ -956,7 +950,7 @@ void CS_PROCF (uiray2, UIRAY2)
           boundary->output_zone[izone] = (int) tmp;
           _radiative_boundary(label, "emissivity", &boundary->emissivity[izone]);
           _radiative_boundary(label, "thickness", &boundary->thickness[izone]);
-          _radiative_boundary(label, "thermal_conductivity", &boundary->thermal_conductivity[izone]);
+          _radiative_boundary(label, "wall_thermal_conductivity", &boundary->thermal_conductivity[izone]);
           _radiative_boundary(label, "external_temperature_profile", &boundary->external_temp[izone]);
           _radiative_boundary(label, "internal_temperature_profile", &boundary->internal_temp[izone]);
           _radiative_boundary(label, "flux", &boundary->conduction_flux[izone]);
@@ -999,7 +993,7 @@ void CS_PROCF (uiray2, UIRAY2)
           bft_error(__FILE__, __LINE__, 0,
                     _("One tries to define radiative boundary conditions on boundary which is not a wall.\n"
                       "The definition of the boundaries natures given in GUI (wall, inlet, outlet,...) \n"
-                      "is modified in a users subroutine (like USCLIM, USCPCL,...). \n"
+                      "is modified in a users subroutine (like cs_user_boundary_conditions, USCPCL,...). \n"
                       "The radiative boundary conditions given in GUI must be coherent \n"
                       "with these new natures.\n"));
 
@@ -1039,9 +1033,9 @@ void CS_PROCF (uiray2, UIRAY2)
       }
     } /* if nature == "wall" */
 
-  } /* for izone */
+    BFT_FREE(faces_list);
 
-  BFT_FREE(faces_list);
+  } /* for izone */
 
   iok = 0;
   for (n = 0; n < *nfabor; n++) {
@@ -1058,7 +1052,7 @@ void CS_PROCF (uiray2, UIRAY2)
          bft_printf("    type = %i\n", boundary->type[izone]);
          bft_printf("    emissivity = %f\n", boundary->emissivity[izone]);
          bft_printf("    thickness= %f\n", boundary->thickness[izone]);
-         bft_printf("    thermal_conductivity = %f\n", boundary->thermal_conductivity[izone]);
+         bft_printf("    wall_thermal_conductivity = %f\n", boundary->thermal_conductivity[izone]);
          bft_printf("    external_temp = %f\n", boundary->external_temp[izone]);
          bft_printf("    internal_temp = %f\n", boundary->internal_temp[izone]);
          bft_printf("    conduction_flux= %f\n", boundary->conduction_flux[izone]);
@@ -1075,7 +1069,7 @@ void CS_PROCF (uiray2, UIRAY2)
        bft_printf("----type = %i\n", boundary->type[izone]);
        bft_printf("----emissivity = %f\n", boundary->emissivity[izone]);
        bft_printf("----thickness= %f\n", boundary->thickness[izone]);
-       bft_printf("----thermal_conductivity = %f\n", boundary->thermal_conductivity[izone]);
+       bft_printf("----wall_thermal_conductivity = %f\n", boundary->thermal_conductivity[izone]);
        bft_printf("----external_temp = %f\n", boundary->external_temp[izone]);
        bft_printf("----internal_temp = %f\n", boundary->internal_temp[izone]);
        bft_printf("----conduction_flux= %f\n", boundary->conduction_flux[izone]);
