@@ -5,7 +5,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2011 EDF S.A.
+  Copyright (C) 1998-2012 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -24,9 +24,7 @@
 
 /*----------------------------------------------------------------------------*/
 
-#if defined(HAVE_CONFIG_H)
-#include "cs_config.h"
-#endif
+#include "cs_defs.h"
 
 /*----------------------------------------------------------------------------
  * Standard C library headers
@@ -1147,6 +1145,35 @@ cs_gui_strcpy_c2f(char        *chainef,
     chainef[i] = ' ';
 }
 
+/*-----------------------------------------------------------------------------
+ * Test if 2 real values are equal (avoiding compiler warnings)
+ *
+ * parameters:
+ *   v1 <-- first value to compare
+ *   v2 <-- second value to compare
+ *
+ * returns:
+ *   1 if values are equal, 0 otherwise
+ *----------------------------------------------------------------------------*/
+
+int
+cs_gui_is_equal_real(cs_real_t v1,
+                     cs_real_t v2)
+{
+  size_t i;
+  int retval = 1;
+
+  const unsigned char *_v1 = (const unsigned char *)(&v1);
+  const unsigned char *_v2 = (const unsigned char *)(&v2);
+
+  for (i = 0; i < sizeof(cs_real_t); i++) {
+    if (_v1[i] != _v2[i])
+      retval = 0;
+  }
+
+  return retval;
+}
+
 /*-----------------------------------------------------------------------------
  * Add timing increment to global MEI time counter.
  *
