@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2011 EDF S.A.
+! Copyright (C) 1998-2012 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -32,7 +32,7 @@ subroutine lagdep &
    ettp   , ettpa  , tepa   , statis ,                            &
    taup   , tlag   , piil   ,                                     &
    bx     , vagaus , gradpr , gradvf , romp   ,                   &
-   brgaus , terbru , fextla )
+   brgaus , terbru , fextla , vislen)
 
 !===============================================================================
 ! Purpose:
@@ -178,7 +178,7 @@ double precision d3 , vpart, vvue
 double precision px , py , pz , distp , d1
 double precision dismin,dismax, ustar, visccf,depint
 
-integer, allocatable, dimension(:) :: ifacl
+double precision vislen(nfabor)
 
 !===============================================================================
 
@@ -187,9 +187,6 @@ integer, allocatable, dimension(:) :: ifacl
 !===============================================================================
 
 
-! Allocae a work array
-allocate(ifacl(nbpart))
-
 !===============================================================================
 ! 1.  Initialization
 !===============================================================================
@@ -260,65 +257,6 @@ endif
         tempf = t0
       endif
 
-!===============================================================================
-! 2. calculation of the normalized wall-normal particle distance (y^+)
-!===============================================================================
-
-
-      dismin = 1.d+20
-      dismax = -1.d+20
-
-      distp = 1.0d+20
-      tepa(ip,jryplu) = 1.0d3
-      nbfac = 0
-
-      do il = itycel(iel),itycel(iel+1)-1
-
-         ifac = icocel(il)
-
-         if (ifac.lt.0) then
-
-            ifac = -ifac
-            izone = ifrlag(ifac)
-
-
- !          Test if the particle is located in a boundary cell
-
-
-            if ( iusclb(izone) .eq. idepo1 .or.                   &
-                 iusclb(izone) .eq. idepo2 .or.                   &
-                 iusclb(izone) .eq. idepo3 .or.                   &
-                 iusclb(izone) .eq. idepfa .or.                   &
-                 iusclb(izone) .eq. irebol     ) then
-
-!
-!              Calculation of the wall units
-!
-               ustar = uetbor(ifac)
-               lvisq = visccf / ustar
-               tvisq =  visccf / (ustar * ustar)
-
-               px = ettp(ip,jxp)
-               py = ettp(ip,jyp)
-               pz = ettp(ip,jzp)
-
-               d1 = abs(px*dlgeo(ifac,1)+py*dlgeo(ifac,2)         &
-                    +pz*dlgeo(ifac,3)+dlgeo(ifac,4))           &
-                    /sqrt( dlgeo(ifac,1)*dlgeo(ifac,1)            &
-                    +dlgeo(ifac,2)*dlgeo(ifac,2)               &
-                    +dlgeo(ifac,3)*dlgeo(ifac,3))
-
-               if (d1.lt.distp) then
-                  ifacl(ip) = ifac
-                  distp = d1
-                  tepa(ip,jryplu)= distp/lvisq
-               endif
-
-            endif
-
-         endif
-
-      enddo
 
 !=========================================================================
 !   If y^+ is greater than the interface location,
@@ -363,7 +301,7 @@ endif
             ter3x = cc * tci
             ter4x = (dtp - aa) * force
 
-            !---> vu fluid terms
+            !---> flow-seen velocity terms
 
             ter1f = ettpa(ip,juf+i0) * aux2
             ter2f = tci * (1.d0-aux2)
@@ -380,7 +318,7 @@ endif
 
             !---> (2.3) Coefficients computation for the stochastic integral
 
-            !---> Integral on the particles position
+            !---> Integral for particles position
 
             gama2  = 0.5d0 * (1.d0 - aux2*aux2 )
             omegam = 0.5d0 * aux4 * ( aux5 - aux2*aa )                  &
@@ -412,12 +350,12 @@ endif
 
             ter5x = p21 * vagaus(ip,id) + p22 * vagaus(ip,3+id)
 
-            !---> integral on the vu fluid velocity
+            !---> integral for the flow-seen velocity
 
             p11 = sqrt( gama2*aux6 )
             ter3f = p11*vagaus(ip,id)
 
-            !---> integrale on the particules velocity
+            !---> integral for the particles velocity
 
             aux9  = 0.5d0 * tlag(ip,id) * (1.d0 - aux2*aux2)
             aux10 = 0.5d0 * taup(ip) * (1.d0 - aux1*aux1)
@@ -451,7 +389,7 @@ endif
                  + p33 * vagaus(ip,6+id)
 
             !
-            ! Update of the particle state vector
+            ! Update of the particle state-vector
             !
 
             ettp(ip,jxp+i0) = ettpa(ip,jxp+i0)                         &
@@ -477,11 +415,11 @@ endif
                   itepa(ip,jimark) = 0
                endif
 
-               if ( itepa(ip,jimark) .eq. 0   .and.                    &
-                    itepa(ip,jdiel)  .eq. iel .and.                    &
-                    ifacl(ip)  .ne. itepa(ip,jdfac)) then
-                  itepa(ip,jimark) = 10
-               endif
+!               if ( itepa(ip,jimark) .eq. 0   .and.                    &
+!                    itepa(ip,jdiel)  .eq. iel .and.                    &
+!                    ifacl(ip)  .ne. itepa(ip,jdfac)) then
+!                  itepa(ip,jimark) = 10
+!               endif
 
             else
 
@@ -495,15 +433,12 @@ endif
 
             endif
 
-            itepa(ip,jdfac) = ifacl(ip)
-            itepa(ip,jdiel) = itepa(ip,jisor)
-
-            dismin=min(dismin,distp)
-            dismax=max(dismax,distp)
+            lvisq = vislen(itepa(ip,jdfac))
+            tvisq = lvisq / uetbor(itepa(ip,jdfac))
 
             call lagesd                                                   &
             !==========
-            ( ifacl(ip) , ip     ,                                         &
+            ( itepa(ip,jdfac) , ip     ,                                   &
               nvar   , nscal  ,                                            &
               nbpmax , nvp    , nvp1   , nvep   , nivep  ,                 &
               ntersl , nvlsta , nvisbr ,                                   &
@@ -521,9 +456,6 @@ endif
 
    enddo
 
-! Free memory
-deallocate(ifacl)
-
 !----
 ! FIN
 !----
