@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2011 EDF S.A.
+! Copyright (C) 1998-2012 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -154,6 +154,7 @@ module lagran
   !    JUF,JVF,JWF  : COMPOSANTES DE LA VITESSE DU FLUIDE VU
 
   !    JMP,JDP      : MASSE, DIAMETRE
+  !    JTAUX        : POUR L'ORDRE 2, AUXILIAIRE DE CALCUL UTILE EN PARALLELE
   !    JTP,JTF,JCP  : TEMPERATURE PARTICULE ET FLUIDE ET CHALEUR SPECIFIQUE
   !    JVLS(NUSVAR) : VARIABLE SUPPLEMENTAIRES
 
@@ -167,7 +168,7 @@ module lagran
                              jup , jvp , jwp ,                               &
                              juf , jvf , jwf ,                               &
                              jmp , jdp , jtp , jtf , jcp ,                   &
-                             jhp , jmch, jmck,                               &
+                             jhp , jmch, jmck, jtaux,                        &
                              jvls(nusvar)
 
   !   Tableau TEPA
@@ -222,7 +223,6 @@ module lagran
   !          = IREBOL -> rebond elastique
   !          = IDEPO1 -> deposition definitive (particule eliminee de la memoire)
   !          = IDEPO2 -> deposition definitive (part. non eliminee de la memoire)
-  !          = IDEPO3 -> deposition temporaire (remise en suspension possible)
   !          = IENCRL -> encrassement (Charbon uniquement IPHYLA = 2)
   !          = JBORD1 -> interactions utilisateur
   !          = JBORD2 -> interactions utilisateur
@@ -317,6 +317,8 @@ module lagran
                              ilhp  , ilmch , ilmck , ildck ,                 &
                              ilvu(nussta)
 
+  integer, save ::           iactfv, iactvx, iactvy, iactvz, iactts
+
   !     DONNEES POUR LES STATISTIQUES VOLUMIQUES
   !     ----------------------------------------
 
@@ -377,7 +379,7 @@ module lagran
   !    ITSTE, ITSTI        : Termes sources pour la thermique
   !    ITSMAS              : Terme source pour la masse
   !    ITSMV1              : Terme source sur F1 (MV legeres)
-  !    ITSMV2              : Terme source sur F2 (MV loudres)
+  !    ITSMV2              : Terme source sur F2 (MV lourdes)
   !    ITSCO               : Terme source sur F3 (C sous forme de CO)
   !    ITSFP4              : Variance du traceur relatif a l air
 
@@ -420,26 +422,32 @@ module lagran
                              tprenc(ncharm2) , visref(ncharm2) , dnpenc
 
   !=============================================================================
-  ! 12. Forces chimiques
+  ! 12. Physico-chemical (DLVO) parameters
 
-  !       1) FORCES DE VAN DER WAALS
-  !       2) FORCES ELECTROSTATIQUES
+  !      cstham : Hamaker constant for the particle/fluid/substrate system
+  !      epseau : Dielectric constant of the fluid
+  !      phi1   : Electrokinetic potential of the first solid
+  !      phi2   : Electrokinetic potential of the second solid
+  !      fion   : Ionic force
 
-  integer, save ::           ladlvo
+  double precision, save ::  cstham , epseau,  phi1 , phi2, fion
 
-  !      CSTHAM : constante d'Hamaker
-  !      CSTFAR : constant de FARADET
-  !      EPSEAU : Constante dielectrique de l'eau
-  !      EPSEAU : Constante dielectrique du vide
-  !      PHI1   : potentiel solide 1
-  !      PHI1   : potentiel solide 2
-  !      FION   : force ionique
-  !      GAMASV : energie de surface
-  !      DPARMN : distance entre particule/paroi minimum
 
-  double precision, save ::  cstham , epseau  , epsvid , phi1 , phi2
-  double precision, save ::  fion   , gamasv  , dcoup  , sigch
-  double precision, save ::  cstfar , dparmn
+!    Faraday constant (C/mol)
+
+  double precision cstfar
+  parameter(cstfar = 9.648d4)
+
+
+!    Vacuum permittivity (F/m):
+
+  double precision epsvid
+  parameter(epsvid = 8.854d-12)
+
+!    Boltzmann constant (J/K):
+
+  double precision kboltz
+  parameter(kboltz = 1.38d-23)
 
   !=============================================================================
   ! 13. Mouvement brownien
@@ -448,8 +456,6 @@ module lagran
 
   integer, save :: lamvbr
 
-  double precision kboltz
-  parameter          (kboltz = 1.38d-23)
 
   !=============================================================================
   ! 14. Schema en temps, dispersion turbulente et equation de poisson
@@ -549,6 +555,7 @@ module lagran
   integer, save ::           itlag
   double precision, save ::  timlag(9999)
 
+
   !=============================================================================
 
 end module lagran
