@@ -5,7 +5,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2011 EDF S.A.
+  Copyright (C) 1998-2012 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -24,9 +24,7 @@
 
 /*----------------------------------------------------------------------------*/
 
-#if defined(HAVE_CONFIG_H)
-#include "cs_config.h"
-#endif
+#include "cs_defs.h"
 
 /*----------------------------------------------------------------------------
  * Standard C library headers
@@ -36,25 +34,18 @@
 #include <stdio.h>
 #include <string.h>
 
-/*----------------------------------------------------------------------------
- * BFT library headers
- *---------------------------------------------------------------------------*/
-
-#include <bft_error.h>
-#include <bft_mem.h>
-
-/*----------------------------------------------------------------------------
- * FVM library headers
- *---------------------------------------------------------------------------*/
-
-#include <fvm_nodal.h>
-#include <fvm_nodal_order.h>
-#include <fvm_nodal_from_desc.h>
-
 /*----------------------------------------------------------------------------
  *  Local headers
  *---------------------------------------------------------------------------*/
 
+#include "bft_error.h"
+#include "bft_mem.h"
+
+#include "fvm_nodal.h"
+#include "fvm_nodal_order.h"
+#include "fvm_nodal_from_desc.h"
+
+#include "cs_mesh_connect.h"
 #include "cs_post.h"
 
 /*----------------------------------------------------------------------------
@@ -79,13 +70,19 @@ typedef struct {
 
 } cs_join_post_t;
 
+/* Directory name separator
+   (historically, '/' for Unix/Linux, '\' for Windows, ':' for Mac
+   but '/' should work for all on modern systems) */
+
+#define DIR_SEPARATOR '/'
+
 /*============================================================================
  * Static global variables
  *===========================================================================*/
 
 static  cs_join_post_t  _cs_join_post_param;
 
-static  cs_bool_t       _cs_join_post_initialized = false;
+static  bool            _cs_join_post_initialized = false;
 
 /*============================================================================
  * Private function definitions
@@ -110,7 +107,7 @@ _init_join_writer(void)
                         "postprocessing",
                         cs_post_get_default_format(),
                         cs_post_get_default_format_options(),
-                        -1, /* No time dependency here */
+                        FVM_WRITER_FIXED_MESH,
                         false,
                         -1,
                         -1.0);
@@ -153,10 +150,10 @@ _post_vtx_dfield(fvm_nodal_t   *mesh,
                           varname,
                           FVM_WRITER_PER_NODE,
                           dim,
-                          FVM_INTERLACE,
+                          CS_INTERLACE,
                           0,
                           parent_num_shift,
-                          FVM_DOUBLE,
+                          CS_DOUBLE,
                           -1,
                           0.,
                           (const void **)var_ptr);
@@ -182,7 +179,7 @@ _post_elt_ifield(fvm_nodal_t  *mesh,
   fvm_writer_t  *writer = _cs_join_post_param.writer;
 
   cs_int_t   parent_num_shift[2]  = {0, 0};
-  fvm_datatype_t  datatype = FVM_DATATYPE_NULL;
+  cs_datatype_t  datatype = CS_DATATYPE_NULL;
 
   const int  *var_ptr[9] = {NULL, NULL, NULL,
                             NULL, NULL, NULL,
@@ -192,9 +189,9 @@ _post_elt_ifield(fvm_nodal_t  *mesh,
   assert(sizeof(cs_int_t) == sizeof(int));
 
   if (sizeof(int) == 4)
-    datatype = FVM_INT32;
+    datatype = CS_INT32;
   else if (sizeof(int) == 8)
-    datatype = FVM_INT64;
+    datatype = CS_INT64;
   else
     bft_error(__FILE__, __LINE__, 0,
               _(" Size of \"int\" is not 4 or 8 bytes.\n"
@@ -207,7 +204,7 @@ _post_elt_ifield(fvm_nodal_t  *mesh,
                           varname,
                           FVM_WRITER_PER_ELEMENT,
                           dim,
-                          FVM_INTERLACE,
+                          CS_INTERLACE,
                           0,
                           parent_num_shift,
                           datatype,
@@ -261,7 +258,7 @@ cs_join_post_mesh(const char            *mesh_name,
   const char *name = NULL;
   int  *ifield = NULL;
   double  *dfield = NULL;
-  fvm_gnum_t  *vertex_gnum = NULL;
+  cs_gnum_t  *vertex_gnum = NULL;
   cs_real_t  *vertex_coord = NULL;
   cs_int_t  *parent_vtx_num = NULL;
   fvm_nodal_t  *post_mesh = NULL;
@@ -312,7 +309,7 @@ cs_join_post_mesh(const char            *mesh_name,
 
   /* Order vertices by increasing global number */
 
-  BFT_MALLOC(vertex_gnum, join_mesh->n_vertices, fvm_gnum_t);
+  BFT_MALLOC(vertex_gnum, join_mesh->n_vertices, cs_gnum_t);
 
   for (i = 0; i < join_mesh->n_vertices; i++)
     vertex_gnum[i] = (join_mesh->vertices[i]).gnum;
@@ -408,6 +405,7 @@ cs_join_post_after_merge(cs_join_param_t          join_param,
 
   int  writer_ids[] = {_cs_join_post_param.writer_num};
   char  *mesh_name = NULL;
+  fvm_nodal_t *adj_mesh = NULL, *sel_mesh = NULL;
 
   if (_cs_join_post_initialized == false)
     return;
@@ -417,32 +415,42 @@ cs_join_post_after_merge(cs_join_param_t          join_param,
   BFT_MALLOC(mesh_name, strlen("AdjacentJoinFaces_j") + 2 + 1, char);
   sprintf(mesh_name,"%s%02d", "AdjacentJoinFaces_j", join_param.num);
 
-  cs_post_define_surface_mesh_by_list(adj_mesh_id,
-                                      mesh_name,
-                                      join_select->n_i_adj_faces,
-                                      join_select->n_b_adj_faces,
-                                      join_select->i_adj_faces,
-                                      join_select->b_adj_faces,
-                                      false,
-                                      false,
-                                      1,
-                                      writer_ids);
+  adj_mesh = cs_mesh_connect_faces_to_nodal(cs_glob_mesh,
+                                            mesh_name,
+                                            false, /* include families */
+                                            join_select->n_i_adj_faces,
+                                            join_select->n_b_adj_faces,
+                                            join_select->i_adj_faces,
+                                            join_select->b_adj_faces);
+
+  cs_post_define_existing_mesh(adj_mesh_id,
+                               adj_mesh,
+                               0,    /* dim_shift */
+                               true, /* transfer ownership */
+                               false,
+                               1,
+                               writer_ids);
 
   sel_mesh_id = cs_post_get_free_mesh_id();
 
   BFT_REALLOC(mesh_name, strlen("JoinFacesAfterMerge_j") + 2 + 1, char);
   sprintf(mesh_name,"%s%02d", "JoinFacesAfterMerge_j", join_param.num);
 
-  cs_post_define_surface_mesh_by_list(sel_mesh_id,
-                                      mesh_name,
-                                      0,
-                                      join_select->n_faces,
-                                      NULL,
-                                      join_select->faces,
-                                      false,
-                                      false,
-                                      1,
-                                      writer_ids);
+  sel_mesh = cs_mesh_connect_faces_to_nodal(cs_glob_mesh,
+                                            mesh_name,
+                                            false, /* include families */
+                                            join_select->n_faces,
+                                            0,
+                                            join_select->faces,
+                                            NULL);
+
+  cs_post_define_existing_mesh(sel_mesh_id,
+                               sel_mesh,
+                               0,    /* dim_shift */
+                               true, /* transfer ownership */
+                               false,
+                               1,
+                               writer_ids);
 
   /* Post */
 
@@ -467,7 +475,7 @@ cs_join_post_after_merge(cs_join_param_t          join_param,
 void
 cs_join_post_after_split(cs_int_t          n_old_i_faces,
                          cs_int_t          n_old_b_faces,
-                         fvm_gnum_t        n_g_new_b_faces,
+                         cs_gnum_t         n_g_new_b_faces,
                          cs_int_t          n_select_faces,
                          const cs_mesh_t  *mesh,
                          cs_join_param_t   join_param)
@@ -476,8 +484,9 @@ cs_join_post_after_split(cs_int_t          n_old_i_faces,
 
   int  writer_ids[] = {_cs_join_post_param.writer_num};
   char  *mesh_name = NULL;
-  cs_int_t  *post_i_faces = NULL, *post_b_faces = NULL;
-  cs_int_t  post_i_mesh_id = cs_post_get_free_mesh_id();
+  cs_lnum_t  *post_i_faces = NULL, *post_b_faces = NULL;
+  fvm_nodal_t  *post_i_mesh = NULL;
+  int  post_i_mesh_id = cs_post_get_free_mesh_id();
 
   const int  n_new_i_faces = mesh->n_i_faces - n_old_i_faces;
   const int  n_new_b_faces = mesh->n_b_faces - n_old_b_faces + n_select_faces;
@@ -502,34 +511,45 @@ cs_join_post_after_split(cs_int_t          n_old_i_faces,
   BFT_MALLOC(mesh_name, strlen("InteriorJoinedFaces_j") + 2 + 1, char);
   sprintf(mesh_name,"%s%02d", "InteriorJoinedFaces_j", join_param.num);
 
-  cs_post_define_surface_mesh_by_list(post_i_mesh_id,
-                                      mesh_name,
-                                      n_new_i_faces,
-                                      0,
-                                      post_i_faces,
-                                      NULL,
-                                      false,
-                                      false,
-                                      1,
-                                      writer_ids);
+  post_i_mesh = cs_mesh_connect_faces_to_nodal(cs_glob_mesh,
+                                               mesh_name,
+                                               false, /* include families */
+                                               n_new_i_faces,
+                                               0,
+                                               post_i_faces,
+                                               NULL);
+
+  cs_post_define_existing_mesh(post_i_mesh_id,
+                               post_i_mesh,
+                               0,    /* dim_shift */
+                               true, /* transfer ownership */
+                               false,
+                               1,
+                               writer_ids);
 
   if (join_param.visualization > 1 && n_g_new_b_faces > 0) {
 
     cs_int_t  post_b_mesh_id = cs_post_get_free_mesh_id();
+    fvm_nodal_t  *post_b_mesh = NULL;
 
     BFT_REALLOC(mesh_name, strlen("BoundaryJoinedFaces_j") + 2 + 1, char);
     sprintf(mesh_name,"%s%02d", "BoundaryJoinedFaces_j", join_param.num);
 
-    cs_post_define_surface_mesh_by_list(post_b_mesh_id,
-                                        mesh_name,
-                                        0,
-                                        n_new_b_faces,
-                                        NULL,
-                                        post_b_faces,
-                                        false,
-                                        false,
-                                        1,
-                                        writer_ids);
+    post_b_mesh = cs_mesh_connect_faces_to_nodal(cs_glob_mesh,
+                                                 mesh_name,
+                                                 false, /* include families */
+                                                 0,
+                                                 n_new_b_faces,
+                                                 NULL,
+                                                 post_b_faces);
+
+    cs_post_define_existing_mesh(post_b_mesh_id,
+                                 post_b_mesh,
+                                 0,    /* dim_shift */
+                                 true, /* transfer ownership */
+                                 false,
+                                 1,
+                                 writer_ids);
 
   }
 
@@ -564,6 +584,7 @@ cs_join_post_cleaned_faces(cs_int_t         n_i_clean_faces,
   int  writer_ids[] = {_cs_join_post_param.writer_num};
   int  post_mesh_id = cs_post_get_free_mesh_id();
   char  *name = NULL;
+  fvm_nodal_t *export_mesh = NULL;
 
   if (_cs_join_post_initialized == false)
     return;
@@ -571,18 +592,23 @@ cs_join_post_cleaned_faces(cs_int_t         n_i_clean_faces,
   BFT_MALLOC(name, strlen("CleanFaces_j") + 2 + 1, char);
   sprintf(name,"%s%02d", "CleanFaces_j", param.num);
 
-  cs_post_define_surface_mesh_by_list(post_mesh_id,
-                                      name,
-                                      n_i_clean_faces,
-                                      n_b_clean_faces,
-                                      i_clean_faces,
-                                      b_clean_faces,
-                                      false,
-                                      false,
-                                      1,
-                                      writer_ids);
+  export_mesh = cs_mesh_connect_faces_to_nodal(cs_glob_mesh,
+                                               name,
+                                               false, /* include families */
+                                               n_i_clean_faces,
+                                               n_b_clean_faces,
+                                               i_clean_faces,
+                                               b_clean_faces);
 
-  /* Otput post-processing data */
+  cs_post_define_existing_mesh(post_mesh_id,
+                               export_mesh,
+                               0,    /* dim_shift */
+                               true, /* transfer ownership */
+                               false,
+                               1,
+                               writer_ids);
+
+  /* Output post-processing data */
 
   cs_post_activate_writer(_cs_join_post_param.writer_num, 1);
   cs_post_write_meshes(1,0);
@@ -617,7 +643,7 @@ cs_join_post_dump_mesh(const char            *basename,
 
   len = strlen("log/JoinDBG_.dat") + strlen(basename) + 4 + 2 + 1;
   BFT_MALLOC(fullname, len, char);
-  sprintf(fullname, "log%cJoin%02dDBG_%s%04d.dat", CS_DIR_SEPARATOR,
+  sprintf(fullname, "log%cJoin%02dDBG_%s%04d.dat", DIR_SEPARATOR,
           param.num, basename, rank_id);
 
 #if 0 && defined(DEBUG) && !defined(NDEBUG) /* Dump mesh structure */
