@@ -5,7 +5,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2011 EDF S.A.
+  Copyright (C) 1998-2012 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -24,9 +24,7 @@
 
 /*----------------------------------------------------------------------------*/
 
-#if defined(HAVE_CONFIG_H)
-#include "cs_config.h"
-#endif
+#include "cs_defs.h"
 
 /*----------------------------------------------------------------------------
  * Standard C library headers
@@ -39,27 +37,17 @@
 #include <float.h>
 #include <assert.h>
 
-/*----------------------------------------------------------------------------
- * BFT library headers
- *---------------------------------------------------------------------------*/
-
-#include <bft_mem.h>
-#include <bft_timer.h>
-#include <bft_printf.h>
-
-/*----------------------------------------------------------------------------
- * FVM library headers
- *---------------------------------------------------------------------------*/
-
-#include <fvm_order.h>
-#include <fvm_io_num.h>
-#include <fvm_parall.h>
-#include <fvm_periodicity.h>
-
 /*----------------------------------------------------------------------------
  * Local headers
  *---------------------------------------------------------------------------*/
 
+#include "bft_mem.h"
+#include "bft_printf.h"
+
+#include "fvm_io_num.h"
+#include "fvm_periodicity.h"
+
+#include "cs_order.h"
 #include "cs_search.h"
 #include "cs_join_post.h"
 
@@ -108,9 +96,9 @@ typedef struct {
   /* The two following arrays are built after the face splitting. So, they
      don't need to be resizable */
 
-  fvm_gnum_t    n_g_subfaces;     /* Global number of subfaces after splitting */
-  fvm_gnum_t   *subface_gconnect; /* Subface -> glob. vertex list */
-  fvm_gnum_t   *subface_gnum;     /* Subface global numbering */
+  cs_gnum_t   n_g_subfaces;     /* Global number of subfaces after splitting */
+  cs_gnum_t  *subface_gconnect; /* Subface -> glob. vertex list */
+  cs_gnum_t  *subface_gnum;     /* Subface global numbering */
 
 } face_builder_t;
 
@@ -262,16 +250,16 @@ _face_bbox(const cs_join_mesh_t  *m,
 
 static void
 _renumber_local_ordered_i(cs_int_t          n_elts,
-                          const fvm_lnum_t  order[],
+                          const cs_lnum_t   order[],
                           const cs_int_t    index[],
-                          fvm_gnum_t        glist[],
+                          cs_gnum_t         glist[],
                           cs_int_t         *new_index[],
-                          fvm_gnum_t       *new_glist[])
+                          cs_gnum_t        *new_glist[])
 {
   cs_int_t  i, j, k, o_id;
 
   cs_int_t  *_new_index = NULL;
-  fvm_gnum_t  *_new_glist = NULL;
+  cs_gnum_t   *_new_glist = NULL;
 
   assert(index[0] == 0); /* case index[0] = 1 coulb be coded in the future */
 
@@ -290,7 +278,7 @@ _renumber_local_ordered_i(cs_int_t          n_elts,
 
   /* Build a new list */
 
-  BFT_MALLOC(_new_glist, _new_index[n_elts], fvm_gnum_t);
+  BFT_MALLOC(_new_glist, _new_index[n_elts], cs_gnum_t);
 
   for (i = 0; i < n_elts; i++) {
 
@@ -321,7 +309,7 @@ _renumber_local_ordered_i(cs_int_t          n_elts,
 
 static void
 _get_faces_to_send(const cs_join_gset_t  *o2n_hist,
-                   const fvm_gnum_t       gnum_rank_index[],
+                   const cs_gnum_t        gnum_rank_index[],
                    cs_int_t              *send_rank_index[],
                    cs_int_t              *send_faces[])
 {
@@ -329,7 +317,7 @@ _get_faces_to_send(const cs_join_gset_t  *o2n_hist,
 
   cs_int_t  reduce_size = 0;
   cs_int_t  *_send_rank_index = NULL, *_send_faces = NULL, *reduce_ids = NULL;
-  fvm_gnum_t  *reduce_index = NULL;
+  cs_gnum_t  *reduce_index = NULL;
   cs_join_gset_t  *new_face_rank = NULL;
 
   const int  n_ranks = cs_glob_n_ranks;
@@ -352,7 +340,7 @@ _get_faces_to_send(const cs_join_gset_t  *o2n_hist,
     if (gnum_rank_index[i] < gnum_rank_index[i+1])
       reduce_size++;
 
-  BFT_MALLOC(reduce_index, reduce_size+1, fvm_gnum_t);
+  BFT_MALLOC(reduce_index, reduce_size+1, cs_gnum_t);
   BFT_MALLOC(reduce_ids, reduce_size, cs_int_t);
 
   reduce_size = 0;
@@ -388,7 +376,7 @@ _get_faces_to_send(const cs_join_gset_t  *o2n_hist,
   for (i = 0; i < n_ranks; i++)
     new_face_rank->index[i+1] += new_face_rank->index[i];
 
-  BFT_MALLOC(new_face_rank->g_list, new_face_rank->index[n_ranks], fvm_gnum_t);
+  BFT_MALLOC(new_face_rank->g_list, new_face_rank->index[n_ranks], cs_gnum_t);
 
   /* Fill the list of ranks */
 
@@ -677,7 +665,7 @@ _dump_face_builder(cs_int_t               face_id,
  *   true if an adjacent face was found else false
  *---------------------------------------------------------------------------*/
 
-static cs_bool_t
+static bool
 _find_best_adj_face(cs_join_param_t         param,
                     cs_int_t                eid,
                     cs_int_t                fid,
@@ -692,13 +680,13 @@ _find_best_adj_face(cs_join_param_t         param,
 
   int  best_fid = -1;
   double  max_plane = -DBL_MAX;
-  cs_bool_t  respect_plane = false;
+  bool  respect_plane = false;
 
   const double  plane2 = param.plane_criteria;
 
 #if 0 && defined(DEBUG) && !defined(NDEBUG)
 #define _DBGTST 1
-  cs_bool_t  tst_dbg = ( fid==492 || fid==1039 || fid==744 || fid==262 ||
+  bool  tst_dbg = ( fid==492 || fid==1039 || fid==744 || fid==262 ||
                          fid==546 || fid==1057 || fid==564 ? true : false);
 #else
 #define _DBGTST 0
@@ -839,8 +827,8 @@ _find_next(cs_join_param_t         param,
 
 #if 0 && defined(DEBUG) && !defined(NDEBUG)
 #define _DBGTST 1
-  cs_bool_t  tst_dbg = ( fid==492 || fid==1039 || fid==744 || fid==262 ||
-                         fid==546 || fid==1057 || fid==564 ? true : false);
+  bool  tst_dbg = (fid==492 || fid==1039 || fid==744 || fid==262 ||
+                   fid==546 || fid==1057 || fid==564 ? true : false);
 #else
 #define _DBGTST 0
 #endif
@@ -885,7 +873,7 @@ _find_next(cs_join_param_t         param,
 
       if (vid3 != vid1) {
 
-        cs_bool_t  is_in_bbox = true;
+        bool  is_in_bbox = true;
         cs_int_t  connect_eid = CS_ABS(edges->edge_lst[i]) - 1;
 
         /* Test if the connected vertex is inside the face */
@@ -897,11 +885,11 @@ _find_next(cs_join_param_t         param,
 
         if (is_in_bbox == true) {
 
-          cs_bool_t  respect_plane = _find_best_adj_face(param,
-                                                         connect_eid, fid,
-                                                         fnorm, adj_fnorm,
-                                                         face_normal,
-                                                         e2f_idx, e2f_lst);
+          bool  respect_plane = _find_best_adj_face(param,
+                                                    connect_eid, fid,
+                                                    fnorm, adj_fnorm,
+                                                    face_normal,
+                                                    e2f_idx, e2f_lst);
 
           if (respect_plane == true) {
 
@@ -1110,15 +1098,15 @@ _split_face(cs_int_t                fid,
   cs_join_rset_t  *_ext_edges = *ext_edges;
   cs_join_rset_t  *_int_edges = *int_edges;
 
-  const fvm_gnum_t  *fgnum = work->face_gnum;
+  const cs_gnum_t  *fgnum = work->face_gnum;
   const int  max_subfaces = param.max_sub_faces;
   const int  verbosity = param.verbosity;
   FILE  *logfile = cs_glob_join_log;
 
 #if 0 && defined(DEBUG) && !defined(NDEBUG)
 #define _DBGTST 1
-  cs_bool_t  tst_dbg = ( fid==492 || fid==1039 || fid==744 || fid==262 ||
-                         fid==546 || fid==1057 || fid==564 ? true : false);
+  bool  tst_dbg = (fid==492 || fid==1039 || fid==744 || fid==262 ||
+                   fid==546 || fid==1057 || fid==564 ? true : false);
   const cs_join_vertex_t  *vertices = work->vertices;
 #else
 #define _DBGTST 0
@@ -1149,7 +1137,7 @@ _split_face(cs_int_t                fid,
 
       cs_int_t  head_edge_num = _head_edges->array[head_edge_shift];
       cs_int_t  edge_num = head_edge_num;
-      cs_int_t  edge_id = FVM_ABS(edge_num) - 1;
+      cs_int_t  edge_id = CS_ABS(edge_num) - 1;
 
 #if _DBGTST && defined(DEBUG) && !defined(NDEBUG)
       if (tst_dbg && logfile != NULL)
@@ -1388,11 +1376,11 @@ _split_face(cs_int_t                fid,
  *   true or false
  *---------------------------------------------------------------------------*/
 
-inline static cs_bool_t
+inline static bool
 _indexed_is_greater(size_t           i1,
                     size_t           i2,
                     const cs_int_t   index[],
-                    const fvm_gnum_t number[])
+                    const cs_gnum_t number[])
 {
   int  i;
 
@@ -1437,23 +1425,23 @@ _get_subface_gnum(face_builder_t         *builder,
                   const cs_join_mesh_t   *work)
 {
   cs_int_t  i, j, k, shift;
-  fvm_gnum_t  min_val;
+  cs_gnum_t  min_val;
 
   cs_int_t  max_size = 0;
   cs_int_t  n_subfaces = builder->face_index[builder->n_faces];
   cs_int_t  *index = builder->subface_index->array;
-  fvm_gnum_t  *gconnect = builder->subface_gconnect;
-  fvm_gnum_t  *glob_list = NULL, *tmp = NULL, *vgnum = NULL;
-  fvm_io_num_t  *subface_io_num = NULL;
+  cs_gnum_t  *gconnect = builder->subface_gconnect;
+  cs_gnum_t  *glob_list = NULL, *tmp = NULL, *vgnum = NULL;
+  fvm_io_num_t *subface_io_num = NULL;
 
-  const fvm_gnum_t  *global_num = NULL;
+  const cs_gnum_t  *global_num = NULL;
   const cs_join_vertex_t  *vertices = work->vertices;
 
   assert(index != NULL);
 
   /* Allocate the buffer we want to define */
 
-  BFT_MALLOC(builder->subface_gnum, n_subfaces, fvm_gnum_t);
+  BFT_MALLOC(builder->subface_gnum, n_subfaces, cs_gnum_t);
 
   /* Re-arrange gconnect in order to have for each subface:
       - vertex with the minimal glob. num. in first place,
@@ -1462,10 +1450,10 @@ _get_subface_gnum(face_builder_t         *builder,
   */
 
   for (i = 0; i < n_subfaces; i++)
-    max_size = FVM_MAX(max_size, index[i+1] - index[i]);
+    max_size = CS_MAX(max_size, index[i+1] - index[i]);
 
-  BFT_MALLOC(tmp, max_size, fvm_gnum_t);
-  BFT_MALLOC(glob_list, index[n_subfaces], fvm_gnum_t);
+  BFT_MALLOC(tmp, max_size, cs_gnum_t);
+  BFT_MALLOC(glob_list, index[n_subfaces], cs_gnum_t);
 
   /* Build glob_list */
 
@@ -1515,7 +1503,7 @@ _get_subface_gnum(face_builder_t         *builder,
   /* Copy glob_list as the new subface global connectivity and
      use it to define a synchronized sub-face connectivity */
 
-  BFT_MALLOC(vgnum, work->n_vertices, fvm_gnum_t);
+  BFT_MALLOC(vgnum, work->n_vertices, cs_gnum_t);
 
   for (i = 0; i < work->n_vertices; i++)
     vgnum[i] = vertices[i].gnum;
@@ -1544,11 +1532,11 @@ _get_subface_gnum(face_builder_t         *builder,
     /* Local ordering */
 
     cs_int_t  *order_index = NULL;
-    fvm_gnum_t  *order_glob_list = NULL;
-    fvm_lnum_t  *order = fvm_order_local_i(NULL,
-                                           glob_list,
-                                           index,
-                                           n_subfaces);
+    cs_gnum_t  *order_glob_list = NULL;
+    cs_lnum_t  *order = cs_order_gnum_i(NULL,
+                                        glob_list,
+                                        index,
+                                        n_subfaces);
 
     _renumber_local_ordered_i(n_subfaces,
                               order,
@@ -1581,11 +1569,11 @@ _get_subface_gnum(face_builder_t         *builder,
   }
   else { /* Serial treatment */
 
-    fvm_gnum_t  gnum = 1;
-    fvm_lnum_t  *order = fvm_order_local_i(NULL,
-                                           glob_list,
-                                           index,
-                                           n_subfaces);
+    cs_gnum_t  gnum = 1;
+    cs_lnum_t  *order = cs_order_gnum_i(NULL,
+                                        glob_list,
+                                        index,
+                                        n_subfaces);
 
     builder->subface_gnum[order[0]] = gnum;
 
@@ -1644,12 +1632,12 @@ _update_mesh_after_split(cs_join_block_info_t    block_info,
                          cs_join_gset_t        **p_o2n_hist)
 {
   cs_int_t  i, j, k, id, shift, n_subfaces, o_id;
-  fvm_gnum_t  prev, cur;
+  cs_gnum_t  prev, cur;
 
   cs_int_t  n_new_faces = 0;
   char  *new_mesh_name = NULL;
   cs_int_t  *subfaces = NULL;
-  fvm_lnum_t  *order = NULL;
+  cs_lnum_t  *order = NULL;
   cs_join_gset_t  *o2n_hist = NULL;
   cs_join_mesh_t  *init_mesh = *mesh, *new_mesh = NULL;
 
@@ -1671,18 +1659,18 @@ _update_mesh_after_split(cs_join_block_info_t    block_info,
   if ((int)block_info.local_size != builder->n_faces)
     bft_error(__FILE__, __LINE__, 0,
               _(" Inconsistent values between:\n"
-                "    block_info.local_size  %8d\n"
-                "    builder->n_faces:      %8d\n"
+                "    block_info.local_size  %8ld\n"
+                "    builder->n_faces:      %8ld\n"
                 " These values should be equal.\n"),
-              block_info.local_size, builder->n_faces);
+              (long)block_info.local_size, (long)builder->n_faces);
 
   /* Compute the number of new faces */
 
   n_subfaces = builder->face_index[builder->n_faces];
 
-  BFT_MALLOC(order, n_subfaces, fvm_lnum_t);
+  BFT_MALLOC(order, n_subfaces, cs_lnum_t);
 
-  fvm_order_local_allocated(NULL, builder->subface_gnum, order, n_subfaces);
+  cs_order_gnum_allocated(NULL, builder->subface_gnum, order, n_subfaces);
 
   prev = 0;
   n_new_faces = 0;
@@ -1722,7 +1710,7 @@ _update_mesh_after_split(cs_join_block_info_t    block_info,
   new_mesh->n_faces = n_new_faces;
   new_mesh->n_g_faces = builder->n_g_subfaces;
 
-  BFT_MALLOC(new_mesh->face_gnum, n_new_faces, fvm_gnum_t);
+  BFT_MALLOC(new_mesh->face_gnum, n_new_faces, cs_gnum_t);
   BFT_MALLOC(new_mesh->face_vtx_idx, n_new_faces + 1, cs_int_t);
 
   for (i = 0; i < n_new_faces; i++) {
@@ -1790,7 +1778,7 @@ _update_mesh_after_split(cs_join_block_info_t    block_info,
       o2n_hist->index[i] = builder->face_index[i];
 
     BFT_MALLOC(o2n_hist->g_list,
-               o2n_hist->index[o2n_hist->n_elts], fvm_gnum_t);
+               o2n_hist->index[o2n_hist->n_elts], cs_gnum_t);
 
     for (i = 0; i < builder->n_faces; i++) {
 
@@ -1843,7 +1831,7 @@ cs_join_split_faces(cs_join_param_t          param,
                     cs_join_gset_t         **old2new_history)
 {
   cs_int_t  fid, j, face_s, subface_s, block_id, vid;
-  fvm_gnum_t  vgnum;
+  cs_gnum_t  vgnum;
   cs_join_split_error_t  code;
   cs_join_block_info_t  block_info;
 
@@ -2072,12 +2060,12 @@ cs_join_split_faces(cs_join_param_t          param,
   /* Display information in case of problem during the face splitting */
 
   {
-    fvm_gnum_t  g_in_buf[4], g_out_buf[4];
+    cs_gnum_t  g_in_buf[4], g_out_buf[4];
 
-    fvm_gnum_t  n_g_face_problems = n_face_problems;
-    fvm_gnum_t  n_g_open_cycles = open_cycle->n_elts;
-    fvm_gnum_t  n_g_edges_twice = edge_traversed_twice->n_elts;
-    fvm_gnum_t  n_g_loop_limit = loop_limit->n_elts;
+    cs_gnum_t  n_g_face_problems = n_face_problems;
+    cs_gnum_t  n_g_open_cycles = open_cycle->n_elts;
+    cs_gnum_t  n_g_edges_twice = edge_traversed_twice->n_elts;
+    cs_gnum_t  n_g_loop_limit = loop_limit->n_elts;
 
 #if defined(HAVE_MPI)
     if (n_ranks > 1) {
@@ -2089,7 +2077,7 @@ cs_join_split_faces(cs_join_param_t          param,
       g_in_buf[2] = n_g_edges_twice;
       g_in_buf[3] = n_g_loop_limit;
 
-      MPI_Allreduce(g_in_buf, g_out_buf, 4, FVM_MPI_GNUM, MPI_SUM, mpi_comm);
+      MPI_Allreduce(g_in_buf, g_out_buf, 4, CS_MPI_GNUM, MPI_SUM, mpi_comm);
 
       n_g_face_problems = g_out_buf[0];
       n_g_open_cycles = g_out_buf[1];
@@ -2168,7 +2156,7 @@ cs_join_split_faces(cs_join_param_t          param,
 
     /* Define subface_gconnect */
 
-    BFT_MALLOC(builder->subface_gconnect, sub_connect_size, fvm_gnum_t);
+    BFT_MALLOC(builder->subface_gconnect, sub_connect_size, cs_gnum_t);
 
     for (j = 0; j < sub_connect_size; j++) {
       vid = builder->subface_connect->array[j] - 1;
@@ -2244,7 +2232,7 @@ cs_join_split_faces(cs_join_param_t          param,
 void
 cs_join_split_update_struct(const cs_join_param_t   param,
                             const cs_join_mesh_t   *work_mesh,
-                            const fvm_gnum_t        gnum_rank_index[],
+                            const cs_gnum_t         gnum_rank_index[],
                             cs_join_gset_t        **o2n_hist,
                             cs_join_mesh_t        **local_mesh)
 {
@@ -2269,12 +2257,12 @@ cs_join_split_update_struct(const cs_join_param_t   param,
 
     cs_int_t  j, subface_id;
     cs_int_t  *send_rank_index = NULL, *send_faces = NULL;
-    fvm_gnum_t  *init_face_gnum = NULL;
+    cs_gnum_t  *init_face_gnum = NULL;
     cs_join_gset_t  *distrib_sync_hist = NULL;
     cs_int_t  n_init_faces = _local_mesh->n_faces;
-    fvm_gnum_t  n_g_init_faces = _local_mesh->n_g_faces;
+    cs_gnum_t  n_g_init_faces = _local_mesh->n_g_faces;
 
-    MPI_Comm  mpi_comm = fvm_parall_get_mpi_comm();
+    MPI_Comm  mpi_comm = cs_glob_mpi_comm;
 
     if (param.perio_type != FVM_PERIODICITY_NULL) {
 
@@ -2282,7 +2270,7 @@ cs_join_split_update_struct(const cs_join_param_t   param,
 
       /* Save the initial global face numbering */
 
-      BFT_MALLOC(init_face_gnum, 2*n_init_faces, fvm_gnum_t);
+      BFT_MALLOC(init_face_gnum, 2*n_init_faces, cs_gnum_t);
 
       for (i = 0; i < n_init_faces; i++) {
         init_face_gnum[2*i] = _local_mesh->face_gnum[i];
@@ -2296,7 +2284,7 @@ cs_join_split_update_struct(const cs_join_param_t   param,
 
       /* Save the initial global face numbering */
 
-      BFT_MALLOC(init_face_gnum, n_init_faces, fvm_gnum_t);
+      BFT_MALLOC(init_face_gnum, n_init_faces, cs_gnum_t);
 
       for (i = 0; i < n_init_faces; i++)
         init_face_gnum[i] = _local_mesh->face_gnum[i];
