@@ -5,7 +5,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2011 EDF S.A.
+  Copyright (C) 1998-2012 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -24,9 +24,7 @@
 
 /*----------------------------------------------------------------------------*/
 
-#if defined(HAVE_CONFIG_H)
-#include "cs_config.h"
-#endif
+#include "cs_defs.h"
 
 /*----------------------------------------------------------------------------
  * Standard C library headers
@@ -38,29 +36,20 @@
 #include <string.h>
 #include <math.h>
 
-/*----------------------------------------------------------------------------
- * BFT library headers
- *---------------------------------------------------------------------------*/
-
-#include <bft_file.h>
-#include <bft_mem.h>
-#include <bft_printf.h>
-
-/*----------------------------------------------------------------------------
- * FVM library headers
- *---------------------------------------------------------------------------*/
-
-#include "fvm_defs.h"
-#include <fvm_parall.h>
-#include <fvm_io_num.h>
-#include <fvm_order.h>
-
 /*----------------------------------------------------------------------------
  *  Local headers
  *---------------------------------------------------------------------------*/
 
+#include "bft_mem.h"
+#include "bft_printf.h"
+
+#include "fvm_defs.h"
+#include "fvm_io_num.h"
+
 #include "cs_join_util.h"
+#include "cs_file.h"
 #include "cs_mesh.h"
+#include "cs_order.h"
 #include "cs_search.h"
 #include "cs_sort.h"
 
@@ -88,6 +77,12 @@ FILE  *cs_glob_join_log = NULL;
  * Macro and type definitions
  *===========================================================================*/
 
+/* Directory name separator
+   (historically, '/' for Unix/Linux, '\' for Windows, ':' for Mac
+   but '/' should work for all on modern systems) */
+
+#define DIR_SEPARATOR '/'
+
 /*============================================================================
  * Private function definitions
  *===========================================================================*/
@@ -318,22 +313,22 @@ _join_select_destroy(cs_join_param_t     param,
  *---------------------------------------------------------------------------*/
 
 static void
-_compact_face_gnum_selection(cs_int_t     n_select_faces,
-                             fvm_gnum_t  *reduce_gnum[],
-                             fvm_gnum_t  *reduce_gnum_index[])
+_compact_face_gnum_selection(cs_int_t    n_select_faces,
+                             cs_gnum_t  *reduce_gnum[],
+                             cs_gnum_t  *reduce_gnum_index[])
 {
   cs_int_t  i;
 
-  fvm_gnum_t  shift = 0;
-  fvm_gnum_t  *_reduce_gnum = *reduce_gnum;
-  fvm_gnum_t  *_reduce_gnum_index = *reduce_gnum_index;
+  cs_gnum_t  shift = 0;
+  cs_gnum_t  *_reduce_gnum = *reduce_gnum;
+  cs_gnum_t  *_reduce_gnum_index = *reduce_gnum_index;
 
   const int  n_ranks = cs_glob_n_ranks;
   const int  local_rank = CS_MAX(cs_glob_rank_id, 0);
 
   assert(_reduce_gnum_index == NULL);
 
-  BFT_MALLOC(_reduce_gnum_index, n_ranks + 1, fvm_gnum_t);
+  BFT_MALLOC(_reduce_gnum_index, n_ranks + 1, cs_gnum_t);
 
   for (i = 0; i < n_ranks; i++)
     _reduce_gnum_index[i] = 0;
@@ -341,10 +336,10 @@ _compact_face_gnum_selection(cs_int_t     n_select_faces,
   if (n_ranks > 1) {
 #if defined(HAVE_MPI)
     MPI_Comm  mpi_comm = cs_glob_mpi_comm;
-    fvm_gnum_t  _n_faces = n_select_faces;
+    cs_gnum_t  _n_faces = n_select_faces;
 
-    MPI_Allgather(&_n_faces, 1, FVM_MPI_GNUM,
-                  &(_reduce_gnum_index[1]), 1, FVM_MPI_GNUM, mpi_comm);
+    MPI_Allgather(&_n_faces, 1, CS_MPI_GNUM,
+                  &(_reduce_gnum_index[1]), 1, CS_MPI_GNUM, mpi_comm);
 #endif
 
     for (i = 0; i < n_ranks; i++)
@@ -356,11 +351,11 @@ _compact_face_gnum_selection(cs_int_t     n_select_faces,
   else {
 
     assert(n_ranks == 1);
-    _reduce_gnum_index[n_ranks] = (fvm_gnum_t)n_select_faces;
+    _reduce_gnum_index[n_ranks] = (cs_gnum_t)n_select_faces;
 
   }
 
-  BFT_MALLOC(_reduce_gnum, n_select_faces, fvm_gnum_t);
+  BFT_MALLOC(_reduce_gnum, n_select_faces, cs_gnum_t);
 
   for (i = 0; i < n_select_faces; i++)
     _reduce_gnum[i] = shift + i + 1;
@@ -507,10 +502,10 @@ _extract_contig_faces(cs_int_t          n_vertices,
 
 /*----------------------------------------------------------------------------
  * Define a structure used for synchronizing "single" vertices.
- * Use a fvm_interface_t structure to help the build.
+ * Use a cs_interface_t structure to help the build.
  *
  * parameters:
- *   interfaces     <-- pointer to a fvm_interface_set_t structure
+ *   interfaces     <-- pointer to a cs_interface_set_t structure
  *   var_size       <-- number of elements in var buffer
  *   count          <-> counter buffer (0: not selected, 1 otherwise)
  *   related_ranks  <-> rank associated to each single vertex (size: var_size)
@@ -518,113 +513,41 @@ _extract_contig_faces(cs_int_t          n_vertices,
  *----------------------------------------------------------------------------*/
 
 static void
-_add_single_vertices(fvm_interface_set_t    *interfaces,
-                     fvm_lnum_t              var_size,
-                     fvm_lnum_t             *count,
-                     fvm_lnum_t             *related_ranks,
-                     cs_join_sync_t         *single)
+_add_single_vertices(cs_interface_set_t  *interfaces,
+                     cs_lnum_t            var_size,
+                     cs_lnum_t           *count,
+                     cs_lnum_t           *related_ranks,
+                     cs_join_sync_t      *single)
 {
-  int  request_count, distant_rank, n_interfaces, total_size;
-  int  id, ii, last_found_rank;
+  int  distant_rank, n_interfaces, last_found_rank;
+  cs_lnum_t  id, ii;
 
-  int  count_size = 0;
-  int  n_max_ranks = 0, n_max_elts = 0;
-  fvm_lnum_t  n_entities = 0;
-  int  *buf = NULL, *send_buf = NULL, *recv_buf = NULL;
+  int  n_max_ranks = 0;
+  cs_lnum_t  count_size = 0, n_entities = 0, total_size = 0, n_max_elts = 0;
+  cs_lnum_t  *buf = NULL, *recv_buf = NULL;
 
-  MPI_Request  *request = NULL;
-  MPI_Status  *status  = NULL;
-  MPI_Comm  mpi_comm = cs_glob_mpi_comm;
-
-  const int  local_rank = CS_MAX(cs_glob_rank_id, 0);
-  const fvm_lnum_t  *local_num = NULL;
-  const fvm_interface_t  *interface = NULL;
+  const cs_lnum_t  *local_id = NULL;
+  const cs_interface_t  *interface = NULL;
 
   assert(count != NULL);
   assert(single != NULL);
 
   /* Initialize and allocate */
 
-  n_interfaces = fvm_interface_set_size(interfaces);
+  n_interfaces = cs_interface_set_size(interfaces);
 
-  for (id = 0; id < n_interfaces; id++) {
-    count_size
-      += fvm_interface_size(fvm_interface_set_get(interfaces, id));
-  }
+  total_size = cs_interface_set_n_elts(interfaces);
 
-  total_size = count_size;
+  BFT_MALLOC(buf, total_size, cs_lnum_t);
 
-  BFT_MALLOC(buf, total_size * 2, int);
+  /* Exchange with distant ranks */
 
-  BFT_MALLOC(request, n_interfaces * 2, MPI_Request);
-  BFT_MALLOC(status,  n_interfaces * 2, MPI_Status);
-
-  /* Send and Receive data from distant ranks with
-     non-blocking communications */
-
-  request_count = 0;
-  count_size  = 0;
-
-  /* Receive */
-
-  for (id = 0; id < n_interfaces; id++) {
-
-    interface = fvm_interface_set_get(interfaces, id);
-    distant_rank = fvm_interface_rank(interface);
-    n_entities = fvm_interface_size(interface);
-
-    recv_buf = buf + count_size;
-
-    MPI_Irecv(recv_buf,
-              n_entities,
-              MPI_INT,
-              distant_rank,
-              distant_rank,
-              mpi_comm,
-              &(request[request_count++]));
-
-    count_size += n_entities;
-
-  }
-
-  assert(count_size == total_size);
-
-  /* Send */
-
-  for (id = 0; id < n_interfaces; id++) {
-
-    /* Preparation of data to send */
-
-    interface = fvm_interface_set_get(interfaces, id);
-    distant_rank   = fvm_interface_rank(interface);
-    n_entities = fvm_interface_size(interface);
-    local_num = fvm_interface_get_local_num(interface);
-
-    send_buf = buf + count_size;
-
-    for (ii = 0; ii < n_entities; ii++)
-      send_buf[ii] = count[local_num[ii]-1];
-
-    MPI_Isend(send_buf,
-              n_entities,
-              MPI_INT,
-              distant_rank,
-              local_rank,
-              mpi_comm,
-              &(request[request_count++]));
-
-    count_size += n_entities;
-
-  }
-
-  assert(count_size == 2*total_size);
-
-  /* Sync after each rank had received all the messages */
-
-  MPI_Waitall(request_count, request, status);
-
-  BFT_FREE(request);
-  BFT_FREE(status);
+  cs_interface_set_copy_array(interfaces,
+                              CS_LNUM_TYPE,
+                              1,
+                              true,
+                              count,
+                              buf);
 
   /* Now we estimate the max. number of ranks and elements involved */
 
@@ -635,16 +558,16 @@ _add_single_vertices(fvm_interface_set_t    *interfaces,
 
     /* Scan data */
 
-    interface = fvm_interface_set_get(interfaces, id);
-    distant_rank = fvm_interface_rank(interface);
-    n_entities = fvm_interface_size(interface);
-    local_num = fvm_interface_get_local_num(interface);
+    interface = cs_interface_set_get(interfaces, id);
+    distant_rank = cs_interface_rank(interface);
+    n_entities = cs_interface_size(interface);
+    local_id = cs_interface_get_elt_ids(interface);
 
     recv_buf = buf + count_size;
 
     for (ii = 0; ii < n_entities; ii++) {
 
-      int  vtx_id = local_num[ii] - 1;
+      int  vtx_id = local_id[ii];
 
       assert(vtx_id < var_size);
 
@@ -680,16 +603,16 @@ _add_single_vertices(fvm_interface_set_t    *interfaces,
 
       /* Scan data */
 
-      interface = fvm_interface_set_get(interfaces, id);
-      distant_rank = fvm_interface_rank(interface);
-      n_entities = fvm_interface_size(interface);
-      local_num = fvm_interface_get_local_num(interface);
+      interface = cs_interface_set_get(interfaces, id);
+      distant_rank = cs_interface_rank(interface);
+      n_entities = cs_interface_size(interface);
+      local_id = cs_interface_get_elt_ids(interface);
 
       recv_buf = buf + count_size;
 
       for (ii = 0; ii < n_entities; ii++) {
 
-        int  vtx_id = local_num[ii] - 1;
+        int  vtx_id = local_id[ii];
 
         if (count[vtx_id] == 0 && recv_buf[ii] > 0) {
 
@@ -698,7 +621,7 @@ _add_single_vertices(fvm_interface_set_t    *interfaces,
             single->ranks[single->n_ranks++] = distant_rank;
           }
 
-          single->array[single->n_elts++] = local_num[ii];
+          single->array[single->n_elts++] = local_id[ii] + 1;
           single->index[single->n_ranks] = single->n_elts;
 
           related_ranks[vtx_id] = distant_rank;
@@ -746,121 +669,54 @@ _add_single_vertices(fvm_interface_set_t    *interfaces,
 
 /*-----------------------------------------------------------------------------
  * Define a structure used for synchronizing "single" vertices.
- * Use a fvm_interface_t structure to help the build.
+ * Use a cs_interface_t structure to help the build.
  *
  * parameters:
- *  interfaces     --> pointer to a fvm_interface_set_t structure
+ *  interfaces     --> pointer to a cs_interface_set_t structure
  *  var_size       --> number of elements in var buffer
  *  related_ranks  <-> rank buffer for synchronization
  *  coupled        <-> pointer to a structure to build on coupled vertices
  *----------------------------------------------------------------------------*/
 
 static void
-_add_coupled_vertices(fvm_interface_set_t    *interfaces,
-                      fvm_lnum_t              var_size,
-                      int                    *related_ranks,
-                      cs_join_sync_t         *coupled)
+_add_coupled_vertices(cs_interface_set_t  *interfaces,
+                      cs_lnum_t            var_size,
+                      int                 *related_ranks,
+                      cs_join_sync_t      *coupled)
 {
-  int  id, ii;
-  int  request_count, distant_rank, n_interfaces, total_size, last_found_rank;
+  int  distant_rank, n_interfaces, last_found_rank;
+  cs_lnum_t id, ii;
 
-  int  count_size = 0;
-  fvm_lnum_t  n_entities = 0;
-  int  *buf = NULL, *send_buf = NULL, *recv_buf = NULL;
+  cs_lnum_t  n_entities = 0, count_size = 0, total_size = 0;
+  int  *buf = NULL, *recv_buf = NULL;
 
-  MPI_Request  *request = NULL;
-  MPI_Status  *status  = NULL;
-  MPI_Comm  mpi_comm = cs_glob_mpi_comm;
+  cs_datatype_t int_type = (sizeof(int) == 8) ? CS_INT64 : CS_INT32;
 
   const int  local_rank = CS_MAX(cs_glob_rank_id, 0);
-  const fvm_lnum_t  *local_num = NULL;
-  const fvm_interface_t  *interface = NULL;
+  const cs_lnum_t  *local_id = NULL;
+  const cs_interface_t  *interface = NULL;
 
   assert(related_ranks != NULL);
   assert(coupled != NULL);
 
   /* Initialize and allocate */
 
-  n_interfaces = fvm_interface_set_size(interfaces);
+  n_interfaces = cs_interface_set_size(interfaces);
 
-  for (id = 0; id < n_interfaces; id++) {
-    count_size
-      += fvm_interface_size(fvm_interface_set_get(interfaces, id));
-  }
+  n_interfaces = cs_interface_set_size(interfaces);
 
-  total_size = count_size;
+  total_size = cs_interface_set_n_elts(interfaces);
 
-  BFT_MALLOC(buf, total_size * 2, int);
+  BFT_MALLOC(buf, total_size, int);
 
-  BFT_MALLOC(request, n_interfaces * 2, MPI_Request);
-  BFT_MALLOC(status,  n_interfaces * 2, MPI_Status);
+  /* Exchange with distant ranks */
 
-  /* Send and Receive data from distant ranks with
-     non-blocking communications */
-
-  request_count = 0;
-  count_size  = 0;
-
-  /* Receive */
-
-  for (id = 0; id < n_interfaces; id++) {
-
-    interface = fvm_interface_set_get(interfaces, id);
-    distant_rank = fvm_interface_rank(interface);
-    n_entities = fvm_interface_size(interface);
-
-    recv_buf = buf + count_size;
-
-    MPI_Irecv(recv_buf,
-              n_entities,
-              MPI_INT,
-              distant_rank,
-              distant_rank,
-              mpi_comm,
-              &(request[request_count++]));
-
-    count_size += n_entities;
-
-  }
-
-  assert(count_size == total_size);
-
-  /* Send */
-
-  for (id = 0; id < n_interfaces; id++) {
-
-    /* Preparation of data to send */
-
-    interface = fvm_interface_set_get(interfaces, id);
-    distant_rank   = fvm_interface_rank(interface);
-    n_entities = fvm_interface_size(interface);
-    local_num = fvm_interface_get_local_num(interface);
-
-    send_buf = buf + count_size;
-
-    for (ii = 0; ii < n_entities; ii++)
-      send_buf[ii] = related_ranks[local_num[ii]-1];
-
-    MPI_Isend(send_buf,
-              n_entities,
-              MPI_INT,
-              distant_rank,
-              local_rank,
-              mpi_comm,
-              &(request[request_count++]));
-
-    count_size += n_entities;
-
-  }
-
-  assert(count_size == 2*total_size);
-
-  /* Sync after each rank had received all the messages */
-
-  MPI_Waitall(request_count, request, status);
-
-  BFT_FREE(request);
-  BFT_FREE(status);
+  cs_interface_set_copy_array(interfaces,
+                              int_type,
+                              1,
+                              true,
+                              related_ranks,
+                              buf);
 
   /* Now we scan each part to build coupled */
 
@@ -873,9 +729,9 @@ _add_coupled_vertices(fvm_interface_set_t    *interfaces,
 
     /* Scan data */
 
-    interface = fvm_interface_set_get(interfaces, id);
-    distant_rank   = fvm_interface_rank(interface);
-    n_entities = fvm_interface_size(interface);
+    interface = cs_interface_set_get(interfaces, id);
+    distant_rank   = cs_interface_rank(interface);
+    n_entities = cs_interface_size(interface);
 
     recv_buf = buf + count_size;
 
@@ -911,10 +767,10 @@ _add_coupled_vertices(fvm_interface_set_t    *interfaces,
 
       /* Retrieve data */
 
-      interface = fvm_interface_set_get(interfaces, id);
-      distant_rank   = fvm_interface_rank(interface);
-      n_entities = fvm_interface_size(interface);
-      local_num = fvm_interface_get_local_num(interface);
+      interface = cs_interface_set_get(interfaces, id);
+      distant_rank   = cs_interface_rank(interface);
+      n_entities = cs_interface_size(interface);
+      local_id = cs_interface_get_elt_ids(interface);
 
       recv_buf = buf + count_size;
 
@@ -927,8 +783,8 @@ _add_coupled_vertices(fvm_interface_set_t    *interfaces,
             coupled->ranks[rank_shift++] = distant_rank;
           }
 
-          assert(local_num[ii] <= var_size);
-          coupled->array[vtx_shift++] = local_num[ii];
+          assert(local_id[ii] < var_size);
+          coupled->array[vtx_shift++] = local_id[ii] + 1;
           coupled->index[rank_shift] = vtx_shift;
         }
 
@@ -971,19 +827,19 @@ _add_coupled_vertices(fvm_interface_set_t    *interfaces,
  *
  * parameters:
  *   n_vertices   <--  number of vertices in the parent mesh
- *   ifs          <--  pointer to a fvm_interface_set_t struct.
+ *   ifs          <--  pointer to a cs_interface_set_t struct.
  *   p_vtx_tag    <->  pointer to an array on vertices. tag=1 if selected
  *   join_select  <->  pointer to a fvm_join_selection_t structure
  *---------------------------------------------------------------------------*/
 
 static void
-_get_missing_vertices(cs_int_t              n_vertices,
-                      fvm_interface_set_t  *ifs,
-                      cs_int_t             *p_vtx_tag[],
-                      cs_join_select_t     *selection)
+_get_missing_vertices(cs_int_t             n_vertices,
+                      cs_interface_set_t  *ifs,
+                      cs_int_t            *p_vtx_tag[],
+                      cs_join_select_t    *selection)
 {
   cs_int_t  i;
-  fvm_gnum_t  n_l_elts, n_g_elts;
+  cs_gnum_t  n_l_elts, n_g_elts;
 
   cs_int_t  *vtx_tag = NULL, *related_ranks = NULL;
 
@@ -1011,7 +867,7 @@ _get_missing_vertices(cs_int_t              n_vertices,
 
   n_l_elts = selection->s_vertices->n_elts;
 
-  MPI_Allreduce(&n_l_elts, &n_g_elts, 1, FVM_MPI_GNUM,
+  MPI_Allreduce(&n_l_elts, &n_g_elts, 1, CS_MPI_GNUM,
                 MPI_SUM, cs_glob_mpi_comm);
 
   if (n_g_elts > 0) {
@@ -1189,17 +1045,17 @@ _add_s_edge(cs_int_t         vertex_tag[],
             cs_int_t         v2_id,
             const cs_int_t   sel_v2v_idx[],
             const cs_int_t   sel_v2v_lst[],
-            int             *p_tmp_size,
-            int             *p_max_size,
-            int             *p_tmp_edges[])
+            cs_lnum_t       *p_tmp_size,
+            cs_lnum_t       *p_max_size,
+            cs_lnum_t       *p_tmp_edges[])
 {
-  int  i, a, b, edge_id;
+  cs_lnum_t  i, a, b, edge_id;
 
   _Bool  is_selected = false, is_found = false;
 
-  int  tmp_size = *p_tmp_size;
-  int  max_size = *p_max_size;
-  int  *tmp_edges = *p_tmp_edges;
+  cs_lnum_t  tmp_size = *p_tmp_size;
+  cs_lnum_t  max_size = *p_max_size;
+  cs_lnum_t *tmp_edges = *p_tmp_edges;
 
   if (vertex_tag[v1_id] > 0)
     if (vertex_tag[v2_id] > 0)
@@ -1213,9 +1069,9 @@ _add_s_edge(cs_int_t         vertex_tag[],
 
       assert(v1_id != v2_id);
       if (v1_id < v2_id)
-        a = v1_id + 1, b = v2_id + 1;
+        a = v1_id, b = v2_id;
       else
-        a = v2_id + 1, b = v1_id + 1;
+        a = v2_id, b = v1_id;
 
       /* n_edges is assumed to be small */
       for (i = 0; i < tmp_size; i++) {
@@ -1235,7 +1091,7 @@ _add_s_edge(cs_int_t         vertex_tag[],
 
         if (tmp_size >= max_size) {
           max_size *= 2;
-          BFT_REALLOC(tmp_edges, 2*max_size, int);
+          BFT_REALLOC(tmp_edges, 2*max_size, cs_lnum_t);
         }
 
       }
@@ -1270,17 +1126,17 @@ _add_s_edge(cs_int_t         vertex_tag[],
  *---------------------------------------------------------------------------*/
 
 static void
-_add_single_edges(fvm_interface_set_t   *ifs,
-                  cs_int_t               vertex_tag[],
-                  cs_join_select_t      *selection,
-                  cs_int_t               sel_v2v_idx[],
-                  cs_int_t               sel_v2v_lst[],
-                  cs_int_t               b_f2v_idx[],
-                  cs_int_t               b_f2v_lst[],
-                  cs_int_t               i_f2v_idx[],
-                  cs_int_t               i_f2v_lst[],
-                  cs_int_t               i_face_cells[],
-                  cs_join_sync_t        *s_edges)
+_add_single_edges(cs_interface_set_t   *ifs,
+                  cs_int_t              vertex_tag[],
+                  cs_join_select_t     *selection,
+                  cs_int_t              sel_v2v_idx[],
+                  cs_int_t              sel_v2v_lst[],
+                  cs_int_t              b_f2v_idx[],
+                  cs_int_t              b_f2v_lst[],
+                  cs_int_t              i_f2v_idx[],
+                  cs_int_t              i_f2v_lst[],
+                  cs_int_t              i_face_cells[],
+                  cs_join_sync_t       *s_edges)
 {
   cs_int_t  i, j, fid, s, e;
 
@@ -1361,9 +1217,9 @@ _add_single_edges(fvm_interface_set_t   *ifs,
     int  last_found_rank = -1;
     int  *edge_tag = NULL;
 
-    const int  n_interfaces = fvm_interface_set_size(ifs);
-    const fvm_lnum_t  *local_num = NULL;
-    const fvm_interface_t  *interface = NULL;
+    const int  n_interfaces = cs_interface_set_size(ifs);
+    const cs_lnum_t  *local_id = NULL;
+    const cs_interface_t  *interface = NULL;
 
     shift = 0;
     s_edges->n_elts = tmp_size;
@@ -1379,16 +1235,16 @@ _add_single_edges(fvm_interface_set_t   *ifs,
 
     for (i = 0; i < n_interfaces; i++) {
 
-      interface = fvm_interface_set_get(ifs, i);
-      distant_rank = fvm_interface_rank(interface);
-      n_entities = fvm_interface_size(interface);
-      local_num = fvm_interface_get_local_num(interface);
+      interface = cs_interface_set_get(ifs, i);
+      distant_rank = cs_interface_rank(interface);
+      n_entities = cs_interface_size(interface);
+      local_id = cs_interface_get_elt_ids(interface);
 
       for (j = 0; j < tmp_size; j++) {
 
         if (edge_tag[j] == 0) { /* Not already treated */
-          if (cs_search_binary(n_entities, tmp_edges[2*j], local_num) > -1) {
-            if (cs_search_binary(n_entities, tmp_edges[2*j+1], local_num) > -1) {
+          if (cs_search_binary(n_entities, tmp_edges[2*j], local_id) > -1) {
+            if (cs_search_binary(n_entities, tmp_edges[2*j+1], local_id) > -1) {
 
               if (last_found_rank != distant_rank) {
                 s_edges->ranks[s_edges->n_ranks] = distant_rank;
@@ -1398,8 +1254,8 @@ _add_single_edges(fvm_interface_set_t   *ifs,
               }
 
               edge_tag[j] = 1; /* Tag as done */
-              s_edges->array[2*shift] = tmp_edges[2*j];
-              s_edges->array[2*shift+1] = tmp_edges[2*j+1];
+              s_edges->array[2*shift] = tmp_edges[2*j] + 1;
+              s_edges->array[2*shift+1] = tmp_edges[2*j+1] + 1;
               shift++;
 
             }
@@ -1416,7 +1272,7 @@ _add_single_edges(fvm_interface_set_t   *ifs,
     /* Memory management */
 
     if (s_edges->n_elts != tmp_size)
-        BFT_REALLOC(s_edges->array, 2*s_edges->n_elts, int);
+      BFT_REALLOC(s_edges->array, 2*s_edges->n_elts, int);
 
     BFT_REALLOC(s_edges->ranks, s_edges->n_ranks, int);
     BFT_REALLOC(s_edges->index, s_edges->n_ranks + 1, int);
@@ -1459,22 +1315,22 @@ _add_single_edges(fvm_interface_set_t   *ifs,
  *---------------------------------------------------------------------------*/
 
 static void
-_add_coupled_edges(fvm_interface_set_t   *ifs,
-                   cs_join_sync_t        *s_edges,
-                   cs_join_sync_t        *c_edges)
+_add_coupled_edges(cs_interface_set_t   *ifs,
+                   cs_join_sync_t       *s_edges,
+                   cs_join_sync_t       *c_edges)
 {
-  int  i, j, id, n_entities;
+  cs_lnum_t  i, j, id, n_entities;
   int  request_count, rank_shift, distant_rank;
 
-  int  *buf = NULL, *recv_buf = NULL, *send_buf = NULL;
+  cs_lnum_t  *buf = NULL, *recv_buf = NULL, *send_buf = NULL;
   MPI_Request  *request = NULL;
   MPI_Status  *status  = NULL;
   MPI_Comm  mpi_comm = cs_glob_mpi_comm;
 
   const int  local_rank = CS_MAX(cs_glob_rank_id, 0);
-  const fvm_lnum_t  *local_num = NULL, *distant_num = NULL;
-  const int  n_interfaces = fvm_interface_set_size(ifs);
-  const fvm_interface_t  *interface = NULL;
+  const cs_lnum_t  *local_id = NULL, *distant_id = NULL;
+  const int  n_interfaces = cs_interface_set_size(ifs);
+  const cs_interface_t  *interface = NULL;
 
   assert(c_edges != NULL);
 
@@ -1491,8 +1347,8 @@ _add_coupled_edges(fvm_interface_set_t   *ifs,
 
   for (id = 0; id < n_interfaces; id++) {
 
-    interface = fvm_interface_set_get(ifs, id);
-    distant_rank = fvm_interface_rank(interface);
+    interface = cs_interface_set_get(ifs, id);
+    distant_rank = cs_interface_rank(interface);
 
     MPI_Irecv(&(buf[id]),
               1,
@@ -1512,8 +1368,8 @@ _add_coupled_edges(fvm_interface_set_t   *ifs,
 
     /* Preparation of data to send */
 
-    interface = fvm_interface_set_get(ifs, id);
-    distant_rank = fvm_interface_rank(interface);
+    interface = cs_interface_set_get(ifs, id);
+    distant_rank = cs_interface_rank(interface);
 
     if (rank_shift < s_edges->n_ranks) {
       if (s_edges->ranks[rank_shift] == distant_rank) {
@@ -1558,8 +1414,8 @@ _add_coupled_edges(fvm_interface_set_t   *ifs,
   for (i = 0; i < n_interfaces; i++) {
     if (buf[i] > 0) {
 
-      interface = fvm_interface_set_get(ifs, i);
-      distant_rank = fvm_interface_rank(interface);
+      interface = cs_interface_set_get(ifs, i);
+      distant_rank = cs_interface_rank(interface);
       c_edges->ranks[rank_shift++] = distant_rank;
       c_edges->index[rank_shift] = buf[i];
 
@@ -1582,8 +1438,8 @@ _add_coupled_edges(fvm_interface_set_t   *ifs,
 
   for (id = 0; id < n_interfaces; id++) {
 
-    interface = fvm_interface_set_get(ifs, id);
-    distant_rank = fvm_interface_rank(interface);
+    interface = cs_interface_set_get(ifs, id);
+    distant_rank = cs_interface_rank(interface);
 
     if (rank_shift < c_edges->n_ranks) {
       if (c_edges->ranks[rank_shift] == distant_rank) {
@@ -1612,8 +1468,8 @@ _add_coupled_edges(fvm_interface_set_t   *ifs,
 
   for (id = 0; id < n_interfaces; id++) {
 
-    interface = fvm_interface_set_get(ifs, id);
-    distant_rank = fvm_interface_rank(interface);
+    interface = cs_interface_set_get(ifs, id);
+    distant_rank = cs_interface_rank(interface);
 
     if (rank_shift < s_edges->n_ranks) {
       if (s_edges->ranks[rank_shift] == distant_rank) {
@@ -1645,30 +1501,34 @@ _add_coupled_edges(fvm_interface_set_t   *ifs,
 
   rank_shift = 0;
 
-  /* Switch received couple vertices from distant num. to local num. */
+  /* Switch received couple vertices from distant id. to local id. */
+
+  cs_interface_set_add_match_ids(ifs);
 
   for (i = 0; i < n_interfaces; i++) {
 
-    interface = fvm_interface_set_get(ifs, i);
-    distant_rank = fvm_interface_rank(interface);
+    interface = cs_interface_set_get(ifs, i);
+    distant_rank = cs_interface_rank(interface);
+    distant_id = cs_interface_get_match_ids(interface);
+
+    n_entities = cs_interface_size(interface);
 
     if (rank_shift < c_edges->n_ranks) {
       if (c_edges->ranks[rank_shift] == distant_rank) {
 
-        n_entities = fvm_interface_size(interface);
-        local_num = fvm_interface_get_local_num(interface);
-        distant_num = fvm_interface_get_distant_num(interface);
+        local_id = cs_interface_get_elt_ids(interface);
 
         for (j = c_edges->index[rank_shift];
-             j < c_edges->index[rank_shift+1]; j++) {
+             j < c_edges->index[rank_shift+1];
+             j++) {
 
-          id = cs_search_binary(n_entities, c_edges->array[2*j], distant_num);
+          id = cs_search_binary(n_entities, c_edges->array[2*j] - 1, distant_id);
           assert(id != -1);
-          c_edges->array[2*j] = local_num[id];
+          c_edges->array[2*j] = local_id[id] + 1;
 
-          id = cs_search_binary(n_entities, c_edges->array[2*j+1], distant_num);
+          id = cs_search_binary(n_entities, c_edges->array[2*j+1] - 1, distant_id);
           assert(id != -1);
-          c_edges->array[2*j+1] = local_num[id];
+          c_edges->array[2*j+1] = local_id[id] + 1;
 
         } /* Loop on couple edges */
 
@@ -1679,6 +1539,8 @@ _add_coupled_edges(fvm_interface_set_t   *ifs,
 
   } /* Loop on interfaces */
 
+  cs_interface_set_free_match_ids(ifs);
+
 #if 0 && defined(DEBUG) && !defined(NDEBUG)
   bft_printf("\n  Coupled edges for the joining operation: (%p)\n",
              c_edges);
@@ -1815,8 +1677,8 @@ _filter_edge_element(cs_join_select_t   *selection,
       for (j = save; j < c_edges->index[i+1]; j++) {
         if (c_edge_tag[j] == 1) {
           c_edges->array[2*shift] = c_edges->array[2*j];
-            c_edges->array[2*shift+1] = c_edges->array[2*j+1];
-           shift++;
+          c_edges->array[2*shift+1] = c_edges->array[2*j+1];
+          shift++;
         }
       }
       save = c_edges->index[i+1];
@@ -1870,23 +1732,23 @@ _filter_edge_element(cs_join_select_t   *selection,
  *  i_f2v_lst     <-- interior "face -> vertex" connect. list
  *  n_vertices    <-- number of vertices in the parent mesh
  *  vtx_tag       <-- tag on vertices. 1 if selected, 0 otherwise
- *  ifs           <-- pointer to a fvm_interface_set_t struct.
+ *  ifs           <-- pointer to a cs_interface_set_t struct.
  *  i_face_cells  <-- interior face -> cells connect.
  *  join_select   <-> pointer to a fvm_join_selection_t structure
  *---------------------------------------------------------------------------*/
 
 static void
-_get_missing_edges(cs_int_t              b_f2v_idx[],
-                   cs_int_t              b_f2v_lst[],
-                   cs_int_t              i_f2v_idx[],
-                   cs_int_t              i_f2v_lst[],
-                   cs_int_t              n_vertices,
-                   cs_int_t              vtx_tag[],
-                   fvm_interface_set_t  *ifs,
-                   cs_int_t              i_face_cells[],
-                   cs_join_select_t     *selection)
+_get_missing_edges(cs_int_t             b_f2v_idx[],
+                   cs_int_t             b_f2v_lst[],
+                   cs_int_t             i_f2v_idx[],
+                   cs_int_t             i_f2v_lst[],
+                   cs_int_t             n_vertices,
+                   cs_int_t             vtx_tag[],
+                   cs_interface_set_t  *ifs,
+                   cs_int_t             i_face_cells[],
+                   cs_join_select_t    *selection)
 {
-  fvm_gnum_t  n_l_elts, n_g_elts;
+  cs_gnum_t  n_l_elts, n_g_elts;
 
   cs_int_t  *sel_v2v_idx = NULL, *sel_v2v_lst = NULL;
 
@@ -1913,7 +1775,7 @@ _get_missing_edges(cs_int_t              b_f2v_idx[],
 
   n_l_elts = selection->s_edges->n_elts;
 
-  MPI_Allreduce(&n_l_elts, &n_g_elts, 1, FVM_MPI_GNUM,
+  MPI_Allreduce(&n_l_elts, &n_g_elts, 1, CS_MPI_GNUM,
                 MPI_SUM, cs_glob_mpi_comm);
 
   if (n_g_elts > 0) {
@@ -2064,9 +1926,9 @@ cs_join_create(int                      join_number,
     char dir[] = "log";
     char rank_add[16] = "";
     char perio_add[16] = "";
-    if (bft_file_isdir(dir) == 0) {
+    if (cs_file_isdir(dir) == 0) {
       if (cs_glob_rank_id < 1)
-        if (bft_file_mkdir_default(dir) != 0)
+        if (cs_file_mkdir_default(dir) != 0)
           bft_error(__FILE__, __LINE__, 0,
                     _("The log directory cannot be created"));
 #if defined(HAVE_MPI)
@@ -2078,7 +1940,7 @@ cs_join_create(int                      join_number,
       strcpy(perio_add, "_perio");
     if (cs_glob_n_ranks > 1)
       sprintf(rank_add, "_r%04d", cs_glob_rank_id);
-    sprintf(logname, "log%cjoin_%02d%s%s.log", CS_DIR_SEPARATOR,
+    sprintf(logname, "log%cjoin_%02d%s%s.log", DIR_SEPARATOR,
             join_number, perio_add, rank_add);
     cs_glob_join_log = fopen(logname, "w");
     if (cs_glob_join_log == NULL)
@@ -2141,8 +2003,8 @@ cs_join_select_create(const char  *selection_criteria,
 
   cs_int_t  *vtx_tag = NULL;
   cs_join_select_t  *selection = NULL;
-  fvm_lnum_t  *order = NULL, *ordered_faces = NULL;
-  fvm_interface_set_t  *ifs = NULL;
+  cs_lnum_t  *order = NULL, *ordered_faces = NULL;
+  cs_interface_set_t  *ifs = NULL;
   cs_mesh_t  *mesh = cs_glob_mesh;
   FILE  *logfile = cs_glob_join_log;
 
@@ -2195,16 +2057,16 @@ cs_join_select_create(const char  *selection_criteria,
 
   /* Extract selected boundary faces */
 
-  BFT_MALLOC(selection->faces, mesh->n_b_faces, fvm_lnum_t);
+  BFT_MALLOC(selection->faces, mesh->n_b_faces, cs_lnum_t);
 
   cs_selector_get_b_face_list(selection_criteria,
                               &(selection->n_faces),
                               selection->faces);
 
-  BFT_MALLOC(order, selection->n_faces, fvm_lnum_t);
-  BFT_MALLOC(ordered_faces, selection->n_faces, fvm_lnum_t);
+  BFT_MALLOC(order, selection->n_faces, cs_lnum_t);
+  BFT_MALLOC(ordered_faces, selection->n_faces, cs_lnum_t);
 
-  fvm_order_local_allocated(selection->faces, NULL, order, selection->n_faces);
+  cs_order_gnum_allocated(selection->faces, NULL, order, selection->n_faces);
 
   for (i = 0; i < selection->n_faces; i++)
     ordered_faces[i] = selection->faces[order[i]];
@@ -2219,10 +2081,10 @@ cs_join_select_create(const char  *selection_criteria,
 #if defined(HAVE_MPI)
   if (n_ranks > 1) { /* Parallel treatment */
 
-    fvm_gnum_t n_l_faces = selection->n_faces;
+    cs_gnum_t n_l_faces = selection->n_faces;
 
     MPI_Allreduce(&n_l_faces, &(selection->n_g_faces),
-                  1, FVM_MPI_GNUM, MPI_SUM, cs_glob_mpi_comm);
+                  1, CS_MPI_GNUM, MPI_SUM, cs_glob_mpi_comm);
 
   }
 #endif
@@ -2256,14 +2118,14 @@ cs_join_select_create(const char  *selection_criteria,
 
     assert(mesh->global_vtx_num != NULL);
 
-    ifs = fvm_interface_set_create(mesh->n_vertices,
-                                   NULL,
-                                   mesh->global_vtx_num,
-                                   NULL,
-                                   0,
-                                   NULL,
-                                   NULL,
-                                   NULL);
+    ifs = cs_interface_set_create(mesh->n_vertices,
+                                  NULL,
+                                  mesh->global_vtx_num,
+                                  NULL,
+                                  0,
+                                  NULL,
+                                  NULL,
+                                  NULL);
 
     assert(ifs != NULL);
 
@@ -2320,7 +2182,7 @@ cs_join_select_create(const char  *selection_criteria,
                        selection);
 
     BFT_FREE(vtx_tag);
-    ifs = fvm_interface_set_destroy(ifs);
+    cs_interface_set_destroy(&ifs);
 
   }
 #endif
@@ -2454,12 +2316,12 @@ cs_join_select_create(const char  *selection_criteria,
  *---------------------------------------------------------------------------*/
 
 cs_join_block_info_t
-cs_join_get_block_info(fvm_gnum_t  n_g_elts,
-                       int         n_ranks,
-                       int         local_rank)
+cs_join_get_block_info(cs_gnum_t  n_g_elts,
+                       int        n_ranks,
+                       int        local_rank)
 {
   size_t  block_size, n_treat_elts;
-  fvm_gnum_t  first_glob_num, last_glob_num;
+  cs_gnum_t  first_glob_num, last_glob_num;
 
   cs_join_block_info_t  block_info;
 
