@@ -8,7 +8,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2011 EDF S.A.
+  Copyright (C) 1998-2012 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -81,11 +81,11 @@ BEGIN_C_DECLS
  *----------------------------------------------------------------------------*/
 
 void
-cs_mesh_connect_get_cell_faces(const cs_mesh_t             *mesh,
-                               fvm_lnum_t                   extr_cell_size,
-                               const fvm_lnum_t             extr_cell_id[],
-                               fvm_lnum_t          * *const p_cell_faces_idx,
-                               fvm_lnum_t          * *const p_cell_faces_val);
+cs_mesh_connect_get_cell_faces(const cs_mesh_t         *mesh,
+                               cs_lnum_t                extr_cell_size,
+                               const cs_lnum_t          extr_cell_id[],
+                               cs_lnum_t        **const p_cell_faces_idx,
+                               cs_lnum_t        **const p_cell_faces_val);
 
 /*----------------------------------------------------------------------------
  * Build a nodal connectivity structure from a subset of a mesh's cells.
@@ -110,9 +110,9 @@ cs_mesh_connect_get_cell_faces(const cs_mesh_t             *mesh,
 fvm_nodal_t *
 cs_mesh_connect_cells_to_nodal(const cs_mesh_t  *mesh,
                                const char       *name,
-                               cs_bool_t         include_families,
-                               fvm_lnum_t        cell_list_size,
-                               fvm_lnum_t        cell_list[]);
+                               bool              include_families,
+                               cs_lnum_t         cell_list_size,
+                               cs_lnum_t         cell_list[]);
 
 /*----------------------------------------------------------------------------
  * Build a nodal connectivity structure from a subset of a mesh's faces.
@@ -139,11 +139,11 @@ cs_mesh_connect_cells_to_nodal(const cs_mesh_t  *mesh,
 fvm_nodal_t *
 cs_mesh_connect_faces_to_nodal(const cs_mesh_t  *mesh,
                                const char       *name,
-                               cs_bool_t         include_families,
-                               fvm_lnum_t        i_face_list_size,
-                               fvm_lnum_t        b_face_list_size,
-                               fvm_lnum_t        i_face_list[],
-                               fvm_lnum_t        b_face_list[]);
+                               bool              include_families,
+                               cs_lnum_t         i_face_list_size,
+                               cs_lnum_t         b_face_list_size,
+                               cs_lnum_t         i_face_list[],
+                               cs_lnum_t         b_face_list[]);
 
 /*----------------------------------------------------------------------------*/
 
