@@ -5,7 +5,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2011 EDF S.A.
+  Copyright (C) 1998-2012 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -24,9 +24,7 @@
 
 /*----------------------------------------------------------------------------*/
 
-#if defined(HAVE_CONFIG_H)
-#include "cs_config.h"
-#endif
+#include "cs_defs.h"
 
 /*----------------------------------------------------------------------------
  * Standard C library headers
@@ -39,21 +37,14 @@
 #include <assert.h>
 #include <float.h>
 
-/*----------------------------------------------------------------------------
- * BFT and FVM library headers
- *----------------------------------------------------------------------------*/
-
-#include <bft_mem.h>
-#include <bft_error.h>
-#include <bft_printf.h>
-
-#include <fvm_defs.h>
-#include <fvm_parall.h>
-
 /*----------------------------------------------------------------------------
  * Local headers
  *----------------------------------------------------------------------------*/
 
+#include "bft_mem.h"
+#include "bft_error.h"
+#include "bft_printf.h"
+
 #include "cs_mesh.h"
 #include "cs_mesh_quantities.h"
 #include "cs_post.h"
@@ -137,10 +128,10 @@ _compute_local_minmax(cs_int_t         n_vals,
  *----------------------------------------------------------------------------*/
 
 static void
-_display_histograms(int         n_steps,
-                    cs_real_t   var_min,
-                    cs_real_t   var_max,
-                    fvm_gnum_t  count[])
+_display_histograms(int        n_steps,
+                    cs_real_t  var_min,
+                    cs_real_t  var_max,
+                    cs_gnum_t  count[])
 {
   int  i, j;
   double var_step;
@@ -149,13 +140,13 @@ _display_histograms(int         n_steps,
 
   if (cs_glob_n_ranks > 1) {
 
-    fvm_gnum_t _g_count[CS_MESH_QUALITY_N_SUBS];
-    fvm_gnum_t *g_count = _g_count;
+    cs_gnum_t _g_count[CS_MESH_QUALITY_N_SUBS];
+    cs_gnum_t *g_count = _g_count;
 
     if (n_steps > CS_MESH_QUALITY_N_SUBS)
-      BFT_MALLOC(g_count, n_steps, fvm_gnum_t);
+      BFT_MALLOC(g_count, n_steps, cs_gnum_t);
 
-    MPI_Allreduce(count, g_count, n_steps, FVM_MPI_GNUM, MPI_SUM,
+    MPI_Allreduce(count, g_count, n_steps, CS_MPI_GNUM, MPI_SUM,
                   cs_glob_mpi_comm);
 
     for (i = 0; i < n_steps; i++)
@@ -180,14 +171,15 @@ _display_histograms(int         n_steps,
     /* Number of elements in each subdivision */
 
     for (i = 0, j = 1; i < n_steps - 1; i++, j++)
-      bft_printf("    %3d : [ %10.5e ; %10.5e [ = %10d\n",
-                 i+1, var_min + i*var_step, var_min + j*var_step, count[i]);
+      bft_printf("    %3d : [ %10.5e ; %10.5e [ = %10llu\n",
+                 i+1, var_min + i*var_step, var_min + j*var_step,
+                 (unsigned long long)(count[i]));
 
-    bft_printf("    %3d : [ %10.5e ; %10.5e ] = %10d\n",
+    bft_printf("    %3d : [ %10.5e ; %10.5e ] = %10llu\n",
                n_steps,
                var_min + (n_steps - 1)*var_step,
                var_max,
-               count[n_steps - 1]);
+               (unsigned long long)(count[n_steps - 1]));
 
   }
 
@@ -212,7 +204,7 @@ _histogram(cs_int_t         n_vals,
   cs_real_t  step;
   cs_real_t  max, min, _max, _min;
 
-  fvm_gnum_t count[CS_MESH_QUALITY_N_SUBS];
+  cs_gnum_t count[CS_MESH_QUALITY_N_SUBS];
   const int  n_steps = CS_MESH_QUALITY_N_SUBS;
 
   assert (sizeof(double) == sizeof(cs_real_t));
@@ -284,7 +276,7 @@ _int_face_histogram(const cs_mesh_t  *mesh,
   cs_real_t  step;
   cs_real_t  max, min, _max, _min;
 
-  fvm_gnum_t count[CS_MESH_QUALITY_N_SUBS];
+  cs_gnum_t count[CS_MESH_QUALITY_N_SUBS];
   const int  n_steps = CS_MESH_QUALITY_N_SUBS;
 
   assert (sizeof (double) == sizeof (cs_real_t));
@@ -834,12 +826,12 @@ cs_mesh_quality(const cs_mesh_t             *mesh,
 {
   cs_int_t  i;
 
-  cs_bool_t  compute_volume = true;
-  cs_bool_t  compute_weighting = true;
-  cs_bool_t  compute_orthogonality = true;
-  cs_bool_t  compute_warping = true;
-  cs_bool_t  vol_fields = false;
-  cs_bool_t  brd_fields = false;
+  bool  compute_volume = true;
+  bool  compute_weighting = true;
+  bool  compute_orthogonality = true;
+  bool  compute_warping = true;
+  bool  vol_fields = false;
+  bool  brd_fields = false;
 
   cs_real_t  *face_to_cell = NULL;
   cs_real_t  *face_to_vtx = NULL;
