@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2011 EDF S.A.
+! Copyright (C) 1998-2012 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -271,6 +271,22 @@ if ( ippmod(ieljou).ge.1 .or.                                     &
    smbrs  , rovsdt )
 endif
 
+! ---> Version atmospherique :
+
+if ( ippmod(iatmos).ge.0 ) then
+   call attssc                                                    &
+   !==========
+ ( nvar   , nscal  , ncepdp , ncesmp ,                            &
+   iscal  ,                                                       &
+   itypfb ,                                                       &
+   icepdc , icetsm , itypsm ,                                     &
+   izfppp ,                                                       &
+   dt     , rtpa   , rtp    , propce , propfa , propfb ,          &
+   coefa  , coefb  , ckupdc , smacel ,                            &
+   smbrs  , rovsdt )
+endif
+
+
 ! ---> Version aerorefrigerant :
 
 if ( ippmod(iaeros).ge.0 ) then
