@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2011 EDF S.A.
+! Copyright (C) 1998-2012 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -26,8 +26,8 @@ subroutine raysol &
  ( nvar   , nscal  ,                                              &
    itypfb ,                                                       &
    dt     , rtp    , rtpa   , propce , propfa , propfb ,          &
-   coefa  , coefb  ,                                              &
-   cofrua , cofrub ,                                              &
+   coefap , coefbp ,                                              &
+   cofafp , cofbfp ,                                              &
    flurds , flurdb ,                                              &
    viscf  , viscb  ,                                              &
    smbrs  , rovsdt ,                                              &
@@ -89,10 +89,8 @@ subroutine raysol &
 ! propce(ncelet, *)! ra ! <-- ! physical properties at cell centers            !
 ! propfa(nfac, *)  ! ra ! <-- ! physical properties at interior face centers   !
 ! propfb(nfabor, *)! ra ! <-- ! physical properties at boundary face centers   !
-! coefa, coefb     ! ra ! <-- ! boundary conditions                            !
-!  (nfabor, *)     !    !     !                                                !
-! cofrua,cofrub    ! tr ! --- ! conditions aux limites aux                     !
-!(nfabor)          !    !     !    faces de bord pour la luminance             !
+! coefap,coefbp    ! tr ! --- ! conditions aux limites aux                     !
+!  cofafp, cofbfp  !    !     !    faces de bord pour la luminance             !
 ! flurds,flurdb    ! tr ! --- ! pseudo flux de masse (faces internes           !
 !(nfac)(nfabor)    !    !     !    et faces de bord )                          !
 ! viscf(nfac)      ! tr ! --- ! visc*surface/dist aux faces internes           !
@@ -144,9 +142,9 @@ integer          itypfb(nfabor)
 double precision dt(ncelet), rtp(ncelet,*), rtpa(ncelet,*)
 double precision propce(ncelet,*)
 double precision propfa(nfac,*), propfb(nfabor,*)
-double precision coefa(nfabor,*), coefb(nfabor,*)
 
-double precision cofrua(nfabor), cofrub(nfabor)
+double precision coefap(nfabor), coefbp(nfabor)
+double precision cofafp(nfabor), cofbfp(nfabor)
 double precision flurds(nfac), flurdb(nfabor)
 
 double precision viscf(nfac), viscb(nfabor)
@@ -169,6 +167,7 @@ integer          imgr1 , imligp, ircflp, ischcp, isstpp, iescap
 integer          ncymap, nitmgp
 integer          idir  , ndirs , kdir  , ipp   , inum
 integer          ii, jj, kk, idtva0, ivar0
+integer          imucpp
 
 double precision epsrgp, blencp, climgp, epsilp, extrap, epsrsp
 double precision sx, sy, sz, domega
@@ -178,7 +177,8 @@ double precision relaxp, thetap
 
 double precision rvoid(1)
 
-double precision, allocatable, dimension(:) :: w10
+double precision, allocatable, dimension(:) :: rhs0
+double precision, allocatable, dimension(:) :: dpvar
 
 !===============================================================================
 
@@ -187,7 +187,8 @@ double precision, allocatable, dimension(:) :: w10
 !===============================================================================
 
 ! Allocate a work array
-allocate(w10(ncelet))
+allocate(rhs0(ncelet))
+allocate(dpvar(ncelet))
 
 !===============================================================================
 ! 1. INITIALISATION
@@ -195,7 +196,6 @@ allocate(w10(ncelet))
 
 ivar0   = 0
 nitmap  = 1000
-!     IMRGRA  = 0
 nswrsp  = 2
 nswrgp  = 100
 imligp  = -1
@@ -203,6 +203,7 @@ ircflp  = 1
 ischcp  = 1
 isstpp  = 0
 iescap  = 0
+imucpp  = 0
 imgr1   = 0
 ncymap  = 100
 nitmgp  = 10
@@ -272,8 +273,9 @@ do ii = -1,1,2
   enddo
 enddo
 
-do ifac = 1,nfabor
-  cofrua(ifac) = cofrua(ifac) *(pi /snplus(ifac))
+do ifac = 1, nfabor
+  coefap(ifac) = coefap(ifac) *(pi /snplus(ifac))
+  cofafp(ifac) = cofafp(ifac) *(pi /snplus(ifac))
 enddo
 
 !===============================================================================
@@ -296,7 +298,7 @@ enddo
 !    a chaque changement de direction
 
 do iel = 1, ncel
-  w10(iel) =  smbrs(iel)
+  rhs0(iel) =  smbrs(iel)
 enddo
 
 !--> ROVSDT charge une seule fois
@@ -352,7 +354,7 @@ do ii = -1,1,2
 !--> Terme source explicite
 
         do iel = 1, ncel
-          smbrs(iel) = w10(iel)
+          smbrs(iel) = rhs0(iel)
         enddo
 
 !--> Terme source implicite (ROVSDT vu plus haut)
@@ -396,20 +398,20 @@ do ii = -1,1,2
         thetap = 1.0d0
         idtva0 = 0
 
-        call codits                                               &
+        call codits &
         !==========
  ( nvar   , nscal  ,                                              &
    idtva0 , ivar0  , iconv1 , idiff1 , ireso1 , ndirc1 ,  nitmap ,&
    imrgra , nswrsp , nswrgp , imligp , ircflp ,                   &
-   ischcp , isstpp , iescap ,                                     &
+   ischcp , isstpp , iescap , imucpp ,                            &
    imgr1  , ncymap , nitmgp , inum   , iwarnp ,                   &
    blencp , epsilp , epsrsp , epsrgp , climgp , extrap ,          &
    relaxp , thetap ,                                              &
    rua    , ru     ,                                              &
-   cofrua , cofrub , cofrua , cofrub , flurds , flurdb ,          &
+   coefap , coefbp , cofafp , cofbfp , flurds , flurdb ,          &
    viscf  , viscb  , viscf  , viscb  ,                            &
-   rovsdt , smbrs  , ru    ,                                      &
-   rvoid  )
+   rovsdt , smbrs  , ru     , dpvar  ,                            &
+   rvoid  , rvoid  )
 
 !===============================================================================
 ! 5.2 INTEGRATION DES FLUX ET TERME SOURCE
@@ -448,7 +450,8 @@ do ii = -1,1,2
 enddo
 
 ! Free memory
-deallocate(w10)
+deallocate(rhs0)
+deallocate(dpvar)
 
 !--------
 ! FORMATS
