@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2011 EDF S.A.
+! Copyright (C) 1998-2012 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -142,14 +142,17 @@ integer          iconvp, idiffp, ndircp, ireslp
 integer          nitmap, nswrsp, ircflp, ischcp, isstpp, iescap
 integer          imgrp , ncymxp, nitmfp
 integer          iptsta
-
+integer          iclalp, iii
+integer          imucpp
 double precision blencp, epsilp, epsrgp, climgp, extrap, relaxp
-double precision epsrsp
+double precision epsrsp, alpha3
 double precision trprod , trrij ,csteps, rctse
 double precision grdpx,grdpy,grdpz,grdsn
 double precision surfn2
 double precision tseps , kseps , ceps2
 double precision tuexpe, thets , thetv , thetap, thetp1
+double precision prdeps, xttdrb, xttke , xttkmg
+double precision hint
 
 double precision rvoid(1)
 
@@ -157,6 +160,7 @@ double precision, allocatable, dimension(:,:) :: grad
 double precision, allocatable, dimension(:) :: w1, w2, w3
 double precision, allocatable, dimension(:) :: w4, w5, w6
 double precision, allocatable, dimension(:) :: w7, w8, w9
+double precision, allocatable, dimension(:) :: dpvar
 
 !===============================================================================
 
@@ -168,7 +172,7 @@ double precision, allocatable, dimension(:) :: w7, w8, w9
 allocate(w1(ncelet), w2(ncelet), w3(ncelet))
 allocate(w4(ncelet), w5(ncelet), w6(ncelet))
 allocate(w8(ncelet), w9(ncelet))
-
+allocate(dpvar(ncelet))
 
 if(iwarni(ivar).ge.1) then
   write(nfecra,1000) nomvar(ipp)
@@ -183,11 +187,13 @@ iflmab = ipprob(ifluma(iu))
 iclvar = iclrtp(ivar,icoef)
 iclvaf = iclrtp(ivar,icoeff)
 
-!     Constante Ce2, qui vaut CE2 pour ITURB=30 et CSSGE2 pour ITRUB=31
+! Constante Ce2, qui vaut CE2 pour ITURB=30 et CSSGE2 pour ITRUB=31
 if (iturb.eq.30) then
   ceps2 = ce2
-else
+elseif (iturb.eq.31) then
   ceps2 = cssge2
+else
+  ceps2 = cebme2
 endif
 
 !     S pour Source, V pour Variable
@@ -307,26 +313,11 @@ endif
 !    ET TERME INSTATIONNAIRE
 !===============================================================================
 
-! ---> Calcul de mij
-
-init = 1
-call divmas(ncelet,ncel,nfac,nfabor,init,nfecra,                  &
-               ifacel,ifabor,propfa(1,iflmas),propfb(1,iflmab),w1)
-
-! ---> Ajout au second membre
-
-do iel = 1, ncel
-  smbr(iel) = smbr(iel)                                           &
-              + iconv(ivar)*w1(iel)*rtpa(iel,ivar)
-enddo
-
 ! ---> Ajout dans la diagonale de la matrice
-!     Extrapolation ou non, meme forme par coherence avec bilsc2
 
 do iel = 1, ncel
   rovsdt(iel) = rovsdt(iel)                                       &
-           + istat(ivar)*(propce(iel,ipcrom)/dt(iel))*volume(iel) &
-           - iconv(ivar)*w1(iel)*thetv
+           + istat(ivar)*(propce(iel,ipcrom)/dt(iel))*volume(iel)
 enddo
 
 
@@ -364,13 +355,40 @@ endif
 
 !     Terme explicite (Production)
 
-do iel = 1, ncel
-!     Demi-traces
-  trprod = w9(iel)
-  trrij  = w8(iel)
-  w1(iel)   =             propce(iel,ipcroo)*volume(iel)*         &
-       ce1*rtpa(iel,iep)/trrij*trprod
-enddo
+! EBRSM
+if (iturb.eq.32) then
+
+  iclalp = iclrtp(ial,icoeff)
+
+  do iel = 1, ncel
+    ! Demi-traces
+    trprod = w9(iel)
+    trrij  = w8(iel)
+    ! Calcul de l echelle de temps de Durbin
+    xttke  = trrij/rtpa(iel,iep)
+    xttkmg = xct*sqrt(propce(iel,ipcvis)/propce(iel,ipcrom)     &
+                                        /rtpa(iel,iep))
+    xttdrb = max(xttke,xttkmg)
+
+    prdeps = trprod/rtpa(iel,iep)
+    alpha3 = rtp(iel,ial)**3
+
+    ! Compute of C_eps_1'
+    w1(iel) = propce(iel,ipcroo)*volume(iel)*                   &
+              ce1*(1.d0+xa1*(1.d0-alpha3)*prdeps)*trprod/xttdrb
+  enddo
+
+else
+
+  do iel = 1, ncel
+    ! Demi-traces
+    trprod = w9(iel)
+    trrij  = w8(iel)
+    w1(iel)   =             propce(iel,ipcroo)*volume(iel)*         &
+         ce1*rtpa(iel,iep)/trrij*trprod
+  enddo
+
+endif
 
 !     Si on extrapole les T.S : PROPCE
 if(isto2t.gt.0) then
@@ -386,11 +404,26 @@ else
 endif
 
 !     Terme implicite (Dissipation)
-do iel = 1, ncel
-  trrij  = w8(iel)
-  smbr(iel) = smbr(iel) - propce(iel,ipcrom)*volume(iel)*         &
-                         ceps2*rtpa(iel,iep)**2/trrij
-enddo
+
+! EBRSM
+if (iturb.eq.32) then
+  do iel = 1, ncel
+    trrij  = w8(iel)
+    ! Calcul de l echelle de temps de Durbin
+    xttke  = trrij/rtpa(iel,iep)
+    xttkmg = xct*sqrt(propce(iel,ipcvis)/propce(iel,ipcrom)     &
+                                        /rtpa(iel,iep))
+    xttdrb = max(xttke,xttkmg)
+    smbr(iel) = smbr(iel) - propce(iel,ipcrom)*volume(iel)*     &
+                             ceps2*rtpa(iel,iep)/xttdrb
+  enddo
+else
+  do iel = 1, ncel
+    trrij  = w8(iel)
+    smbr(iel) = smbr(iel) - propce(iel,ipcrom)*volume(iel)*     &
+                           ceps2*rtpa(iel,iep)**2/trrij
+  enddo
+endif
 
 ! ---> Matrice
 
@@ -399,11 +432,27 @@ if(isto2t.gt.0) then
 else
   thetap = 1.d0
 endif
-do iel = 1, ncel
-  trrij  = w8(iel)
-  rovsdt(iel) = rovsdt(iel) + ceps2*propce(iel,ipcrom)*volume(iel)&
-                     *rtpa(iel,iep)/trrij*thetap
-enddo
+
+! EBRSM
+if (iturb.eq.32) then
+  do iel = 1, ncel
+    trrij  = w8(iel)
+    ! Calcul de l echelle de temps de Durbin
+    xttke  = trrij/rtpa(iel,iep)
+    xttkmg = xct*sqrt(propce(iel,ipcvis)/propce(iel,ipcrom)     &
+                                        /rtpa(iel,iep))
+    xttdrb = max(xttke,xttkmg)
+    rovsdt(iel) = rovsdt(iel) +                                 &
+                  ceps2*propce(iel,ipcrom)*volume(iel)*         &
+                  thetap/xttdrb
+  enddo
+else
+  do iel = 1, ncel
+    trrij  = w8(iel)
+    rovsdt(iel) = rovsdt(iel) + ceps2*propce(iel,ipcrom)*volume(iel)&
+                       *rtpa(iel,iep)/trrij*thetap
+  enddo
+endif
 
 !===============================================================================
 ! 7. TERMES DE GRAVITE
@@ -445,10 +494,10 @@ endif
 
 !===============================================================================
 ! 8.a TERMES DE DIFFUSION  A.grad(Eps) : PARTIE EXTRADIAGONALE EXPLICITE
-!     RIJ STANDARD
+!     RIJ STANDARD (Daly Harlow: generalized gradient hypothesis method)
 !===============================================================================
 
-if (iturb.eq.30) then
+if (iturb.eq.30.or.iturb.eq.32) then
 
 ! ---> Calcul du grad(Eps)
 
@@ -474,13 +523,31 @@ if (iturb.eq.30) then
 
 ! ---> Calcul des termes extradiagonaux de A.grad(Eps)
 
-  do iel = 1 , ncel
-    trrij  = w8(iel)
-    csteps  = propce(iel,ipcroo) * crijep *trrij / rtpa(iel,iep)
-    w4(iel) = csteps * (rtpa(iel,ir12)*grad(iel,2) + rtpa(iel,ir13)*grad(iel,3))
-    w5(iel) = csteps * (rtpa(iel,ir12)*grad(iel,1) + rtpa(iel,ir23)*grad(iel,3))
-    w6(iel) = csteps * (rtpa(iel,ir13)*grad(iel,1) + rtpa(iel,ir23)*grad(iel,2))
-  enddo
+  ! EBRSM
+  if (iturb.eq.32) then
+    do iel = 1 , ncel
+      trrij  = w8(iel)
+      xttke  = trrij/rtpa(iel,iep)
+      xttkmg = xct*sqrt(propce(iel,ipcvis)/propce(iel,ipcrom)   &
+                                          /rtpa(iel,iep))
+      xttdrb = max(xttke,xttkmg)
+      csteps = propce(iel,ipcroo) * csebm/sigebm * xttdrb
+
+      w4(iel) = csteps * (rtpa(iel,ir12)*grad(iel,2) + rtpa(iel,ir13)*grad(iel,3))
+      w5(iel) = csteps * (rtpa(iel,ir12)*grad(iel,1) + rtpa(iel,ir23)*grad(iel,3))
+      w6(iel) = csteps * (rtpa(iel,ir13)*grad(iel,1) + rtpa(iel,ir23)*grad(iel,2))
+    enddo
+  else
+    do iel = 1 , ncel
+      trrij  = w8(iel)
+      !FIXME it should be csrij/sigmae instead of crijep
+      csteps  = propce(iel,ipcroo) * crijep *trrij / rtpa(iel,iep)
+
+      w4(iel) = csteps * (rtpa(iel,ir12)*grad(iel,2) + rtpa(iel,ir13)*grad(iel,3))
+      w5(iel) = csteps * (rtpa(iel,ir12)*grad(iel,1) + rtpa(iel,ir23)*grad(iel,3))
+      w6(iel) = csteps * (rtpa(iel,ir13)*grad(iel,1) + rtpa(iel,ir23)*grad(iel,2))
+    enddo
+  endif
 
 ! ---> Assemblage de { A.grad(Eps) } .S aux faces
 
@@ -509,27 +576,45 @@ if (iturb.eq.30) then
 
 !===============================================================================
 ! 8.b TERMES DE DIFFUSION  A.grad(Eps) : PARTIE DIAGONALE
-!     RIJ STANDARD
+!     RIJ STANDARD ou EBRSM
 !===============================================================================
 !     Implicitation de (grad(eps).n)n en gradient facette
 !     Si IDIFRE=1, terme correctif explicite
 !        grad(eps)-(grad(eps).n)n calcule en gradient cellule
 !     Les termes de bord sont uniquement pris en compte dans la partie
 !        en (grad(eps).n)n
-!     (W1,W2,W3) contient toujours le gradient de la variable traitee
+!     grad contient toujours le gradient de la variable traitee
 
 !     La synchronisation des halos du gradient de epsilon a ete faite dans
 !       grdcel. Pas utile de recommencer.
 
   if (idifre.eq.1) then
 
-    do iel = 1, ncel
-      trrij  = w8(iel)
-      csteps = propce(iel,ipcroo) * crijep *trrij/rtpa(iel,iep)
-      w4(iel)=csteps*rtpa(iel,ir11)
-      w5(iel)=csteps*rtpa(iel,ir22)
-      w6(iel)=csteps*rtpa(iel,ir33)
-    enddo
+    ! EBRSM
+    if (iturb.eq.32) then
+      do iel = 1, ncel
+        trrij  = w8(iel)
+        xttke  = trrij/rtpa(iel,iep)
+        xttkmg = xct*sqrt(propce(iel,ipcvis)/propce(iel,ipcrom)   &
+                                            /rtpa(iel,iep))
+        xttdrb = max(xttke,xttkmg)
+        csteps = propce(iel,ipcroo) * csebm/sigebm * xttdrb
+
+        w4(iel)=csteps*rtpa(iel,ir11)
+        w5(iel)=csteps*rtpa(iel,ir22)
+        w6(iel)=csteps*rtpa(iel,ir33)
+      enddo
+
+    else
+      do iel = 1, ncel
+        trrij  = w8(iel)
+        !FIXME it should be csrij/sigmae instead of crijep
+        csteps = propce(iel,ipcroo) * crijep *trrij/rtpa(iel,iep)
+        w4(iel)=csteps*rtpa(iel,ir11)
+        w5(iel)=csteps*rtpa(iel,ir22)
+        w6(iel)=csteps*rtpa(iel,ir33)
+      enddo
+    endif
 
 ! --->  TRAITEMENT DU PARALLELISME ET DE LA PERIODICITE
 
@@ -556,7 +641,7 @@ if (iturb.eq.30) then
       grdpz=grdpz-grdsn*surfac(3,ifac)/surfn2
 
       viscf(ifac)= 0.5d0*(                                        &
-           (w4(ii)+w4(jj))*grdpx*surfac(1,ifac)                   &
+            (w4(ii)+w4(jj))*grdpx*surfac(1,ifac)                  &
            +(w5(ii)+w5(jj))*grdpy*surfac(2,ifac)                  &
            +(w6(ii)+w6(jj))*grdpz*surfac(3,ifac))
 
@@ -591,13 +676,32 @@ if (iturb.eq.30) then
 ! ---> Viscosite orthotrope pour partie implicite
 
   if( idiff(ivar).ge. 1 ) then
-    do iel = 1, ncel
-      trrij  = w8(iel)
-      rctse = propce(iel,ipcrom) * crijep * trrij/rtpa(iel,iep)
-      w1(iel) = propce(iel,ipcvis) + idifft(ivar)*rctse*rtpa(iel,ir11)
-      w2(iel) = propce(iel,ipcvis) + idifft(ivar)*rctse*rtpa(iel,ir22)
-      w3(iel) = propce(iel,ipcvis) + idifft(ivar)*rctse*rtpa(iel,ir33)
-    enddo
+
+    ! EBRSM
+    if (iturb.eq.32) then
+      do iel = 1, ncel
+        trrij  = w8(iel)
+        xttke  = trrij/rtpa(iel,iep)
+
+        xttkmg = xct*sqrt(propce(iel,ipcvis)/propce(iel,ipcrom)   &
+                                            /rtpa(iel,iep))
+        xttdrb = max(xttke,xttkmg)
+        rctse  = propce(iel,ipcrom) * csebm/sigebm *xttdrb
+
+        w1(iel) = propce(iel,ipcvis) + idifft(ivar)*rctse*rtpa(iel,ir11)
+        w2(iel) = propce(iel,ipcvis) + idifft(ivar)*rctse*rtpa(iel,ir22)
+        w3(iel) = propce(iel,ipcvis) + idifft(ivar)*rctse*rtpa(iel,ir33)
+      enddo
+    else
+      do iel = 1, ncel
+        trrij  = w8(iel)
+        !FIXME it should be csrij/sigmae instead of crijep
+        rctse = propce(iel,ipcrom) * crijep * trrij/rtpa(iel,iep)
+        w1(iel) = propce(iel,ipcvis) + idifft(ivar)*rctse*rtpa(iel,ir11)
+        w2(iel) = propce(iel,ipcvis) + idifft(ivar)*rctse*rtpa(iel,ir22)
+        w3(iel) = propce(iel,ipcvis) + idifft(ivar)*rctse*rtpa(iel,ir33)
+      enddo
+    endif
 
     call visort                                                   &
     !==========
@@ -605,6 +709,21 @@ if (iturb.eq.30) then
    w1     , w2     , w3     ,                                     &
    viscf  , viscb  )
 
+    ! Translate coefa into cofaf and coefb into cofbf
+    do ifac = 1, nfabor
+
+      iel = ifabor(ifac)
+
+      hint = ( w1(iel)*surfbo(1,ifac)*surfbo(1,ifac)                            &
+             + w2(iel)*surfbo(2,ifac)*surfbo(2,ifac)                            &
+             + w3(iel)*surfbo(3,ifac)*surfbo(3,ifac))/surfbn(ifac)**2/distb(ifac)
+
+      ! Translate coefa into cofaf and coefb into cofbf
+      coefa(ifac, iclvaf) = -hint*coefa(ifac,iclvar)
+      coefb(ifac, iclvaf) = hint*(1.d0-coefb(ifac,iclvar))
+
+    enddo
+
   else
 
     do ifac = 1, nfac
@@ -612,11 +731,16 @@ if (iturb.eq.30) then
     enddo
     do ifac = 1, nfabor
       viscb(ifac) = 0.d0
+
+      ! Translate coefa into cofaf and coefb into cofbf
+      coefa(ifac, iclvaf) = 0.d0
+      coefb(ifac, iclvaf) = 0.d0
     enddo
 
   endif
 
 else
+
 !===============================================================================
 ! 8.c TERMES DE DIFFUSION
 !     RIJ SSG
@@ -648,7 +772,6 @@ else
 
 endif
 
-
 !===============================================================================
 ! 9. RESOLUTION
 !===============================================================================
@@ -672,10 +795,10 @@ ircflp = ircflu(ivar)
 ischcp = ischcv(ivar)
 isstpp = isstpc(ivar)
 iescap = 0
+imucpp = 0
 imgrp  = imgr  (ivar)
 ncymxp = ncymax(ivar)
 nitmfp = nitmgf(ivar)
-!MO      IPP    =
 iwarnp = iwarni(ivar)
 blencp = blencv(ivar)
 epsilp = epsilo(ivar)
@@ -685,12 +808,12 @@ climgp = climgr(ivar)
 extrap = extrag(ivar)
 relaxp = relaxv(ivar)
 
-call codits                                                       &
+call codits &
 !==========
  ( nvar   , nscal  ,                                              &
    idtvar , ivar   , iconvp , idiffp , ireslp , ndircp , nitmap , &
    imrgra , nswrsp , nswrgp , imligp , ircflp ,                   &
-   ischcp , isstpp , iescap ,                                     &
+   ischcp , isstpp , iescap , imucpp ,                            &
    imgrp  , ncymxp , nitmfp , ipp    , iwarnp ,                   &
    blencp , epsilp , epsrsp , epsrgp , climgp , extrap ,          &
    relaxp , thetv  ,                                              &
@@ -699,8 +822,8 @@ call codits                                                       &
                      coefa(1,iclvaf) , coefb(1,iclvaf) ,          &
                      propfa(1,iflmas), propfb(1,iflmab),          &
    viscf  , viscb  , viscf  , viscb  ,                            &
-   rovsdt , smbr   , rtp(1,ivar)     ,                            &
-   rvoid  )
+   rovsdt , smbr   , rtp(1,ivar)     , dpvar  ,                   &
+   rvoid  , rvoid  )
 
 !===============================================================================
 ! 10. IMPRESSIONS
