@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2011 EDF S.A.
+! Copyright (C) 1998-2012 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -144,6 +144,7 @@ integer          nitmap, nswrsp, ircflp, ischcp, isstpp, iescap
 integer          imgrp , ncymxp, nitmfp
 integer          iptsta
 integer          isoluc
+integer          imucpp
 
 double precision blencp, epsilp, epsrgp, climgp, extrap, relaxp
 double precision epsrsp
@@ -152,6 +153,7 @@ double precision grdpx , grdpy , grdpz , grdsn
 double precision surfn2
 double precision tuexpr, thets , thetv , thetp1
 double precision d1s3  , d2s3
+double precision hint
 
 double precision rvoid(1)
 
@@ -159,6 +161,7 @@ double precision, allocatable, dimension(:,:) :: grad
 double precision, allocatable, dimension(:) :: w1, w2, w3
 double precision, allocatable, dimension(:) :: w4, w5, w6
 double precision, allocatable, dimension(:) :: w7, w8
+double precision, allocatable, dimension(:) :: dpvar
 
 !===============================================================================
 
@@ -170,7 +173,7 @@ double precision, allocatable, dimension(:) :: w7, w8
 allocate(w1(ncelet), w2(ncelet), w3(ncelet))
 allocate(w4(ncelet), w5(ncelet), w6(ncelet))
 allocate(w7(ncelet), w8(ncelet))
-
+allocate(dpvar(ncelet))
 
 if(iwarni(ivar).ge.1) then
   write(nfecra,1000) nomvar(ipp)
@@ -297,26 +300,11 @@ endif
 !    ET TERME INSTATIONNAIRE
 !===============================================================================
 
-! ---> Calcul de mij
-
-init = 1
-call divmas(ncelet,ncel,nfac,nfabor,init,nfecra,                  &
-               ifacel,ifabor,propfa(1,iflmas),propfb(1,iflmab),w1)
-
-! ---> Ajout au second membre
-
-do iel = 1, ncel
-  smbr(iel) = smbr(iel)                                           &
-              + iconv(ivar)*w1(iel)*rtpa(iel,ivar)
-enddo
-
 ! ---> Ajout dans la diagonale de la matrice
-!     Extrapolation ou non, meme forme par coherence avec bilsc2
 
 do iel=1,ncel
   rovsdt(iel) = rovsdt(iel)                                       &
-            + istat(ivar)*(propce(iel,ipcrom)/dt(iel))*volume(iel)&
-            - iconv(ivar)*w1(iel)*thetv
+            + istat(ivar)*(propce(iel,ipcrom)/dt(iel))*volume(iel)
 enddo
 
 
@@ -659,7 +647,7 @@ endif
 
 ! ---> Viscosite orthotrope pour partie implicite
 
-if( idiff(ivar).ge. 1 ) then
+if (idiff(ivar).ge.1) then
   do iel = 1, ncel
     trrij = w8(iel)
     rctse = propce(iel,ipcrom) * csrij * trrij / rtpa(iel,iep)
@@ -674,6 +662,21 @@ if( idiff(ivar).ge. 1 ) then
    w1     , w2     , w3     ,                                     &
    viscf  , viscb  )
 
+  ! Translate coefa into cofaf and coefb into cofbf
+  do ifac = 1, nfabor
+
+    iel = ifabor(ifac)
+
+    hint = ( w1(iel)*surfbo(1,ifac)*surfbo(1,ifac)                            &
+           + w2(iel)*surfbo(2,ifac)*surfbo(2,ifac)                            &
+           + w3(iel)*surfbo(3,ifac)*surfbo(3,ifac))/surfbn(ifac)**2/distb(ifac)
+
+    ! Translate coefa into cofaf and coefb into cofbf
+    coefa(ifac, iclvaf) = -hint*coefa(ifac,iclvar)
+    coefb(ifac, iclvaf) = hint*(1.d0-coefb(ifac,iclvar))
+
+  enddo
+
 else
 
   do ifac = 1, nfac
@@ -681,6 +684,10 @@ else
   enddo
   do ifac = 1, nfabor
     viscb(ifac) = 0.d0
+
+    ! Translate coefa into cofaf and coefb into cofbf
+    coefa(ifac, iclvaf) = 0.d0
+    coefb(ifac, iclvaf) = 0.d0
   enddo
 
 endif
@@ -710,10 +717,10 @@ ircflp = ircflu(ivar)
 ischcp = ischcv(ivar)
 isstpp = isstpc(ivar)
 iescap = 0
+imucpp = 0
 imgrp  = imgr  (ivar)
 ncymxp = ncymax(ivar)
 nitmfp = nitmgf(ivar)
-!MO      IPP    =
 iwarnp = iwarni(ivar)
 blencp = blencv(ivar)
 epsilp = epsilo(ivar)
@@ -723,12 +730,12 @@ climgp = climgr(ivar)
 extrap = extrag(ivar)
 relaxp = relaxv(ivar)
 
-call codits                                                       &
+call codits &
 !==========
  ( nvar   , nscal  ,                                              &
    idtvar , ivar   , iconvp , idiffp , ireslp , ndircp , nitmap , &
    imrgra , nswrsp , nswrgp , imligp , ircflp ,                   &
-   ischcp , isstpp , iescap ,                                     &
+   ischcp , isstpp , iescap , imucpp ,                            &
    imgrp  , ncymxp , nitmfp , ipp    , iwarnp ,                   &
    blencp , epsilp , epsrsp , epsrgp , climgp , extrap ,          &
    relaxp , thetv  ,                                              &
@@ -737,9 +744,8 @@ call codits                                                       &
                      coefa(1,iclvaf) , coefb(1,iclvaf) ,          &
                      propfa(1,iflmas), propfb(1,iflmab),          &
    viscf  , viscb  , viscf  , viscb  ,                            &
-   rovsdt , smbr   , rtp(1,ivar)     ,                            &
-   rvoid  )
-
+   rovsdt , smbr   , rtp(1,ivar)     , dpvar  ,                   &
+   rvoid  , rvoid  )
 
 !===============================================================================
 ! 11. IMPRESSIONS
@@ -749,6 +755,7 @@ call codits                                                       &
 deallocate(w1, w2, w3)
 deallocate(w4, w5, w6)
 deallocate(w7, w8)
+deallocate(dpvar)
 
 !--------
 ! FORMATS
