@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2011 EDF S.A.
+! Copyright (C) 1998-2012 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -113,7 +113,7 @@ integer          iel   , ifac  , init  , inc   , iccocg, ivar
 integer          ii, iivar , iiun  , ifacpt
 integer          iclipk, iclipw, isqrt
 integer          nswrgp, imligp
-integer          iclikp, iclomg
+integer          iclik , iclomg, iclikf, iclomf
 integer          iclvar, iclvaf
 integer          iconvp, idiffp, ndircp, ireslp
 integer          nitmap, nswrsp, ircflp, ischcp, isstpp, iescap
@@ -122,12 +122,13 @@ integer          ipcrom, ipbrom, ipcvst, ipcvis, iflmas, iflmab
 integer          iwarnp, ipp
 integer          iptsta
 integer          ipcroo, ipbroo, ipcvto, ipcvlo
+integer          imucpp
 
 double precision rnorm , d2s3, divp23, epz2
 double precision deltk , deltw, a11, a12, a22, a21
 double precision unsdet, romvsd
 double precision prdtur, xk, xw, xeps, xnu
-double precision visct , rom
+double precision visct , rom, visclc, visctc, hint
 double precision blencp, epsilp, epsrgp, climgp, extrap, relaxp
 double precision thetp1, thetak, thetaw, thets, thetap, epsrsp
 double precision tuexpk, tuexpw
@@ -142,8 +143,9 @@ double precision, allocatable, dimension(:) :: smbrk, smbrw, rovsdt
 double precision, allocatable, dimension(:) :: tinstk, tinstw, xf1
 double precision, allocatable, dimension(:,:) :: gradk, grado, grad
 double precision, allocatable, dimension(:) :: w1, w2, w3
-double precision, allocatable, dimension(:) :: w4, w5, w6
+double precision, allocatable, dimension(:) :: w5, w6
 double precision, allocatable, dimension(:) :: w7, w8
+double precision, allocatable, dimension(:) :: dpvar
 
 !===============================================================================
 
@@ -159,14 +161,16 @@ allocate(tinstk(ncelet), tinstw(ncelet), xf1(ncelet))
 
 ! Allocate work arrays
 allocate(w1(ncelet), w2(ncelet), w3(ncelet))
-allocate(w4(ncelet), w5(ncelet), w6(ncelet))
+allocate(w5(ncelet), w6(ncelet))
 allocate(w7(ncelet), w8(ncelet))
-
+allocate(dpvar(ncelet))
 
 epz2 = epzero**2
 
-iclikp = iclrtp(ik ,icoef)
+iclik  = iclrtp(ik ,icoef)
 iclomg = iclrtp(iomg,icoef)
+iclikf = iclrtp(ik ,icoeff)
+iclomf = iclrtp(iomg,icoeff)
 
 ipcrom = ipproc(irom  )
 ipcvst = ipproc(ivisct)
@@ -226,7 +230,7 @@ call grdcel &
 !==========
  ( ik  , imrgra , inc    , iccocg , nswrgp , imligp ,             &
    iwarnp , nfecra , epsrgp , climgp , extrap ,                   &
-   rtpa(1,ik)   , coefa(1,iclikp) , coefb(1,iclikp) ,             &
+   rtpa(1,ik)   , coefa(1,iclik)  , coefb(1,iclik)  ,             &
    gradk  )
 
 nswrgp = nswrgr(iomg)
@@ -396,17 +400,6 @@ call ustskw                                                       &
    smbrk  , smbrw  , dam    , w3     )
 !        ------   ------   ------   ------
 
-!===============================================================================
-! 6. TERME D'ACCUMULATION DE MASSE -(dRO/dt)*Volume
-
-!      Le terme est stocke dans         W4
-!      En sortie de l'etape on conserve W1-4,XF1,TINSTK,TINSTW,SMBRK,SMBRW,DAM
-!===============================================================================
-
-init = 1
-call divmas(ncelet,ncel,nfac,nfabor,init,nfecra,                  &
-               ifacel,ifabor,propfa(1,iflmas),propfb(1,iflmab),w4)
-
 !===============================================================================
 ! 7. ON FINALISE LE CALCUL DES TERMES SOURCES
 
@@ -456,7 +449,7 @@ if(isto2t.gt.0) then
 !       Pour la suite et le pas de temps suivant
     propce(iel,iptsta) = smbrk(iel)
 !       Termes dependant de la variable resolue et theta PROPCE
-    smbrk(iel) = iconv(ik)*w4(iel)*rtpa(iel,ik) - thets*tuexpk
+    smbrk(iel) = - thets*tuexpk
 !       On suppose -DAM > 0 : on implicite
 !         le terme utilisateur dependant de la variable resolue
     smbrk(iel) = dam(iel)*rtpa(iel,ik) + smbrk(iel)
@@ -466,7 +459,7 @@ if(isto2t.gt.0) then
 !       Pour la suite et le pas de temps suivant
     propce(iel,iptsta+1) = smbrw(iel)
 !       Termes dependant de la variable resolue et theta PROPCE
-    smbrw(iel) = iconv(iomg)*w4(iel)*rtpa(iel,iomg) - thets*tuexpw
+    smbrw(iel) = - thets*tuexpw
 !       On suppose -W3 > 0 : on implicite
 !         le terme utilisateur dependant de la variable resolue
     smbrw(iel) =  w3(iel)*rtpa(iel,iomg) + smbrw(iel)
@@ -476,10 +469,8 @@ if(isto2t.gt.0) then
 !     Si on n'extrapole pas les T.S.
 else
   do iel = 1, ncel
-    smbrk(iel) = smbrk(iel) + dam(iel)*rtpa(iel,ik)            &
-         +iconv(ik)*w4(iel)*rtpa(iel,ik)
-    smbrw(iel) = smbrw(iel) + w3 (iel)*rtpa(iel,iomg)           &
-         +iconv(iomg)*w4(iel)*rtpa(iel,iomg)
+    smbrk(iel) = smbrk(iel) + dam(iel)*rtpa(iel,ik)
+    smbrw(iel) = smbrw(iel) + w3 (iel)*rtpa(iel,iomg)
   enddo
 endif
 
@@ -507,6 +498,40 @@ if (iilagr.eq.2 .and. ltsdyn.eq.1) then
 
 endif
 
+!===============================================================================
+! 8.2 Re-set Boundary conditions flux coefficient for k and omega
+
+!     The definition of cofaf requires hint=(mu+muT/sigma)/distb where sigma
+!     is not constant in the k-omega model (and not directly accessible)
+!===============================================================================
+
+do ifac = 1, nfabor
+
+  iel = ifabor(ifac)
+
+  ! --- Physical Propreties
+  visclc = propce(iel,ipcvis)
+  visctc = propce(iel,ipcvst)
+
+  xxf1 = xf1(iel)
+
+  ! k
+  sigma = xxf1*ckwsk1 + (1.d0-xxf1)*ckwsk2
+  hint = (visclc+visctc/sigma)/distb(ifac)
+
+  ! Translate coefa into cofaf and coefb into cofbf
+  coefa(ifac, iclikf) = -hint*coefa(ifac,iclik)
+  coefb(ifac, iclikf) = hint*(1.d0-coefb(ifac,iclik))
+
+  ! Omega
+  sigma = xxf1*ckwsw1 + (1.d0-xxf1)*ckwsw2
+  hint = (visclc+visctc/sigma)/distb(ifac)
+
+  ! Translate coefa into cofaf and coefb into cofbf
+  coefa(ifac, iclomf) = -hint*coefa(ifac,iclomg)
+  coefb(ifac, iclomf) = hint*(1.d0-coefb(ifac,iclomg))
+
+enddo
 
 !===============================================================================
 ! 9. PRISE EN COMPTE DES TERMES DE CONV/DIFF DANS LE SECOND MEMBRE
@@ -570,6 +595,7 @@ if (ikecou.eq.1) then
   ischcp = ischcv(ivar)
   isstpp = isstpc(ivar)
   iwarnp = iwarni(ivar)
+  imucpp = 0
   blencp = blencv(ivar)
   epsrgp = epsrgr(ivar)
   climgp = climgr(ivar)
@@ -582,18 +608,18 @@ if (ikecou.eq.1) then
  ( nvar   , nscal  ,                                              &
    idtvar , ivar   , iconvp , idiffp , nswrgp , imligp , ircflp , &
    ischcp , isstpp , inc    , imrgra , iccocg ,                   &
-   ipp    , iwarnp ,                                              &
+   ipp    , iwarnp , imucpp ,                                     &
    blencp , epsrgp , climgp , extrap , relaxp , thetap ,          &
    rtpa(1,ivar)    , rtpa(1,ivar)    ,                            &
    coefa(1,iclvar) , coefb(1,iclvar) ,                            &
    coefa(1,iclvaf) , coefb(1,iclvaf) ,                            &
-   propfa(1,iflmas), propfb(1,iflmab), viscf  , viscb  ,          &
+   propfa(1,iflmas), propfb(1,iflmab), viscf  , viscb  , rvoid  , &
    w5     )
 
 
   if (iwarni(ivar).ge.2) then
     isqrt = 1
-    call prodsc(ncelet,ncel,isqrt,smbrk,smbrk,rnorm)
+    call prodsc(ncel,isqrt,smbrk,smbrk,rnorm)
     write(nfecra,1100) chaine(1:8) ,rnorm
   endif
 
@@ -665,7 +691,7 @@ if (ikecou.eq.1) then
 
   if (iwarni(ivar).ge.2) then
     isqrt = 1
-    call prodsc(ncelet,ncel,isqrt,smbrw,smbrw,rnorm)
+    call prodsc(ncel,isqrt,smbrw,smbrw,rnorm)
     write(nfecra,1100) chaine(1:8) ,rnorm
   endif
 
@@ -807,13 +833,12 @@ if (ikecou.eq.1) then
 endif
 
 ! --- RHO/DT et DIV
-!     Extrapolation ou non, meme forme par coherence avec bilsc2
 
 do iel = 1, ncel
   rom = propce(iel,ipcrom)
   romvsd = rom*volume(iel)/dt(iel)
-  tinstk(iel) = istat(ik)*romvsd   -iconv(ik)*w4(iel)*thetav(ik)
-  tinstw(iel) = istat(iomg)*romvsd -iconv(iomg)*w4(iel)*thetav(iomg)
+  tinstk(iel) = istat(ik)*romvsd
+  tinstw(iel) = istat(iomg)*romvsd
 enddo
 
 ! --- Source de masse (le theta est deja inclus par catsma)
@@ -930,10 +955,10 @@ ircflp = ircflu(ivar)
 ischcp = ischcv(ivar)
 isstpp = isstpc(ivar)
 iescap = 0
+imucpp = 0
 imgrp  = imgr  (ivar)
 ncymxp = ncymax(ivar)
 nitmfp = nitmgf(ivar)
-!MO      IPP    =
 iwarnp = iwarni(ivar)
 blencp = blencv(ivar)
 epsilp = epsilo(ivar)
@@ -944,12 +969,12 @@ extrap = extrag(ivar)
 relaxp = relaxv(ivar)
 thetap = thetav(ivar)
 
-call codits                                                       &
+call codits &
 !==========
  ( nvar   , nscal  ,                                              &
    idtvar , ivar   , iconvp , idiffp , ireslp , ndircp , nitmap , &
    imrgra , nswrsp , nswrgp , imligp , ircflp ,                   &
-   ischcp , isstpp , iescap ,                                     &
+   ischcp , isstpp , iescap , imucpp ,                            &
    imgrp  , ncymxp , nitmfp , ipp    , iwarnp ,                   &
    blencp , epsilp , epsrsp , epsrgp , climgp , extrap ,          &
    relaxp , thetap ,                                              &
@@ -958,9 +983,8 @@ call codits                                                       &
                      coefa(1,iclvaf) , coefb(1,iclvaf) ,          &
                      propfa(1,iflmas), propfb(1,iflmab),          &
    viscf  , viscb  , viscf  , viscb  ,                            &
-   tinstk , smbrk  , rtp(1,ivar)     ,                            &
-   rvoid  )
-
+   tinstk , smbrk  , rtp(1,ivar)     , dpvar  ,                   &
+   rvoid  , rvoid  )
 
 ! ---> Traitement de omega
 
@@ -1011,6 +1035,7 @@ ircflp = ircflu(ivar)
 ischcp = ischcv(ivar)
 isstpp = isstpc(ivar)
 iescap = 0
+imucpp = 0
 imgrp  = imgr  (ivar)
 ncymxp = ncymax(ivar)
 nitmfp = nitmgf(ivar)
@@ -1025,12 +1050,12 @@ extrap = extrag(ivar)
 relaxp = relaxv(ivar)
 thetap = thetav(ivar)
 
-call codits                                                       &
+call codits &
 !==========
  ( nvar   , nscal  ,                                              &
    idtvar , ivar   , iconvp , idiffp , ireslp , ndircp , nitmap , &
    imrgra , nswrsp , nswrgp , imligp , ircflp ,                   &
-   ischcp , isstpp , iescap ,                                     &
+   ischcp , isstpp , iescap , imucpp ,                            &
    imgrp  , ncymxp , nitmfp , ipp    , iwarnp ,                   &
    blencp , epsilp , epsrsp , epsrgp , climgp , extrap ,          &
    relaxp , thetap ,                                              &
@@ -1039,9 +1064,8 @@ call codits                                                       &
                      coefa(1,iclvaf) , coefb(1,iclvaf) ,          &
                      propfa(1,iflmas), propfb(1,iflmab),          &
    viscf  , viscb  , viscf  , viscb  ,                            &
-   tinstw , smbrw  , rtp(1,ivar)     ,                            &
-   rvoid  )
-
+   tinstw , smbrw  , rtp(1,ivar)     , dpvar  ,                   &
+   rvoid  , rvoid  )
 
 !===============================================================================
 ! 14. CLIPPING
@@ -1115,8 +1139,9 @@ deallocate(dam)
 deallocate(smbrk, smbrw, rovsdt)
 deallocate(tinstk, tinstw, xf1)
 deallocate(w1, w2, w3)
-deallocate(w4, w5, w6)
+deallocate(w5, w6)
 deallocate(w7, w8)
+deallocate(dpvar)
 
 !--------
 ! FORMATS
