@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2011 EDF S.A.
+! Copyright (C) 1998-2012 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -107,6 +107,8 @@ double precision propfa(nfac,*), propfb(ndimfb,*)
 double precision coefa(ndimfb,*), coefb(ndimfb,*)
 double precision ckupdc(ncepdp,6)
 
+integer,          dimension(1), target :: ivoid
+double precision, dimension(1), target :: rvoid1, rvoid2, rvoid3, rvoid4
 double precision, dimension(ncesmp,nvar), target ::  smacel
 double precision, dimension(ncelet,ntersl), target :: tslagr
 
@@ -164,15 +166,28 @@ ipbrom = ipprob(irom  )
 if(iwarni(iep).ge.1) then
   if (iturb.eq.30) then
     write(nfecra,1000)
-  else
+  elseif (iturb.eq.31) then
     write(nfecra,1001)
+  else
+    write(nfecra,1002)
   endif
 endif
 
 
-!     SI ITURB=30 (RIJ STD) ON STOCKE DIRECTEMENT LA PRODUCTION DANS
-!     LE TABLEAU PRODUC
-!     SI ITURB=31 (SSG) ON STOCKE LE GRADIENT DE VITESSE DANS GRDVIT
+! Si iturb=30 (rij std) on stocke directement la production dans
+! le tableau produc
+! Si iturb=31 (SSG) ou 32 (EBRSM) on stocke le gradient de vitesse dans grdvit
+
+! Set some pointers to non-null values based on issues with version 2.0 and
+! associated solution on Blue Gene/Q. This will require further investigation
+! for the trunk, but the solution used here should be acceptable
+! in the meantime.
+
+itpsmp => ivoid
+smcelp => rvoid1
+gammap => rvoid2
+tslage => rvoid3
+tslagi => rvoid4
 
 !===============================================================================
 ! 2.a CALCUL DU TENSEUR DE PRODUCTION POUR LE RIJ STANDARD
@@ -180,7 +195,7 @@ endif
 
 if (iturb.eq.30) then
 
-  ! Allocate temporary arrays for gradients calculation
+  !FIXME compute the velocity gradient in once.  ! Allocate temporary arrays for gradients calculation
   allocate(gradu(ncelet,3), gradv(ncelet,3), gradw(ncelet,3))
 
   do ii = 1 , 6
@@ -306,8 +321,8 @@ if (iturb.eq.30) then
 else
 
 !===============================================================================
-! 2.b CALCUL DU GRADIENT DE VITESSE POUR LE RIJ SSG
-!     ATTENTION: GRDVIT(IEL,J,I) = dUi/dxj(IEL)
+! 2.b Calcul du gradient de vitesse pour le Rij SSG et EBRSM
+!     ATTENTION: grdvit(iel,j,i) = dUi/dxj(IEL)
 !===============================================================================
 
 ! CALCUL DU GRADIENT DES 3 COMPOSANTES DE LA VITESSE
@@ -328,7 +343,7 @@ else
 
     call grdvec &
     !==========
-  ( iu     , imrgra , inc    , iccocg , nswrgp , imligp ,          &
+  ( iu     , imrgra , inc    , nswrgp , imligp ,                   &
     iwarnp , nfecra ,                                              &
     epsrgp , climgp , extrap ,                                     &
     ilved  ,                                                       &
@@ -399,11 +414,9 @@ endif
 ! 4.  Boucle sur les variables Rij (6 variables)
 !     L'ordre est R11 R22 R33 R12 R13 R23 (La place de ces variables
 !     est IR11.    ..
-!     On resout les equation dans une routine semblable a covofi.F
+!     On resout les equation dans une routine semblable a covofi.f90
 !===============================================================================
 
-
-
 do isou = 1, 6
   if    (isou.eq.1) then
     ivar   = ir11
@@ -446,8 +459,8 @@ do isou = 1, 6
    tslage , tslagi ,                                              &
    smbr   , rovsdt )
 
-  else
-    !     Rij-epsilon SSG
+  elseif (iturb.eq.31.or.iturb.eq.32) then
+    ! Rij-epsilon SSG or EBRSM
     call resssg                                                   &
     !==========
  ( nvar   , nscal  , ncepdp , ncesmp ,                            &
@@ -493,7 +506,12 @@ call reseps                                                       &
 ! 6. CLIPPING
 !===============================================================================
 
-iclip  = 2
+if (iturb.eq.32) then
+  iclip = 1
+else
+  iclip = 2
+endif
+
 call clprij                                                       &
 !==========
  ( ncelet , ncel   , nvar   ,                                     &
@@ -521,6 +539,9 @@ if (allocated(grdvit)) deallocate(grdvit)
  1001 format(/,                                                   &
 '   ** RESOLUTION DU Rij-EPSILON SSG             ',/,&
 '      -----------------------------             ',/)
+ 1002 format(/,                                                   &
+'   ** RESOLUTION DU Rij-EPSILON EBRSM                        ',/,&
+'      --------------------------------------------           ',/)
 
 #else
 
@@ -530,6 +551,9 @@ if (allocated(grdvit)) deallocate(grdvit)
  1001 format(/,                                                   &
 '   ** SOLVING Rij-EPSILON SSG'                   ,/,&
 '      -----------------------'                   ,/)
+ 1002 format(/,                                                   &
+'   ** SOLVING Rij-EPSILON EBRSM                              ',/,&
+'      --------------------------------------                 ',/)
 
 #endif
 
